// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_WEB = false;
var ENVIRONMENT_IS_WORKER = false;
var ENVIRONMENT_IS_NODE = true;
var ENVIRONMENT_IS_SHELL = false;

// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)

if (Module['ENVIRONMENT']) {
  if (Module['ENVIRONMENT'] === 'WEB') {
    ENVIRONMENT_IS_WEB = true;
  } else if (Module['ENVIRONMENT'] === 'WORKER') {
    ENVIRONMENT_IS_WORKER = true;
  } else if (Module['ENVIRONMENT'] === 'NODE') {
    ENVIRONMENT_IS_NODE = true;
  } else if (Module['ENVIRONMENT'] === 'SHELL') {
    ENVIRONMENT_IS_SHELL = true;
  } else {
    throw new Error('The provided Module[\'ENVIRONMENT\'] value is not valid. It must be one of: WEB|WORKER|NODE|SHELL.');
  }
} else {
  ENVIRONMENT_IS_WEB = typeof window === 'object';
  ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
  ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER;
  ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
}

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = console.log;
  if (!Module['printErr']) Module['printErr'] = console.warn;

  var nodeFS;
  var nodePath;

  Module['read'] = function shell_read(filename, binary) {
    if (!nodeFS) nodeFS = require('fs');
    if (!nodePath) nodePath = require('path');
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    return binary ? ret : ret.toString();
  };

  Module['readBinary'] = function readBinary(filename) {
    var ret = Module['read'](filename, true);
    if (!ret.buffer) {
      ret = new Uint8Array(ret);
    }
    assert(ret.buffer);
    return ret;
  };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (!Module['thisProgram']) {
    if (process['argv'].length > 1) {
      Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
    } else {
      Module['thisProgram'] = 'unknown-program';
    }
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function shell_read() { throw 'no read() available' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof quit === 'function') {
    Module['quit'] = function(status, toThrow) {
      quit(status);
    }
  }

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function shell_read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (ENVIRONMENT_IS_WORKER) {
    Module['readBinary'] = function readBinary(url) {
      var xhr = new XMLHttpRequest();
      xhr.open('GET', url, false);
      xhr.responseType = 'arraybuffer';
      xhr.send(null);
      return new Uint8Array(xhr.response);
    };
  }

  Module['readAsync'] = function readAsync(url, onload, onerror) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'arraybuffer';
    xhr.onload = function xhr_onload() {
      if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
        onload(xhr.response);
      } else {
        onerror();
      }
    };
    xhr.onerror = onerror;
    xhr.send(null);
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function shell_print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function shell_printErr(x) {
      console.warn(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WORKER) {
    Module['load'] = importScripts;
  }

  if (typeof Module['setWindowTitle'] === 'undefined') {
    Module['setWindowTitle'] = function(title) { document.title = title };
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}
if (!Module['quit']) {
  Module['quit'] = function(status, toThrow) {
    throw toThrow;
  }
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// Free the object hierarchy contained in the overrides, this lets the GC
// reclaim data used e.g. in memoryInitializerRequest, which is a large typed array.
moduleOverrides = undefined;



// {{PREAMBLE_ADDITIONS}}

// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in:
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at:
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
    return value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  prepVararg: function (ptr, type) {
    if (type === 'double' || type === 'i64') {
      // move so the load is aligned
      if (ptr & 7) {
        assert((ptr & 7) === 4);
        ptr += 4;
      }
    } else {
      assert((ptr & 3) === 0);
    }
    return ptr;
  },
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      return Module['dynCall_' + sig].apply(null, [ptr].concat(args));
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      // optimize away arguments usage in common cases
      if (sig.length === 1) {
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func);
        };
      } else if (sig.length === 2) {
        sigCache[func] = function dynCall_wrapper(arg) {
          return Runtime.dynCall(sig, func, [arg]);
        };
      } else {
        // general case
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func, Array.prototype.slice.call(arguments));
        };
      }
    }
    return sigCache[func];
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = HEAP32[DYNAMICTOP_PTR>>2];var end = (((ret + size + 15)|0) & -16);HEAP32[DYNAMICTOP_PTR>>2] = end;if (end >= TOTAL_MEMORY) {var success = enlargeMemory();if (!success) {HEAP32[DYNAMICTOP_PTR>>2] = ret;return 0;}}return ret;},
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*(+4294967296))) : ((+((low>>>0)))+((+((high|0)))*(+4294967296)))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}



Module["Runtime"] = Runtime;



//========================================
// Runtime essentials
//========================================

var ABORT = 0; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

/** @type {function(*, string=)} */
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try { func = eval('_' + ident); } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        var len = (str.length << 2) + 1;
        ret = Runtime.stackAlloc(len);
        stringToUTF8(str, ret, len);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface.
  ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) {
      if (opts && opts.async) {
        EmterpreterAsync.asyncFinalizers.push(function() {
          Runtime.stackRestore(stack);
        });
        return;
      }
      Runtime.stackRestore(stack);
    }
    return ret;
  }

  var sourceRegex = /^function\s*[a-zA-Z$_0-9]*\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }

  // sources of useful functions. we create this lazily as it can trigger a source decompression on this entire file
  var JSsource = null;
  function ensureJSsource() {
    if (!JSsource) {
      JSsource = {};
      for (var fun in JSfuncs) {
        if (JSfuncs.hasOwnProperty(fun)) {
          // Elements of toCsource are arrays of three items:
          // the code, and the return value
          JSsource[fun] = parseJSFunc(JSfuncs[fun]);
        }
      }
    }
  }

  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      ensureJSsource();
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=(' + convertCode.returnValue + ');';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    if (!numericArgs) {
      // If we had a stack, restore it
      ensureJSsource();
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["ccall"] = ccall;
Module["cwrap"] = cwrap;

/** @type {function(number, number, string, boolean=)} */
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module["setValue"] = setValue;

/** @type {function(number, string, boolean=)} */
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module["getValue"] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module["ALLOC_NORMAL"] = ALLOC_NORMAL;
Module["ALLOC_STACK"] = ALLOC_STACK;
Module["ALLOC_STATIC"] = ALLOC_STATIC;
Module["ALLOC_DYNAMIC"] = ALLOC_DYNAMIC;
Module["ALLOC_NONE"] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
/** @type {function((TypedArray|Array<number>|number), string, number, number=)} */
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [typeof _malloc === 'function' ? _malloc : Runtime.staticAlloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(/** @type {!Uint8Array} */ (slab), ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module["allocate"] = allocate;

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return Runtime.staticAlloc(size);
  if (!runtimeInitialized) return Runtime.dynamicAlloc(size);
  return _malloc(size);
}
Module["getMemory"] = getMemory;

/** @type {function(number, number=)} */
function Pointer_stringify(ptr, length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return Module['UTF8ToString'](ptr);
}
Module["Pointer_stringify"] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}
Module["AsciiToString"] = AsciiToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}
Module["stringToAscii"] = stringToAscii;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

var UTF8Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf8') : undefined;
function UTF8ArrayToString(u8Array, idx) {
  var endPtr = idx;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  while (u8Array[endPtr]) ++endPtr;

  if (endPtr - idx > 16 && u8Array.subarray && UTF8Decoder) {
    return UTF8Decoder.decode(u8Array.subarray(idx, endPtr));
  } else {
    var u0, u1, u2, u3, u4, u5;

    var str = '';
    while (1) {
      // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
      u0 = u8Array[idx++];
      if (!u0) return str;
      if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
      u1 = u8Array[idx++] & 63;
      if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
      u2 = u8Array[idx++] & 63;
      if ((u0 & 0xF0) == 0xE0) {
        u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
      } else {
        u3 = u8Array[idx++] & 63;
        if ((u0 & 0xF8) == 0xF0) {
          u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
        } else {
          u4 = u8Array[idx++] & 63;
          if ((u0 & 0xFC) == 0xF8) {
            u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
          } else {
            u5 = u8Array[idx++] & 63;
            u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
          }
        }
      }
      if (u0 < 0x10000) {
        str += String.fromCharCode(u0);
      } else {
        var ch = u0 - 0x10000;
        str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
      }
    }
  }
}
Module["UTF8ArrayToString"] = UTF8ArrayToString;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8,ptr);
}
Module["UTF8ToString"] = UTF8ToString;

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}
Module["stringToUTF8Array"] = stringToUTF8Array;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8 to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  return stringToUTF8Array(str, HEAPU8,outPtr, maxBytesToWrite);
}
Module["stringToUTF8"] = stringToUTF8;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}
Module["lengthBytesUTF8"] = lengthBytesUTF8;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

var UTF16Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf-16le') : undefined;
function UTF16ToString(ptr) {
  var endPtr = ptr;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  var idx = endPtr >> 1;
  while (HEAP16[idx]) ++idx;
  endPtr = idx << 1;

  if (endPtr - ptr > 32 && UTF16Decoder) {
    return UTF16Decoder.decode(HEAPU8.subarray(ptr, endPtr));
  } else {
    var i = 0;

    var str = '';
    while (1) {
      var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
      if (codeUnit == 0) return str;
      ++i;
      // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
      str += String.fromCharCode(codeUnit);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}


function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}


function demangle(func) {
  var __cxa_demangle_func = Module['___cxa_demangle'] || Module['__cxa_demangle'];
  if (__cxa_demangle_func) {
    try {
      var s =
        func.substr(1);
      var len = lengthBytesUTF8(s)+1;
      var buf = _malloc(len);
      stringToUTF8(s, buf, len);
      var status = _malloc(4);
      var ret = __cxa_demangle_func(buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed
    } catch(e) {
      // ignore problems here
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
    // failure when using libcxxabi, don't demangle
    return func;
  }
  Runtime.warnOnce('warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  return func;
}

function demangleAll(text) {
  var regex =
    /__Z[\w\d_]+/g;
  return text.replace(regex,
    function(x) {
      var y = demangle(x);
      return x === y ? x : (x + ' [' + y + ']');
    });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  var js = jsStackTrace();
  if (Module['extraStackTrace']) js += '\n' + Module['extraStackTrace']();
  return demangleAll(js);
}
Module["stackTrace"] = stackTrace;

// Memory management

var PAGE_SIZE = 16384;
var WASM_PAGE_SIZE = 65536;
var ASMJS_PAGE_SIZE = 16777216;
var MIN_TOTAL_MEMORY = 16777216;

function alignUp(x, multiple) {
  if (x % multiple > 0) {
    x += multiple - (x % multiple);
  }
  return x;
}

var HEAP,
/** @type {ArrayBuffer} */
  buffer,
/** @type {Int8Array} */
  HEAP8,
/** @type {Uint8Array} */
  HEAPU8,
/** @type {Int16Array} */
  HEAP16,
/** @type {Uint16Array} */
  HEAPU16,
/** @type {Int32Array} */
  HEAP32,
/** @type {Uint32Array} */
  HEAPU32,
/** @type {Float32Array} */
  HEAPF32,
/** @type {Float64Array} */
  HEAPF64;

function updateGlobalBuffer(buf) {
  Module['buffer'] = buffer = buf;
}

function updateGlobalBufferViews() {
  Module['HEAP8'] = HEAP8 = new Int8Array(buffer);
  Module['HEAP16'] = HEAP16 = new Int16Array(buffer);
  Module['HEAP32'] = HEAP32 = new Int32Array(buffer);
  Module['HEAPU8'] = HEAPU8 = new Uint8Array(buffer);
  Module['HEAPU16'] = HEAPU16 = new Uint16Array(buffer);
  Module['HEAPU32'] = HEAPU32 = new Uint32Array(buffer);
  Module['HEAPF32'] = HEAPF32 = new Float32Array(buffer);
  Module['HEAPF64'] = HEAPF64 = new Float64Array(buffer);
}

var STATIC_BASE, STATICTOP, staticSealed; // static area
var STACK_BASE, STACKTOP, STACK_MAX; // stack area
var DYNAMIC_BASE, DYNAMICTOP_PTR; // dynamic area handled by sbrk

  STATIC_BASE = STATICTOP = STACK_BASE = STACKTOP = STACK_MAX = DYNAMIC_BASE = DYNAMICTOP_PTR = 0;
  staticSealed = false;



function abortOnCannotGrowMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which allows increasing the size at runtime but prevents some optimizations, (3) set Module.TOTAL_MEMORY to a higher value before the program runs, or (4) if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ');
}


function enlargeMemory() {
  abortOnCannotGrowMemory();
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 536870912;
if (TOTAL_MEMORY < TOTAL_STACK) Module.printErr('TOTAL_MEMORY should be larger than TOTAL_STACK, was ' + TOTAL_MEMORY + '! (TOTAL_STACK=' + TOTAL_STACK + ')');

// Initialize the runtime's memory



// Use a provided buffer, if there is one, or else allocate a new one
if (Module['buffer']) {
  buffer = Module['buffer'];
} else {
  // Use a WebAssembly memory where available
  {
    buffer = new ArrayBuffer(TOTAL_MEMORY);
  }
}
updateGlobalBufferViews();


function getTotalMemory() {
  return TOTAL_MEMORY;
}

// Endianness check (note: assumes compiler arch was little-endian)
  HEAP32[0] = 0x63736d65; /* 'emsc' */
HEAP16[1] = 0x6373;
if (HEAPU8[2] !== 0x73 || HEAPU8[3] !== 0x63) throw 'Runtime error: expected the system to be little-endian!';

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Module['dynCall_v'](func);
      } else {
        Module['dynCall_vi'](func, callback.arg);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module["addOnPreRun"] = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module["addOnInit"] = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module["addOnPreMain"] = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module["addOnExit"] = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module["addOnPostRun"] = addOnPostRun;

// Tools

/** @type {function(string, boolean=, number=)} */
function intArrayFromString(stringy, dontAddNull, length) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}
Module["intArrayFromString"] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module["intArrayToString"] = intArrayToString;

// Deprecated: This function should not be called because it is unsafe and does not provide
// a maximum length limit of how many bytes it is allowed to write. Prefer calling the
// function stringToUTF8Array() instead, which takes in a maximum length that can be used
// to be secure from out of bounds writes.
/** @deprecated */
function writeStringToMemory(string, buffer, dontAddNull) {
  Runtime.warnOnce('writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!');

  var /** @type {number} */ lastChar, /** @type {number} */ end;
  if (dontAddNull) {
    // stringToUTF8Array always appends null. If we don't want to do that, remember the
    // character that existed at the location where the null will be placed, and restore
    // that after the write (below).
    end = buffer + lengthBytesUTF8(string);
    lastChar = HEAP8[end];
  }
  stringToUTF8(string, buffer, Infinity);
  if (dontAddNull) HEAP8[end] = lastChar; // Restore the value under the null character.
}
Module["writeStringToMemory"] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  HEAP8.set(array, buffer);
}
Module["writeArrayToMemory"] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}
Module["writeAsciiToMemory"] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


if (!Math['clz32']) Math['clz32'] = function(x) {
  x = x >>> 0;
  for (var i = 0; i < 32; i++) {
    if (x & (1 << (31 - i))) return i;
  }
  return 32;
};
Math.clz32 = Math['clz32']

if (!Math['trunc']) Math['trunc'] = function(x) {
  return x < 0 ? Math.ceil(x) : Math.floor(x);
};
Math.trunc = Math['trunc'];

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_round = Math.round;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;
var Math_trunc = Math.trunc;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function getUniqueRunDependency(id) {
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module["addRunDependency"] = addRunDependency;

function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module["removeRunDependency"] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data



var memoryInitializer = null;






// === Body ===

var ASM_CONSTS = [function($0) { Module.debugPointer($0); },
 function($0, $1, $2, $3, $4) { Module.blit($0, $1, $2, $3, $4); },
 function() { return Module.acquireInputLock(); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.mouseButtonStateAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.mouseMoveFlagAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.mouseMoveXDeltaAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.mouseMoveYDeltaAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.keyEventFlagAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.keyCodeAddr); },
 function() { return Module.getInputValue(Module.InputBufferAddresses.keyStateAddr); },
 function() { Module.releaseInputLock(); },
 function($0, $1, $2, $3) { Module.openAudio($0, $1, $2, $3); },
 function($0, $1, $2) { return Module.enqueueAudio($0, $1, $2); }];

function _emscripten_asm_const_iiiii(code, a0, a1, a2, a3) {
  return ASM_CONSTS[code](a0, a1, a2, a3);
}

function _emscripten_asm_const_i(code) {
  return ASM_CONSTS[code]();
}

function _emscripten_asm_const_ii(code, a0) {
  return ASM_CONSTS[code](a0);
}

function _emscripten_asm_const_iiii(code, a0, a1, a2) {
  return ASM_CONSTS[code](a0, a1, a2);
}

function _emscripten_asm_const_iiiiii(code, a0, a1, a2, a3, a4) {
  return ASM_CONSTS[code](a0, a1, a2, a3, a4);
}



STATIC_BASE = Runtime.GLOBAL_BASE;

STATICTOP = STATIC_BASE + 660784;
/* global initializers */  __ATINIT__.push({ func: function() { __GLOBAL__sub_I_ether_cpp() } }, { func: function() { __GLOBAL__sub_I_sony_cpp() } }, { func: function() { __GLOBAL__sub_I_disk_cpp() } }, { func: function() { __GLOBAL__sub_I_cdrom_cpp() } }, { func: function() { __GLOBAL__sub_I_video_cpp() } }, { func: function() { __GLOBAL__sub_I_audio_cpp() } }, { func: function() { __GLOBAL__sub_I_video_sdl_cpp() } }, { func: function() { __GLOBAL__sub_I_prefs_unix_cpp() } });


memoryInitializer = "BasiliskII.js.mem";





/* no memory initializer */
var tempDoublePtr = STATICTOP; STATICTOP += 16;

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}



  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }function ___cxa_atexit() {
  return _atexit.apply(null, arguments)
  }


  var _tzname=STATICTOP; STATICTOP += 16;;

  var _daylight=STATICTOP; STATICTOP += 16;;

  var _timezone=STATICTOP; STATICTOP += 16;;function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;

      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;

      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());

      function extractZone(date) {
        var match = date.toTimeString().match(/\(([A-Za-z ]+)\)$/);
        return match ? match[1] : "GMT";
      };
      var winterName = extractZone(winter);
      var summerName = extractZone(summer);
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      if (summer.getTimezoneOffset() < winter.getTimezoneOffset()) {
        // Northern hemisphere
        HEAP32[((_tzname)>>2)]=winterNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
      } else {
        HEAP32[((_tzname)>>2)]=summerNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=winterNamePtr;
      }
    }





  function _sem_wait() {}

  function _sem_post() {}




  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};

  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};

  function ___setErrNo(value) {
      if (Module['___errno_location']) HEAP32[((Module['___errno_location']())>>2)]=value;
      return value;
    }

  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up; up--) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};

  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              // we will read data by chunks of BUFSIZE
              var BUFSIZE = 256;
              var buf = new Buffer(BUFSIZE);
              var bytesRead = 0;

              var isPosixPlatform = (process.platform != 'win32'); // Node doesn't offer a direct check, so test by exclusion

              var fd = process.stdin.fd;
              if (isPosixPlatform) {
                // Linux and Mac cannot use process.stdin.fd (which isn't set up as sync)
                var usingDevice = false;
                try {
                  fd = fs.openSync('/dev/stdin', 'r');
                  usingDevice = true;
                } catch (e) {}
              }

              try {
                bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
              } catch(e) {
                // Cross-platform differences: on Windows, reading EOF throws an exception, but on other OSes,
                // reading EOF returns 0. Uniformize behavior by treating the EOF exception to return 0.
                if (e.toString().indexOf('EOF') != -1) bytesRead = 0;
                else throw e;
              }

              if (usingDevice) { fs.closeSync(fd); }
              if (bytesRead > 0) {
                result = buf.slice(0, bytesRead).toString('utf-8');
              } else {
                result = null;
              }

            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val); // val == 0 would cut text output off in the middle.
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val);
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }}};

  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap,
                msync: MEMFS.stream_ops.msync
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.length which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }

        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.length : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();

          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) {
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }

          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else {
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        },msync:function (stream, buffer, offset, length, mmapFlags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          if (mmapFlags & 2) {
            // MAP_PRIVATE calls need not to be synced back to underlying fs
            return 0;
          }

          var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
          // should we check if bytesWritten and length are the same?
          return 0;
        }}};

  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);

          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);

            var src = populate ? remote : local;
            var dst = populate ? local : remote;

            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }

        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        if (!req) {
          return callback("Unable to connect to IndexedDB");
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;

          var fileStore;

          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }

          if (!fileStore.indexNames.contains('timestamp')) {
            fileStore.createIndex('timestamp', 'timestamp', { unique: false });
          }
        };
        req.onsuccess = function() {
          db = req.result;

          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};

        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };

        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));

        while (check.length) {
          var path = check.pop();
          var stat;

          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }

          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }

          entries[path] = { timestamp: stat.mtime };
        }

        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};

        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);

          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function(e) {
            callback(this.error);
            e.preventDefault();
          };

          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');

          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;

            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }

            entries[cursor.primaryKey] = { timestamp: cursor.key };

            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;

        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }

        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }

          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }

        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);

          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }

        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },reconcile:function (src, dst, callback) {
        var total = 0;

        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });

        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });

        if (!total) {
          return callback(null);
        }

        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);

        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };

        transaction.onerror = function(e) {
          done(this.error);
          e.preventDefault();
        };

        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });

        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};

  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        flags &= ~0x200000 /*O_PATH*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x800 /*O_NONBLOCK*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x8000 /*O_LARGEFILE*/; // Ignore this flag from musl, otherwise node.js fails to open the file.
        flags &= ~0x80000 /*O_CLOEXEC*/; // Some applications may pass it; it makes no sense for a single process.
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            path = fs.readlinkSync(path);
            path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
            return path;
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }

          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }

          return position;
        }}};

  var WORKERFS={DIR_MODE:16895,FILE_MODE:33279,reader:null,mount:function (mount) {
        assert(ENVIRONMENT_IS_WORKER);
        if (!WORKERFS.reader) WORKERFS.reader = new FileReaderSync();
        var root = WORKERFS.createNode(null, '/', WORKERFS.DIR_MODE, 0);
        var createdParents = {};
        function ensureParent(path) {
          // return the parent node, creating subdirs as necessary
          var parts = path.split('/');
          var parent = root;
          for (var i = 0; i < parts.length-1; i++) {
            var curr = parts.slice(0, i+1).join('/');
            // Issue 4254: Using curr as a node name will prevent the node
            // from being found in FS.nameTable when FS.open is called on
            // a path which holds a child of this node,
            // given that all FS functions assume node names
            // are just their corresponding parts within their given path,
            // rather than incremental aggregates which include their parent's
            // directories.
            if (!createdParents[curr]) {
              createdParents[curr] = WORKERFS.createNode(parent, parts[i], WORKERFS.DIR_MODE, 0);
            }
            parent = createdParents[curr];
          }
          return parent;
        }
        function base(path) {
          var parts = path.split('/');
          return parts[parts.length-1];
        }
        // We also accept FileList here, by using Array.prototype
        Array.prototype.forEach.call(mount.opts["files"] || [], function(file) {
          WORKERFS.createNode(ensureParent(file.name), base(file.name), WORKERFS.FILE_MODE, 0, file, file.lastModifiedDate);
        });
        (mount.opts["blobs"] || []).forEach(function(obj) {
          WORKERFS.createNode(ensureParent(obj["name"]), base(obj["name"]), WORKERFS.FILE_MODE, 0, obj["data"]);
        });
        (mount.opts["packages"] || []).forEach(function(pack) {
          pack['metadata'].files.forEach(function(file) {
            var name = file.filename.substr(1); // remove initial slash
            WORKERFS.createNode(ensureParent(name), base(name), WORKERFS.FILE_MODE, 0, pack['blob'].slice(file.start, file.end));
          });
        });
        return root;
      },createNode:function (parent, name, mode, dev, contents, mtime) {
        var node = FS.createNode(parent, name, mode);
        node.mode = mode;
        node.node_ops = WORKERFS.node_ops;
        node.stream_ops = WORKERFS.stream_ops;
        node.timestamp = (mtime || new Date).getTime();
        assert(WORKERFS.FILE_MODE !== WORKERFS.DIR_MODE);
        if (mode === WORKERFS.FILE_MODE) {
          node.size = contents.size;
          node.contents = contents;
        } else {
          node.size = 4096;
          node.contents = {};
        }
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          return {
            dev: 1,
            ino: undefined,
            mode: node.mode,
            nlink: 1,
            uid: 0,
            gid: 0,
            rdev: undefined,
            size: node.size,
            atime: new Date(node.timestamp),
            mtime: new Date(node.timestamp),
            ctime: new Date(node.timestamp),
            blksize: 4096,
            blocks: Math.ceil(node.size / 4096),
          };
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rename:function (oldNode, newDir, newName) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },unlink:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },rmdir:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readdir:function (node) {
          var entries = ['.', '..'];
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newName, oldPath) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        },readlink:function (node) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          if (position >= stream.node.size) return 0;
          var chunk = stream.node.contents.slice(position, position + length);
          var ab = WORKERFS.reader.readAsArrayBuffer(chunk);
          buffer.set(new Uint8Array(ab), offset);
          return chunk.size;
        },write:function (stream, buffer, offset, length, position) {
          throw new FS.ErrnoError(ERRNO_CODES.EIO);
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.size;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        }}};

  var _stdin=STATICTOP; STATICTOP += 16;;

  var _stdout=STATICTOP; STATICTOP += 16;;

  var _stderr=STATICTOP; STATICTOP += 16;;var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},filesystems:null,syncFSRequests:0,handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};

        if (!path) return { path: '', node: null };

        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }

        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }

        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);

        // start at the root
        var current = FS.root;
        var current_path = '/';

        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }

          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);

          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }

          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);

              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;

              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }

        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;


        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };

          FS.FSNode.prototype = {};

          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;

          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }

        var node = new FS.FSNode(parent, name, mode, rdev);

        FS.hashAddNode(node);

        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var perms = ['r', 'w', 'rw'][flag & 3];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if (FS.flagsToPermissionString(flags) !== 'r' || // opening for write
              (flags & 512)) { // TODO: check for O_SEARCH? (== search for dir only)
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];

        while (check.length) {
          var m = check.pop();

          mounts.push(m);

          check.push.apply(check, m.mounts);
        }

        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }

        FS.syncFSRequests++;

        if (FS.syncFSRequests > 1) {
          console.log('warning: ' + FS.syncFSRequests + ' FS.syncfs operations in flight at once, probably just doing extra work');
        }

        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;

        function doCallback(err) {
          assert(FS.syncFSRequests > 0);
          FS.syncFSRequests--;
          return callback(err);
        }

        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return doCallback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            doCallback(null);
          }
        };

        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;

        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });

          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;

          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }

          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }

        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };

        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;

        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;

          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }

        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });

        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }

        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);

        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];

          while (current) {
            var next = current.name_next;

            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }

            current = next;
          }
        });

        // no longer a mountpoint
        node.mounted = null;

        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdirTree:function (path, mode) {
        var dirs = path.split('/');
        var d = '';
        for (var i = 0; i < dirs.length; ++i) {
          if (!dirs[i]) continue;
          d += '/' + dirs[i];
          try {
            FS.mkdir(d, mode);
          } catch(e) {
            if (e.errno != ERRNO_CODES.EEXIST) throw e;
          }
        }
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // According to POSIX, we should map EISDIR to EPERM, but
          // we instead do what Linux does (and we must, as we use
          // the musl linux libc).
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return PATH.resolve(FS.getPath(link.parent), link.node_ops.readlink(link));
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // if asked only for a directory, then this must be one
        if ((flags & 65536) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);

        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        if (stream.getdents) stream.getdents = null; // free readdir state
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },msync:function (stream, buffer, offset, length, mmapFlags) {
        if (!stream || !stream.stream_ops.msync) {
          return 0;
        }
        return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
      },munmap:function (stream) {
        return 0;
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = UTF8ArrayToString(buf, 0);
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var buf = new Uint8Array(lengthBytesUTF8(data)+1);
          var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
          FS.write(stream, buf, 0, actualNumBytes, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (lookup.node === null) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/electron');
        FS.mkdir('/macintosh.js')
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function(stream, buffer, offset, length, pos) { return length; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createSpecialDirectories:function () {
        // create /proc/self/fd which allows /proc/self/fd/6 => readlink gives the name of the stream for fd 6 (see test_unistd_ttyname)
        FS.mkdir('/proc');
        FS.mkdir('/proc/self');
        FS.mkdir('/proc/self/fd');
        FS.mount({
          mount: function() {
            var node = FS.createNode('/proc/self', 'fd', 16384 | 511 /* 0777 */, 73);
            node.node_ops = {
              lookup: function(parent, name) {
                var fd = +name;
                var stream = FS.getStream(fd);
                if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
                var ret = {
                  parent: null,
                  mount: { mountpoint: 'fake' },
                  node_ops: { readlink: function() { return stream.path } }
                };
                ret.parent = ret; // make it look like a simple root node
                return ret;
              }
            };
            return node;
          }
        }, {}, '/proc/self/fd');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops

        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }

        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');

        var stdout = FS.open('/dev/stdout', 'w');
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');

        var stderr = FS.open('/dev/stderr', 'w');
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          //Module.printErr(stackTrace()); // useful for debugging
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();

        FS.nameTable = new Array(4096);

        FS.mount(MEMFS, {}, '/');

        FS.createDefaultDirectories();
        FS.createDefaultDevices();
        FS.createSpecialDirectories();

        // Begin surgery
        //if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); var NODEJS_PATH = require("path"); NODEFS.staticInit(); };
        //FS.mount(NODEFS, { root: '.' }, '/home/electron');
        // onmessage(() => {
        //   console.log('Message received from main script');
        // });

        // End surgery

        FS.filesystems = {
          'MEMFS': MEMFS,
          'IDBFS': IDBFS,
          'NODEFS': NODEFS,
          'WORKERFS': WORKERFS,
        };
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;

        FS.ensureErrnoError();

        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];

        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        // force-flush all streams, so we get musl std streams printed out
        var fflush = Module['_fflush'];
        if (fflush) fflush(0);
        // close all of our streams
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";

          var chunkSize = 1024*1024; // Chunk size in bytes

          if (!hasByteServing) chunkSize = datalength;

          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");

            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);

            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }

            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });

          if (usesGzip || !datalength) {
            // if the server uses gzip or doesn't supply the length, we have to download the whole file to get the (uncompressed) length
            chunkSize = datalength = 1; // this will force getter(0)/doXHR do download the whole file
            datalength = this.getter(0).length;
            chunkSize = datalength;
            console.log("LazyFiles on gzip forces download of the whole file when length is accessed");
          }

          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperties(lazyArray, {
            length: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._length;
              }
            },
            chunkSize: {
              get: function() {
                if(!this.lengthKnown) {
                  this.cacheLength();
                }
                return this._chunkSize;
              }
            }
          });

          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }

        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperties(node, {
          usedBytes: {
            get: function() { return this.contents.length; }
          }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
        Browser.init(); // XXX perhaps this method should move onto Browser?
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        var dep = getUniqueRunDependency('cp ' + fullname); // might have several active requests for the same fullname
        function processData(byteArray) {
          function finish(byteArray) {
            if (preFinish) preFinish();
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency(dep);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency(dep);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency(dep);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};var SYSCALLS={DEFAULT_POLLMASK:5,mappings:{},umask:511,calculateAt:function (dirfd, path) {
        if (path[0] !== '/') {
          // relative path
          var dir;
          if (dirfd === -100) {
            dir = FS.cwd();
          } else {
            var dirstream = FS.getStream(dirfd);
            if (!dirstream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
            dir = dirstream.path;
          }
          path = PATH.join2(dir, path);
        }
        return path;
      },doStat:function (func, path, buf) {
        try {
          var stat = func(path);
        } catch (e) {
          if (e && e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
            // an error occurred while trying to look up the path; we should just report ENOTDIR
            return -ERRNO_CODES.ENOTDIR;
          }
          throw e;
        }
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=(stat.atime.getTime() / 1000)|0;
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=(stat.mtime.getTime() / 1000)|0;
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=(stat.ctime.getTime() / 1000)|0;
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      },doMsync:function (addr, stream, len, flags) {
        var buffer = new Uint8Array(HEAPU8.subarray(addr, addr + len));
        FS.msync(stream, buffer, 0, len, flags);
      },doMkdir:function (path, mode) {
        // remove a trailing slash, if one - /a/b/ has basename of '', but
        // we want to create b in the context of this function
        path = PATH.normalize(path);
        if (path[path.length-1] === '/') path = path.substr(0, path.length-1);
        FS.mkdir(path, mode, 0);
        return 0;
      },doMknod:function (path, mode, dev) {
        // we don't want this in the JS API as it uses mknod to create all nodes.
        switch (mode & 61440) {
          case 32768:
          case 8192:
          case 24576:
          case 4096:
          case 49152:
            break;
          default: return -ERRNO_CODES.EINVAL;
        }
        FS.mknod(path, mode, dev);
        return 0;
      },doReadlink:function (path, buf, bufsize) {
        if (bufsize <= 0) return -ERRNO_CODES.EINVAL;
        var ret = FS.readlink(path);

        var len = Math.min(bufsize, lengthBytesUTF8(ret));
        var endChar = HEAP8[buf+len];
        stringToUTF8(ret, buf, bufsize+1);
        // readlink is one of the rare functions that write out a C string, but does never append a null to the output buffer(!)
        // stringToUTF8() always appends a null byte, so restore the character under the null byte after the write.
        HEAP8[buf+len] = endChar;

        return len;
      },doAccess:function (path, amode) {
        if (amode & ~7) {
          // need a valid mode
          return -ERRNO_CODES.EINVAL;
        }
        var node;
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
        var perms = '';
        if (amode & 4) perms += 'r';
        if (amode & 2) perms += 'w';
        if (amode & 1) perms += 'x';
        if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
          return -ERRNO_CODES.EACCES;
        }
        return 0;
      },doDup:function (path, flags, suggestFD) {
        var suggest = FS.getStream(suggestFD);
        if (suggest) FS.close(suggest);
        return FS.open(path, flags, 0, suggestFD, suggestFD).fd;
      },doReadv:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.read(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
          if (curr < len) break; // nothing more to read
        }
        return ret;
      },doWritev:function (stream, iov, iovcnt, offset) {
        var ret = 0;
        for (var i = 0; i < iovcnt; i++) {
          var ptr = HEAP32[(((iov)+(i*8))>>2)];
          var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
          var curr = FS.write(stream, HEAP8,ptr, len, offset);
          if (curr < 0) return -1;
          ret += curr;
        }
        return ret;
      },varargs:0,get:function (varargs) {
        SYSCALLS.varargs += 4;
        var ret = HEAP32[(((SYSCALLS.varargs)-(4))>>2)];
        return ret;
      },getStr:function () {
        var ret = Pointer_stringify(SYSCALLS.get());
        return ret;
      },getStreamFromFD:function () {
        var stream = FS.getStream(SYSCALLS.get());
        if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return stream;
      },getSocketFromFD:function () {
        var socket = SOCKFS.getSocket(SYSCALLS.get());
        if (!socket) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        return socket;
      },getSocketAddress:function (allowNull) {
        var addrp = SYSCALLS.get(), addrlen = SYSCALLS.get();
        if (allowNull && addrp === 0) return null;
        var info = __read_sockaddr(addrp, addrlen);
        if (info.errno) throw new FS.ErrnoError(info.errno);
        info.addr = DNS.lookup_addr(info.addr) || info.addr;
        return info;
      },get64:function () {
        var low = SYSCALLS.get(), high = SYSCALLS.get();
        if (low >= 0) assert(high === 0);
        else assert(high === -1);
        return low;
      },getZero:function () {
        assert(SYSCALLS.get() === 0);
      }};function ___syscall195(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_stat64
      var path = SYSCALLS.getStr(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall194(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ftruncate64
      var fd = SYSCALLS.get(), zero = SYSCALLS.getZero(), length = SYSCALLS.get64();
      FS.ftruncate(fd, length);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall197(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_fstat64
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get();
      return SYSCALLS.doStat(FS.stat, stream.path, buf);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


  var GL={counter:1,lastError:0,buffers:[],mappedBuffers:{},programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],vaos:[],contexts:[],currentContext:null,offscreenCanvases:{},timerQueriesEXT:[],byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],programInfos:{},stringCache:{},tempFixedLengthArray:[],packAlignment:4,unpackAlignment:4,init:function () {
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }

        // For functions such as glDrawBuffers, glInvalidateFramebuffer and glInvalidateSubFramebuffer that need to pass a short array to the WebGL API,
        // create a set of short fixed-length arrays to avoid having to generate any garbage when calling those functions.
        for (var i = 0; i < 32; i++) {
          GL.tempFixedLengthArray.push(new Array(i));
        }
      },recordError:function recordError(errorCode) {
        if (!GL.lastError) {
          GL.lastError = errorCode;
        }
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:256,miniTempBuffer:null,miniTempBufferViews:[0],getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        return source;
      },createContext:function (canvas, webGLContextAttributes) {
        if (typeof webGLContextAttributes['majorVersion'] === 'undefined' && typeof webGLContextAttributes['minorVersion'] === 'undefined') {
          webGLContextAttributes['majorVersion'] = 1;
          webGLContextAttributes['minorVersion'] = 0;
        }


        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
          try {
            if (webGLContextAttributes['majorVersion'] == 1 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl", webGLContextAttributes) || canvas.getContext("experimental-webgl", webGLContextAttributes);
            } else if (webGLContextAttributes['majorVersion'] == 2 && webGLContextAttributes['minorVersion'] == 0) {
              ctx = canvas.getContext("webgl2", webGLContextAttributes);
            } else {
              throw 'Unsupported WebGL context version ' + majorVersion + '.' + minorVersion + '!'
            }
          } finally {
            canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e, JSON.stringify(webGLContextAttributes)]);
          return 0;
        }
        // possible GL_DEBUG entry point: ctx = wrapDebugGL(ctx);

        if (!ctx) return 0;
        return GL.registerContext(ctx, webGLContextAttributes);
      },registerContext:function (ctx, webGLContextAttributes) {
        var handle = GL.getNewId(GL.contexts);
        var context = {
          handle: handle,
          attributes: webGLContextAttributes,
          version: webGLContextAttributes['majorVersion'],
          GLctx: ctx
        };


        // Store the created context object so that we can access the context given a canvas without having to pass the parameters again.
        if (ctx.canvas) ctx.canvas.GLctxObject = context;
        GL.contexts[handle] = context;
        if (typeof webGLContextAttributes['enableExtensionsByDefault'] === 'undefined' || webGLContextAttributes['enableExtensionsByDefault']) {
          GL.initExtensions(context);
        }
        return handle;
      },makeContextCurrent:function (contextHandle) {
        var context = GL.contexts[contextHandle];
        if (!context) return false;
        GLctx = Module.ctx = context.GLctx; // Active WebGL context object.
        GL.currentContext = context; // Active Emscripten GL layer context object.
        return true;
      },getContext:function (contextHandle) {
        return GL.contexts[contextHandle];
      },deleteContext:function (contextHandle) {
        if (GL.currentContext === GL.contexts[contextHandle]) GL.currentContext = null;
        if (typeof JSEvents === 'object') JSEvents.removeAllHandlersOnTarget(GL.contexts[contextHandle].GLctx.canvas); // Release all JS event handlers on the DOM element that the GL context is associated with since the context is now deleted.
        if (GL.contexts[contextHandle] && GL.contexts[contextHandle].GLctx.canvas) GL.contexts[contextHandle].GLctx.canvas.GLctxObject = undefined; // Make sure the canvas object no longer refers to the context object so there are no GC surprises.
        GL.contexts[contextHandle] = null;
      },initExtensions:function (context) {
        // If this function is called without a specific context object, init the extensions of the currently active context.
        if (!context) context = GL.currentContext;

        if (context.initExtensionsDone) return;
        context.initExtensionsDone = true;

        var GLctx = context.GLctx;

        context.maxVertexAttribs = GLctx.getParameter(GLctx.MAX_VERTEX_ATTRIBS);

        // Detect the presence of a few extensions manually, this GL interop layer itself will need to know if they exist.

        if (context.version < 2) {
          // Extension available from Firefox 26 and Google Chrome 30
          var instancedArraysExt = GLctx.getExtension('ANGLE_instanced_arrays');
          if (instancedArraysExt) {
            GLctx['vertexAttribDivisor'] = function(index, divisor) { instancedArraysExt['vertexAttribDivisorANGLE'](index, divisor); };
            GLctx['drawArraysInstanced'] = function(mode, first, count, primcount) { instancedArraysExt['drawArraysInstancedANGLE'](mode, first, count, primcount); };
            GLctx['drawElementsInstanced'] = function(mode, count, type, indices, primcount) { instancedArraysExt['drawElementsInstancedANGLE'](mode, count, type, indices, primcount); };
          }

          // Extension available from Firefox 25 and WebKit
          var vaoExt = GLctx.getExtension('OES_vertex_array_object');
          if (vaoExt) {
            GLctx['createVertexArray'] = function() { return vaoExt['createVertexArrayOES'](); };
            GLctx['deleteVertexArray'] = function(vao) { vaoExt['deleteVertexArrayOES'](vao); };
            GLctx['bindVertexArray'] = function(vao) { vaoExt['bindVertexArrayOES'](vao); };
            GLctx['isVertexArray'] = function(vao) { return vaoExt['isVertexArrayOES'](vao); };
          }

          var drawBuffersExt = GLctx.getExtension('WEBGL_draw_buffers');
          if (drawBuffersExt) {
            GLctx['drawBuffers'] = function(n, bufs) { drawBuffersExt['drawBuffersWEBGL'](n, bufs); };
          }
        }

        GLctx.disjointTimerQueryExt = GLctx.getExtension("EXT_disjoint_timer_query");

        // These are the 'safe' feature-enabling extensions that don't add any performance impact related to e.g. debugging, and
        // should be enabled by default so that client GLES2/GL code will not need to go through extra hoops to get its stuff working.
        // As new extensions are ratified at http://www.khronos.org/registry/webgl/extensions/ , feel free to add your new extensions
        // here, as long as they don't produce a performance impact for users that might not be using those extensions.
        // E.g. debugging-related extensions should probably be off by default.
        var automaticallyEnabledExtensions = [ "OES_texture_float", "OES_texture_half_float", "OES_standard_derivatives",
                                               "OES_vertex_array_object", "WEBGL_compressed_texture_s3tc", "WEBGL_depth_texture",
                                               "OES_element_index_uint", "EXT_texture_filter_anisotropic", "ANGLE_instanced_arrays",
                                               "OES_texture_float_linear", "OES_texture_half_float_linear", "WEBGL_compressed_texture_atc",
                                               "WEBGL_compressed_texture_pvrtc", "EXT_color_buffer_half_float", "WEBGL_color_buffer_float",
                                               "EXT_frag_depth", "EXT_sRGB", "WEBGL_draw_buffers", "WEBGL_shared_resources",
                                               "EXT_shader_texture_lod", "EXT_color_buffer_float"];

        function shouldEnableAutomatically(extension) {
          var ret = false;
          automaticallyEnabledExtensions.forEach(function(include) {
            if (ext.indexOf(include) != -1) {
              ret = true;
            }
          });
          return ret;
        }

        var exts = GLctx.getSupportedExtensions();
        if (exts && exts.length > 0) {
          GLctx.getSupportedExtensions().forEach(function(ext) {
            if (automaticallyEnabledExtensions.indexOf(ext) != -1) {
              GLctx.getExtension(ext); // Calling .getExtension enables that extension permanently, no need to store the return value to be enabled.
            }
          });
        }
      },populateUniformTable:function (program) {
        var p = GL.programs[program];
        GL.programInfos[program] = {
          uniforms: {},
          maxUniformLength: 0, // This is eagerly computed below, since we already enumerate all uniforms anyway.
          maxAttributeLength: -1, // This is lazily computed and cached, computed when/if first asked, "-1" meaning not computed yet.
          maxUniformBlockNameLength: -1 // Lazily computed as well
        };

        var ptable = GL.programInfos[program];
        var utable = ptable.uniforms;
        // A program's uniform table maps the string name of an uniform to an integer location of that uniform.
        // The global GL.uniforms map maps integer locations to WebGLUniformLocations.
        var numUniforms = GLctx.getProgramParameter(p, GLctx.ACTIVE_UNIFORMS);
        for (var i = 0; i < numUniforms; ++i) {
          var u = GLctx.getActiveUniform(p, i);

          var name = u.name;
          ptable.maxUniformLength = Math.max(ptable.maxUniformLength, name.length+1);

          // Strip off any trailing array specifier we might have got, e.g. "[0]".
          if (name.indexOf(']', name.length-1) !== -1) {
            var ls = name.lastIndexOf('[');
            name = name.slice(0, ls);
          }

          // Optimize memory usage slightly: If we have an array of uniforms, e.g. 'vec3 colors[3];', then
          // only store the string 'colors' in utable, and 'colors[0]', 'colors[1]' and 'colors[2]' will be parsed as 'colors'+i.
          // Note that for the GL.uniforms table, we still need to fetch the all WebGLUniformLocations for all the indices.
          var loc = GLctx.getUniformLocation(p, name);
          if (loc != null)
          {
            var id = GL.getNewId(GL.uniforms);
            utable[name] = [u.size, id];
            GL.uniforms[id] = loc;

            for (var j = 1; j < u.size; ++j) {
              var n = name + '['+j+']';
              loc = GLctx.getUniformLocation(p, n);
              id = GL.getNewId(GL.uniforms);

              GL.uniforms[id] = loc;
            }
          }
        }
      }};




  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;

      if (!Browser.mainLoop.func) {
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }

      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setTimeout() {
          var timeUntilNextTick = Math.max(0, Browser.mainLoop.tickStartTime + value - _emscripten_get_now())|0;
          setTimeout(Browser.mainLoop.runner, timeUntilNextTick); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_rAF() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      } else if (mode == 2 /*EM_TIMING_SETIMMEDIATE*/) {
        if (!window['setImmediate']) {
          // Emulate setImmediate. (note: not a complete polyfill, we don't emulate clearImmediate() to keep code size to minimum, since not needed)
          var setImmediates = [];
          var emscriptenMainLoopMessageId = 'setimmediate';
          function Browser_setImmediate_messageHandler(event) {
            if (event.source === window && event.data === emscriptenMainLoopMessageId) {
              event.stopPropagation();
              setImmediates.shift()();
            }
          }
          window.addEventListener("message", Browser_setImmediate_messageHandler, true);
          window['setImmediate'] = function Browser_emulated_setImmediate(func) {
            setImmediates.push(func);
            if (ENVIRONMENT_IS_WORKER) {
              if (Module['setImmediates'] === undefined) Module['setImmediates'] = [];
              Module['setImmediates'].push(func);
              window.postMessage({target: emscriptenMainLoopMessageId}); // In --proxy-to-worker, route the message via proxyClient.js
            } else window.postMessage(emscriptenMainLoopMessageId, "*"); // On the main thread, can just send the message to itself.
          }
        }
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setImmediate() {
          window['setImmediate'](Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'immediate';
      }
      return 0;
    }

  function _emscripten_get_now() { abort() }

  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg, noSetTiming) {
      Module['noExitRuntime'] = true;

      Module.print('Hiii')

      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');

      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;

      var browserIterationFunc;
      if (typeof arg !== 'undefined') {
        browserIterationFunc = function() {
          Module['dynCall_vi'](func, arg);
        };
      } else {
        browserIterationFunc = function() {
          Module['dynCall_v'](func);
        };
      }

      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;

      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        Module.print("runner");

        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();

          // catches pause/resume main loop from blocker execution
          if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;

          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }

        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;

        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        } else if (Browser.mainLoop.timingMode == 0/*EM_TIMING_SETTIMEOUT*/) {
          Browser.mainLoop.tickStartTime = _emscripten_get_now();
        }

        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.


        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }

        Browser.mainLoop.runIter(browserIterationFunc);


        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;

        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();

        Browser.mainLoop.scheduler();
      }

      if (!noSetTiming) {
        if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
        else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)

        Browser.mainLoop.scheduler();
      }

      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg, true /* do not set timing and call scheduler, we will do it on the next lines */);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
          Browser.mainLoop.scheduler();
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullscreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers

        if (Browser.initted) return;
        Browser.initted = true;

        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }

        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).

        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);

        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);

        // Canvas event setup

        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === Module['canvas'] ||
                                document['mozPointerLockElement'] === Module['canvas'] ||
                                document['webkitPointerLockElement'] === Module['canvas'] ||
                                document['msPointerLockElement'] === Module['canvas'];
        }
        var canvas = Module['canvas'];
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;

          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);

          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);

          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && Module['canvas'].requestPointerLock) {
                Module['canvas'].requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.

        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };

          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }

          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
        } else {
          ctx = canvas.getContext('2d');
        }

        if (!ctx) return null;

        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');

          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullscreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullscreen:function (lockPointer, resizeCanvas, vrDevice) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        Browser.vrDevice = vrDevice;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        if (typeof Browser.vrDevice === 'undefined') Browser.vrDevice = null;

        var canvas = Module['canvas'];
        function fullscreenChange() {
          Browser.isFullscreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['fullscreenElement'] || document['mozFullScreenElement'] ||
               document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.exitFullscreen = document['exitFullscreen'] ||
                                    document['cancelFullScreen'] ||
                                    document['mozCancelFullScreen'] ||
                                    document['msExitFullscreen'] ||
                                    document['webkitCancelFullScreen'] ||
                                    function() {};
            canvas.exitFullscreen = canvas.exitFullscreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullscreen = true;
            if (Browser.resizeCanvas) Browser.setFullscreenCanvasSize();
          } else {

            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);

            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullscreen);
          if (Module['onFullscreen']) Module['onFullscreen'](Browser.isFullscreen);
          Browser.updateCanvasDimensions(canvas);
        }

        if (!Browser.fullscreenHandlersInstalled) {
          Browser.fullscreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullscreenChange, false);
          document.addEventListener('mozfullscreenchange', fullscreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullscreenChange, false);
          document.addEventListener('MSFullscreenChange', fullscreenChange, false);
        }

        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);

        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullscreen = canvasContainer['requestFullscreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullscreen'] ? function() { canvasContainer['webkitRequestFullscreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null) ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);

        if (vrDevice) {
          canvasContainer.requestFullscreen({ vrDisplay: vrDevice });
        } else {
          canvasContainer.requestFullscreen();
        }
      },requestFullScreen:function (lockPointer, resizeCanvas, vrDevice) {
          Module.printErr('Browser.requestFullScreen() is deprecated. Please call Browser.requestFullscreen instead.');
          Browser.requestFullScreen = function(lockPointer, resizeCanvas, vrDevice) {
            return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
          }
          return Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice);
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },allowAsyncCallbacks:true,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function () {
        Browser.allowAsyncCallbacks = false;
      },resumeAsyncCallbacks:function () { // marks future callbacks as ok to execute, and synchronously runs any remaining ones right now
        Browser.allowAsyncCallbacks = true;
        if (Browser.queuedAsyncCallbacks.length > 0) {
          var callbacks = Browser.queuedAsyncCallbacks;
          Browser.queuedAsyncCallbacks = [];
          callbacks.forEach(function(func) {
            func();
          });
        }
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } // drop it on the floor otherwise, next interval will kick in
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll':
            delta = event.detail;
            break;
          case 'mousewheel':
            delta = event.wheelDelta;
            break;
          case 'wheel':
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }

          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;

          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);

          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL

            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);

            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);

            var coords = { x: adjustedX, y: adjustedY };

            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              var last = Browser.touches[touch.identifier];
              if (!last) last = coords;
              Browser.lastTouches[touch.identifier] = last;
              Browser.touches[touch.identifier] = coords;
            }
            return;
          }

          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);

          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);

          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        var dep = !noRunDep ? getUniqueRunDependency('al ' + url) : '';
        Module['readAsync'](url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (dep) removeRunDependency(dep);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (dep) addRunDependency(dep);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullscreenCanvasSize:function () {
        // check if SDL is available
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['fullscreenElement'] || document['mozFullScreenElement'] ||
             document['msFullscreenElement'] || document['webkitFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};





















  var _environ=STATICTOP; STATICTOP += 16;;var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;

      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = ENV['LOGNAME'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }

      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }

      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;

      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }

  function _putenv(string) {
      // int putenv(char *string);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/putenv.html
      // WARNING: According to the standard (and the glibc implementation), the
      //          string is taken by reference so future changes are reflected.
      //          We copy it instead, possibly breaking some uses.
      if (string === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      string = Pointer_stringify(string);
      var splitPoint = string.indexOf('=')
      if (string === '' || string.indexOf('=') === -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = string.slice(0, splitPoint);
      var value = string.slice(splitPoint + 1);
      if (!(name in ENV) || ENV[name] !== value) {
        ENV[name] = value;
        ___buildEnvironment(ENV);
      }
      return 0;
    }

  function _SDL_RWFromConstMem(mem, size) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      SDL.rwops.push({ bytes: mem, count: size });
      return id;
    }function _TTF_FontHeight(font) {
      var fontData = SDL.fonts[font];
      return fontData.size;
    }function _TTF_SizeText(font, text, w, h) {
      var fontData = SDL.fonts[font];
      if (w) {
        HEAP32[((w)>>2)]=SDL.estimateTextWidth(fontData, Pointer_stringify(text));
      }
      if (h) {
        HEAP32[((h)>>2)]=fontData.size;
      }
      return 0;
    }function _TTF_RenderText_Solid(font, text, color) {
      // XXX the font and color are ignored
      text = Pointer_stringify(text) || ' '; // if given an empty string, still return a valid surface
      var fontData = SDL.fonts[font];
      var w = SDL.estimateTextWidth(fontData, text);
      var h = fontData.size;
      var color = SDL.loadColorToCSSRGB(color); // XXX alpha breaks fonts?
      var fontString = SDL.makeFontString(h, fontData.name);
      var surf = SDL.makeSurface(w, h, 0, false, 'text:' + text); // bogus numbers..
      var surfData = SDL.surfaces[surf];
      surfData.ctx.save();
      surfData.ctx.fillStyle = color;
      surfData.ctx.font = fontString;
      // use bottom alligment, because it works
      // same in all browsers, more info here:
      // https://bugzilla.mozilla.org/show_bug.cgi?id=737852
      surfData.ctx.textBaseline = 'bottom';
      surfData.ctx.fillText(text, 0, h|0);
      surfData.ctx.restore();
      return surf;
    }function _Mix_HaltMusic() {
      var audio = SDL.music.audio;
      if (audio) {
        audio.src = audio.src; // rewind <media> element
        audio.currentPosition = 0; // rewind Web Audio graph playback.
        audio.pause();
      }
      SDL.music.audio = null;
      if (SDL.hookMusicFinished) {
        Module['dynCall_v'](SDL.hookMusicFinished);
      }
      return 0;
    }function _Mix_PlayMusic(id, loops) {
      // Pause old music if it exists.
      if (SDL.music.audio) {
        if (!SDL.music.audio.paused) Module.printErr('Music is already playing. ' + SDL.music.source);
        SDL.music.audio.pause();
      }
      var info = SDL.audios[id];
      var audio;
      if (info.webAudio) { // Play via Web Audio API
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new webAudio object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else if (info.audio) { // Play via the <audio> element
        audio = info.audio;
      }
      audio['onended'] = function() { if (SDL.music.audio == this) _Mix_HaltMusic(); } // will send callback
      audio.loop = loops != 0; // TODO: handle N loops for finite N
      audio.volume = SDL.music.volume;
      SDL.music.audio = audio;
      audio.play();
      return 0;
    }function _Mix_FreeChunk(id) {
      SDL.audios[id] = null;
    }function _Mix_LoadWAV_RW(rwopsID, freesrc) {
      var rwops = SDL.rwops[rwopsID];


      if (rwops === undefined)
        return 0;

      var filename = '';
      var audio;
      var webAudio;
      var bytes;

      if (rwops.filename !== undefined) {
        filename = PATH.resolve(rwops.filename);
        var raw = Module["preloadedAudios"][filename];
        if (!raw) {
          if (raw === null) Module.printErr('Trying to reuse preloaded audio, but freePreloadedMediaOnUse is set!');
          if (!Module.noAudioDecoding) Runtime.warnOnce('Cannot find preloaded audio ' + filename);

          // see if we can read the file-contents from the in-memory FS
          try {
            bytes = FS.readFile(filename);
          } catch (e) {
            Module.printErr('Couldn\'t find file for: ' + filename);
            return 0;
          }
        }
        if (Module['freePreloadedMediaOnUse']) {
          Module["preloadedAudios"][filename] = null;
        }
        audio = raw;
      }
      else if (rwops.bytes !== undefined) {
        // For Web Audio context buffer decoding, we must make a clone of the audio data, but for <media> element,
        // a view to existing data is sufficient.
        if (SDL.webAudioAvailable()) bytes = HEAPU8.buffer.slice(rwops.bytes, rwops.bytes + rwops.count);
        else bytes = HEAPU8.subarray(rwops.bytes, rwops.bytes + rwops.count);
      }
      else {
        return 0;
      }

      var arrayBuffer = bytes ? bytes.buffer || bytes : bytes;

      // To allow user code to work around browser bugs with audio playback on <audio> elements an Web Audio, enable
      // the user code to hook in a callback to decide on a file basis whether each file should use Web Audio or <audio> for decoding and playback.
      // In particular, see https://bugzilla.mozilla.org/show_bug.cgi?id=654787 and ?id=1012801 for tradeoffs.
      var canPlayWithWebAudio = Module['SDL_canPlayWithWebAudio'] === undefined || Module['SDL_canPlayWithWebAudio'](filename, arrayBuffer);

      if (bytes !== undefined && SDL.webAudioAvailable() && canPlayWithWebAudio) {
        audio = undefined;
        webAudio = {};
        // The audio decoding process is asynchronous, which gives trouble if user code plays the audio data back immediately
        // after loading. Therefore prepare an array of callback handlers to run when this audio decoding is complete, which
        // will then start the playback (with some delay).
        webAudio.onDecodeComplete = []; // While this member array exists, decoding hasn't finished yet.
        function onDecodeComplete(data) {
          webAudio.decodedBuffer = data;
          // Call all handlers that were waiting for this decode to finish, and clear the handler list.
          webAudio.onDecodeComplete.forEach(function(e) { e(); });
          webAudio.onDecodeComplete = undefined; // Don't allow more callback handlers since audio has finished decoding.
        }

        SDL.audioContext['decodeAudioData'](arrayBuffer, onDecodeComplete);
      } else if (audio === undefined && bytes) {
        // Here, we didn't find a preloaded audio but we either were passed a filepath for
        // which we loaded bytes, or we were passed some bytes
        var blob = new Blob([bytes], {type: rwops.mimetype});
        var url = URL.createObjectURL(blob);
        audio = new Audio();
        audio.src = url;
        audio.mozAudioChannelType = 'content'; // bugzilla 910340
      }

      var id = SDL.audios.length;
      // Keep the loaded audio in the audio arrays, ready for playback
      SDL.audios.push({
        source: filename,
        audio: audio, // Points to the <audio> element, if loaded
        webAudio: webAudio // Points to a Web Audio -specific resource object, if loaded
      });
      return id;
    }function _Mix_PlayChannel(channel, id, loops) {
      // TODO: handle fixed amount of N loops. Currently loops either 0 or infinite times.

      // Get the audio element associated with the ID
      var info = SDL.audios[id];
      if (!info) return -1;
      if (!info.audio && !info.webAudio) return -1;

      // If the user asks us to allocate a channel automatically, get the first
      // free one.
      if (channel == -1) {
        for (var i = SDL.channelMinimumNumber; i < SDL.numChannels; i++) {
          if (!SDL.channels[i].audio) {
            channel = i;
            break;
          }
        }
        if (channel == -1) {
          Module.printErr('All ' + SDL.numChannels + ' channels in use!');
          return -1;
        }
      }
      var channelInfo = SDL.channels[channel];
      var audio;
      if (info.webAudio) {
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        // Make our instance look similar to the instance of a <media> to make api simple.
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else {
        // We clone the audio node to utilize the preloaded audio buffer, since
        // the browser has already preloaded the audio file.
        audio = info.audio.cloneNode(true);
        audio.numChannels = info.audio.numChannels;
        audio.frequency = info.audio.frequency;
      }
      audio['onended'] = function SDL_audio_onended() { // TODO: cache these
        if (channelInfo.audio == this) { channelInfo.audio.paused = true; channelInfo.audio = null; }
        if (SDL.channelFinished) Runtime.getFuncWrapper(SDL.channelFinished, 'vi')(channel);
      }
      channelInfo.audio = audio;
      // TODO: handle N loops. Behavior matches Mix_PlayMusic
      audio.loop = loops != 0;
      audio.volume = channelInfo.volume;
      audio.play();
      return channel;
    }function _SDL_PauseAudio(pauseOn) {
      if (!SDL.audio) {
        return;
      }
      if (pauseOn) {
        if (SDL.audio.timer !== undefined) {
          clearTimeout(SDL.audio.timer);
          SDL.audio.numAudioTimersPending = 0;
          SDL.audio.timer = undefined;
        }
      } else if (!SDL.audio.timer) {
        // Start the audio playback timer callback loop.
        SDL.audio.numAudioTimersPending = 1;
        SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1);
      }
      SDL.audio.paused = pauseOn;
    }function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
        SDL.allocateChannels(0);
      }
    }function _SDL_LockSurface(surf) {
      var surfData = SDL.surfaces[surf];

      surfData.locked++;
      if (surfData.locked > 1) return 0;

      if (!surfData.buffer) {
        surfData.buffer = _malloc(surfData.width * surfData.height * 4);
        HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
      }

      // Mark in C/C++-accessible SDL structure
      // SDL_Surface has the following fields: Uint32 flags, SDL_PixelFormat *format; int w, h; Uint16 pitch; void *pixels; ...
      // So we have fields all of the same size, and 5 of them before us.
      // TODO: Use macros like in library.js
      HEAP32[(((surf)+(20))>>2)]=surfData.buffer;

      if (surf == SDL.screen && Module.screenIsReadOnly && surfData.image) return 0;

      if (SDL.defaults.discardOnLock) {
        if (!surfData.image) {
          surfData.image = surfData.ctx.createImageData(surfData.width, surfData.height);
        }
        if (!SDL.defaults.opaqueFrontBuffer) return;
      } else {
        surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
      }

      // Emulate desktop behavior and kill alpha values on the locked surface. (very costly!) Set SDL.defaults.opaqueFrontBuffer = false
      // if you don't want this.
      if (surf == SDL.screen && SDL.defaults.opaqueFrontBuffer) {
        var data = surfData.image.data;
        var num = data.length;
        for (var i = 0; i < num/4; i++) {
          data[i*4+3] = 255; // opacity, as canvases blend alpha
        }
      }

      if (SDL.defaults.copyOnLock && !SDL.defaults.discardOnLock) {
        // Copy pixel data to somewhere accessible to 'C/C++'
        if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
          // If this is neaded then
          // we should compact the data from 32bpp to 8bpp index.
          // I think best way to implement this is use
          // additional colorMap hash (color->index).
          // Something like this:
          //
          // var size = surfData.width * surfData.height;
          // var data = '';
          // for (var i = 0; i<size; i++) {
          //   var color = SDL.translateRGBAToColor(
          //     surfData.image.data[i*4   ],
          //     surfData.image.data[i*4 +1],
          //     surfData.image.data[i*4 +2],
          //     255);
          //   var index = surfData.colorMap[color];
          //   HEAP8[(((surfData.buffer)+(i))>>0)]=index;
          // }
          throw 'CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set' + new Error().stack;
        } else {
          HEAPU8.set(surfData.image.data, surfData.buffer);
        }
      }

      return 0;
    }

  function _SDL_FreeRW(rwopsID) {
      SDL.rwops[rwopsID] = null;
      while (SDL.rwops.length > 0 && SDL.rwops[SDL.rwops.length-1] === null) {
        SDL.rwops.pop();
      }
    }function _IMG_Load_RW(rwopsID, freeSrc) {
      try {
        // stb_image integration support
        var cleanup = function() {
          if (rwops && freeSrc) _SDL_FreeRW(rwopsID);
        }
        var addCleanup = function(func) {
          var old = cleanup;
          cleanup = function added_cleanup() {
            old();
            func();
          }
        }
        var callStbImage = function(func, params) {
          var x = Module['_malloc'](4);
          var y = Module['_malloc'](4);
          var comp = Module['_malloc'](4);
          addCleanup(function() {
            Module['_free'](x);
            Module['_free'](y);
            Module['_free'](comp);
            if (data) Module['_stbi_image_free'](data);
          });
          var data = Module['_' + func].apply(null, params.concat([x, y, comp, 0]));
          if (!data) return null;
          return {
            rawData: true,
            data: data,
            width: HEAP32[((x)>>2)],
            height: HEAP32[((y)>>2)],
            size: HEAP32[((x)>>2)] * HEAP32[((y)>>2)] * HEAP32[((comp)>>2)],
            bpp: HEAP32[((comp)>>2)]
          };
        }

        var rwops = SDL.rwops[rwopsID];
        if (rwops === undefined) {
          return 0;
        }

        var filename = rwops.filename;
        if (filename === undefined) {
          Runtime.warnOnce('Only file names that have been preloaded are supported for IMG_Load_RW. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins');
          return 0;
        }

        if (!raw) {
          filename = PATH.resolve(filename);
          var raw = Module["preloadedImages"][filename];
          if (!raw) {
            if (raw === null) Module.printErr('Trying to reuse preloaded image, but freePreloadedMediaOnUse is set!');
            Runtime.warnOnce('Cannot find preloaded image ' + filename);
            Runtime.warnOnce('Cannot find preloaded image ' + filename + '. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins');
            return 0;
          } else if (Module['freePreloadedMediaOnUse']) {
            Module["preloadedImages"][filename] = null;
          }
        }

        var surf = SDL.makeSurface(raw.width, raw.height, 0, false, 'load:' + filename);
        var surfData = SDL.surfaces[surf];
        surfData.ctx.globalCompositeOperation = "copy";
        if (!raw.rawData) {
          surfData.ctx.drawImage(raw, 0, 0, raw.width, raw.height, 0, 0, raw.width, raw.height);
        } else {
          var imageData = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
          if (raw.bpp == 4) {
            // rgba
            imageData.data.set(HEAPU8.subarray((raw.data),(raw.data+raw.size)));
          } else if (raw.bpp == 3) {
            // rgb
            var pixels = raw.size/3;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = 255;
            }
          } else if (raw.bpp == 2) {
            // grayscale + alpha
            var pixels = raw.size;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              var gray = HEAPU8[((sourcePtr++)>>0)];
              var alpha = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = gray;
              data[destPtr++] = gray;
              data[destPtr++] = gray;
              data[destPtr++] = alpha;
            }
          } else if (raw.bpp == 1) {
            // grayscale
            var pixels = raw.size;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              var value = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = 255;
            }
          } else {
            Module.printErr('cannot handle bpp ' + raw.bpp);
            return 0;
          }
          surfData.ctx.putImageData(imageData, 0, 0);
        }
        surfData.ctx.globalCompositeOperation = "source-over";
        // XXX SDL does not specify that loaded images must have available pixel data, in fact
        //     there are cases where you just want to blit them, so you just need the hardware
        //     accelerated version. However, code everywhere seems to assume that the pixels
        //     are in fact available, so we retrieve it here. This does add overhead though.
        _SDL_LockSurface(surf);
        surfData.locked--; // The surface is not actually locked in this hack
        if (SDL.GL) {
          // After getting the pixel data, we can free the canvas and context if we do not need to do 2D canvas blitting
          surfData.canvas = surfData.ctx = null;
        }
        return surf;
      } finally {
        cleanup();
      }
    }

  function _SDL_RWFromFile(_name, mode) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      var name = Pointer_stringify(_name)
      SDL.rwops.push({ filename: name, mimetype: Browser.getMimetype(name) });
      return id;
    }function _IMG_Load(filename){
      var rwops = _SDL_RWFromFile(filename);
      var result = _IMG_Load_RW(rwops, 1);
      return result;
    }function _SDL_UpperBlitScaled(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, true);
    }function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, false);
    }function _SDL_GetTicks() {
      return (Date.now() - SDL.startTime)|0;
    }var SDL={defaults:{width:320,height:200,copyOnLock:true,discardOnLock:false,opaqueFrontBuffer:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],rwops:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,glAttributes:{0:3,1:3,2:2,3:0,4:0,5:1,6:16,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:1,16:0,17:0,18:0},keyboardState:null,keyboardMap:{},canRequestFullscreen:false,isRequestingFullscreen:false,textInput:false,startTime:null,initFlags:0,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},TOUCH_DEFAULT_ID:0,eventHandler:null,eventHandlerContext:null,eventHandlerTemp:0,keyCodes:{16:1249,17:1248,18:1250,20:1081,33:1099,34:1102,35:1101,36:1098,37:1104,38:1106,39:1103,40:1105,44:316,45:1097,46:127,91:1251,93:1125,96:1122,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,106:1109,107:1111,109:1110,110:1123,111:1108,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,124:1128,125:1129,126:1130,127:1131,128:1132,129:1133,130:1134,131:1135,132:1136,133:1137,134:1138,135:1139,144:1107,160:94,161:33,162:34,163:35,164:36,165:37,166:38,167:95,168:40,169:41,170:42,171:43,172:124,173:45,174:123,175:125,176:126,181:127,182:129,183:128,188:44,190:46,191:47,192:96,219:91,220:92,221:93,222:39,224:1251},scanCodes:{8:42,9:43,13:40,27:41,32:44,35:204,39:53,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,58:203,59:51,61:46,91:47,92:49,93:48,96:52,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,127:76,305:224,308:226,316:70},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + 0)>>2)],
          y: HEAP32[((rect + 4)>>2)],
          w: HEAP32[((rect + 8)>>2)],
          h: HEAP32[((rect + 12)>>2)]
        };
      },updateRect:function (rect, r) {
        HEAP32[((rect)>>2)]=r.x;
        HEAP32[(((rect)+(4))>>2)]=r.y;
        HEAP32[(((rect)+(8))>>2)]=r.w;
        HEAP32[(((rect)+(12))>>2)]=r.h;
      },intersectionOfRects:function (first, second) {
        var leftX = Math.max(first.x, second.x);
        var leftY = Math.max(first.y, second.y);
        var rightX = Math.min(first.x + first.w, second.x + second.w);
        var rightY = Math.min(first.y + first.h, second.y + second.h);

        return {
          x: leftX,
          y: leftY,
          w: Math.max(leftX, rightX) - leftX,
          h: Math.max(leftY, rightY) - leftY
        }
      },checkPixelFormat:function (fmt) {
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var is_SDL_HWSURFACE = flags & 0x00000001;
        var is_SDL_HWPALETTE = flags & 0x00200000;
        var is_SDL_OPENGL = flags & 0x04000000;

        var surf = _malloc(60);
        var pixelFormat = _malloc(44);
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        var buffer = 0;

        // preemptively initialize this for software surfaces,
        // otherwise it will be lazily initialized inside of SDL_LockSurface
        if (!is_SDL_HWSURFACE && !is_SDL_OPENGL) {
          buffer = _malloc(width * height * 4);
        }

        HEAP32[((surf)>>2)]=flags;
        HEAP32[(((surf)+(4))>>2)]=pixelFormat;
        HEAP32[(((surf)+(8))>>2)]=width;
        HEAP32[(((surf)+(12))>>2)]=height;
        HEAP32[(((surf)+(16))>>2)]=width * bpp;  // assuming RGBA or indexed for now,
                                                                                          // since that is what ImageData gives us in browsers
        HEAP32[(((surf)+(20))>>2)]=buffer;

        HEAP32[(((surf)+(36))>>2)]=0;
        HEAP32[(((surf)+(40))>>2)]=0;
        HEAP32[(((surf)+(44))>>2)]=Module["canvas"].width;
        HEAP32[(((surf)+(48))>>2)]=Module["canvas"].height;

        HEAP32[(((surf)+(56))>>2)]=1;

        HEAP32[((pixelFormat)>>2)]=-2042224636;
        HEAP32[(((pixelFormat)+(4))>>2)]=0;// TODO
        HEAP8[(((pixelFormat)+(8))>>0)]=bpp * 8;
        HEAP8[(((pixelFormat)+(9))>>0)]=bpp;

        HEAP32[(((pixelFormat)+(12))>>2)]=rmask || 0x000000ff;
        HEAP32[(((pixelFormat)+(16))>>2)]=gmask || 0x0000ff00;
        HEAP32[(((pixelFormat)+(20))>>2)]=bmask || 0x00ff0000;
        HEAP32[(((pixelFormat)+(24))>>2)]=amask || 0xff000000;

        // Decide if we want to use WebGL or not
        SDL.GL = SDL.GL || is_SDL_OPENGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }

        var webGLContextAttributes = {
          antialias: ((SDL.glAttributes[13 /*SDL_GL_MULTISAMPLEBUFFERS*/] != 0) && (SDL.glAttributes[14 /*SDL_GL_MULTISAMPLESAMPLES*/] > 1)),
          depth: (SDL.glAttributes[6 /*SDL_GL_DEPTH_SIZE*/] > 0),
          stencil: (SDL.glAttributes[7 /*SDL_GL_STENCIL_SIZE*/] > 0),
          alpha: (SDL.glAttributes[3 /*SDL_GL_ALPHA_SIZE*/] > 0)
        };

        var ctx = Browser.createContext(canvas, is_SDL_OPENGL, usePageCanvas, webGLContextAttributes);

        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,

          isFlagSet: function(flag) {
            return flags & flag;
          }
        };

        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }

        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;

        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;

        var buffer  = surfData.buffer;

        if (!surfData.image.data32) {
          surfData.image.data32 = new Uint32Array(surfData.image.data.buffer);
        }
        var data32   = surfData.image.data32;

        var colors32 = surfData.colors32;

        for (var y = startY; y < endY; ++y) {
          var base = y * fullWidth;
          for (var x = startX; x < endX; ++x) {
            data32[base + x] = colors32[HEAPU8[((buffer + base + x)>>0)]];
          }
        }
      },freeSurface:function (surf) {
        var refcountPointer = surf + 56;
        var refcount = HEAP32[((refcountPointer)>>2)];
        if (refcount > 1) {
          HEAP32[((refcountPointer)>>2)]=refcount - 1;
          return;
        }

        var info = SDL.surfaces[surf];
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        if (info.buffer) _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;

        if (surf === SDL.screen) {
          SDL.screen = null;
        }
      },blitSurface__deps:["SDL_LockSurface"],blitSurface:function (src, srcrect, dst, dstrect, scale) {
        var srcData = SDL.surfaces[src];
        var dstData = SDL.surfaces[dst];
        var sr, dr;
        if (srcrect) {
          sr = SDL.loadRect(srcrect);
        } else {
          sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
        }
        if (dstrect) {
          dr = SDL.loadRect(dstrect);
        } else {
          dr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
        }
        if (dstData.clipRect) {
          var widthScale = (!scale || sr.w === 0) ? 1 : sr.w / dr.w;
          var heightScale = (!scale || sr.h === 0) ? 1 : sr.h / dr.h;

          dr = SDL.intersectionOfRects(dstData.clipRect, dr);

          sr.w = dr.w * widthScale;
          sr.h = dr.h * heightScale;

          if (dstrect) {
            SDL.updateRect(dstrect, dr);
          }
        }
        var blitw, blith;
        if (scale) {
          blitw = dr.w; blith = dr.h;
        } else {
          blitw = sr.w; blith = sr.h;
        }
        if (sr.w === 0 || sr.h === 0 || blitw === 0 || blith === 0) {
          return 0;
        }
        var oldAlpha = dstData.ctx.globalAlpha;
        dstData.ctx.globalAlpha = srcData.alpha/255;
        dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, blitw, blith);
        dstData.ctx.globalAlpha = oldAlpha;
        if (dst != SDL.screen) {
          // XXX As in IMG_Load, for compatibility we write out |pixels|
          Runtime.warnOnce('WARNING: copying canvas data to memory for compatibility');
          _SDL_LockSurface(dst);
          dstData.locked--; // The surface is not actually locked in this hack
        }
        return 0;
      },downFingers:{},savedKeydown:null,receiveEvent:function (event) {
        function unpressAllPressedKeys() {
          // Un-press all pressed keys: TODO
          for (var code in SDL.keyboardMap) {
            SDL.events.push({
              type: 'keyup',
              keyCode: SDL.keyboardMap[code]
            });
          }
        };
        switch(event.type) {
          case 'touchstart': case 'touchmove': {
            event.preventDefault();

            var touches = [];

            // Clear out any touchstart events that we've already processed
            if (event.type === 'touchstart') {
              for (var i = 0; i < event.touches.length; i++) {
                var touch = event.touches[i];
                if (SDL.downFingers[touch.identifier] != true) {
                  SDL.downFingers[touch.identifier] = true;
                  touches.push(touch);
                }
              }
            } else {
              touches = event.touches;
            }

            var firstTouch = touches[0];
            if (firstTouch) {
              if (event.type == 'touchstart') {
                SDL.DOMButtons[0] = 1;
              }
              var mouseEventType;
              switch(event.type) {
                case 'touchstart': mouseEventType = 'mousedown'; break;
                case 'touchmove': mouseEventType = 'mousemove'; break;
              }
              var mouseEvent = {
                type: mouseEventType,
                button: 0,
                pageX: firstTouch.clientX,
                pageY: firstTouch.clientY
              };
              SDL.events.push(mouseEvent);
            }

            for (var i = 0; i < touches.length; i++) {
              var touch = touches[i];
              SDL.events.push({
                type: event.type,
                touch: touch
              });
            };
            break;
          }
          case 'touchend': {
            event.preventDefault();

            // Remove the entry in the SDL.downFingers hash
            // because the finger is no longer down.
            for(var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              if (SDL.downFingers[touch.identifier] === true) {
                delete SDL.downFingers[touch.identifier];
              }
            }

            var mouseEvent = {
              type: 'mouseup',
              button: 0,
              pageX: event.changedTouches[0].clientX,
              pageY: event.changedTouches[0].clientY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(mouseEvent);

            for (var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              SDL.events.push({
                type: 'touchend',
                touch: touch
              });
            };
            break;
          }
          case 'DOMMouseScroll': case 'mousewheel': case 'wheel':
            var delta = -Browser.getMouseWheelDelta(event); // Flip the wheel direction to translate from browser wheel direction (+:down) to SDL direction (+:up)
            delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.

            // Simulate old-style SDL events representing mouse wheel input as buttons
            var button = delta > 0 ? 3 /*SDL_BUTTON_WHEELUP-1*/ : 4 /*SDL_BUTTON_WHEELDOWN-1*/; // Subtract one since JS->C marshalling is defined to add one back.
            SDL.events.push({ type: 'mousedown', button: button, pageX: event.pageX, pageY: event.pageY });
            SDL.events.push({ type: 'mouseup', button: button, pageX: event.pageX, pageY: event.pageY });

            // Pass a delta motion event.
            SDL.events.push({ type: 'wheel', deltaX: 0, deltaY: delta });
            event.preventDefault(); // If we don't prevent this, then 'wheel' event will be sent again by the browser as 'DOMMouseScroll' and we will receive this same event the second time.
            break;
          case 'mousemove':
            if (SDL.DOMButtons[0] === 1) {
              SDL.events.push({
                type: 'touchmove',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            }
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup':
            // If we preventDefault on keydown events, the subsequent keypress events
            // won't fire. However, it's fine (and in some cases necessary) to
            // preventDefault for keys that don't generate a character. Otherwise,
            // preventDefault is the right thing to do in general.
            if (event.type !== 'keydown' || (!SDL.unicode && !SDL.textInput) || (event.keyCode === 8 /* backspace */ || event.keyCode === 9 /* tab */)) {
              event.preventDefault();
            }

            if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
              SDL.events.push({
                type: 'touchstart',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                return;
              }

              SDL.events.push({
                type: 'touchend',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
              SDL.DOMButtons[event.button] = 0;
            }

            // We can only request fullscreen as the result of user input.
            // Due to this limitation, we toggle a boolean on keydown which
            // SDL_WM_ToggleFullScreen will check and subsequently set another
            // flag indicating for us to request fullscreen on the following
            // keyup. This isn't perfect, but it enables SDL_WM_ToggleFullScreen
            // to work as the result of a keypress (which is an extremely
            // common use case).
            if (event.type === 'keydown' || event.type === 'mousedown') {
              SDL.canRequestFullscreen = true;
            } else if (event.type === 'keyup' || event.type === 'mouseup') {
              if (SDL.isRequestingFullscreen) {
                Module['requestFullscreen'](/*lockPointer=*/true, /*resizeCanvas=*/true);
                SDL.isRequestingFullscreen = false;
              }
              SDL.canRequestFullscreen = false;
            }

            // SDL expects a unicode character to be passed to its keydown events.
            // Unfortunately, the browser APIs only provide a charCode property on
            // keypress events, so we must backfill in keydown events with their
            // subsequent keypress event's charCode.
            if (event.type === 'keypress' && SDL.savedKeydown) {
              // charCode is read-only
              SDL.savedKeydown.keypressCharCode = event.charCode;
              SDL.savedKeydown = null;
            } else if (event.type === 'keydown') {
              SDL.savedKeydown = event;
            }

            // Don't push keypress events unless SDL_StartTextInput has been called.
            if (event.type !== 'keypress' || SDL.textInput) {
              SDL.events.push(event);
            }
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            event.preventDefault();
            break;
          case 'focus':
            SDL.events.push(event);
            event.preventDefault();
            break;
          case 'blur':
            SDL.events.push(event);
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'visibilitychange':
            SDL.events.push({
              type: 'visibilitychange',
              visible: !document.hidden
            });
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            // manually triggered resize event doesn't have a preventDefault member
            if (event.preventDefault) {
              event.preventDefault();
            }
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // If we have a handler installed, this will push the events to the app
        // instead of the app polling for them.
        SDL.flushEventsToHandler();
        return;
      },lookupKeyCodeForEvent:function (event) {
          var code = event.keyCode;
          if (code >= 65 && code <= 90) {
            code += 32; // make lowercase for SDL
          } else {
            code = SDL.keyCodes[event.keyCode] || event.keyCode;
            // If this is one of the modifier keys (224 | 1<<10 - 227 | 1<<10), and the event specifies that it is
            // a right key, add 4 to get the right key SDL key code.
            if (event.location === KeyboardEvent.DOM_KEY_LOCATION_RIGHT && code >= (224 | 1<<10) && code <= (227 | 1<<10)) {
              code += 4;
            }
          }
          return code;
      },handleEvent:function (event) {
        if (event.handled) return;
        event.handled = true;

        switch (event.type) {
          case 'touchstart': case 'touchend': case 'touchmove': {
            Browser.calculateMouseEvent(event);
            break;
          }
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            var code = SDL.lookupKeyCodeForEvent(event);
            HEAP8[(((SDL.keyboardState)+(code))>>0)]=down;
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))>>0)] ? 0x0040 : 0) | // KMOD_LCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))>>0)] ? 0x0001 : 0) | // KMOD_LSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))>>0)] ? 0x0100 : 0) | // KMOD_LALT
              (HEAP8[(((SDL.keyboardState)+(1252))>>0)] ? 0x0080 : 0) | // KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1253))>>0)] ? 0x0002 : 0) | // KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1254))>>0)] ? 0x0200 : 0); //  KMOD_RALT
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }

            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            break;
          }
        }
      },flushEventsToHandler:function () {
        if (!SDL.eventHandler) return;

        while (SDL.pollEvent(SDL.eventHandlerTemp)) {
          Module['dynCall_iii'](SDL.eventHandler, SDL.eventHandlerContext, SDL.eventHandlerTemp);
        }
      },pollEvent:function (ptr) {
        if (SDL.initFlags & 0x200 && SDL.joystickEventState) {
          // If SDL_INIT_JOYSTICK was supplied AND the joystick system is configured
          // to automatically query for events, query for joystick events.
          SDL.queryJoysticks();
        }
        if (ptr) {
          while (SDL.events.length > 0) {
            if (SDL.makeCEvent(SDL.events.shift(), ptr) !== false) return 1;
          }
          return 0;
        } else {
          // XXX: somewhat risky in that we do not check if the event is real or not (makeCEvent returns false) if no pointer supplied
          return SDL.events.length > 0;
        }
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a copy of a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, 28);
          _free(event); // the copy is no longer needed
          return;
        }

        SDL.handleEvent(event);

        switch (event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = SDL.lookupKeyCodeForEvent(event);
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }

            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(8))>>0)]=down ? 1 : 0;
            HEAP8[(((ptr)+(9))>>0)]=0; // TODO
            HEAP32[(((ptr)+(12))>>2)]=scan;
            HEAP32[(((ptr)+(16))>>2)]=key;
            HEAP16[(((ptr)+(20))>>1)]=SDL.modState;
            // some non-character keys (e.g. backspace and tab) won't have keypressCharCode set, fill in with the keyCode.
            HEAP32[(((ptr)+(24))>>2)]=event.keypressCharCode || key;

            break;
          }
          case 'keypress': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(8 + i))>>0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup': case 'mousemove': {
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP8[(((ptr)+(16))>>0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(17))>>0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
            } else {
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP32[(((ptr)+(16))>>2)]=SDL.buttonState;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(28))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(32))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'wheel': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(16))>>2)]=event.deltaX;
            HEAP32[(((ptr)+(20))>>2)]=event.deltaY;
            break;
          }
          case 'touchstart': case 'touchend': case 'touchmove': {
            var touch = event.touch;
            if (!Browser.touches[touch.identifier]) break;
            var w = Module['canvas'].width;
            var h = Module['canvas'].height;
            var x = Browser.touches[touch.identifier].x / w;
            var y = Browser.touches[touch.identifier].y / h;
            var lx = Browser.lastTouches[touch.identifier].x / w;
            var ly = Browser.lastTouches[touch.identifier].y / h;
            var dx = x - lx;
            var dy = y - ly;
            if (touch['deviceID'] === undefined) touch.deviceID = SDL.TOUCH_DEFAULT_ID;
            if (dx === 0 && dy === 0 && event.type === 'touchmove') return false; // don't send these if nothing happened
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=_SDL_GetTicks();
            (tempI64 = [touch.deviceID>>>0,(tempDouble=touch.deviceID,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[(((ptr)+(8))>>2)]=tempI64[0],HEAP32[(((ptr)+(12))>>2)]=tempI64[1]);
            (tempI64 = [touch.identifier>>>0,(tempDouble=touch.identifier,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[(((ptr)+(16))>>2)]=tempI64[0],HEAP32[(((ptr)+(20))>>2)]=tempI64[1]);
            HEAPF32[(((ptr)+(24))>>2)]=x;
            HEAPF32[(((ptr)+(28))>>2)]=y;
            HEAPF32[(((ptr)+(32))>>2)]=dx;
            HEAPF32[(((ptr)+(36))>>2)]=dy;
            if (touch.force !== undefined) {
              HEAPF32[(((ptr)+(40))>>2)]=touch.force;
            } else { // No pressure data, send a digital 0/1 pressure.
              HEAPF32[(((ptr)+(40))>>2)]=event.type == "touchend" ? 0 : 1;
            }
            break;
          }
          case 'unload': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=event.w;
            HEAP32[(((ptr)+(8))>>2)]=event.h;
            break;
          }
          case 'joystick_button_up': case 'joystick_button_down': {
            var state = event.type === 'joystick_button_up' ? 0 : 1;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.button;
            HEAP8[(((ptr)+(6))>>0)]=state;
            break;
          }
          case 'joystick_axis_motion': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.axis;
            HEAP32[(((ptr)+(8))>>2)]=SDL.joystickAxisValueConversion(event.value);
            break;
          }
          case 'focus': {
            var SDL_WINDOWEVENT_FOCUS_GAINED = 12 /* SDL_WINDOWEVENT_FOCUS_GAINED */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_GAINED;
            break;
          }
          case 'blur': {
            var SDL_WINDOWEVENT_FOCUS_LOST = 13 /* SDL_WINDOWEVENT_FOCUS_LOST */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_LOST;
            break;
          }
          case 'visibilitychange': {
            var SDL_WINDOWEVENT_SHOWN  = 1 /* SDL_WINDOWEVENT_SHOWN */;
            var SDL_WINDOWEVENT_HIDDEN = 2 /* SDL_WINDOWEVENT_HIDDEN */;
            var visibilityEventID = event.visible ? SDL_WINDOWEVENT_SHOWN : SDL_WINDOWEVENT_HIDDEN;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=visibilityEventID;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },makeFontString:function (height, fontName) {
        if (fontName.charAt(0) != "'" && fontName.charAt(0) != '"') {
          // https://developer.mozilla.org/ru/docs/Web/CSS/font-family
          // Font family names containing whitespace should be quoted.
          // BTW, quote all font names is easier than searching spaces
          fontName = '"' + fontName + '"';
        }
        return height + 'px ' + fontName + ', serif';
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = SDL.makeFontString(h, fontData.name);
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num && num != 0) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = Math.min(Math.max(volume, 0), 128) / 128;
          if (info.audio) {
            try {
              info.audio.volume = info.volume; // For <audio> element
              if (info.audio.webAudioGainNode) info.audio.webAudioGainNode['gain']['value'] = info.volume; // For WebAudio playback
            } catch(e) {
              Module.printErr('setGetVolume failed to set audio volume: ' + e);
            }
          }
        }
        return ret;
      },setPannerPosition:function (info, x, y, z) {
        if (!info) return;
        if (info.audio) {
          if (info.audio.webAudioPannerNode) {
            info.audio.webAudioPannerNode['setPosition'](x, y, z);
          }
        }
      },playWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) return; // This instance is already playing, don't start again.
        if (!SDL.webAudioAvailable()) return;
        try {
          var webAudio = audio.resource.webAudio;
          audio.paused = false;
          if (!webAudio.decodedBuffer) {
            if (webAudio.onDecodeComplete === undefined) abort("Cannot play back audio object that was not loaded");
            webAudio.onDecodeComplete.push(function() { if (!audio.paused) SDL.playWebAudio(audio); });
            return;
          }
          audio.webAudioNode = SDL.audioContext['createBufferSource']();
          audio.webAudioNode['buffer'] = webAudio.decodedBuffer;
          audio.webAudioNode['loop'] = audio.loop;
          audio.webAudioNode['onended'] = function() { audio['onended'](); } // For <media> element compatibility, route the onended signal to the instance.

          audio.webAudioPannerNode = SDL.audioContext['createPanner']();
          // avoid Chrome bug
          // If posz = 0, the sound will come from only the right.
          // By posz = -0.5 (slightly ahead), the sound will come from right and left correctly.
          audio.webAudioPannerNode["setPosition"](0, 0, -.5);
          audio.webAudioPannerNode['panningModel'] = 'equalpower';

          // Add an intermediate gain node to control volume.
          audio.webAudioGainNode = SDL.audioContext['createGain']();
          audio.webAudioGainNode['gain']['value'] = audio.volume;

          audio.webAudioNode['connect'](audio.webAudioPannerNode);
          audio.webAudioPannerNode['connect'](audio.webAudioGainNode);
          audio.webAudioGainNode['connect'](SDL.audioContext['destination']);

          audio.webAudioNode['start'](0, audio.currentPosition);
          audio.startTime = SDL.audioContext['currentTime'] - audio.currentPosition;
        } catch(e) {
          Module.printErr('playWebAudio failed: ' + e);
        }
      },pauseWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) {
          try {
            // Remember where we left off, so that if/when we resume, we can restart the playback at a proper place.
            audio.currentPosition = (SDL.audioContext['currentTime'] - audio.startTime) % audio.resource.webAudio.decodedBuffer.duration;
            // Important: When we reach here, the audio playback is stopped by the user. But when calling .stop() below, the Web Audio
            // graph will send the onended signal, but we don't want to process that, since pausing should not clear/destroy the audio
            // channel.
            audio.webAudioNode['onended'] = undefined;
            audio.webAudioNode.stop(0); // 0 is a default parameter, but WebKit is confused by it #3861
            audio.webAudioNode = undefined;
          } catch(e) {
            Module.printErr('pauseWebAudio failed: ' + e);
          }
        }
        audio.paused = true;
      },openAudioContext:function () {
        // Initialize Web Audio API if we haven't done so yet. Note: Only initialize Web Audio context ever once on the web page,
        // since initializing multiple times fails on Chrome saying 'audio resources have been exhausted'.
        if (!SDL.audioContext) {
          if (typeof(AudioContext) !== 'undefined') SDL.audioContext = new AudioContext();
          else if (typeof(webkitAudioContext) !== 'undefined') SDL.audioContext = new webkitAudioContext();
        }
      },webAudioAvailable:function () { return !!SDL.audioContext; },fillWebAudioBufferFromHeap:function (heapPtr, sizeSamplesPerChannel, dstAudioBuffer) {
        // The input audio data is interleaved across the channels, i.e. [L, R, L, R, L, R, ...] and is either 8-bit or 16-bit as
        // supported by the SDL API. The output audio wave data for Web Audio API must be in planar buffers of [-1,1]-normalized Float32 data,
        // so perform a buffer conversion for the data.
        var numChannels = SDL.audio.channels;
        for(var c = 0; c < numChannels; ++c) {
          var channelData = dstAudioBuffer['getChannelData'](c);
          if (channelData.length != sizeSamplesPerChannel) {
            throw 'Web Audio output buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + sizeSamplesPerChannel + ' samples!';
          }
          if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              channelData[j] = (HEAP16[(((heapPtr)+((j*numChannels + c)*2))>>1)]) / 0x8000;
            }
          } else if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              var v = (HEAP8[(((heapPtr)+(j*numChannels + c))>>0)]);
              channelData[j] = ((v >= 0) ? v-128 : v+128) /128;
            }
          }
        }
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      },joystickEventState:1,lastJoystickState:{},joystickNamePool:{},recordJoystickState:function (joystick, state) {
        // Standardize button state.
        var buttons = new Array(state.buttons.length);
        for (var i = 0; i < state.buttons.length; i++) {
          buttons[i] = SDL.getJoystickButtonState(state.buttons[i]);
        }

        SDL.lastJoystickState[joystick] = {
          buttons: buttons,
          axes: state.axes.slice(0),
          timestamp: state.timestamp,
          index: state.index,
          id: state.id
        };
      },getJoystickButtonState:function (button) {
        if (typeof button === 'object') {
          // Current gamepad API editor's draft (Firefox Nightly)
          // https://dvcs.w3.org/hg/gamepad/raw-file/default/gamepad.html#idl-def-GamepadButton
          return button['pressed'];
        } else {
          // Current gamepad API working draft (Firefox / Chrome Stable)
          // http://www.w3.org/TR/2012/WD-gamepad-20120529/#gamepad-interface
          return button > 0;
        }
      },queryJoysticks:function () {
        for (var joystick in SDL.lastJoystickState) {
          var state = SDL.getGamepad(joystick - 1);
          var prevState = SDL.lastJoystickState[joystick];
          // If joystick was removed, state returns null.
          if (typeof state === 'undefined') return;
          // Check only if the timestamp has differed.
          // NOTE: Timestamp is not available in Firefox.
          if (typeof state.timestamp !== 'number' || state.timestamp !== prevState.timestamp) {
            var i;
            for (i = 0; i < state.buttons.length; i++) {
              var buttonState = SDL.getJoystickButtonState(state.buttons[i]);
              // NOTE: The previous state already has a boolean representation of
              //       its button, so no need to standardize its button state here.
              if (buttonState !== prevState.buttons[i]) {
                // Insert button-press event.
                SDL.events.push({
                  type: buttonState ? 'joystick_button_down' : 'joystick_button_up',
                  joystick: joystick,
                  index: joystick - 1,
                  button: i
                });
              }
            }
            for (i = 0; i < state.axes.length; i++) {
              if (state.axes[i] !== prevState.axes[i]) {
                // Insert axes-change event.
                SDL.events.push({
                  type: 'joystick_axis_motion',
                  joystick: joystick,
                  index: joystick - 1,
                  axis: i,
                  value: state.axes[i]
                });
              }
            }

            SDL.recordJoystickState(joystick, state);
          }
        }
      },joystickAxisValueConversion:function (value) {
        // Make sure value is properly clamped
        value = Math.min(1, Math.max(value, -1));
        // Ensures that 0 is 0, 1 is 32767, and -1 is 32768.
        return Math.ceil(((value+1) * 32767.5) - 32768);
      },getGamepads:function () {
        var fcn = navigator.getGamepads || navigator.webkitGamepads || navigator.mozGamepads || navigator.gamepads || navigator.webkitGetGamepads;
        if (fcn !== undefined) {
          // The function must be applied on the navigator object.
          return fcn.apply(navigator);
        } else {
          return [];
        }
      },getGamepad:function (deviceIndex) {
        var gamepads = SDL.getGamepads();
        if (gamepads.length > deviceIndex && deviceIndex >= 0) {
          return gamepads[deviceIndex];
        }
        return null;
      }};function _SDL_SetVideoMode(width, height, depth, flags) {
      ['touchstart', 'touchend', 'touchmove', 'mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'wheel', 'mouseout'].forEach(function(event) {
        Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
      });

      var canvas = Module['canvas'];

      // (0,0) means 'use fullscreen' in native; in Emscripten, use the current canvas size.
      if (width == 0 && height == 0) {
        width = canvas.width;
        height = canvas.height;
      }

      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          if (!SDL.settingVideoMode) {
            SDL.receiveEvent({
              type: 'resize',
              w: w,
              h: h
            });
          }
        });
      }

      if (width !== canvas.width || height !== canvas.height) {
        SDL.settingVideoMode = true; // SetVideoMode itself should not trigger resize events
        Browser.setCanvasSize(width, height);
        SDL.settingVideoMode = false;
      }

      // Free the old surface first if there is one
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        assert(!SDL.screen);
      }

      if (SDL.GL) flags = flags | 0x04000000; // SDL_OPENGL - if we are using GL, then later calls to SetVideoMode may not mention GL, but we do need it. Once in GL mode, we never leave it.

      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');

      return SDL.screen;
    }




  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC);

  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if ((ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self['performance'] && self['performance']['now']) {
        var start = self['performance']['now']();
        while (self['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  Module["_usleep"] = _usleep;

  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullscreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }

  function _SDL_UnlockSurface(surf) {
      assert(!SDL.GL); // in GL mode we do not keep around 2D canvases and contexts

      var surfData = SDL.surfaces[surf];

      if (!surfData.locked || --surfData.locked > 0) {
        return;
      }

      // Copy pixel data to image
      if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
        SDL.copyIndexedColorData(surfData);
      } else if (!surfData.colors) {
        var data = surfData.image.data;
        var buffer = surfData.buffer;
        assert(buffer % 4 == 0, 'Invalid buffer offset: ' + buffer);
        var src = buffer >> 2;
        var dst = 0;
        var isScreen = surf == SDL.screen;
        var num;
        if (typeof CanvasPixelArray !== 'undefined' && data instanceof CanvasPixelArray) {
          // IE10/IE11: ImageData objects are backed by the deprecated CanvasPixelArray,
          // not UInt8ClampedArray. These don't have buffers, so we need to revert
          // to copying a byte at a time. We do the undefined check because modern
          // browsers do not define CanvasPixelArray anymore.
          num = data.length;
          while (dst < num) {
            var val = HEAP32[src]; // This is optimized. Instead, we could do HEAP32[(((buffer)+(dst))>>2)];
            data[dst  ] = val & 0xff;
            data[dst+1] = (val >> 8) & 0xff;
            data[dst+2] = (val >> 16) & 0xff;
            data[dst+3] = isScreen ? 0xff : ((val >> 24) & 0xff);
            src++;
            dst += 4;
          }
        } else {
          var data32 = new Uint32Array(data.buffer);
          if (isScreen && SDL.defaults.opaqueFrontBuffer) {
            num = data32.length;
            // logically we need to do
            //      while (dst < num) {
            //          data32[dst++] = HEAP32[src++] | 0xff000000
            //      }
            // the following code is faster though, because
            // .set() is almost free - easily 10x faster due to
            // native memcpy efficiencies, and the remaining loop
            // just stores, not load + store, so it is faster
            data32.set(HEAP32.subarray(src, src + num));
            var data8 = new Uint8Array(data.buffer);
            var i = 3;
            var j = i + 4*num;
            if (num % 8 == 0) {
              // unrolling gives big speedups
              while (i < j) {
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
                data8[i] = 0xff;
                i = i + 4 | 0;
              }
             } else {
              while (i < j) {
                data8[i] = 0xff;
                i = i + 4 | 0;
              }
            }
          } else {
            data32.set(HEAP32.subarray(src, src + data32.length));
          }
        }
      } else {
        var width = Module['canvas'].width;
        var height = Module['canvas'].height;
        var s = surfData.buffer;
        var data = surfData.image.data;
        var colors = surfData.colors; // TODO: optimize using colors32
        for (var y = 0; y < height; y++) {
          var base = y*width*4;
          for (var x = 0; x < width; x++) {
            // See comment above about signs
            var val = HEAPU8[((s++)>>0)] * 4;
            var start = base + x*4;
            data[start]   = colors[val];
            data[start+1] = colors[val+1];
            data[start+2] = colors[val+2];
          }
          s += width*3;
        }
      }
      // Copy to canvas
      surfData.ctx.putImageData(surfData.image, 0, 0);
      // Note that we save the image, so future writes are fast. But, memory is not yet released
    }

  function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5*Runtime.QUANTUM_SIZE);
      HEAP32[((ret+Runtime.QUANTUM_SIZE*0)>>2)]=0; // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*1)>>2)]=0; // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*2)>>2)]=0;
      HEAP32[((ret+Runtime.QUANTUM_SIZE*3)>>2)]=Module["canvas"].width;
      HEAP32[((ret+Runtime.QUANTUM_SIZE*4)>>2)]=Module["canvas"].height;
      return ret;
    }

  function _sem_init() {}

  function ___syscall54(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ioctl
      var stream = SYSCALLS.getStreamFromFD(), op = SYSCALLS.get();
      switch (op) {
        case 21505: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        case 21506: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0; // no-op, not actually adjusting terminal settings
        }
        case 21519: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          var argp = SYSCALLS.get();
          HEAP32[((argp)>>2)]=0;
          return 0;
        }
        case 21520: {
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return -ERRNO_CODES.EINVAL; // not supported
        }
        case 21531: {
          var argp = SYSCALLS.get();
          return FS.ioctl(stream, op, argp);
        }
        case 21523: {
          // TODO: in theory we should write to the winsize struct that gets
          // passed in, but for now musl doesn't read anything on it
          if (!stream.tty) return -ERRNO_CODES.ENOTTY;
          return 0;
        }
        default: abort('bad ioctl syscall ' + op);
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


  var ___tm_current=STATICTOP; STATICTOP += 48;;


  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();

      var start = new Date(date.getFullYear(), 0, 1);
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=-(date.getTimezoneOffset() * 60);

      // DST is in December in South
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dst = (date.getTimezoneOffset() == Math.min(winterOffset, summerOffset))|0;
      HEAP32[(((tmPtr)+(32))>>2)]=dst;

      var zonePtr = HEAP32[(((_tzname)+(dst ? Runtime.QUANTUM_SIZE : 0))>>2)];
      HEAP32[(((tmPtr)+(40))>>2)]=zonePtr;

      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }



  function ___syscall38(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // rename
      var old_path = SYSCALLS.getStr(), new_path = SYSCALLS.getStr();
      FS.rename(old_path, new_path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


  function _llvm_exp2_f32(x) {
      return Math.pow(2, x);
    }function _llvm_exp2_f64() {
  return _llvm_exp2_f32.apply(null, arguments)
  }

  function ___syscall33(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // access
      var path = SYSCALLS.getStr(), amode = SYSCALLS.get();
      return SYSCALLS.doAccess(path, amode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }


  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((ptr)+(4))>>2)]=((now % 1000)*1000)|0; // microseconds
      return 0;
    }

  function _SDL_PumpEvents(){
      SDL.events.forEach(function(event) {
        SDL.handleEvent(event);
      });
    }

  function _SDL_WM_SetCaption(title, icon) {
      if (title && typeof Module['setWindowTitle'] !== 'undefined') {
        Module['setWindowTitle'](Pointer_stringify(title));
      }
      icon = icon && Pointer_stringify(icon);
    }


  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    }

  function _SDL_mutexV() { return 0 }

  function _SDL_mutexP() { return 0 }

  var _llvm_pow_f64=Math_pow;







  function ___syscall122(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // uname
      var buf = SYSCALLS.get();
      if (!buf) return -ERRNO_CODES.EFAULT
      var layout = {"sysname":0,"nodename":65,"domainname":325,"machine":260,"version":195,"release":130,"__size__":390};
      function copyString(element, value) {
        var offset = layout[element];
        writeAsciiToMemory(value, buf + offset);
      }
      copyString('sysname', 'Emscripten');
      copyString('nodename', 'emscripten');
      copyString('release', '1.0');
      copyString('version', '#1');
      copyString('machine', 'x86-JS');
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }



  function ___syscall40(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // rmdir
      var path = SYSCALLS.getStr();
      FS.rmdir(path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function _SDL_QuitSubSystem(flags) {
      Module.print('SDL_QuitSubSystem called (and ignored)');
    }

  function ___assert_fail(condition, filename, line, func) {
      ABORT = true;
      throw 'Assertion failed: ' + Pointer_stringify(condition) + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + stackTrace();
    }

  function _SDL_MapRGB(fmt, r, g, b) {
      SDL.checkPixelFormat(fmt);
      // We assume the machine is little-endian.
      return r&0xff|(g&0xff)<<8|(b&0xff)<<16|0xff000000;
    }



  function ___syscall39(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // mkdir
      var path = SYSCALLS.getStr(), mode = SYSCALLS.get();
      return SYSCALLS.doMkdir(path, mode);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }



  function _abort() {
      Module['abort']();
    }



  function ___lock() {}

  function ___unlock() {}

  function _SDL_VideoModeOK(width, height, depth, flags) {
      // SDL_VideoModeOK returns 0 if the requested mode is not supported under any bit depth, or returns the
      // bits-per-pixel of the closest available mode with the given width, height and requested surface flags
      return depth; // all modes are ok.
    }

  var _emscripten_asm_const_int=true;


  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  function _SDL_UpdateRect(surf, x, y, w, h) {
      // We actually do the whole screen in Unlock...
    }

  function ___cxa_pure_virtual() {
      ABORT = true;
      throw 'Pure virtual function called!';
    }

  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }

  function _sem_destroy() {}

  function _SDL_VideoDriverName(buf, max_size) {
      if (SDL.startTime === null) {
        return 0; //return NULL
      }
      //driverName - emscripten_sdl_driver
      var driverName = [101, 109, 115, 99, 114, 105, 112, 116, 101,
        110, 95, 115, 100, 108, 95, 100, 114, 105, 118, 101, 114];

      var index = 0;
      var size  = driverName.length;

      if (max_size <= size) {
        size = max_size - 1; //-1 cause null-terminator
      }

      while (index < size) {
          var value = driverName[index];
          HEAP8[(((buf)+(index))>>0)]=value;
          index++;
      }

      HEAP8[(((buf)+(index))>>0)]=0;
      return buf;
    }

  function ___syscall10(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // unlink
      var path = SYSCALLS.getStr();
      FS.unlink(path);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }



  function __inet_pton4_raw(str) {
      var b = str.split('.');
      for (var i = 0; i < 4; i++) {
        var tmp = Number(b[i]);
        if (isNaN(tmp)) return null;
        b[i] = tmp;
      }
      return (b[0] | (b[1] << 8) | (b[2] << 16) | (b[3] << 24)) >>> 0;
    }

  function __inet_pton6_raw(str) {
      var words;
      var w, offset, z, i;
      /* http://home.deds.nl/~aeron/regex/ */
      var valid6regx = /^((?=.*::)(?!.*::.+::)(::)?([\dA-F]{1,4}:(:|\b)|){5}|([\dA-F]{1,4}:){6})((([\dA-F]{1,4}((?!\3)::|:\b|$))|(?!\2\3)){2}|(((2[0-4]|1\d|[1-9])?\d|25[0-5])\.?\b){4})$/i
      var parts = [];
      if (!valid6regx.test(str)) {
        return null;
      }
      if (str === "::") {
        return [0, 0, 0, 0, 0, 0, 0, 0];
      }
      // Z placeholder to keep track of zeros when splitting the string on ":"
      if (str.indexOf("::") === 0) {
        str = str.replace("::", "Z:"); // leading zeros case
      } else {
        str = str.replace("::", ":Z:");
      }

      if (str.indexOf(".") > 0) {
        // parse IPv4 embedded stress
        str = str.replace(new RegExp('[.]', 'g'), ":");
        words = str.split(":");
        words[words.length-4] = parseInt(words[words.length-4]) + parseInt(words[words.length-3])*256;
        words[words.length-3] = parseInt(words[words.length-2]) + parseInt(words[words.length-1])*256;
        words = words.slice(0, words.length-2);
      } else {
        words = str.split(":");
      }

      offset = 0; z = 0;
      for (w=0; w < words.length; w++) {
        if (typeof words[w] === 'string') {
          if (words[w] === 'Z') {
            // compressed zeros - write appropriate number of zero words
            for (z = 0; z < (8 - words.length+1); z++) {
              parts[w+z] = 0;
            }
            offset = z-1;
          } else {
            // parse hex to field to 16-bit value and write it in network byte-order
            parts[w+offset] = _htons(parseInt(words[w],16));
          }
        } else {
          // parsed IPv4 words
          parts[w+offset] = words[w];
        }
      }
      return [
        (parts[1] << 16) | parts[0],
        (parts[3] << 16) | parts[2],
        (parts[5] << 16) | parts[4],
        (parts[7] << 16) | parts[6]
      ];
    }var DNS={address_map:{id:1,addrs:{},names:{}},lookup_name:function (name) {
        // If the name is already a valid ipv4 / ipv6 address, don't generate a fake one.
        var res = __inet_pton4_raw(name);
        if (res !== null) {
          return name;
        }
        res = __inet_pton6_raw(name);
        if (res !== null) {
          return name;
        }

        // See if this name is already mapped.
        var addr;

        if (DNS.address_map.addrs[name]) {
          addr = DNS.address_map.addrs[name];
        } else {
          var id = DNS.address_map.id++;
          assert(id < 65535, 'exceeded max address mappings of 65535');

          addr = '172.29.' + (id & 0xff) + '.' + (id & 0xff00);

          DNS.address_map.names[addr] = name;
          DNS.address_map.addrs[name] = addr;
        }

        return addr;
      },lookup_addr:function (addr) {
        if (DNS.address_map.names[addr]) {
          return DNS.address_map.names[addr];
        }

        return null;
      }};function _gethostbyname(name) {
      name = Pointer_stringify(name);

      // generate hostent
      var ret = _malloc(20); // XXX possibly leaked, as are others here
      var nameBuf = _malloc(name.length+1);
      stringToUTF8(name, nameBuf, name.length+1);
      HEAP32[((ret)>>2)]=nameBuf;
      var aliasesBuf = _malloc(4);
      HEAP32[((aliasesBuf)>>2)]=0;
      HEAP32[(((ret)+(4))>>2)]=aliasesBuf;
      var afinet = 2;
      HEAP32[(((ret)+(8))>>2)]=afinet;
      HEAP32[(((ret)+(12))>>2)]=4;
      var addrListBuf = _malloc(12);
      HEAP32[((addrListBuf)>>2)]=addrListBuf+8;
      HEAP32[(((addrListBuf)+(4))>>2)]=0;
      HEAP32[(((addrListBuf)+(8))>>2)]=__inet_pton4_raw(DNS.lookup_name(name));
      HEAP32[(((ret)+(16))>>2)]=addrListBuf;
      return ret;
    }

  function _SDL_WM_GrabInput() {}

  function ___syscall3(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // read
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get();
      return FS.read(stream, HEAP8,buf, count);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall5(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // open
      var pathname = SYSCALLS.getStr(), flags = SYSCALLS.get(), mode = SYSCALLS.get() // optional TODO
      var stream = FS.open(pathname, flags, mode);
      return stream.fd;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall4(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // write
      var stream = SYSCALLS.getStreamFromFD(), buf = SYSCALLS.get(), count = SYSCALLS.get();
      return FS.write(stream, HEAP8,buf, count);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall6(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // close
      var stream = SYSCALLS.getStreamFromFD();
      FS.close(stream);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }







  var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] &&
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};

        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };

        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };

        // If debug is enabled register simple default logging callbacks for each Event.

        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }

        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };

        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;

        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });

        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;

        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;

          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }

          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));

              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');

              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }

              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }

              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'

              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }

              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);

              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;

              // If node we use the ws library.
              var WebSocketConstructor;
              if (ENVIRONMENT_IS_NODE) {
                WebSocketConstructor = require('ws');
              } else if (ENVIRONMENT_IS_WEB) {
                WebSocketConstructor = window['WebSocket'];
              } else {
                WebSocketConstructor = WebSocket;
              }
              ws = new WebSocketConstructor(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }


          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };

          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);

          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }

          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;

          var handleOpen = function () {

            Module['websocket'].emit('open', sock.stream.fd);

            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };

          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer

            // An empty ArrayBuffer will emit a pseudo disconnect event
            // as recv/recvmsg will return zero which indicates that a socket
            // has performed a shutdown although the connection has not been disconnected yet.
            if (data.byteLength == 0) {
              return;
            }
            data = new Uint8Array(data);  // make a typed array view on the array buffer


            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }

            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };

          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g.
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }

          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;

          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }

          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }

          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }

          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port;
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }

          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }

          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }

          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;

          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.

          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);

              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;

              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g.
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }

          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);

          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }

          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }

          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }

          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }

          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);

              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }

          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };


          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }

          return res;
        }}};


  var Sockets={BUFFER_SIZE:10240,MAX_BUFFER_SIZE:10485760,nextFd:1,fds:{},nextport:1,maxport:65535,peer:null,connections:{},portmap:{},localAddr:4261412874,addrPool:[33554442,50331658,67108874,83886090,100663306,117440522,134217738,150994954,167772170,184549386,201326602,218103818,234881034]};

  function __inet_ntop4_raw(addr) {
      return (addr & 0xff) + '.' + ((addr >> 8) & 0xff) + '.' + ((addr >> 16) & 0xff) + '.' + ((addr >> 24) & 0xff)
    }

  function __inet_ntop6_raw(ints) {
      //  ref:  http://www.ietf.org/rfc/rfc2373.txt - section 2.5.4
      //  Format for IPv4 compatible and mapped  128-bit IPv6 Addresses
      //  128-bits are split into eight 16-bit words
      //  stored in network byte order (big-endian)
      //  |                80 bits               | 16 |      32 bits        |
      //  +-----------------------------------------------------------------+
      //  |               10 bytes               |  2 |      4 bytes        |
      //  +--------------------------------------+--------------------------+
      //  +               5 words                |  1 |      2 words        |
      //  +--------------------------------------+--------------------------+
      //  |0000..............................0000|0000|    IPv4 ADDRESS     | (compatible)
      //  +--------------------------------------+----+---------------------+
      //  |0000..............................0000|FFFF|    IPv4 ADDRESS     | (mapped)
      //  +--------------------------------------+----+---------------------+
      var str = "";
      var word = 0;
      var longest = 0;
      var lastzero = 0;
      var zstart = 0;
      var len = 0;
      var i = 0;
      var parts = [
        ints[0] & 0xffff,
        (ints[0] >> 16),
        ints[1] & 0xffff,
        (ints[1] >> 16),
        ints[2] & 0xffff,
        (ints[2] >> 16),
        ints[3] & 0xffff,
        (ints[3] >> 16)
      ];

      // Handle IPv4-compatible, IPv4-mapped, loopback and any/unspecified addresses

      var hasipv4 = true;
      var v4part = "";
      // check if the 10 high-order bytes are all zeros (first 5 words)
      for (i = 0; i < 5; i++) {
        if (parts[i] !== 0) { hasipv4 = false; break; }
      }

      if (hasipv4) {
        // low-order 32-bits store an IPv4 address (bytes 13 to 16) (last 2 words)
        v4part = __inet_ntop4_raw(parts[6] | (parts[7] << 16));
        // IPv4-mapped IPv6 address if 16-bit value (bytes 11 and 12) == 0xFFFF (6th word)
        if (parts[5] === -1) {
          str = "::ffff:";
          str += v4part;
          return str;
        }
        // IPv4-compatible IPv6 address if 16-bit value (bytes 11 and 12) == 0x0000 (6th word)
        if (parts[5] === 0) {
          str = "::";
          //special case IPv6 addresses
          if(v4part === "0.0.0.0") v4part = ""; // any/unspecified address
          if(v4part === "0.0.0.1") v4part = "1";// loopback address
          str += v4part;
          return str;
        }
      }

      // Handle all other IPv6 addresses

      // first run to find the longest contiguous zero words
      for (word = 0; word < 8; word++) {
        if (parts[word] === 0) {
          if (word - lastzero > 1) {
            len = 0;
          }
          lastzero = word;
          len++;
        }
        if (len > longest) {
          longest = len;
          zstart = word - longest + 1;
        }
      }

      for (word = 0; word < 8; word++) {
        if (longest > 1) {
          // compress contiguous zeros - to produce "::"
          if (parts[word] === 0 && word >= zstart && word < (zstart + longest) ) {
            if (word === zstart) {
              str += ":";
              if (zstart === 0) str += ":"; //leading zeros case
            }
            continue;
          }
        }
        // converts 16-bit words from big-endian to little-endian before converting to hex string
        str += Number(_ntohs(parts[word] & 0xffff)).toString(16);
        str += word < 7 ? ":" : "";
      }
      return str;
    }function __read_sockaddr(sa, salen) {
      // family / port offsets are common to both sockaddr_in and sockaddr_in6
      var family = HEAP16[((sa)>>1)];
      var port = _ntohs(HEAP16[(((sa)+(2))>>1)]);
      var addr;

      switch (family) {
        case 2:
          if (salen !== 16) {
            return { errno: ERRNO_CODES.EINVAL };
          }
          addr = HEAP32[(((sa)+(4))>>2)];
          addr = __inet_ntop4_raw(addr);
          break;
        case 10:
          if (salen !== 28) {
            return { errno: ERRNO_CODES.EINVAL };
          }
          addr = [
            HEAP32[(((sa)+(8))>>2)],
            HEAP32[(((sa)+(12))>>2)],
            HEAP32[(((sa)+(16))>>2)],
            HEAP32[(((sa)+(20))>>2)]
          ];
          addr = __inet_ntop6_raw(addr);
          break;
        default:
          return { errno: ERRNO_CODES.EAFNOSUPPORT };
      }

      return { family: family, addr: addr, port: port };
    }

  function __write_sockaddr(sa, family, addr, port) {
      switch (family) {
        case 2:
          addr = __inet_pton4_raw(addr);
          HEAP16[((sa)>>1)]=family;
          HEAP32[(((sa)+(4))>>2)]=addr;
          HEAP16[(((sa)+(2))>>1)]=_htons(port);
          break;
        case 10:
          addr = __inet_pton6_raw(addr);
          HEAP32[((sa)>>2)]=family;
          HEAP32[(((sa)+(8))>>2)]=addr[0];
          HEAP32[(((sa)+(12))>>2)]=addr[1];
          HEAP32[(((sa)+(16))>>2)]=addr[2];
          HEAP32[(((sa)+(20))>>2)]=addr[3];
          HEAP16[(((sa)+(2))>>1)]=_htons(port);
          HEAP32[(((sa)+(4))>>2)]=0;
          HEAP32[(((sa)+(24))>>2)]=0;
          break;
        default:
          return { errno: ERRNO_CODES.EAFNOSUPPORT };
      }
      // kind of lame, but let's match _read_sockaddr's interface
      return {};
    }function ___syscall102(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // socketcall
      var call = SYSCALLS.get(), socketvararg = SYSCALLS.get();
      // socketcalls pass the rest of the arguments in a struct
      SYSCALLS.varargs = socketvararg;
      switch (call) {
        case 1: { // socket
          var domain = SYSCALLS.get(), type = SYSCALLS.get(), protocol = SYSCALLS.get();
          var sock = SOCKFS.createSocket(domain, type, protocol);
          assert(sock.stream.fd < 64); // XXX ? select() assumes socket fd values are in 0..63
          return sock.stream.fd;
        }
        case 2: { // bind
          var sock = SYSCALLS.getSocketFromFD(), info = SYSCALLS.getSocketAddress();
          sock.sock_ops.bind(sock, info.addr, info.port);
          return 0;
        }
        case 3: { // connect
          var sock = SYSCALLS.getSocketFromFD(), info = SYSCALLS.getSocketAddress();
          sock.sock_ops.connect(sock, info.addr, info.port);
          return 0;
        }
        case 4: { // listen
          var sock = SYSCALLS.getSocketFromFD(), backlog = SYSCALLS.get();
          sock.sock_ops.listen(sock, backlog);
          return 0;
        }
        case 5: { // accept
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          var newsock = sock.sock_ops.accept(sock);
          if (addr) {
            var res = __write_sockaddr(addr, newsock.family, DNS.lookup_name(newsock.daddr), newsock.dport);
            assert(!res.errno);
          }
          return newsock.stream.fd;
        }
        case 6: { // getsockname
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          // TODO: sock.saddr should never be undefined, see TODO in websocket_sock_ops.getname
          var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(sock.saddr || '0.0.0.0'), sock.sport);
          assert(!res.errno);
          return 0;
        }
        case 7: { // getpeername
          var sock = SYSCALLS.getSocketFromFD(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          if (!sock.daddr) {
            return -ERRNO_CODES.ENOTCONN; // The socket is not connected.
          }
          var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(sock.daddr), sock.dport);
          assert(!res.errno);
          return 0;
        }
        case 11: { // sendto
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), length = SYSCALLS.get(), flags = SYSCALLS.get(), dest = SYSCALLS.getSocketAddress(true);
          if (!dest) {
            // send, no address provided
            return FS.write(sock.stream, HEAP8,message, length);
          } else {
            // sendto an address
            return sock.sock_ops.sendmsg(sock, HEAP8,message, length, dest.addr, dest.port);
          }
        }
        case 12: { // recvfrom
          var sock = SYSCALLS.getSocketFromFD(), buf = SYSCALLS.get(), len = SYSCALLS.get(), flags = SYSCALLS.get(), addr = SYSCALLS.get(), addrlen = SYSCALLS.get();
          var msg = sock.sock_ops.recvmsg(sock, len);
          if (!msg) return 0; // socket is closed
          if (addr) {
            var res = __write_sockaddr(addr, sock.family, DNS.lookup_name(msg.addr), msg.port);
            assert(!res.errno);
          }
          HEAPU8.set(msg.buffer, buf);
          return msg.buffer.byteLength;
        }
        case 14: { // setsockopt
          return -ERRNO_CODES.ENOPROTOOPT; // The option is unknown at the level indicated.
        }
        case 15: { // getsockopt
          var sock = SYSCALLS.getSocketFromFD(), level = SYSCALLS.get(), optname = SYSCALLS.get(), optval = SYSCALLS.get(), optlen = SYSCALLS.get();
          // Minimal getsockopt aimed at resolving https://github.com/kripken/emscripten/issues/2211
          // so only supports SOL_SOCKET with SO_ERROR.
          if (level === 1) {
            if (optname === 4) {
              HEAP32[((optval)>>2)]=sock.error;
              HEAP32[((optlen)>>2)]=4;
              sock.error = null; // Clear the error (The SO_ERROR option obtains and then clears this field).
              return 0;
            }
          }
          return -ERRNO_CODES.ENOPROTOOPT; // The option is unknown at the level indicated.
        }
        case 16: { // sendmsg
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), flags = SYSCALLS.get();
          var iov = HEAP32[(((message)+(8))>>2)];
          var num = HEAP32[(((message)+(12))>>2)];
          // read the address and port to send to
          var addr, port;
          var name = HEAP32[((message)>>2)];
          var namelen = HEAP32[(((message)+(4))>>2)];
          if (name) {
            var info = __read_sockaddr(name, namelen);
            if (info.errno) return -info.errno;
            port = info.port;
            addr = DNS.lookup_addr(info.addr) || info.addr;
          }
          // concatenate scatter-gather arrays into one message buffer
          var total = 0;
          for (var i = 0; i < num; i++) {
            total += HEAP32[(((iov)+((8 * i) + 4))>>2)];
          }
          var view = new Uint8Array(total);
          var offset = 0;
          for (var i = 0; i < num; i++) {
            var iovbase = HEAP32[(((iov)+((8 * i) + 0))>>2)];
            var iovlen = HEAP32[(((iov)+((8 * i) + 4))>>2)];
            for (var j = 0; j < iovlen; j++) {
              view[offset++] = HEAP8[(((iovbase)+(j))>>0)];
            }
          }
          // write the buffer
          return sock.sock_ops.sendmsg(sock, view, 0, total, addr, port);
        }
        case 17: { // recvmsg
          var sock = SYSCALLS.getSocketFromFD(), message = SYSCALLS.get(), flags = SYSCALLS.get();
          var iov = HEAP32[(((message)+(8))>>2)];
          var num = HEAP32[(((message)+(12))>>2)];
          // get the total amount of data we can read across all arrays
          var total = 0;
          for (var i = 0; i < num; i++) {
            total += HEAP32[(((iov)+((8 * i) + 4))>>2)];
          }
          // try to read total data
          var msg = sock.sock_ops.recvmsg(sock, total);
          if (!msg) return 0; // socket is closed

          // TODO honor flags:
          // MSG_OOB
          // Requests out-of-band data. The significance and semantics of out-of-band data are protocol-specific.
          // MSG_PEEK
          // Peeks at the incoming message.
          // MSG_WAITALL
          // Requests that the function block until the full amount of data requested can be returned. The function may return a smaller amount of data if a signal is caught, if the connection is terminated, if MSG_PEEK was specified, or if an error is pending for the socket.

          // write the source address out
          var name = HEAP32[((message)>>2)];
          if (name) {
            var res = __write_sockaddr(name, sock.family, DNS.lookup_name(msg.addr), msg.port);
            assert(!res.errno);
          }
          // write the buffer out to the scatter-gather arrays
          var bytesRead = 0;
          var bytesRemaining = msg.buffer.byteLength;
          for (var i = 0; bytesRemaining > 0 && i < num; i++) {
            var iovbase = HEAP32[(((iov)+((8 * i) + 0))>>2)];
            var iovlen = HEAP32[(((iov)+((8 * i) + 4))>>2)];
            if (!iovlen) {
              continue;
            }
            var length = Math.min(iovlen, bytesRemaining);
            var buf = msg.buffer.subarray(bytesRead, bytesRead + length);
            HEAPU8.set(buf, iovbase + bytesRead);
            bytesRead += length;
            bytesRemaining -= length;
          }

          // TODO set msghdr.msg_flags
          // MSG_EOR
          // End of record was received (if supported by the protocol).
          // MSG_OOB
          // Out-of-band data was received.
          // MSG_TRUNC
          // Normal data was truncated.
          // MSG_CTRUNC

          return bytesRead;
        }
        default: abort('unsupported socketcall syscall ' + call);
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }



  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function ___syscall142(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // newselect
      // readfds are supported,
      // writefds checks socket open status
      // exceptfds not supported
      // timeout is always 0 - fully async
      var nfds = SYSCALLS.get(), readfds = SYSCALLS.get(), writefds = SYSCALLS.get(), exceptfds = SYSCALLS.get(), timeout = SYSCALLS.get();

      assert(nfds <= 64, 'nfds must be less than or equal to 64');  // fd sets have 64 bits // TODO: this could be 1024 based on current musl headers
      assert(!exceptfds, 'exceptfds not supported');

      var total = 0;

      var srcReadLow = (readfds ? HEAP32[((readfds)>>2)] : 0),
          srcReadHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0);
      var srcWriteLow = (writefds ? HEAP32[((writefds)>>2)] : 0),
          srcWriteHigh = (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0);
      var srcExceptLow = (exceptfds ? HEAP32[((exceptfds)>>2)] : 0),
          srcExceptHigh = (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);

      var dstReadLow = 0,
          dstReadHigh = 0;
      var dstWriteLow = 0,
          dstWriteHigh = 0;
      var dstExceptLow = 0,
          dstExceptHigh = 0;

      var allLow = (readfds ? HEAP32[((readfds)>>2)] : 0) |
                   (writefds ? HEAP32[((writefds)>>2)] : 0) |
                   (exceptfds ? HEAP32[((exceptfds)>>2)] : 0);
      var allHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0) |
                    (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0) |
                    (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);

      function check(fd, low, high, val) {
        return (fd < 32 ? (low & val) : (high & val));
      }

      for (var fd = 0; fd < nfds; fd++) {
        var mask = 1 << (fd % 32);
        if (!(check(fd, allLow, allHigh, mask))) {
          continue;  // index isn't in the set
        }

        var stream = FS.getStream(fd);
        if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);

        var flags = SYSCALLS.DEFAULT_POLLMASK;

        if (stream.stream_ops.poll) {
          flags = stream.stream_ops.poll(stream);
        }

        if ((flags & 1) && check(fd, srcReadLow, srcReadHigh, mask)) {
          fd < 32 ? (dstReadLow = dstReadLow | mask) : (dstReadHigh = dstReadHigh | mask);
          total++;
        }
        if ((flags & 4) && check(fd, srcWriteLow, srcWriteHigh, mask)) {
          fd < 32 ? (dstWriteLow = dstWriteLow | mask) : (dstWriteHigh = dstWriteHigh | mask);
          total++;
        }
        if ((flags & 2) && check(fd, srcExceptLow, srcExceptHigh, mask)) {
          fd < 32 ? (dstExceptLow = dstExceptLow | mask) : (dstExceptHigh = dstExceptHigh | mask);
          total++;
        }
      }

      if (readfds) {
        HEAP32[((readfds)>>2)]=dstReadLow;
        HEAP32[(((readfds)+(4))>>2)]=dstReadHigh;
      }
      if (writefds) {
        HEAP32[((writefds)>>2)]=dstWriteLow;
        HEAP32[(((writefds)+(4))>>2)]=dstWriteHigh;
      }
      if (exceptfds) {
        HEAP32[((exceptfds)>>2)]=dstExceptLow;
        HEAP32[(((exceptfds)+(4))>>2)]=dstExceptHigh;
      }

      return total;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall140(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // llseek
      var stream = SYSCALLS.getStreamFromFD(), offset_high = SYSCALLS.get(), offset_low = SYSCALLS.get(), result = SYSCALLS.get(), whence = SYSCALLS.get();
      // NOTE: offset_high is unused - Emscripten's off_t is 32-bit
      var offset = offset_low;
      FS.llseek(stream, offset, whence);
      HEAP32[((result)>>2)]=stream.position;
      if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null; // reset readdir state
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall145(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // readv
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doReadv(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall146(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // writev
      var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      return SYSCALLS.doWritev(stream, iov, iovcnt);
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall221(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // fcntl64
      var stream = SYSCALLS.getStreamFromFD(), cmd = SYSCALLS.get();
      switch (cmd) {
        case 0: {
          var arg = SYSCALLS.get();
          if (arg < 0) {
            return -ERRNO_CODES.EINVAL;
          }
          var newStream;
          newStream = FS.open(stream.path, stream.flags, 0, arg);
          return newStream.fd;
        }
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4: {
          var arg = SYSCALLS.get();
          stream.flags |= arg;
          return 0;
        }
        case 12:
        case 12: {
          var arg = SYSCALLS.get();
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        }
        case 13:
        case 14:
        case 13:
        case 14:
          return 0; // Pretend that the locking is successful.
        case 16:
        case 8:
          return -ERRNO_CODES.EINVAL; // These are for sockets. We don't have them fully implemented yet.
        case 9:
          // musl trusts getown return values, due to a bug where they must be, as they overlap with errors. just return -1 here, so fnctl() returns that, and we set errno ourselves.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default: {
          return -ERRNO_CODES.EINVAL;
        }
      }
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall220(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // SYS_getdents64
      var stream = SYSCALLS.getStreamFromFD(), dirp = SYSCALLS.get(), count = SYSCALLS.get();
      if (!stream.getdents) {
        stream.getdents = FS.readdir(stream.path);
      }
      var pos = 0;
      while (stream.getdents.length > 0 && pos + 268 <= count) {
        var id;
        var type;
        var name = stream.getdents.pop();
        assert(name.length < 256); // limit of dirent struct
        if (name[0] === '.') {
          id = 1;
          type = 4; // DT_DIR
        } else {
          var child = FS.lookupNode(stream.node, name);
          id = child.id;
          type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
                 FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
                 FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
                 8;                             // DT_REG, regular file.
        }
        HEAP32[((dirp + pos)>>2)]=id;
        HEAP32[(((dirp + pos)+(4))>>2)]=stream.position;
        HEAP16[(((dirp + pos)+(8))>>1)]=268;
        HEAP8[(((dirp + pos)+(10))>>0)]=type;
        for (var i = 0; i < name.length; i++) {
          HEAP8[(((dirp + pos)+(11 + i))>>0)]=name.charCodeAt(i);
        }
        HEAP8[(((dirp + pos)+(11 + i))>>0)]=0;
        pos += 268;
      }
      return pos;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  var ___dso_handle=STATICTOP; STATICTOP += 16;;
FS.staticInit();__ATINIT__.unshift(function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() });__ATMAIN__.push(function() { FS.ignorePermissions = false });__ATEXIT__.push(function() { FS.quit() });Module["FS"]=FS;Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_stat"] = FS.stat;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;Module["FS_unlink"] = FS.unlink;;
__ATINIT__.unshift(function() { TTY.init() });__ATEXIT__.push(function() { TTY.shutdown() });;
var GLctx; GL.init();
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas, vrDevice) { Module.printErr("Module.requestFullScreen is deprecated. Please call Module.requestFullscreen instead."); Module["requestFullScreen"] = Module["requestFullscreen"]; Browser.requestFullScreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestFullscreen"] = function Module_requestFullscreen(lockPointer, resizeCanvas, vrDevice) { Browser.requestFullscreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
  Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) { return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes) };
if (ENVIRONMENT_IS_NODE) {
    _emscripten_get_now = function _emscripten_get_now_actual() {
      var t = process['hrtime']();
      return t[0] * 1e3 + t[1] / 1e6;
    };
  } else if (typeof dateNow !== 'undefined') {
    _emscripten_get_now = dateNow;
  } else if (typeof self === 'object' && self['performance'] && typeof self['performance']['now'] === 'function') {
    _emscripten_get_now = function() { return self['performance']['now'](); };
  } else if (typeof performance === 'object' && typeof performance['now'] === 'function') {
    _emscripten_get_now = function() { return performance['now'](); };
  } else {
    _emscripten_get_now = Date.now;
  };
___buildEnvironment(ENV);;
__ATINIT__.push(function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); });;
DYNAMICTOP_PTR = allocate(1, "i32", ALLOC_STATIC);

STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = Runtime.alignMemory(STACK_MAX);

HEAP32[DYNAMICTOP_PTR>>2] = DYNAMIC_BASE;

staticSealed = true; // seal the static portion of memory


function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    Module["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };

Module.asmLibraryArg = { "abort": abort, "assert": assert, "enlargeMemory": enlargeMemory, "getTotalMemory": getTotalMemory, "abortOnCannotGrowMemory": abortOnCannotGrowMemory, "invoke_iiii": invoke_iiii, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_ii": invoke_ii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_viiiiii": invoke_viiiiii, "invoke_iii": invoke_iii, "invoke_viiii": invoke_viiii, "___syscall221": ___syscall221, "___syscall220": ___syscall220, "__inet_ntop6_raw": __inet_ntop6_raw, "_SDL_RWFromFile": _SDL_RWFromFile, "___assert_fail": ___assert_fail, "_emscripten_asm_const_ii": _emscripten_asm_const_ii, "_llvm_exp2_f64": _llvm_exp2_f64, "_SDL_ShowCursor": _SDL_ShowCursor, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "_SDL_FreeSurface": _SDL_FreeSurface, "_Mix_PlayChannel": _Mix_PlayChannel, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_Mix_PlayMusic": _Mix_PlayMusic, "_Mix_LoadWAV_RW": _Mix_LoadWAV_RW, "__write_sockaddr": __write_sockaddr, "___cxa_atexit": ___cxa_atexit, "__exit": __exit, "_Mix_HaltMusic": _Mix_HaltMusic, "_SDL_UpdateRect": _SDL_UpdateRect, "___syscall140": ___syscall140, "___syscall142": ___syscall142, "___syscall145": ___syscall145, "___syscall146": ___syscall146, "_emscripten_asm_const_iiiii": _emscripten_asm_const_iiiii, "_SDL_QuitSubSystem": _SDL_QuitSubSystem, "___syscall122": ___syscall122, "__inet_ntop4_raw": __inet_ntop4_raw, "_SDL_GetTicks": _SDL_GetTicks, "_sem_init": _sem_init, "_SDL_VideoDriverName": _SDL_VideoDriverName, "_emscripten_asm_const_i": _emscripten_asm_const_i, "_SDL_LockSurface": _SDL_LockSurface, "___setErrNo": ___setErrNo, "_emscripten_get_now": _emscripten_get_now, "___syscall10": ___syscall10, "_SDL_MapRGB": _SDL_MapRGB, "___syscall3": ___syscall3, "___lock": ___lock, "_SDL_SetVideoMode": _SDL_SetVideoMode, "___syscall6": ___syscall6, "___syscall5": ___syscall5, "___syscall4": ___syscall4, "_time": _time, "_gettimeofday": _gettimeofday, "_SDL_UpperBlitScaled": _SDL_UpperBlitScaled, "_exit": _exit, "__inet_pton4_raw": __inet_pton4_raw, "_putenv": _putenv, "___syscall102": ___syscall102, "_llvm_pow_f64": _llvm_pow_f64, "_IMG_Load": _IMG_Load, "_TTF_FontHeight": _TTF_FontHeight, "___buildEnvironment": ___buildEnvironment, "_SDL_PumpEvents": _SDL_PumpEvents, "_localtime_r": _localtime_r, "_tzset": _tzset, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "___syscall197": ___syscall197, "___syscall195": ___syscall195, "___syscall194": ___syscall194, "_sem_wait": _sem_wait, "_TTF_RenderText_Solid": _TTF_RenderText_Solid, "_getenv": _getenv, "___syscall33": ___syscall33, "___syscall39": ___syscall39, "___syscall38": ___syscall38, "_emscripten_asm_const_iiiiii": _emscripten_asm_const_iiiiii, "_gethostbyname": _gethostbyname, "_SDL_UnlockSurface": _SDL_UnlockSurface, "_abort": _abort, "_localtime": _localtime, "___cxa_pure_virtual": ___cxa_pure_virtual, "_llvm_exp2_f32": _llvm_exp2_f32, "___syscall40": ___syscall40, "_sem_destroy": _sem_destroy, "_SDL_CloseAudio": _SDL_CloseAudio, "__inet_pton6_raw": __inet_pton6_raw, "__read_sockaddr": __read_sockaddr, "_usleep": _usleep, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "_SDL_FreeRW": _SDL_FreeRW, "_sem_post": _sem_post, "_SDL_PauseAudio": _SDL_PauseAudio, "_Mix_FreeChunk": _Mix_FreeChunk, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_IMG_Load_RW": _IMG_Load_RW, "_TTF_SizeText": _TTF_SizeText, "___syscall54": ___syscall54, "___unlock": ___unlock, "_SDL_mutexP": _SDL_mutexP, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_SDL_mutexV": _SDL_mutexV, "_emscripten_asm_const_iiii": _emscripten_asm_const_iiii, "_SDL_VideoModeOK": _SDL_VideoModeOK, "_atexit": _atexit, "_SDL_UpperBlit": _SDL_UpperBlit, "_SDL_RWFromConstMem": _SDL_RWFromConstMem, "DYNAMICTOP_PTR": DYNAMICTOP_PTR, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "cttz_i8": cttz_i8, "___dso_handle": ___dso_handle };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
'use asm';


  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);

  var DYNAMICTOP_PTR=env.DYNAMICTOP_PTR|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var cttz_i8=env.cttz_i8|0;
  var ___dso_handle=env.___dso_handle|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntS = 0, tempValue = 0, tempDouble = 0.0;
  var tempRet0 = 0;

  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_max=global.Math.max;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var enlargeMemory=env.enlargeMemory;
  var getTotalMemory=env.getTotalMemory;
  var abortOnCannotGrowMemory=env.abortOnCannotGrowMemory;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_ii=env.invoke_ii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_viiii=env.invoke_viiii;
  var ___syscall221=env.___syscall221;
  var ___syscall220=env.___syscall220;
  var __inet_ntop6_raw=env.__inet_ntop6_raw;
  var _SDL_RWFromFile=env._SDL_RWFromFile;
  var ___assert_fail=env.___assert_fail;
  var _emscripten_asm_const_ii=env._emscripten_asm_const_ii;
  var _llvm_exp2_f64=env._llvm_exp2_f64;
  var _SDL_ShowCursor=env._SDL_ShowCursor;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var _SDL_FreeSurface=env._SDL_FreeSurface;
  var _Mix_PlayChannel=env._Mix_PlayChannel;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _Mix_PlayMusic=env._Mix_PlayMusic;
  var _Mix_LoadWAV_RW=env._Mix_LoadWAV_RW;
  var __write_sockaddr=env.__write_sockaddr;
  var ___cxa_atexit=env.___cxa_atexit;
  var __exit=env.__exit;
  var _Mix_HaltMusic=env._Mix_HaltMusic;
  var _SDL_UpdateRect=env._SDL_UpdateRect;
  var ___syscall140=env.___syscall140;
  var ___syscall142=env.___syscall142;
  var ___syscall145=env.___syscall145;
  var ___syscall146=env.___syscall146;
  var _emscripten_asm_const_iiiii=env._emscripten_asm_const_iiiii;
  var _SDL_QuitSubSystem=env._SDL_QuitSubSystem;
  var ___syscall122=env.___syscall122;
  var __inet_ntop4_raw=env.__inet_ntop4_raw;
  var _SDL_GetTicks=env._SDL_GetTicks;
  var _sem_init=env._sem_init;
  var _SDL_VideoDriverName=env._SDL_VideoDriverName;
  var _emscripten_asm_const_i=env._emscripten_asm_const_i;
  var _SDL_LockSurface=env._SDL_LockSurface;
  var ___setErrNo=env.___setErrNo;
  var _emscripten_get_now=env._emscripten_get_now;
  var ___syscall10=env.___syscall10;
  var _SDL_MapRGB=env._SDL_MapRGB;
  var ___syscall3=env.___syscall3;
  var ___lock=env.___lock;
  var _SDL_SetVideoMode=env._SDL_SetVideoMode;
  var ___syscall6=env.___syscall6;
  var ___syscall5=env.___syscall5;
  var ___syscall4=env.___syscall4;
  var _time=env._time;
  var _gettimeofday=env._gettimeofday;
  var _SDL_UpperBlitScaled=env._SDL_UpperBlitScaled;
  var _exit=env._exit;
  var __inet_pton4_raw=env.__inet_pton4_raw;
  var _putenv=env._putenv;
  var ___syscall102=env.___syscall102;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _IMG_Load=env._IMG_Load;
  var _TTF_FontHeight=env._TTF_FontHeight;
  var ___buildEnvironment=env.___buildEnvironment;
  var _SDL_PumpEvents=env._SDL_PumpEvents;
  var _localtime_r=env._localtime_r;
  var _tzset=env._tzset;
  var _SDL_WM_GrabInput=env._SDL_WM_GrabInput;
  var ___syscall197=env.___syscall197;
  var ___syscall195=env.___syscall195;
  var ___syscall194=env.___syscall194;
  var _sem_wait=env._sem_wait;
  var _TTF_RenderText_Solid=env._TTF_RenderText_Solid;
  var _getenv=env._getenv;
  var ___syscall33=env.___syscall33;
  var ___syscall39=env.___syscall39;
  var ___syscall38=env.___syscall38;
  var _emscripten_asm_const_iiiiii=env._emscripten_asm_const_iiiiii;
  var _gethostbyname=env._gethostbyname;
  var _SDL_UnlockSurface=env._SDL_UnlockSurface;
  var _abort=env._abort;
  var _localtime=env._localtime;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var _llvm_exp2_f32=env._llvm_exp2_f32;
  var ___syscall40=env.___syscall40;
  var _sem_destroy=env._sem_destroy;
  var _SDL_CloseAudio=env._SDL_CloseAudio;
  var __inet_pton6_raw=env.__inet_pton6_raw;
  var __read_sockaddr=env.__read_sockaddr;
  var _usleep=env._usleep;
  var _SDL_GetVideoInfo=env._SDL_GetVideoInfo;
  var _SDL_FreeRW=env._SDL_FreeRW;
  var _sem_post=env._sem_post;
  var _SDL_PauseAudio=env._SDL_PauseAudio;
  var _Mix_FreeChunk=env._Mix_FreeChunk;
  var _SDL_WM_SetCaption=env._SDL_WM_SetCaption;
  var _IMG_Load_RW=env._IMG_Load_RW;
  var _TTF_SizeText=env._TTF_SizeText;
  var ___syscall54=env.___syscall54;
  var ___unlock=env.___unlock;
  var _SDL_mutexP=env._SDL_mutexP;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var _SDL_mutexV=env._SDL_mutexV;
  var _emscripten_asm_const_iiii=env._emscripten_asm_const_iiii;
  var _SDL_VideoModeOK=env._SDL_VideoModeOK;
  var _atexit=env._atexit;
  var _SDL_UpperBlit=env._SDL_UpperBlit;
  var _SDL_RWFromConstMem=env._SDL_RWFromConstMem;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS
function __Z8ExtFSHFSjtjjs($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$$i156 = 0, $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i140 = 0, $$0$i$i62 = 0, $$0$i$i67 = 0, $$0$i$i82 = 0, $$0$i104$i = 0, $$0$i110$i = 0, $$0$i118 = 0, $$0$i121 = 0, $$0$i153 = 0, $$0$i72 = 0, $$0$i75 = 0, $$0$i76$i = 0, $$0$i85 = 0, $$0$i92 = 0, $$010$i$i = 0, $$010$i$i131 = 0, $$0100122$i = 0, $$012$i$i = 0, $$012$i$i112 = 0, $$013$i$i = 0, $$013$i$i113 = 0, $$03440$i = 0, $$05$i108$i = 0, $$05$i74$i = 0, $$0511$pn$i$i = 0, $$0511$pn$i$i130 = 0, $$06$i$i = 0, $$06$i$i137 = 0, $$06$i$i79 = 0, $$06$i101$i = 0, $$06$i109$i = 0, $$06$i75$i = 0, $$0612$pn$i$i = 0, $$0612$pn$i$i129 = 0, $$06584$i = 0, $$066$lcssa$i = 0, $$07$i$i = 0, $$07$i$i138 = 0, $$07$i$i80 = 0, $$07$i102$i = 0, $$094$lcssa$i = 0, $$096$$i = 0, $$096$lcssa$i = 0, $$096121$i = 0, $$099$off0$i = 0, $$1$i = 0, $$1$i120 = 0, $$1$i124 = 0, $$1$i155 = 0, $$1$i158 = 0, $$1$i77 = 0, $$1$i87 = 0, $$137$i = 0, $$197$i = 0, $$2$i = 0, $$2$i101 = 0, $$2$i126 = 0, $$2$i97 = 0, $$222$i = 0, $$225$i = 0, $$298$i = 0, $$4$ph$i = 0, $$4$ph$i142 = 0, $$5$i = 0, $$5$i150 = 0, $$6$i = 0, $$6$i152 = 0, $$pn$i$i = 0, $$pn$i$i144 = 0, $$pre$i108 = 0, $$pre$phi$i110Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi28$iZ2D = 0, $$sink$i = 0, $$sink$i$i = 0, $$sink$i$i115 = 0, $1000 = 0, $1001 = 0, $1008 = 0, $1019 = 0, $103 = 0, $1034 = 0, $1040 = 0, $1046 = 0, $1052 = 0, $1060 = 0, $1065 = 0, $1070 = 0, $108 = 0, $1081 = 0, $1086 = 0, $1088 = 0, $1097 = 0, $11 = 0, $1103 = 0, $1104 = 0, $1110 = 0, $1116 = 0, $1124 = 0, $1129 = 0, $1134 = 0, $1145 = 0, $1150 = 0, $1152 = 0, $1161 = 0, $1167 = 0, $1174 = 0, $1176 = 0, $1182 = 0, $1184 = 0, $119 = 0, $1190 = 0, $1192 = 0, $1198 = 0, $1199 = 0, $12 = 0, $1213 = 0, $1224 = 0, $1230 = 0, $1233 = 0, $1239 = 0, $124 = 0, $1247 = 0, $1248 = 0, $1253 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1267 = 0, $1269 = 0, $1270 = 0, $1279 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1286 = 0, $1287 = 0, $1291 = 0, $1293 = 0, $1297 = 0, $1311 = 0, $1313 = 0, $1319 = 0, $1320 = 0, $1322 = 0, $1326 = 0, $1327 = 0, $1329 = 0, $1340 = 0, $1344 = 0, $135 = 0, $1350 = 0, $1352 = 0, $1359 = 0, $1360 = 0, $1366 = 0, $1373 = 0, $1380 = 0, $1394 = 0, $1399 = 0, $1404 = 0, $1405 = 0, $1409 = 0, $141 = 0, $1414 = 0, $1418 = 0, $1420 = 0, $1424 = 0, $1430 = 0, $1436 = 0, $1438 = 0, $1445 = 0, $1449 = 0, $1455 = 0, $1462 = 0, $1463 = 0, $1468 = 0, $1474 = 0, $1476 = 0, $148 = 0, $1481 = 0, $1482 = 0, $1485 = 0, $1490 = 0, $1495 = 0, $1500 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1520 = 0, $1524 = 0, $1529 = 0, $1530 = 0, $1535 = 0, $1537 = 0, $1544 = 0, $1550 = 0, $1551 = 0, $1557 = 0, $1558 = 0, $156 = 0, $1564 = 0, $1569 = 0, $1575 = 0, $1576 = 0, $1582 = 0, $1588 = 0, $1589 = 0, $1595 = 0, $1601 = 0, $1602 = 0, $1607 = 0, $1613 = 0, $1614 = 0, $1619 = 0, $1625 = 0, $1626 = 0, $1631 = 0, $1637 = 0, $1638 = 0, $164 = 0, $1644 = 0, $1650 = 0, $1656 = 0, $1657 = 0, $1662 = 0, $1668 = 0, $1669 = 0, $1674 = 0, $1680 = 0, $1687 = 0, $1689 = 0, $1694 = 0, $1701 = 0, $1707 = 0, $1709 = 0, $1715 = 0, $1717 = 0, $172 = 0, $1723 = 0, $1726 = 0, $1733 = 0, $1744 = 0, $1746 = 0, $1753 = 0, $1759 = 0, $1761 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $177 = 0, $1772 = 0, $1776 = 0, $1780 = 0, $1786 = 0, $1792 = 0, $1793 = 0, $18 = 0, $1801 = 0, $1809 = 0, $1816 = 0, $1817 = 0, $1820 = 0, $1821 = 0, $1827 = 0, $1837 = 0, $1839 = 0, $1842 = 0, $1848 = 0, $1854 = 0, $1860 = 0, $1862 = 0, $1868 = 0, $187 = 0, $1876 = 0, $1882 = 0, $1883 = 0, $1889 = 0, $1897 = 0, $190 = 0, $1903 = 0, $1909 = 0, $1921 = 0, $1926 = 0, $1928 = 0, $1934 = 0, $1939 = 0, $1947 = 0, $1954 = 0, $1961 = 0, $1968 = 0, $1975 = 0, $198 = 0, $1981 = 0, $1983 = 0, $1985 = 0, $1988 = 0, $199 = 0, $1993 = 0, $1994 = 0, $1998 = 0, $20 = 0, $2004 = 0, $2010 = 0, $2012 = 0, $2018 = 0, $2024 = 0, $2030 = 0, $2036 = 0, $2042 = 0, $2048 = 0, $205 = 0, $2054 = 0, $2061 = 0, $2067 = 0, $2074 = 0, $2080 = 0, $2086 = 0, $2093 = 0, $2097 = 0, $2102 = 0, $2103 = 0, $2108 = 0, $214 = 0, $217 = 0, $219 = 0, $22 = 0, $224 = 0, $232 = 0, $237 = 0, $242 = 0, $253 = 0, $258 = 0, $260 = 0, $269 = 0, $272 = 0, $278 = 0, $28 = 0, $285 = 0, $293 = 0, $301 = 0, $309 = 0, $314 = 0, $324 = 0, $327 = 0, $33 = 0, $335 = 0, $336 = 0, $342 = 0, $351 = 0, $352 = 0, $354 = 0, $361 = 0, $367 = 0, $368 = 0, $374 = 0, $38 = 0, $380 = 0, $382 = 0, $388 = 0, $394 = 0, $400 = 0, $406 = 0, $412 = 0, $418 = 0, $424 = 0, $430 = 0, $436 = 0, $44 = 0, $443 = 0, $449 = 0, $456 = 0, $458 = 0, $464 = 0, $470 = 0, $476 = 0, $482 = 0, $488 = 0, $49 = 0, $494 = 0, $5 = 0, $500 = 0, $506 = 0, $51 = 0, $513 = 0, $519 = 0, $520 = 0, $524 = 0, $528 = 0, $534 = 0, $535 = 0, $54 = 0, $540 = 0, $546 = 0, $548 = 0, $55 = 0, $554 = 0, $555 = 0, $558 = 0, $564 = 0, $572 = 0, $573 = 0, $578 = 0, $586 = 0, $594 = 0, $595 = 0, $597 = 0, $598 = 0, $6 = 0, $600 = 0, $601 = 0, $605 = 0, $611 = 0, $618 = 0, $620 = 0, $621 = 0, $623 = 0, $625 = 0, $631 = 0, $634 = 0, $641 = 0, $649 = 0, $651 = 0, $658 = 0, $66 = 0, $664 = 0, $666 = 0, $669 = 0, $670 = 0, $671 = 0, $677 = 0, $679 = 0, $685 = 0, $693 = 0, $699 = 0, $7 = 0, $702 = 0, $711 = 0, $717 = 0, $719 = 0, $725 = 0, $733 = 0, $739 = 0, $740 = 0, $746 = 0, $754 = 0, $760 = 0, $768 = 0, $774 = 0, $780 = 0, $781 = 0, $799 = 0, $8 = 0, $806 = 0, $809 = 0, $810 = 0, $815 = 0, $821 = 0, $823 = 0, $829 = 0, $83 = 0, $834 = 0, $839 = 0, $85 = 0, $850 = 0, $855 = 0, $857 = 0, $866 = 0, $876 = 0, $878 = 0, $884 = 0, $892 = 0, $90 = 0, $904 = 0, $906 = 0, $912 = 0, $917 = 0, $922 = 0, $933 = 0, $938 = 0, $940 = 0, $948 = 0, $949 = 0, $954 = 0, $959 = 0, $965 = 0, $98 = 0, $984 = 0, $990 = 0, $sext$i136 = 0, $sext$i78 = 0, $trunc = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 30229
 STACKTOP = STACKTOP + 1184 | 0; //@line 30230
 $5 = sp + 1100 | 0; //@line 30231
 $6 = sp + 1024 | 0; //@line 30232
 $7 = sp; //@line 30233
 $8 = $1 & 65535; //@line 30234
 $11 = ($8 & 512 | 0) != 0; //@line 30237
 $trunc = $8 & 61695; //@line 30238
 L1 : do {
  if ($trunc << 16 >> 16 < -24555) {
   do {
    switch ($trunc << 16 >> 16) {
    case -24576:
     {
      $12 = $2 + 48 | 0; //@line 30245
      if ($11) {
       $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 30252
      } else {
       $18 = 0; //@line 30254
      }
      $$0 = __ZL7fs_openjjjb($2, $18, $0, 0) | 0; //@line 30257
      STACKTOP = sp; //@line 30258
      return $$0 | 0; //@line 30258
     }
    case -24575:
     {
      $20 = $2 + 24 | 0; //@line 30262
      $22 = 123608 + ($20 >>> 16 << 2) | 0; //@line 30264
      HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$22 >> 2] | 0) + 4 >> 2] & 127]($20) | 0) << 16 >> 16; //@line 30271
      $28 = HEAP32[30848] | 0; //@line 30272
      HEAP32[$5 + 32 >> 2] = $28 + 306; //@line 30275
      _Execute68k($28 + 752 | 0, $5); //@line 30277
      $33 = (HEAP32[30848] | 0) + 306 | 0; //@line 30279
      $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($33 >>> 16 << 2) >> 2] >> 2] & 127]($33) | 0; //@line 30284
      if (($38 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
       $$0$i = -51; //@line 30291
      } else {
       $44 = 123608 + ($38 >>> 16 << 2) | 0; //@line 30294
       if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[$44 >> 2] >> 2] & 127]($38) | 0)) {
        $$0$i = -38; //@line 30300
       } else {
        $49 = $38 + 54 | 0; //@line 30302
        $51 = 123608 + ($49 >>> 16 << 2) | 0; //@line 30304
        $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$51 >> 2] >> 2] & 127]($49) | 0; //@line 30307
        $55 = $38 + 4 | 0; //@line 30308
        L13 : do {
         if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 2)) {
          _close($54) | 0; //@line 30319
         } else {
          $66 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$44 >> 2] >> 2] & 127]($38) | 0; //@line 30323
          $$06$i$i = HEAP32[30826] | 0; //@line 30324
          if ($$06$i$i | 0) {
           $$07$i$i = $$06$i$i; //@line 30327
           while (1) {
            if ((HEAP32[$$07$i$i + 4 >> 2] | 0) == ($66 | 0)) {
             break;
            }
            $$0$i$i = HEAP32[$$07$i$i >> 2] | 0; //@line 30335
            if (!$$0$i$i) {
             break L13;
            } else {
             $$07$i$i = $$0$i$i; //@line 30340
            }
           }
           __ZL19get_path_for_fsitemP6FSItem($$07$i$i); //@line 30343
           __Z11close_rforkPKci(657423, $54); //@line 30344
          }
         }
        } while (0);
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] & 31]($49, -1); //@line 30351
        HEAP32[$6 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$22 >> 2] | 0) + 4 >> 2] & 127]($20) | 0; //@line 30356
        _Execute68k((HEAP32[30848] | 0) + 724 | 0, $6); //@line 30359
        $$0$i = HEAP32[$6 >> 2] & 65535; //@line 30362
       }
      }
      $$0 = $$0$i; //@line 30365
      STACKTOP = sp; //@line 30366
      return $$0 | 0; //@line 30366
     }
    case -24574:
     {
      $83 = $2 + 36 | 0; //@line 30370
      $85 = 123608 + ($83 >>> 16 << 2) | 0; //@line 30372
      if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[$85 >> 2] >> 2] & 127]($83) | 0) < 0) {
       $$0 = -50; //@line 30378
       STACKTOP = sp; //@line 30379
       return $$0 | 0; //@line 30379
      }
      $90 = $2 + 24 | 0; //@line 30381
      HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($90 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($90) | 0) << 16 >> 16; //@line 30390
      $98 = HEAP32[30848] | 0; //@line 30391
      HEAP32[$5 + 32 >> 2] = $98 + 306; //@line 30394
      _Execute68k($98 + 752 | 0, $5); //@line 30396
      $103 = (HEAP32[30848] | 0) + 306 | 0; //@line 30398
      $108 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($103 >>> 16 << 2) >> 2] >> 2] & 127]($103) | 0; //@line 30403
      if (($108 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
       $$0 = -51; //@line 30410
       STACKTOP = sp; //@line 30411
       return $$0 | 0; //@line 30411
      }
      if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($108 >>> 16 << 2) >> 2] >> 2] & 127]($108) | 0)) {
       $$0 = -38; //@line 30420
       STACKTOP = sp; //@line 30421
       return $$0 | 0; //@line 30421
      }
      $119 = $108 + 54 | 0; //@line 30423
      $124 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($119 >>> 16 << 2) >> 2] >> 2] & 127]($119) | 0; //@line 30428
      if (($124 | 0) < 0) {
       $126 = $108 + 4 | 0; //@line 30431
       $135 = $2 + 40 | 0; //@line 30440
       if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($126 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($126) | 0) & 2)) {
        $$0 = -38; //@line 30442
        STACKTOP = sp; //@line 30443
        return $$0 | 0; //@line 30443
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($135 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($135, 0); //@line 30450
       $$0 = -39; //@line 30451
       STACKTOP = sp; //@line 30452
       return $$0 | 0; //@line 30452
      }
      $141 = $2 + 44 | 0; //@line 30454
      switch ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($141 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($141) | 0) & 3) {
      case 1:
       {
        $148 = $2 + 46 | 0; //@line 30465
        if ((_lseek($124, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($148 >>> 16 << 2) >> 2] >> 2] & 127]($148) | 0, 0) | 0) < 0) {
         $$0 = -40; //@line 30474
         STACKTOP = sp; //@line 30475
         return $$0 | 0; //@line 30475
        }
        break;
       }
      case 2:
       {
        $156 = $2 + 46 | 0; //@line 30480
        if ((_lseek($124, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($156 >>> 16 << 2) >> 2] >> 2] & 127]($156) | 0, 2) | 0) < 0) {
         $$0 = -40; //@line 30489
         STACKTOP = sp; //@line 30490
         return $$0 | 0; //@line 30490
        }
        break;
       }
      case 3:
       {
        $164 = $2 + 46 | 0; //@line 30495
        if ((_lseek($124, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($164 >>> 16 << 2) >> 2] >> 2] & 127]($164) | 0, 1) | 0) < 0) {
         $$0 = -40; //@line 30504
         STACKTOP = sp; //@line 30505
         return $$0 | 0; //@line 30505
        }
        break;
       }
      default:
       {}
      }
      $172 = $2 + 32 | 0; //@line 30512
      $177 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($172 >>> 16 << 2) >> 2] >> 2] & 127]($172) | 0; //@line 30517
      $187 = __Z10extfs_readiPvj($124, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($177 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($177) | 0, FUNCTION_TABLE_ii[HEAP32[HEAP32[$85 >> 2] >> 2] & 127]($83) | 0) | 0; //@line 30527
      switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
      case 0:
       {
        $$0$i$i62 = 0; //@line 30532
        break;
       }
      case 21:
      case 2:
       {
        $$0$i$i62 = -43; //@line 30536
        break;
       }
      case 1:
      case 13:
       {
        $$0$i$i62 = -54; //@line 30540
        break;
       }
      case 17:
       {
        $$0$i$i62 = -48; //@line 30544
        break;
       }
      case 39:
      case 16:
       {
        $$0$i$i62 = -47; //@line 30548
        break;
       }
      case 28:
       {
        $$0$i$i62 = -34; //@line 30552
        break;
       }
      case 30:
       {
        $$0$i$i62 = -44; //@line 30556
        break;
       }
      case 24:
       {
        $$0$i$i62 = -42; //@line 30560
        break;
       }
      case 12:
       {
        $$0$i$i62 = -108; //@line 30564
        break;
       }
      default:
       {
        $$0$i$i62 = -36; //@line 30568
       }
      }
      $190 = $2 + 40 | 0; //@line 30571
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($190 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($190, ($187 | 0) > 0 ? $187 : 0); //@line 30579
      $198 = _lseek($124, 0, 1) | 0; //@line 30580
      $199 = $108 + 16 | 0; //@line 30581
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($199 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($199, $198); //@line 30587
      $205 = $2 + 46 | 0; //@line 30588
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($205 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($205, $198); //@line 30594
      $214 = ($187 | 0) == (FUNCTION_TABLE_ii[HEAP32[HEAP32[$85 >> 2] >> 2] & 127]($83) | 0); //@line 30598
      $$0 = $214 ? 0 : ($187 | 0) < 0 ? $$0$i$i62 : -39; //@line 30602
      STACKTOP = sp; //@line 30603
      return $$0 | 0; //@line 30603
     }
    case -24573:
     {
      $217 = $2 + 36 | 0; //@line 30607
      $219 = 123608 + ($217 >>> 16 << 2) | 0; //@line 30609
      if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[$219 >> 2] >> 2] & 127]($217) | 0) < 0) {
       $$0 = -50; //@line 30615
       STACKTOP = sp; //@line 30616
       return $$0 | 0; //@line 30616
      }
      $224 = $2 + 24 | 0; //@line 30618
      HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($224 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($224) | 0) << 16 >> 16; //@line 30627
      $232 = HEAP32[30848] | 0; //@line 30628
      HEAP32[$5 + 32 >> 2] = $232 + 306; //@line 30631
      _Execute68k($232 + 752 | 0, $5); //@line 30633
      $237 = (HEAP32[30848] | 0) + 306 | 0; //@line 30635
      $242 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($237 >>> 16 << 2) >> 2] >> 2] & 127]($237) | 0; //@line 30640
      if (($242 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
       $$0 = -51; //@line 30647
       STACKTOP = sp; //@line 30648
       return $$0 | 0; //@line 30648
      }
      if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($242 >>> 16 << 2) >> 2] >> 2] & 127]($242) | 0)) {
       $$0 = -38; //@line 30657
       STACKTOP = sp; //@line 30658
       return $$0 | 0; //@line 30658
      }
      $253 = $242 + 54 | 0; //@line 30660
      $258 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($253 >>> 16 << 2) >> 2] >> 2] & 127]($253) | 0; //@line 30665
      if (($258 | 0) < 0) {
       $260 = $242 + 4 | 0; //@line 30668
       if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($260 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($260) | 0) & 2)) {
        $$0 = -38; //@line 30678
        STACKTOP = sp; //@line 30679
        return $$0 | 0; //@line 30679
       }
       $269 = $2 + 40 | 0; //@line 30681
       $272 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$219 >> 2] >> 2] & 127]($217) | 0; //@line 30684
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($269 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($269, $272); //@line 30690
       $$0 = 0; //@line 30691
       STACKTOP = sp; //@line 30692
       return $$0 | 0; //@line 30692
      }
      $278 = $2 + 44 | 0; //@line 30694
      switch ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($278 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($278) | 0) & 3) {
      case 1:
       {
        $285 = $2 + 46 | 0; //@line 30705
        if ((_lseek($258, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($285 >>> 16 << 2) >> 2] >> 2] & 127]($285) | 0, 0) | 0) < 0) {
         $$0 = -40; //@line 30714
         STACKTOP = sp; //@line 30715
         return $$0 | 0; //@line 30715
        }
        break;
       }
      case 2:
       {
        $293 = $2 + 46 | 0; //@line 30720
        if ((_lseek($258, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($293 >>> 16 << 2) >> 2] >> 2] & 127]($293) | 0, 2) | 0) < 0) {
         $$0 = -40; //@line 30729
         STACKTOP = sp; //@line 30730
         return $$0 | 0; //@line 30730
        }
        break;
       }
      case 3:
       {
        $301 = $2 + 46 | 0; //@line 30735
        if ((_lseek($258, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($301 >>> 16 << 2) >> 2] >> 2] & 127]($301) | 0, 1) | 0) < 0) {
         $$0 = -40; //@line 30744
         STACKTOP = sp; //@line 30745
         return $$0 | 0; //@line 30745
        }
        break;
       }
      default:
       {}
      }
      $309 = $2 + 32 | 0; //@line 30752
      $314 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($309 >>> 16 << 2) >> 2] >> 2] & 127]($309) | 0; //@line 30757
      $324 = __Z11extfs_writeiPvj($258, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($314 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($314) | 0, FUNCTION_TABLE_ii[HEAP32[HEAP32[$219 >> 2] >> 2] & 127]($217) | 0) | 0; //@line 30767
      switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
      case 0:
       {
        $$0$i$i67 = 0; //@line 30772
        break;
       }
      case 21:
      case 2:
       {
        $$0$i$i67 = -43; //@line 30776
        break;
       }
      case 1:
      case 13:
       {
        $$0$i$i67 = -54; //@line 30780
        break;
       }
      case 17:
       {
        $$0$i$i67 = -48; //@line 30784
        break;
       }
      case 39:
      case 16:
       {
        $$0$i$i67 = -47; //@line 30788
        break;
       }
      case 28:
       {
        $$0$i$i67 = -34; //@line 30792
        break;
       }
      case 30:
       {
        $$0$i$i67 = -44; //@line 30796
        break;
       }
      case 24:
       {
        $$0$i$i67 = -42; //@line 30800
        break;
       }
      case 12:
       {
        $$0$i$i67 = -108; //@line 30804
        break;
       }
      default:
       {
        $$0$i$i67 = -36; //@line 30808
       }
      }
      $327 = $2 + 40 | 0; //@line 30811
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($327 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($327, ($324 | 0) > 0 ? $324 : 0); //@line 30819
      $335 = _lseek($258, 0, 1) | 0; //@line 30820
      $336 = $242 + 16 | 0; //@line 30821
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($336 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($336, $335); //@line 30827
      $342 = $2 + 46 | 0; //@line 30828
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($342 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($342, $335); //@line 30834
      $351 = ($324 | 0) == (FUNCTION_TABLE_ii[HEAP32[HEAP32[$219 >> 2] >> 2] & 127]($217) | 0); //@line 30838
      $$0 = $351 ? 0 : $$0$i$i67; //@line 30840
      STACKTOP = sp; //@line 30841
      return $$0 | 0; //@line 30841
     }
    case -24569:
     {
      $352 = $2 + 18 | 0; //@line 30845
      $354 = 123608 + ($352 >>> 16 << 2) | 0; //@line 30847
      if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$354 >> 2] >> 2] & 127]($352) | 0) {
       $361 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$354 >> 2] >> 2] & 127]($352) | 0; //@line 30855
       $367 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($361 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($361) | 0; //@line 30861
       $368 = HEAP8[657390] | 0; //@line 30862
       HEAP8[$367 >> 0] = $368; //@line 30863
       if ($368 << 24 >> 24) {
        $$010$i$i = $368 << 24 >> 24; //@line 30867
        $$0511$pn$i$i = 657390; //@line 30867
        $$0612$pn$i$i = $367; //@line 30867
        do {
         $$0511$pn$i$i = $$0511$pn$i$i + 1 | 0; //@line 30869
         $$0612$pn$i$i = $$0612$pn$i$i + 1 | 0; //@line 30870
         $$010$i$i = $$010$i$i + -1 | 0; //@line 30871
         HEAP8[$$0612$pn$i$i >> 0] = HEAP8[$$0511$pn$i$i >> 0] | 0; //@line 30873
        } while (($$010$i$i | 0) != 0);
       }
      }
      $374 = $2 + 30 | 0; //@line 30883
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($374 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($374, 0); //@line 30889
      $380 = $2 + 34 | 0; //@line 30890
      $382 = __Z13TimeToMacTimel(HEAP32[30843] | 0) | 0; //@line 30892
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($380 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($380, $382); //@line 30898
      $388 = $2 + 38 | 0; //@line 30899
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($388 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($388, 0); //@line 30905
      $394 = $2 + 40 | 0; //@line 30906
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($394 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($394, 1); //@line 30912
      $400 = $2 + 42 | 0; //@line 30913
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($400 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($400, 0); //@line 30919
      $406 = $2 + 44 | 0; //@line 30920
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($406 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($406, 0); //@line 30926
      $412 = $2 + 46 | 0; //@line 30927
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($412 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($412, 65535); //@line 30933
      $418 = $2 + 48 | 0; //@line 30934
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($418 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($418, 16384); //@line 30940
      $424 = $2 + 52 | 0; //@line 30941
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($424 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($424, 16384); //@line 30947
      $430 = $2 + 56 | 0; //@line 30948
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($430 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($430, 0); //@line 30954
      $436 = $2 + 58 | 0; //@line 30955
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($436 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($436, HEAP32[383] | 0); //@line 30962
      $443 = $2 + 62 | 0; //@line 30963
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($443 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($443, 65535); //@line 30969
      if (!$11) {
       $$0 = 0; //@line 30971
       STACKTOP = sp; //@line 30972
       return $$0 | 0; //@line 30972
      }
      $449 = $2 + 66 | 0; //@line 30974
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($449 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($449, HEAP32[30849] | 0); //@line 30981
      $456 = $2 + 68 | 0; //@line 30982
      $458 = (HEAP32[30848] | 0) + 26 | 0; //@line 30984
      $464 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($458 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($458) | 0; //@line 30990
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($456 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($456, $464); //@line 30996
      $470 = $2 + 70 | 0; //@line 30997
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($470 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($470, 25185); //@line 31003
      $476 = $2 + 72 | 0; //@line 31004
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($476 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($476, 0); //@line 31010
      $482 = $2 + 76 | 0; //@line 31011
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($482 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($482, 0); //@line 31017
      $488 = $2 + 78 | 0; //@line 31018
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($488 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($488, 0); //@line 31024
      $494 = $2 + 82 | 0; //@line 31025
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($494 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($494, 1); //@line 31031
      $500 = $2 + 86 | 0; //@line 31032
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($500 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($500, 1); //@line 31038
      $506 = $2 + 90 | 0; //@line 31039
      dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($506 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($506) | 0; //@line 31046
      stop = dest + 32 | 0; //@line 31046
      do {
       HEAP8[dest >> 0] = 0; //@line 31046
       dest = dest + 1 | 0; //@line 31046
      } while ((dest | 0) < (stop | 0));
      $$0 = 0; //@line 31047
      STACKTOP = sp; //@line 31048
      return $$0 | 0; //@line 31048
     }
    case -24568:
     {
      $513 = $2 + 48 | 0; //@line 31052
      if ($11) {
       $519 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($513 >>> 16 << 2) >> 2] >> 2] & 127]($513) | 0; //@line 31059
      } else {
       $519 = 0; //@line 31061
      }
      $520 = __ZL17get_item_and_pathjjRP6FSItemb($2, $519, $5) | 0; //@line 31063
      L112 : do {
       if (!($520 << 16 >> 16)) {
        if (!(_access(657423, 0) | 0)) {
         $$1$i = -48; //@line 31070
        } else {
         $524 = _creat(657423, 438) | 0; //@line 31072
         if (($524 | 0) >= 0) {
          _close($524) | 0; //@line 31075
          $$1$i = 0; //@line 31076
          break;
         }
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$1$i = 0; //@line 31083
           break L112;
           break;
          }
         case 21:
         case 2:
          {
           $$1$i = -43; //@line 31088
           break L112;
           break;
          }
         case 1:
         case 13:
          {
           $$1$i = -54; //@line 31093
           break L112;
           break;
          }
         case 17:
          {
           $$1$i = -48; //@line 31098
           break L112;
           break;
          }
         case 39:
         case 16:
          {
           $$1$i = -47; //@line 31103
           break L112;
           break;
          }
         case 28:
          {
           $$1$i = -34; //@line 31108
           break L112;
           break;
          }
         case 30:
          {
           $$1$i = -44; //@line 31113
           break L112;
           break;
          }
         case 24:
          {
           $$1$i = -42; //@line 31118
           break L112;
           break;
          }
         case 12:
          {
           $$1$i = -108; //@line 31123
           break L112;
           break;
          }
         default:
          {
           $$1$i = -36; //@line 31128
           break L112;
          }
         }
        }
       } else {
        $$1$i = $520; //@line 31134
       }
      } while (0);
      $$0 = $$1$i; //@line 31137
      STACKTOP = sp; //@line 31138
      return $$0 | 0; //@line 31138
     }
    case -24567:
     {
      $528 = $2 + 48 | 0; //@line 31142
      if ($11) {
       $534 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($528 >>> 16 << 2) >> 2] >> 2] & 127]($528) | 0; //@line 31149
      } else {
       $534 = 0; //@line 31151
      }
      $535 = __ZL17get_item_and_pathjjRP6FSItemb($2, $534, $5) | 0; //@line 31153
      L134 : do {
       if (!($535 << 16 >> 16)) {
        if (__Z12extfs_removePKc(657423) | 0) {
         $$0$i72 = 0; //@line 31159
        } else {
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$0$i72 = 0; //@line 31165
           break L134;
           break;
          }
         case 21:
         case 2:
          {
           $$0$i72 = -43; //@line 31170
           break L134;
           break;
          }
         case 1:
         case 13:
          {
           $$0$i72 = -54; //@line 31175
           break L134;
           break;
          }
         case 17:
          {
           $$0$i72 = -48; //@line 31180
           break L134;
           break;
          }
         case 39:
         case 16:
          {
           $$0$i72 = -47; //@line 31185
           break L134;
           break;
          }
         case 28:
          {
           $$0$i72 = -34; //@line 31190
           break L134;
           break;
          }
         case 30:
          {
           $$0$i72 = -44; //@line 31195
           break L134;
           break;
          }
         case 24:
          {
           $$0$i72 = -42; //@line 31200
           break L134;
           break;
          }
         case 12:
          {
           $$0$i72 = -108; //@line 31205
           break L134;
           break;
          }
         default:
          {
           $$0$i72 = -36; //@line 31210
           break L134;
          }
         }
        }
       } else {
        $$0$i72 = $535; //@line 31216
       }
      } while (0);
      $$0 = $$0$i72; //@line 31219
      STACKTOP = sp; //@line 31220
      return $$0 | 0; //@line 31220
     }
    case -24566:
     {
      $540 = $2 + 48 | 0; //@line 31224
      if ($11) {
       $546 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($540 >>> 16 << 2) >> 2] >> 2] & 127]($540) | 0; //@line 31231
      } else {
       $546 = 0; //@line 31233
      }
      $$0 = __ZL7fs_openjjjb($2, $546, $0, 1) | 0; //@line 31236
      STACKTOP = sp; //@line 31237
      return $$0 | 0; //@line 31237
     }
    case -24565:
     {
      $548 = $2 + 48 | 0; //@line 31241
      if ($11) {
       $554 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($548 >>> 16 << 2) >> 2] >> 2] & 127]($548) | 0; //@line 31248
      } else {
       $554 = 0; //@line 31250
      }
      $555 = __ZL17get_item_and_pathjjRP6FSItemb($2, $554, $5) | 0; //@line 31252
      if (!($555 << 16 >> 16)) {
       _strcpy($7, 657423) | 0; //@line 31255
       $558 = (HEAP32[30848] | 0) + 238 | 0; //@line 31257
       $564 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($558 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($558) | 0; //@line 31263
       dest = $564; //@line 31270
       src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2) | 0; //@line 31270
       stop = dest + 50 | 0; //@line 31270
       do {
        HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 31270
        dest = dest + 1 | 0; //@line 31270
        src = src + 1 | 0; //@line 31270
       } while ((dest | 0) < (stop | 0));
       $572 = (HEAP32[30848] | 0) + 256 | 0; //@line 31272
       $573 = $2 + 28 | 0; //@line 31273
       $578 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($573 >>> 16 << 2) >> 2] >> 2] & 127]($573) | 0; //@line 31278
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($572 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($572, $578); //@line 31284
       $586 = __ZL17get_item_and_pathjjRP6FSItemb((HEAP32[30848] | 0) + 238 | 0, $554, $6) | 0; //@line 31287
       L160 : do {
        if (!($586 << 16 >> 16)) {
         if (!(_access(657423, 0) | 0)) {
          $$0$i75 = -48; //@line 31294
         } else {
          if (__Z12extfs_renamePKcS0_($7, 657423) | 0) {
           $594 = (HEAP32[$5 >> 2] | 0) + 4 | 0; //@line 31299
           $595 = HEAP32[$594 >> 2] | 0; //@line 31300
           $597 = (HEAP32[$6 >> 2] | 0) + 4 | 0; //@line 31302
           $598 = HEAP32[$597 >> 2] | 0; //@line 31303
           $$012$i$i = HEAP32[30826] | 0; //@line 31304
           if ($$012$i$i | 0) {
            $$013$i$i = $$012$i$i; //@line 31307
            do {
             $600 = $$013$i$i + 8 | 0; //@line 31309
             $601 = HEAP32[$600 >> 2] | 0; //@line 31310
             if (($601 | 0) == ($595 | 0)) {
              $$sink$i$i = $598; //@line 31313
              label = 117; //@line 31314
             } else {
              if (($601 | 0) == ($598 | 0)) {
               $$sink$i$i = $595; //@line 31318
               label = 117; //@line 31319
              }
             }
             if ((label | 0) == 117) {
              label = 0; //@line 31323
              HEAP32[$600 >> 2] = $$sink$i$i; //@line 31324
             }
             $$013$i$i = HEAP32[$$013$i$i >> 2] | 0; //@line 31326
            } while (($$013$i$i | 0) != 0);
           }
           HEAP32[$594 >> 2] = $598; //@line 31335
           HEAP32[$597 >> 2] = $595; //@line 31336
           $$0$i75 = 0; //@line 31337
           break;
          }
          switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
          case 0:
           {
            $$0$i75 = 0; //@line 31344
            break L160;
            break;
           }
          case 21:
          case 2:
           {
            $$0$i75 = -43; //@line 31349
            break L160;
            break;
           }
          case 1:
          case 13:
           {
            $$0$i75 = -54; //@line 31354
            break L160;
            break;
           }
          case 17:
           {
            $$0$i75 = -48; //@line 31359
            break L160;
            break;
           }
          case 39:
          case 16:
           {
            $$0$i75 = -47; //@line 31364
            break L160;
            break;
           }
          case 28:
           {
            $$0$i75 = -34; //@line 31369
            break L160;
            break;
           }
          case 30:
           {
            $$0$i75 = -44; //@line 31374
            break L160;
            break;
           }
          case 24:
           {
            $$0$i75 = -42; //@line 31379
            break L160;
            break;
           }
          case 12:
           {
            $$0$i75 = -108; //@line 31384
            break L160;
            break;
           }
          default:
           {
            $$0$i75 = -36; //@line 31389
            break L160;
           }
          }
         }
        } else {
         $$0$i75 = $586; //@line 31395
        }
       } while (0);
       $$1$i77 = $$0$i75; //@line 31398
      } else {
       $$1$i77 = $555; //@line 31400
      }
      $$0 = $$1$i77; //@line 31402
      STACKTOP = sp; //@line 31403
      return $$0 | 0; //@line 31403
     }
    case -24564:
     {
      $605 = $2 + 48 | 0; //@line 31407
      if ($11) {
       $620 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($605 >>> 16 << 2) >> 2] >> 2] & 127]($605) | 0; //@line 31414
      } else {
       $620 = 0; //@line 31416
      }
      $611 = $2 + 28 | 0; //@line 31418
      $sext$i78 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($611 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($611) | 0) << 16; //@line 31425
      $618 = $sext$i78 >> 16; //@line 31426
      L192 : do {
       if (($sext$i78 | 0) < 65536) {
        $621 = __ZL17get_item_and_pathjjRP6FSItemb($2, $620, $5) | 0; //@line 31430
        if (!($621 << 16 >> 16)) {
         label = 139; //@line 31433
        } else {
         $$6$i = $621; //@line 31435
        }
       } else {
        $623 = __ZL15get_current_dirjjRjb($2, $620, $6, 1) | 0; //@line 31438
        L195 : do {
         if (!($623 << 16 >> 16)) {
          $625 = HEAP32[$6 >> 2] | 0; //@line 31442
          $$06$i$i79 = HEAP32[30826] | 0; //@line 31443
          if (!$$06$i$i79) {
           $$4$ph$i = -120; //@line 31446
          } else {
           $$07$i$i80 = $$06$i$i79; //@line 31448
           while (1) {
            if ((HEAP32[$$07$i$i80 + 4 >> 2] | 0) == ($625 | 0)) {
             break;
            }
            $$0$i$i82 = HEAP32[$$07$i$i80 >> 2] | 0; //@line 31456
            if (!$$0$i$i82) {
             $$4$ph$i = -120; //@line 31459
             break L195;
            } else {
             $$07$i$i80 = $$0$i$i82; //@line 31462
            }
           }
           __ZL19get_path_for_fsitemP6FSItem($$07$i$i80); //@line 31465
           $631 = _opendir(657423) | 0; //@line 31466
           if (!$631) {
            $$4$ph$i = -120; //@line 31469
           } else {
            L202 : do {
             if (($sext$i78 | 0) > 0) {
              $$06584$i = 0; //@line 31474
              L203 : while (1) {
               do {
                $634 = _readdir($631) | 0; //@line 31477
                if (!$634) {
                 break L203;
                }
               } while ((HEAP8[$634 + 11 >> 0] | 0) == 46);
               $$06584$i = $$06584$i + 1 | 0; //@line 31489
               if (($$06584$i | 0) >= ($618 | 0)) {
                $$066$lcssa$i = $634; //@line 31494
                break L202;
               }
              }
              _closedir($631) | 0; //@line 31498
              $$4$ph$i = -43; //@line 31499
              break L195;
             } else {
              $$066$lcssa$i = 0; //@line 31502
             }
            } while (0);
            $641 = $$066$lcssa$i + 11 | 0; //@line 31505
            __Z18add_path_componentPcPKc(657423, $641); //@line 31506
            HEAP32[$5 >> 2] = __ZL11find_fsitemPKcP6FSItem($641, $$07$i$i80) | 0; //@line 31508
            _closedir($631) | 0; //@line 31509
            label = 139; //@line 31510
            break L192;
           }
          }
         } else {
          $$4$ph$i = $623; //@line 31515
         }
        } while (0);
        $$6$i = $$4$ph$i; //@line 31518
       }
      } while (0);
      if ((label | 0) == 139) {
       if (!(_stat(657423, $6) | 0)) {
        if ((HEAP32[$6 + 12 >> 2] & 61440 | 0) == 16384) {
         $$5$i = -43; //@line 31530
        } else {
         $649 = $2 + 18 | 0; //@line 31532
         $651 = 123608 + ($649 >>> 16 << 2) | 0; //@line 31534
         L217 : do {
          if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$651 >> 2] >> 2] & 127]($649) | 0) {
           $658 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$651 >> 2] >> 2] & 127]($649) | 0; //@line 31543
           $664 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($658 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($658) | 0; //@line 31549
           $666 = (HEAP32[$5 >> 2] | 0) + 20 | 0; //@line 31551
           HEAP8[$664 >> 0] = _strlen($666) | 0; //@line 31554
           $$05$i74$i = $666; //@line 31555
           $$pn$i$i = $664; //@line 31555
           while (1) {
            $$06$i75$i = $$pn$i$i + 1 | 0; //@line 31557
            $669 = $$05$i74$i + 1 | 0; //@line 31558
            $670 = HEAP8[$$05$i74$i >> 0] | 0; //@line 31559
            switch ($670 << 24 >> 24) {
            case 0:
             {
              break L217;
              break;
             }
            case 58:
             {
              $$0$i76$i = 47; //@line 31566
              break;
             }
            default:
             {
              $$0$i76$i = $670; //@line 31570
             }
            }
            HEAP8[$$06$i75$i >> 0] = $$0$i76$i; //@line 31573
            $$05$i74$i = $669; //@line 31574
            $$pn$i$i = $$06$i75$i; //@line 31574
           }
          }
         } while (0);
         $671 = $2 + 24 | 0; //@line 31578
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($671 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($671, 0); //@line 31584
         $677 = $2 + 30 | 0; //@line 31585
         $679 = (_access(657423, 2) | 0) != 0 & 1; //@line 31588
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($677 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($677, $679); //@line 31594
         $685 = HEAP32[$5 >> 2] | 0; //@line 31595
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($605 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($605, HEAP32[$685 + 4 >> 2] | 0); //@line 31603
         $693 = $2 + 72 | 0; //@line 31604
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($693 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($693, 0); //@line 31610
         $699 = $2 + 76 | 0; //@line 31611
         $702 = __Z13TimeToMacTimel(HEAP32[$6 + 56 >> 2] | 0) | 0; //@line 31614
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($699 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($699, $702); //@line 31620
         __Z9get_finfoPKcjjb(657423, $2 + 32 | 0, $11 ? $2 + 84 | 0 : 0, 0); //@line 31624
         $711 = $2 + 52 | 0; //@line 31625
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($711 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($711, 0); //@line 31631
         $717 = $2 + 54 | 0; //@line 31632
         $719 = HEAP32[$6 + 36 >> 2] | 0; //@line 31634
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($717 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($717, $719); //@line 31640
         $725 = $2 + 58 | 0; //@line 31641
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($725 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($725, ($719 | 16383) + 1 | 0); //@line 31649
         $733 = $2 + 62 | 0; //@line 31650
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($733 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($733, 0); //@line 31656
         $739 = __Z14get_rfork_sizePKc(657423) | 0; //@line 31657
         $740 = $2 + 64 | 0; //@line 31658
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($740 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($740, $739); //@line 31664
         $746 = $2 + 68 | 0; //@line 31665
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($746 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($746, ($739 | 16383) + 1 | 0); //@line 31673
         if ($11) {
          $754 = $2 + 80 | 0; //@line 31675
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($754 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($754, 0); //@line 31681
          $760 = $2 + 100 | 0; //@line 31682
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($760 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($760, HEAP32[$685 + 8 >> 2] | 0); //@line 31690
          $768 = $2 + 104 | 0; //@line 31691
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($768 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($768, 0); //@line 31697
          $$5$i = 0; //@line 31698
         } else {
          $$5$i = 0; //@line 31700
         }
        }
       } else {
        $$5$i = -43; //@line 31704
       }
       $$6$i = $$5$i; //@line 31706
      }
      $$0 = $$6$i; //@line 31708
      STACKTOP = sp; //@line 31709
      return $$0 | 0; //@line 31709
     }
    case -24563:
     {
      $774 = $2 + 48 | 0; //@line 31713
      if ($11) {
       $780 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($774 >>> 16 << 2) >> 2] >> 2] & 127]($774) | 0; //@line 31720
      } else {
       $780 = 0; //@line 31722
      }
      $781 = __ZL17get_item_and_pathjjRP6FSItemb($2, $780, $5) | 0; //@line 31724
      if (!($781 << 16 >> 16)) {
       L235 : do {
        if ((_stat(657423, $6) | 0) < 0) {
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$0$i85 = 0; //@line 31735
           break L235;
           break;
          }
         case 21:
         case 2:
          {
           $$0$i85 = -43; //@line 31740
           break L235;
           break;
          }
         case 1:
         case 13:
          {
           $$0$i85 = -54; //@line 31745
           break L235;
           break;
          }
         case 17:
          {
           $$0$i85 = -48; //@line 31750
           break L235;
           break;
          }
         case 39:
         case 16:
          {
           $$0$i85 = -47; //@line 31755
           break L235;
           break;
          }
         case 28:
          {
           $$0$i85 = -34; //@line 31760
           break L235;
           break;
          }
         case 30:
          {
           $$0$i85 = -44; //@line 31765
           break L235;
           break;
          }
         case 24:
          {
           $$0$i85 = -42; //@line 31770
           break L235;
           break;
          }
         case 12:
          {
           $$0$i85 = -108; //@line 31775
           break L235;
           break;
          }
         default:
          {
           $$0$i85 = -36; //@line 31780
           break L235;
          }
         }
        } else {
         if ((HEAP32[$6 + 12 >> 2] & 61440 | 0) == 16384) {
          $$0$i85 = -43; //@line 31790
         } else {
          __Z9set_finfoPKcjjb(657423, $2 + 32 | 0, $11 ? $2 + 84 | 0 : 0, 0); //@line 31795
          $$0$i85 = 0; //@line 31796
         }
        }
       } while (0);
       $$1$i87 = $$0$i85; //@line 31800
      } else {
       $$1$i87 = $781; //@line 31802
      }
      $$0 = $$1$i87; //@line 31804
      STACKTOP = sp; //@line 31805
      return $$0 | 0; //@line 31805
     }
    case -24562:
     {
      HEAP32[$5 + 32 >> 2] = $0; //@line 31810
      _Execute68k((HEAP32[30848] | 0) + 670 | 0, $5); //@line 31813
      $$0 = HEAP32[$5 >> 2] & 65535; //@line 31816
      STACKTOP = sp; //@line 31817
      return $$0 | 0; //@line 31817
     }
    case -24561:
     {
      $799 = $2 + 22 | 0; //@line 31821
      $806 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($799 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($799) | 0) << 16 >> 16; //@line 31829
      $$0 = ($806 | 0) == (HEAP32[30849] | 0) ? 0 : -58; //@line 31833
      STACKTOP = sp; //@line 31834
      return $$0 | 0; //@line 31834
     }
    case -24560:
     {
      $809 = $2 + 40 | 0; //@line 31838
      $810 = $2 + 36 | 0; //@line 31839
      $815 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($810 >>> 16 << 2) >> 2] >> 2] & 127]($810) | 0; //@line 31844
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($809 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($809, $815); //@line 31850
      $$0 = 0; //@line 31851
      STACKTOP = sp; //@line 31852
      return $$0 | 0; //@line 31852
     }
    case -24559:
     {
      $821 = $2 + 24 | 0; //@line 31856
      $823 = 123608 + ($821 >>> 16 << 2) | 0; //@line 31858
      HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$823 >> 2] | 0) + 4 >> 2] & 127]($821) | 0) << 16 >> 16; //@line 31865
      $829 = HEAP32[30848] | 0; //@line 31866
      HEAP32[$5 + 32 >> 2] = $829 + 306; //@line 31869
      _Execute68k($829 + 752 | 0, $5); //@line 31871
      $834 = (HEAP32[30848] | 0) + 306 | 0; //@line 31873
      $839 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($834 >>> 16 << 2) >> 2] >> 2] & 127]($834) | 0; //@line 31878
      do {
       if (($839 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
        $$2$i = -51; //@line 31886
       } else {
        if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($839 >>> 16 << 2) >> 2] >> 2] & 127]($839) | 0)) {
         $$2$i = -38; //@line 31895
        } else {
         $850 = $839 + 54 | 0; //@line 31897
         $855 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($850 >>> 16 << 2) >> 2] >> 2] & 127]($850) | 0; //@line 31902
         if (($855 | 0) < 0) {
          $857 = $839 + 4 | 0; //@line 31905
          $866 = $2 + 28 | 0; //@line 31914
          if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($857 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($857) | 0) & 2)) {
           $$2$i = -38; //@line 31916
           break;
          }
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($866 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($866, 0); //@line 31924
          $$2$i = 0; //@line 31925
          break;
         }
         L266 : do {
          if ((_fstat($855, $5) | 0) < 0) {
           switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
           case 0:
            {
             $$0$i92 = 0; //@line 31936
             break L266;
             break;
            }
           case 21:
           case 2:
            {
             $$0$i92 = -43; //@line 31941
             break L266;
             break;
            }
           case 1:
           case 13:
            {
             $$0$i92 = -54; //@line 31946
             break L266;
             break;
            }
           case 17:
            {
             $$0$i92 = -48; //@line 31951
             break L266;
             break;
            }
           case 39:
           case 16:
            {
             $$0$i92 = -47; //@line 31956
             break L266;
             break;
            }
           case 28:
            {
             $$0$i92 = -34; //@line 31961
             break L266;
             break;
            }
           case 30:
            {
             $$0$i92 = -44; //@line 31966
             break L266;
             break;
            }
           case 24:
            {
             $$0$i92 = -42; //@line 31971
             break L266;
             break;
            }
           case 12:
            {
             $$0$i92 = -108; //@line 31976
             break L266;
             break;
            }
           default:
            {
             $$0$i92 = -36; //@line 31981
             break L266;
            }
           }
          } else {
           $876 = $839 + 8 | 0; //@line 31986
           $878 = HEAP32[$5 + 36 >> 2] | 0; //@line 31988
           FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($876 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($876, $878); //@line 31994
           $884 = $839 + 12 | 0; //@line 31995
           FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($884 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($884, ($878 | 16383) + 1 | 0); //@line 32003
           $892 = $2 + 28 | 0; //@line 32004
           FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($892 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($892, $878); //@line 32010
           HEAP32[$6 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$823 >> 2] | 0) + 4 >> 2] & 127]($821) | 0; //@line 32015
           _Execute68k((HEAP32[30848] | 0) + 766 | 0, $6); //@line 32018
           $$0$i92 = 0; //@line 32019
          }
         } while (0);
         $$2$i = $$0$i92; //@line 32022
        }
       }
      } while (0);
      $$0 = $$2$i; //@line 32026
      STACKTOP = sp; //@line 32027
      return $$0 | 0; //@line 32027
     }
    case -24558:
     {
      $904 = $2 + 24 | 0; //@line 32031
      $906 = 123608 + ($904 >>> 16 << 2) | 0; //@line 32033
      HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$906 >> 2] | 0) + 4 >> 2] & 127]($904) | 0) << 16 >> 16; //@line 32040
      $912 = HEAP32[30848] | 0; //@line 32041
      HEAP32[$5 + 32 >> 2] = $912 + 306; //@line 32044
      _Execute68k($912 + 752 | 0, $5); //@line 32046
      $917 = (HEAP32[30848] | 0) + 306 | 0; //@line 32048
      $922 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($917 >>> 16 << 2) >> 2] >> 2] & 127]($917) | 0; //@line 32053
      L283 : do {
       if (($922 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
        $$2$i97 = -51; //@line 32061
       } else {
        if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($922 >>> 16 << 2) >> 2] >> 2] & 127]($922) | 0)) {
         $$2$i97 = -38; //@line 32070
        } else {
         $933 = $922 + 54 | 0; //@line 32072
         $938 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($933 >>> 16 << 2) >> 2] >> 2] & 127]($933) | 0; //@line 32077
         if (($938 | 0) < 0) {
          $940 = $922 + 4 | 0; //@line 32080
          $948 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($940 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($940) | 0) & 2 | 0) == 0; //@line 32088
          $$2$i97 = $948 ? -38 : 0; //@line 32090
          break;
         }
         $949 = $2 + 28 | 0; //@line 32093
         $954 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($949 >>> 16 << 2) >> 2] >> 2] & 127]($949) | 0; //@line 32098
         if ((_ftruncate($938, $954) | 0) >= 0) {
          $959 = $922 + 8 | 0; //@line 32102
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($959 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($959, $954); //@line 32108
          $965 = $922 + 12 | 0; //@line 32109
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($965 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($965, ($954 | 16383) + 1 | 0); //@line 32117
          HEAP32[$6 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$906 >> 2] | 0) + 4 >> 2] & 127]($904) | 0; //@line 32122
          _Execute68k((HEAP32[30848] | 0) + 766 | 0, $6); //@line 32125
          $$2$i97 = 0; //@line 32126
          break;
         }
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$2$i97 = 0; //@line 32133
           break L283;
           break;
          }
         case 21:
         case 2:
          {
           $$2$i97 = -43; //@line 32138
           break L283;
           break;
          }
         case 1:
         case 13:
          {
           $$2$i97 = -54; //@line 32143
           break L283;
           break;
          }
         case 17:
          {
           $$2$i97 = -48; //@line 32148
           break L283;
           break;
          }
         case 39:
         case 16:
          {
           $$2$i97 = -47; //@line 32153
           break L283;
           break;
          }
         case 28:
          {
           $$2$i97 = -34; //@line 32158
           break L283;
           break;
          }
         case 30:
          {
           $$2$i97 = -44; //@line 32163
           break L283;
           break;
          }
         case 24:
          {
           $$2$i97 = -42; //@line 32168
           break L283;
           break;
          }
         case 12:
          {
           $$2$i97 = -108; //@line 32173
           break L283;
           break;
          }
         default:
          {
           $$2$i97 = -36; //@line 32178
           break L283;
          }
         }
        }
       }
      } while (0);
      $$0 = $$2$i97; //@line 32185
      STACKTOP = sp; //@line 32186
      return $$0 | 0; //@line 32186
     }
    case -24556:
     {
      HEAP32[$5 + 32 >> 2] = $2; //@line 32191
      _Execute68k((HEAP32[30848] | 0) + 632 | 0, $5); //@line 32194
      $$0 = HEAP32[$5 >> 2] & 65535; //@line 32197
      STACKTOP = sp; //@line 32198
      return $$0 | 0; //@line 32198
     }
    case -24557:
     {
      $$0 = 0; //@line 32202
      STACKTOP = sp; //@line 32203
      return $$0 | 0; //@line 32203
     }
    default:
     {
      break L1;
     }
    }
   } while (0);
  } else {
   if ($trunc << 16 >> 16 < 2) {
    if ($trunc << 16 >> 16 < -24511) {
     switch ($trunc << 16 >> 16) {
     case -24555:
      {
       do {
        if ($11) {
         $984 = $2 + 48 | 0; //@line 32220
         $990 = __ZL17get_item_and_pathjjRP6FSItemb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($984 >>> 16 << 2) >> 2] >> 2] & 127]($984) | 0, $6) | 0; //@line 32226
         if ($990 << 16 >> 16) {
          $$2$i101 = $990; //@line 32229
          break;
         }
         if (!(_stat(657423, $7) | 0)) {
          if ((HEAP32[$7 + 12 >> 2] & 61440 | 0) == 16384) {
           $1000 = HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] | 0; //@line 32242
           $1001 = $0 + 78 | 0; //@line 32243
           $$222$i = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1001 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1001) | 0; //@line 32250
           $$225$i = $1000; //@line 32250
           $$pre$phi$iZ2D = $5; //@line 32250
           label = 216; //@line 32251
           break;
          }
         }
         $$2$i101 = -120; //@line 32255
        } else {
         $1008 = $2 + 22 | 0; //@line 32257
         HEAP32[$5 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1008 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1008) | 0; //@line 32264
         _Execute68k((HEAP32[30848] | 0) + 682 | 0, $5); //@line 32267
         $1019 = (HEAP32[$5 >> 2] & 65535 | 0) == 0; //@line 32270
         $$sink$i = $1019 ? $1008 : $0 + 78 | 0; //@line 32272
         $$222$i = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$sink$i >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$sink$i) | 0; //@line 32280
         $$225$i = $1019 ? 0 : 2; //@line 32280
         $$pre$phi$iZ2D = $5; //@line 32280
         label = 216; //@line 32281
        }
       } while (0);
       if ((label | 0) == 216) {
        HEAP32[$$pre$phi$iZ2D >> 2] = 0; //@line 32285
        HEAP32[$5 + 4 >> 2] = $$225$i; //@line 32287
        HEAP32[$5 + 8 >> 2] = $$222$i << 16 >> 16; //@line 32291
        _Execute68k((HEAP32[30848] | 0) + 694 | 0, $5); //@line 32294
        $$2$i101 = HEAP32[$$pre$phi$iZ2D >> 2] & 65535; //@line 32297
       }
       $$0 = $$2$i101; //@line 32299
       STACKTOP = sp; //@line 32300
       return $$0 | 0; //@line 32300
      }
     case -24552:
      {
       $1034 = $2 + 36 | 0; //@line 32304
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1034 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1034, 0); //@line 32310
       $1040 = $2 + 40 | 0; //@line 32311
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1040 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1040, 0); //@line 32317
       $1046 = $2 + 44 | 0; //@line 32318
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1046 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1046, 0); //@line 32324
       $1052 = $2 + 24 | 0; //@line 32325
       HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1052 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1052) | 0) << 16 >> 16; //@line 32334
       $1060 = HEAP32[30848] | 0; //@line 32335
       HEAP32[$5 + 32 >> 2] = $1060 + 306; //@line 32338
       _Execute68k($1060 + 752 | 0, $5); //@line 32340
       $1065 = (HEAP32[30848] | 0) + 306 | 0; //@line 32342
       $1070 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1065 >>> 16 << 2) >> 2] >> 2] & 127]($1065) | 0; //@line 32347
       if (($1070 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
        $$0 = -51; //@line 32354
        STACKTOP = sp; //@line 32355
        return $$0 | 0; //@line 32355
       }
       if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1070 >>> 16 << 2) >> 2] >> 2] & 127]($1070) | 0)) {
        $$0 = -38; //@line 32364
        STACKTOP = sp; //@line 32365
        return $$0 | 0; //@line 32365
       }
       $1081 = $1070 + 54 | 0; //@line 32367
       $1086 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1081 >>> 16 << 2) >> 2] >> 2] & 127]($1081) | 0; //@line 32372
       if (($1086 | 0) >= 0) {
        $1103 = _lseek($1086, 0, 1) | 0; //@line 32375
        $1104 = $1070 + 16 | 0; //@line 32376
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1104 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1104, $1103); //@line 32382
        $1110 = $2 + 46 | 0; //@line 32383
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1110 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1110, $1103); //@line 32389
        $$0 = 0; //@line 32390
        STACKTOP = sp; //@line 32391
        return $$0 | 0; //@line 32391
       }
       $1088 = $1070 + 4 | 0; //@line 32393
       $1097 = $2 + 46 | 0; //@line 32402
       if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1088 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($1088) | 0) & 2)) {
        $$0 = -38; //@line 32404
        STACKTOP = sp; //@line 32405
        return $$0 | 0; //@line 32405
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1097 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1097, 0); //@line 32412
       $$0 = 0; //@line 32413
       STACKTOP = sp; //@line 32414
       return $$0 | 0; //@line 32414
      }
     case -24523:
     case -24553:
      {
       $$0 = 0; //@line 32418
       STACKTOP = sp; //@line 32419
       return $$0 | 0; //@line 32419
      }
     default:
      {
       break L1;
      }
     }
    }
    if ($trunc << 16 >> 16 < -24508) {
     switch ($trunc << 16 >> 16) {
     case -24510:
     case -24511:
      {
       $$0 = 0; //@line 32431
       break;
      }
     default:
      {
       break L1;
      }
     }
     STACKTOP = sp; //@line 32438
     return $$0 | 0; //@line 32438
    }
    if ($trunc << 16 >> 16 >= -24507) {
     if ($trunc << 16 >> 16 < 1) {
      switch ($trunc << 16 >> 16) {
      case -24507:
       {
        $$0 = 0; //@line 32446
        break;
       }
      default:
       {
        break L1;
       }
      }
      STACKTOP = sp; //@line 32453
      return $$0 | 0; //@line 32453
     }
     switch ($trunc << 16 >> 16) {
     case 1:
      {
       break;
      }
     default:
      {
       break L1;
      }
     }
     HEAP32[$5 + 32 >> 2] = $2; //@line 32464
     _Execute68k((HEAP32[30848] | 0) + 778 | 0, $5); //@line 32467
     $$0 = HEAP32[$5 >> 2] & 65535; //@line 32470
     STACKTOP = sp; //@line 32471
     return $$0 | 0; //@line 32471
    }
    switch ($trunc << 16 >> 16) {
    case -24508:
     {
      break;
     }
    default:
     {
      break L1;
     }
    }
    $1116 = $2 + 24 | 0; //@line 32481
    HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1116 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1116) | 0) << 16 >> 16; //@line 32490
    $1124 = HEAP32[30848] | 0; //@line 32491
    HEAP32[$5 + 32 >> 2] = $1124 + 306; //@line 32494
    _Execute68k($1124 + 752 | 0, $5); //@line 32496
    $1129 = (HEAP32[30848] | 0) + 306 | 0; //@line 32498
    $1134 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1129 >>> 16 << 2) >> 2] >> 2] & 127]($1129) | 0; //@line 32503
    if (($1134 | 0) == 0 | (HEAP32[$5 >> 2] & 65535 | 0) != 0) {
     $$0 = -51; //@line 32510
     STACKTOP = sp; //@line 32511
     return $$0 | 0; //@line 32511
    }
    if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1134 >>> 16 << 2) >> 2] >> 2] & 127]($1134) | 0)) {
     $$0 = -38; //@line 32520
     STACKTOP = sp; //@line 32521
     return $$0 | 0; //@line 32521
    }
    $1145 = $1134 + 54 | 0; //@line 32523
    $1150 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1145 >>> 16 << 2) >> 2] >> 2] & 127]($1145) | 0; //@line 32528
    if (($1150 | 0) < 0) {
     $1152 = $1134 + 4 | 0; //@line 32531
     $1161 = $2 + 46 | 0; //@line 32540
     if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1152 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($1152) | 0) & 2)) {
      $$0 = -38; //@line 32542
      STACKTOP = sp; //@line 32543
      return $$0 | 0; //@line 32543
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1161 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1161, 0); //@line 32550
     $$0 = 0; //@line 32551
     STACKTOP = sp; //@line 32552
     return $$0 | 0; //@line 32552
    }
    $1167 = $2 + 44 | 0; //@line 32554
    switch ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1167 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1167) | 0) & 3) {
    case 1:
     {
      $1174 = $2 + 46 | 0; //@line 32565
      $1176 = 123608 + ($1174 >>> 16 << 2) | 0; //@line 32567
      if ((_lseek($1150, FUNCTION_TABLE_ii[HEAP32[HEAP32[$1176 >> 2] >> 2] & 127]($1174) | 0, 0) | 0) < 0) {
       $$0 = -40; //@line 32574
       STACKTOP = sp; //@line 32575
       return $$0 | 0; //@line 32575
      } else {
       $$pre$phi$i110Z2D = $1174; //@line 32577
       $$pre$phi28$iZ2D = $1176; //@line 32577
      }
      break;
     }
    case 2:
     {
      $1182 = $2 + 46 | 0; //@line 32582
      $1184 = 123608 + ($1182 >>> 16 << 2) | 0; //@line 32584
      if ((_lseek($1150, FUNCTION_TABLE_ii[HEAP32[HEAP32[$1184 >> 2] >> 2] & 127]($1182) | 0, 2) | 0) < 0) {
       $$0 = -40; //@line 32591
       STACKTOP = sp; //@line 32592
       return $$0 | 0; //@line 32592
      } else {
       $$pre$phi$i110Z2D = $1182; //@line 32594
       $$pre$phi28$iZ2D = $1184; //@line 32594
      }
      break;
     }
    case 3:
     {
      $1190 = $2 + 46 | 0; //@line 32599
      $1192 = 123608 + ($1190 >>> 16 << 2) | 0; //@line 32601
      if ((_lseek($1150, FUNCTION_TABLE_ii[HEAP32[HEAP32[$1192 >> 2] >> 2] & 127]($1190) | 0, 1) | 0) < 0) {
       $$0 = -40; //@line 32608
       STACKTOP = sp; //@line 32609
       return $$0 | 0; //@line 32609
      } else {
       $$pre$phi$i110Z2D = $1190; //@line 32611
       $$pre$phi28$iZ2D = $1192; //@line 32611
      }
      break;
     }
    default:
     {
      $$pre$i108 = $2 + 46 | 0; //@line 32616
      $$pre$phi$i110Z2D = $$pre$i108; //@line 32619
      $$pre$phi28$iZ2D = 123608 + ($$pre$i108 >>> 16 << 2) | 0; //@line 32619
     }
    }
    $1198 = _lseek($1150, 0, 1) | 0; //@line 32622
    $1199 = $1134 + 16 | 0; //@line 32623
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1199 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1199, $1198); //@line 32629
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$$pre$phi28$iZ2D >> 2] | 0) + 12 >> 2] & 31]($$pre$phi$i110Z2D, $1198); //@line 32633
    $$0 = 0; //@line 32634
    STACKTOP = sp; //@line 32635
    return $$0 | 0; //@line 32635
   }
   do {
    switch ($trunc << 16 >> 16) {
    case 2:
     {
      $1213 = $2 + 22 | 0; //@line 32640
      HEAP32[$5 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1213 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1213) | 0; //@line 32647
      _Execute68k((HEAP32[30848] | 0) + 790 | 0, $5); //@line 32650
      $$0 = HEAP32[$5 >> 2] & 65535; //@line 32653
      STACKTOP = sp; //@line 32654
      return $$0 | 0; //@line 32654
     }
    case 5:
     {
      $1224 = $2 + 48 | 0; //@line 32658
      $1230 = __ZL17get_item_and_pathjjRP6FSItemb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1224 >>> 16 << 2) >> 2] >> 2] & 127]($1224) | 0, $5) | 0; //@line 32664
      if (!($1230 << 16 >> 16)) {
       _strcpy($7, 657423) | 0; //@line 32667
       $1233 = (HEAP32[30848] | 0) + 238 | 0; //@line 32669
       $1239 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1233 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1233) | 0; //@line 32675
       dest = $1239; //@line 32682
       src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2) | 0; //@line 32682
       stop = dest + 50 | 0; //@line 32682
       do {
        HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 32682
        dest = dest + 1 | 0; //@line 32682
        src = src + 1 | 0; //@line 32682
       } while ((dest | 0) < (stop | 0));
       $1247 = (HEAP32[30848] | 0) + 256 | 0; //@line 32684
       $1248 = $2 + 28 | 0; //@line 32685
       $1253 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1248 >>> 16 << 2) >> 2] >> 2] & 127]($1248) | 0; //@line 32690
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1247 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1247, $1253); //@line 32696
       $1260 = (HEAP32[30848] | 0) + 238 | 0; //@line 32698
       $1261 = $2 + 36 | 0; //@line 32699
       $1267 = __ZL17get_item_and_pathjjRP6FSItemb($1260, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1261 >>> 16 << 2) >> 2] >> 2] & 127]($1261) | 0, $6) | 0; //@line 32705
       L389 : do {
        if (!($1267 << 16 >> 16)) {
         $1269 = HEAP32[$5 >> 2] | 0; //@line 32709
         $1270 = $1269 + 16 | 0; //@line 32710
         __Z18add_path_componentPcPKc(657423, HEAP32[$1270 >> 2] | 0); //@line 32712
         if (!(_access(657423, 0) | 0)) {
          $$0$i118 = -48; //@line 32716
         } else {
          if (__Z12extfs_renamePKcS0_($7, 657423) | 0) {
           $1279 = __ZL11find_fsitemPKcP6FSItem(HEAP32[$1270 >> 2] | 0, HEAP32[$6 >> 2] | 0) | 0; //@line 32722
           if (!$1279) {
            $$0$i118 = 0; //@line 32725
            break;
           }
           $1281 = $1269 + 4 | 0; //@line 32728
           $1282 = HEAP32[$1281 >> 2] | 0; //@line 32729
           $1283 = $1279 + 4 | 0; //@line 32730
           $1284 = HEAP32[$1283 >> 2] | 0; //@line 32731
           $$012$i$i112 = HEAP32[30826] | 0; //@line 32732
           if ($$012$i$i112 | 0) {
            $$013$i$i113 = $$012$i$i112; //@line 32735
            do {
             $1286 = $$013$i$i113 + 8 | 0; //@line 32737
             $1287 = HEAP32[$1286 >> 2] | 0; //@line 32738
             if (($1287 | 0) == ($1282 | 0)) {
              $$sink$i$i115 = $1284; //@line 32741
              label = 255; //@line 32742
             } else {
              if (($1287 | 0) == ($1284 | 0)) {
               $$sink$i$i115 = $1282; //@line 32746
               label = 255; //@line 32747
              }
             }
             if ((label | 0) == 255) {
              label = 0; //@line 32751
              HEAP32[$1286 >> 2] = $$sink$i$i115; //@line 32752
             }
             $$013$i$i113 = HEAP32[$$013$i$i113 >> 2] | 0; //@line 32754
            } while (($$013$i$i113 | 0) != 0);
           }
           HEAP32[$1281 >> 2] = $1284; //@line 32763
           HEAP32[$1283 >> 2] = $1282; //@line 32764
           $$0$i118 = 0; //@line 32765
           break;
          }
          switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
          case 0:
           {
            $$0$i118 = 0; //@line 32772
            break L389;
            break;
           }
          case 21:
          case 2:
           {
            $$0$i118 = -43; //@line 32777
            break L389;
            break;
           }
          case 1:
          case 13:
           {
            $$0$i118 = -54; //@line 32782
            break L389;
            break;
           }
          case 17:
           {
            $$0$i118 = -48; //@line 32787
            break L389;
            break;
           }
          case 39:
          case 16:
           {
            $$0$i118 = -47; //@line 32792
            break L389;
            break;
           }
          case 28:
           {
            $$0$i118 = -34; //@line 32797
            break L389;
            break;
           }
          case 30:
           {
            $$0$i118 = -44; //@line 32802
            break L389;
            break;
           }
          case 24:
           {
            $$0$i118 = -42; //@line 32807
            break L389;
            break;
           }
          case 12:
           {
            $$0$i118 = -108; //@line 32812
            break L389;
            break;
           }
          default:
           {
            $$0$i118 = -36; //@line 32817
            break L389;
           }
          }
         }
        } else {
         $$0$i118 = $1267; //@line 32823
        }
       } while (0);
       $$1$i120 = $$0$i118; //@line 32826
      } else {
       $$1$i120 = $1230; //@line 32828
      }
      $$0 = $$1$i120; //@line 32830
      STACKTOP = sp; //@line 32831
      return $$0 | 0; //@line 32831
     }
    case 6:
     {
      $1291 = $2 + 48 | 0; //@line 32835
      $1293 = 123608 + ($1291 >>> 16 << 2) | 0; //@line 32837
      $1297 = __ZL17get_item_and_pathjjRP6FSItemb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[$1293 >> 2] >> 2] & 127]($1291) | 0, $5) | 0; //@line 32841
      L419 : do {
       if (!($1297 << 16 >> 16)) {
        if (!(_access(657423, 0) | 0)) {
         $$0$i121 = -48; //@line 32848
        } else {
         if ((_mkdir(657423, 511) | 0) >= 0) {
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[$1293 >> 2] | 0) + 12 >> 2] & 31]($1291, HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] | 0); //@line 32859
          $$0$i121 = 0; //@line 32860
          break;
         }
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$0$i121 = 0; //@line 32867
           break L419;
           break;
          }
         case 21:
         case 2:
          {
           $$0$i121 = -43; //@line 32872
           break L419;
           break;
          }
         case 1:
         case 13:
          {
           $$0$i121 = -54; //@line 32877
           break L419;
           break;
          }
         case 17:
          {
           $$0$i121 = -48; //@line 32882
           break L419;
           break;
          }
         case 39:
         case 16:
          {
           $$0$i121 = -47; //@line 32887
           break L419;
           break;
          }
         case 28:
          {
           $$0$i121 = -34; //@line 32892
           break L419;
           break;
          }
         case 30:
          {
           $$0$i121 = -44; //@line 32897
           break L419;
           break;
          }
         case 24:
          {
           $$0$i121 = -42; //@line 32902
           break L419;
           break;
          }
         case 12:
          {
           $$0$i121 = -108; //@line 32907
           break L419;
           break;
          }
         default:
          {
           $$0$i121 = -36; //@line 32912
           break L419;
          }
         }
        }
       } else {
        $$0$i121 = $1297; //@line 32918
       }
      } while (0);
      $$0 = $$0$i121; //@line 32921
      STACKTOP = sp; //@line 32922
      return $$0 | 0; //@line 32922
     }
    case 7:
     {
      $1311 = $2 + 26 | 0; //@line 32926
      $1313 = 123608 + ($1311 >>> 16 << 2) | 0; //@line 32928
      $1319 = $2 + 28 | 0; //@line 32934
      $1320 = $2 + 22 | 0; //@line 32935
      $1322 = 123608 + ($1320 >>> 16 << 2) | 0; //@line 32937
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1313 >> 2] | 0) + 4 >> 2] & 127]($1311) | 0)) {
       $1326 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1322 >> 2] | 0) + 4 >> 2] & 127]($1320) | 0; //@line 32942
       $1327 = $0 + 78 | 0; //@line 32943
       $1329 = 123608 + ($1327 >>> 16 << 2) | 0; //@line 32945
       if (($1326 | 0) == (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1329 >> 2] | 0) + 4 >> 2] & 127]($1327) | 0)) {
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1319 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1319, 0); //@line 32957
        $1340 = $2 + 32 | 0; //@line 32958
        $1344 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1329 >> 2] | 0) + 4 >> 2] & 127]($1327) | 0; //@line 32962
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1340 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1340, $1344); //@line 32968
        $1350 = $2 + 18 | 0; //@line 32969
        $1352 = 123608 + ($1350 >>> 16 << 2) | 0; //@line 32971
        if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1352 >> 2] >> 2] & 127]($1350) | 0) {
         $1359 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1352 >> 2] >> 2] & 127]($1350) | 0; //@line 32979
         $1360 = $0 + 44 | 0; //@line 32980
         $1366 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1359 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1359) | 0; //@line 32986
         dest = $1366; //@line 32993
         src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1360 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1360) | 0; //@line 32993
         stop = dest + 28 | 0; //@line 32993
         do {
          HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 32993
          dest = dest + 1 | 0; //@line 32993
          src = src + 1 | 0; //@line 32993
         } while ((dest | 0) < (stop | 0));
        }
        $1373 = $2 + 48 | 0; //@line 32995
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1373 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1373, 2); //@line 33001
        $$1$i124 = 0; //@line 33002
       } else {
        label = 280; //@line 33004
       }
      } else {
       label = 280; //@line 33007
      }
      do {
       if ((label | 0) == 280) {
        $1380 = 123608 + ($1319 >>> 16 << 2) | 0; //@line 33012
        HEAP32[$5 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1380 >> 2] >> 2] & 127]($1319) | 0; //@line 33016
        HEAP32[$5 + 4 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1313 >> 2] | 0) + 4 >> 2] & 127]($1311) | 0; //@line 33022
        HEAP32[$5 + 8 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1322 >> 2] | 0) + 4 >> 2] & 127]($1320) | 0; //@line 33028
        $1394 = HEAP32[30848] | 0; //@line 33029
        HEAP32[$5 + 32 >> 2] = $1394 + 306; //@line 33032
        _Execute68k($1394 + 614 | 0, $5); //@line 33034
        $1399 = (HEAP32[30848] | 0) + 306 | 0; //@line 33036
        $1404 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1399 >>> 16 << 2) >> 2] >> 2] & 127]($1399) | 0; //@line 33041
        $1405 = HEAP32[$5 >> 2] | 0; //@line 33042
        if ($1405 & 65535 | 0) {
         $$1$i124 = $1405 & 65535; //@line 33047
         break;
        }
        $1409 = $1404 + 12 | 0; //@line 33050
        $1414 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1409 >>> 16 << 2) >> 2] >> 2] & 127]($1409) | 0; //@line 33055
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[$1380 >> 2] | 0) + 12 >> 2] & 31]($1319, $1414); //@line 33059
        $1418 = $2 + 32 | 0; //@line 33060
        $1420 = 123608 + ($1404 >>> 16 << 2) | 0; //@line 33062
        $1424 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1420 >> 2] >> 2] & 127]($1404) | 0) + 78 | 0; //@line 33066
        $1430 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1424 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1424) | 0; //@line 33072
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1418 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1418, $1430); //@line 33078
        $1436 = $2 + 18 | 0; //@line 33079
        $1438 = 123608 + ($1436 >>> 16 << 2) | 0; //@line 33081
        if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1438 >> 2] >> 2] & 127]($1436) | 0) {
         $1445 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1438 >> 2] >> 2] & 127]($1436) | 0; //@line 33089
         $1449 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1420 >> 2] >> 2] & 127]($1404) | 0) + 44 | 0; //@line 33093
         $1455 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1445 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1445) | 0; //@line 33099
         dest = $1455; //@line 33106
         src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1449 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1449) | 0; //@line 33106
         stop = dest + 28 | 0; //@line 33106
         do {
          HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 33106
          dest = dest + 1 | 0; //@line 33106
          src = src + 1 | 0; //@line 33106
         } while ((dest | 0) < (stop | 0));
        }
        $1462 = $2 + 48 | 0; //@line 33108
        $1463 = $1404 + 4 | 0; //@line 33109
        $1468 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1463 >>> 16 << 2) >> 2] >> 2] & 127]($1463) | 0; //@line 33114
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1462 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1462, $1468); //@line 33120
        $$1$i124 = 0; //@line 33121
       }
      } while (0);
      $$0 = $$1$i124; //@line 33124
      STACKTOP = sp; //@line 33125
      return $$0 | 0; //@line 33125
     }
    case 8:
     {
      $1474 = $2 + 28 | 0; //@line 33129
      $1476 = 123608 + ($1474 >>> 16 << 2) | 0; //@line 33131
      $1481 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1476 >> 2] | 0) + 4 >> 2] & 127]($1474) | 0) == 0; //@line 33136
      $1482 = $2 + 24 | 0; //@line 33137
      $1485 = HEAP32[123608 + ($1482 >>> 16 << 2) >> 2] | 0; //@line 33140
      L455 : do {
       if ($1481) {
        HEAP32[$5 >> 2] = (FUNCTION_TABLE_ii[HEAP32[$1485 + 4 >> 2] & 127]($1482) | 0) << 16 >> 16; //@line 33148
        $1490 = HEAP32[30848] | 0; //@line 33149
        HEAP32[$5 + 32 >> 2] = $1490 + 306; //@line 33152
        _Execute68k($1490 + 752 | 0, $5); //@line 33154
        $1495 = (HEAP32[30848] | 0) + 306 | 0; //@line 33156
        $1500 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1495 >>> 16 << 2) >> 2] >> 2] & 127]($1495) | 0; //@line 33161
        if (!(HEAP32[$5 >> 2] & 65535)) {
         $$2$i126 = $1500; //@line 33166
         label = 293; //@line 33167
        } else {
         $$137$i = -51; //@line 33169
        }
       } else {
        FUNCTION_TABLE_vii[HEAP32[$1485 + 16 >> 2] & 31]($1482, 0); //@line 33174
        if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1476 >> 2] | 0) + 4 >> 2] & 127]($1474) | 0) > 0) {
         $1511 = $6 + 32 | 0; //@line 33181
         $1512 = $6 + 36 | 0; //@line 33182
         $1513 = $6 + 40 | 0; //@line 33183
         $$03440$i = 0; //@line 33184
         while (1) {
          HEAP32[$1511 >> 2] = $0; //@line 33186
          HEAP32[$1512 >> 2] = $1482; //@line 33187
          $1520 = HEAP32[30848] | 0; //@line 33188
          HEAP32[$1513 >> 2] = $1520 + 306; //@line 33190
          _Execute68k($1520 + 736 | 0, $6); //@line 33192
          $1524 = (HEAP32[30848] | 0) + 306 | 0; //@line 33194
          $1529 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1524 >>> 16 << 2) >> 2] >> 2] & 127]($1524) | 0; //@line 33199
          $1530 = HEAP32[$6 >> 2] | 0; //@line 33200
          $$03440$i = $$03440$i + 1 | 0; //@line 33203
          if ($1530 & 65535 | 0) {
           break;
          }
          if (($$03440$i | 0) >= (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1476 >> 2] | 0) + 4 >> 2] & 127]($1474) | 0)) {
           $$2$i126 = $1529; //@line 33215
           label = 293; //@line 33216
           break L455;
          }
         }
         $$137$i = $1530 & 65535; //@line 33221
        } else {
         $$137$i = -51; //@line 33223
        }
       }
      } while (0);
      if ((label | 0) == 293) {
       if (!$$2$i126) {
        $$137$i = -51; //@line 33230
       } else {
        $1535 = $2 + 18 | 0; //@line 33232
        $1537 = 123608 + ($1535 >>> 16 << 2) | 0; //@line 33234
        if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1537 >> 2] >> 2] & 127]($1535) | 0) {
         $1544 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1537 >> 2] >> 2] & 127]($1535) | 0; //@line 33242
         $1550 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1544 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1544) | 0; //@line 33248
         $1551 = $$2$i126 + 62 | 0; //@line 33249
         $1557 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1551 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1551) | 0; //@line 33255
         $1558 = HEAP8[$1557 >> 0] | 0; //@line 33256
         HEAP8[$1550 >> 0] = $1558; //@line 33257
         if ($1558 << 24 >> 24) {
          $$010$i$i131 = $1558 << 24 >> 24; //@line 33261
          $$0511$pn$i$i130 = $1557; //@line 33261
          $$0612$pn$i$i129 = $1550; //@line 33261
          do {
           $$0511$pn$i$i130 = $$0511$pn$i$i130 + 1 | 0; //@line 33263
           $$0612$pn$i$i129 = $$0612$pn$i$i129 + 1 | 0; //@line 33264
           $$010$i$i131 = $$010$i$i131 + -1 | 0; //@line 33265
           HEAP8[$$0612$pn$i$i129 >> 0] = HEAP8[$$0511$pn$i$i130 >> 0] | 0; //@line 33267
          } while (($$010$i$i131 | 0) != 0);
         }
        }
        $1564 = $2 + 32 | 0; //@line 33277
        $1569 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$2$i126 >>> 16 << 2) >> 2] >> 2] & 127]($$2$i126) | 0; //@line 33282
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1564 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1564, $1569); //@line 33288
        $1575 = $2 + 36 | 0; //@line 33289
        $1576 = $$2$i126 + 4 | 0; //@line 33290
        $1582 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1576 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($1576) | 0; //@line 33296
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1575 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($1575, $1582); //@line 33302
        $1588 = $2 + 38 | 0; //@line 33303
        $1589 = $$2$i126 + 6 | 0; //@line 33304
        $1595 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1589 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1589) | 0; //@line 33310
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1588 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1588, $1595); //@line 33316
        $1601 = $2 + 40 | 0; //@line 33317
        $1602 = $$2$i126 + 8 | 0; //@line 33318
        $1607 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1602 >>> 16 << 2) >> 2] >> 2] & 127]($1602) | 0; //@line 33323
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1601 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1601, $1607); //@line 33329
        $1613 = $2 + 44 | 0; //@line 33330
        $1614 = $$2$i126 + 12 | 0; //@line 33331
        $1619 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1614 >>> 16 << 2) >> 2] >> 2] & 127]($1614) | 0; //@line 33336
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1613 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1613, $1619); //@line 33342
        $1625 = $2 + 48 | 0; //@line 33343
        $1626 = $$2$i126 + 16 | 0; //@line 33344
        $1631 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1626 >>> 16 << 2) >> 2] >> 2] & 127]($1626) | 0; //@line 33349
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1625 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1625, $1631); //@line 33355
        $1637 = $2 + 52 | 0; //@line 33356
        $1638 = $$2$i126 + 20 | 0; //@line 33357
        $1644 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1638 >>> 16 << 2) >> 2] >> 2] & 127]($1638) | 0) + 78 | 0; //@line 33363
        $1650 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1644 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1644) | 0; //@line 33369
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1637 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1637, $1650); //@line 33375
        $1656 = $2 + 54 | 0; //@line 33376
        $1657 = $$2$i126 + 30 | 0; //@line 33377
        $1662 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1657 >>> 16 << 2) >> 2] >> 2] & 127]($1657) | 0; //@line 33382
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1656 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1656, $1662); //@line 33388
        $1668 = $2 + 58 | 0; //@line 33389
        $1669 = $$2$i126 + 58 | 0; //@line 33390
        $1674 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1669 >>> 16 << 2) >> 2] >> 2] & 127]($1669) | 0; //@line 33395
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1668 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1668, $1674); //@line 33401
        $$137$i = 0; //@line 33402
       }
      }
      $$0 = $$137$i; //@line 33405
      STACKTOP = sp; //@line 33406
      return $$0 | 0; //@line 33406
     }
    case 9:
     {
      $1680 = $2 + 28 | 0; //@line 33410
      $sext$i136 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1680 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1680) | 0) << 16; //@line 33417
      $1687 = $sext$i136 >> 16; //@line 33418
      L475 : do {
       if (($sext$i136 | 0) < 0) {
        $1689 = $2 + 48 | 0; //@line 33422
        $1694 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1689 >>> 16 << 2) >> 2] >> 2] & 127]($1689) | 0; //@line 33427
        $$06$i$i137 = HEAP32[30826] | 0; //@line 33428
        L477 : do {
         if ($$06$i$i137 | 0) {
          $$07$i$i138 = $$06$i$i137; //@line 33432
          while (1) {
           if ((HEAP32[$$07$i$i138 + 4 >> 2] | 0) == ($1694 | 0)) {
            break;
           }
           $$0$i$i140 = HEAP32[$$07$i$i138 >> 2] | 0; //@line 33440
           if (!$$0$i$i140) {
            break L477;
           } else {
            $$07$i$i138 = $$0$i$i140; //@line 33445
           }
          }
          HEAP32[$5 >> 2] = $$07$i$i138; //@line 33448
          __ZL19get_path_for_fsitemP6FSItem($$07$i$i138); //@line 33449
          label = 321; //@line 33450
          break L475;
         }
        } while (0);
        HEAP32[$5 >> 2] = 0; //@line 33454
        $$6$i152 = -120; //@line 33455
       } else {
        if (!$1687) {
         $1701 = $2 + 48 | 0; //@line 33459
         $1707 = __ZL17get_item_and_pathjjRP6FSItemb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1701 >>> 16 << 2) >> 2] >> 2] & 127]($1701) | 0, $5) | 0; //@line 33465
         if (!($1707 << 16 >> 16)) {
          label = 321; //@line 33468
          break;
         } else {
          $$6$i152 = $1707; //@line 33471
          break;
         }
        }
        $1709 = $2 + 48 | 0; //@line 33475
        $1715 = __ZL15get_current_dirjjRjb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1709 >>> 16 << 2) >> 2] >> 2] & 127]($1709) | 0, $6, 1) | 0; //@line 33481
        L487 : do {
         if (!($1715 << 16 >> 16)) {
          $1717 = HEAP32[$6 >> 2] | 0; //@line 33485
          $$06$i101$i = HEAP32[30826] | 0; //@line 33486
          if (!$$06$i101$i) {
           $$4$ph$i142 = -120; //@line 33489
          } else {
           $$07$i102$i = $$06$i101$i; //@line 33491
           while (1) {
            if ((HEAP32[$$07$i102$i + 4 >> 2] | 0) == ($1717 | 0)) {
             break;
            }
            $$0$i104$i = HEAP32[$$07$i102$i >> 2] | 0; //@line 33499
            if (!$$0$i104$i) {
             $$4$ph$i142 = -120; //@line 33502
             break L487;
            } else {
             $$07$i102$i = $$0$i104$i; //@line 33505
            }
           }
           __ZL19get_path_for_fsitemP6FSItem($$07$i102$i); //@line 33508
           $1723 = _opendir(657423) | 0; //@line 33509
           if (!$1723) {
            $$4$ph$i142 = -120; //@line 33512
           } else {
            L494 : do {
             if (($sext$i136 | 0) > 0) {
              $$0100122$i = 0; //@line 33517
              L495 : while (1) {
               do {
                $1726 = _readdir($1723) | 0; //@line 33520
                if (!$1726) {
                 break L495;
                }
               } while ((HEAP8[$1726 + 11 >> 0] | 0) == 46);
               $$0100122$i = $$0100122$i + 1 | 0; //@line 33532
               if (($$0100122$i | 0) >= ($1687 | 0)) {
                $$094$lcssa$i = $1726; //@line 33537
                break L494;
               }
              }
              _closedir($1723) | 0; //@line 33541
              $$4$ph$i142 = -43; //@line 33542
              break L487;
             } else {
              $$094$lcssa$i = 0; //@line 33545
             }
            } while (0);
            $1733 = $$094$lcssa$i + 11 | 0; //@line 33548
            __Z18add_path_componentPcPKc(657423, $1733); //@line 33549
            HEAP32[$5 >> 2] = __ZL11find_fsitemPKcP6FSItem($1733, $$07$i102$i) | 0; //@line 33551
            _closedir($1723) | 0; //@line 33552
            label = 321; //@line 33553
            break L475;
           }
          }
         } else {
          $$4$ph$i142 = $1715; //@line 33558
         }
        } while (0);
        $$6$i152 = $$4$ph$i142; //@line 33561
       }
      } while (0);
      if ((label | 0) == 321) {
       L506 : do {
        if ((_stat(657423, $6) | 0) < 0) {
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$5$i150 = 0; //@line 33573
           break L506;
           break;
          }
         case 21:
         case 2:
          {
           $$5$i150 = -43; //@line 33578
           break L506;
           break;
          }
         case 1:
         case 13:
          {
           $$5$i150 = -54; //@line 33583
           break L506;
           break;
          }
         case 17:
          {
           $$5$i150 = -48; //@line 33588
           break L506;
           break;
          }
         case 39:
         case 16:
          {
           $$5$i150 = -47; //@line 33593
           break L506;
           break;
          }
         case 28:
          {
           $$5$i150 = -34; //@line 33598
           break L506;
           break;
          }
         case 30:
          {
           $$5$i150 = -44; //@line 33603
           break L506;
           break;
          }
         case 24:
          {
           $$5$i150 = -42; //@line 33608
           break L506;
           break;
          }
         case 12:
          {
           $$5$i150 = -108; //@line 33613
           break L506;
           break;
          }
         default:
          {
           $$5$i150 = -36; //@line 33618
           break L506;
          }
         }
        } else {
         if (($1687 | 0) == -1) {
          if ((HEAP32[$6 + 12 >> 2] & 61440 | 0) != 16384) {
           $$5$i150 = -120; //@line 33630
           break;
          }
         }
         $1744 = $2 + 18 | 0; //@line 33634
         $1746 = 123608 + ($1744 >>> 16 << 2) | 0; //@line 33636
         L522 : do {
          if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$1746 >> 2] >> 2] & 127]($1744) | 0) {
           $1753 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1746 >> 2] >> 2] & 127]($1744) | 0; //@line 33645
           $1759 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1753 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1753) | 0; //@line 33651
           $1761 = (HEAP32[$5 >> 2] | 0) + 20 | 0; //@line 33653
           HEAP8[$1759 >> 0] = _strlen($1761) | 0; //@line 33656
           $$05$i108$i = $1761; //@line 33657
           $$pn$i$i144 = $1759; //@line 33657
           while (1) {
            $$06$i109$i = $$pn$i$i144 + 1 | 0; //@line 33659
            $1764 = $$05$i108$i + 1 | 0; //@line 33660
            $1765 = HEAP8[$$05$i108$i >> 0] | 0; //@line 33661
            switch ($1765 << 24 >> 24) {
            case 0:
             {
              break L522;
              break;
             }
            case 58:
             {
              $$0$i110$i = 47; //@line 33668
              break;
             }
            default:
             {
              $$0$i110$i = $1765; //@line 33672
             }
            }
            HEAP8[$$06$i109$i >> 0] = $$0$i110$i; //@line 33675
            $$05$i108$i = $1764; //@line 33676
            $$pn$i$i144 = $$06$i109$i; //@line 33676
           }
          }
         } while (0);
         $1766 = $2 + 24 | 0; //@line 33680
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1766 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1766, 0); //@line 33686
         $1772 = $2 + 30 | 0; //@line 33687
         $1776 = (HEAP32[$6 + 12 >> 2] & 61440 | 0) == 16384; //@line 33691
         $1780 = ($1776 ? 16 : 0) | (_access(657423, 2) | 0) != 0; //@line 33696
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1772 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($1772, $1780); //@line 33702
         $1786 = $2 + 31 | 0; //@line 33703
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1786 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($1786, 0); //@line 33709
         $1792 = $2 + 48 | 0; //@line 33710
         $1793 = HEAP32[$5 >> 2] | 0; //@line 33711
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1792 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1792, HEAP32[$1793 + 4 >> 2] | 0); //@line 33719
         $1801 = $2 + 100 | 0; //@line 33720
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1801 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1801, HEAP32[$1793 + 8 >> 2] | 0); //@line 33728
         $1809 = $2 + 72 | 0; //@line 33729
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1809 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1809, 0); //@line 33735
         $1816 = HEAP32[$6 + 56 >> 2] | 0; //@line 33737
         $1817 = $1793 + 52 | 0; //@line 33738
         if (($1816 | 0) > (HEAP32[$1817 >> 2] | 0)) {
          HEAP32[$1817 >> 2] = $1816; //@line 33742
          $$099$off0$i = 0; //@line 33743
         } else {
          $$099$off0$i = 1; //@line 33745
         }
         $1820 = $2 + 76 | 0; //@line 33747
         $1821 = __Z13TimeToMacTimel($1816) | 0; //@line 33748
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1820 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1820, $1821); //@line 33754
         $1827 = $2 + 80 | 0; //@line 33755
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1827 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1827, 0); //@line 33761
         __Z9get_finfoPKcjjb(657423, $2 + 32 | 0, $2 + 84 | 0, $1776); //@line 33764
         if (!$1776) {
          $1854 = $2 + 52 | 0; //@line 33766
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1854 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1854, 0); //@line 33772
          $1860 = $2 + 54 | 0; //@line 33773
          $1862 = HEAP32[$6 + 36 >> 2] | 0; //@line 33775
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1860 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1860, $1862); //@line 33781
          $1868 = $2 + 58 | 0; //@line 33782
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1868 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1868, ($1862 | 16383) + 1 | 0); //@line 33790
          $1876 = $2 + 62 | 0; //@line 33791
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1876 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1876, 0); //@line 33797
          $1882 = __Z14get_rfork_sizePKc(657423) | 0; //@line 33798
          $1883 = $2 + 64 | 0; //@line 33799
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1883 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1883, $1882); //@line 33805
          $1889 = $2 + 68 | 0; //@line 33806
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1889 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1889, ($1882 | 16383) + 1 | 0); //@line 33814
          $1897 = $2 + 104 | 0; //@line 33815
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1897 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1897, 0); //@line 33821
          $$5$i150 = 0; //@line 33822
          break;
         }
         if ($$099$off0$i) {
          $$298$i = HEAP32[$1793 + 56 >> 2] | 0; //@line 33828
         } else {
          $1837 = _opendir(657423) | 0; //@line 33830
          if (!$1837) {
           $$197$i = 0; //@line 33833
          } else {
           $1839 = _readdir($1837) | 0; //@line 33835
           if (!$1839) {
            $$096$lcssa$i = 0; //@line 33838
           } else {
            $$096121$i = 0; //@line 33840
            $1842 = $1839; //@line 33840
            while (1) {
             $$096$$i = ((HEAP8[$1842 + 11 >> 0] | 0) != 46 & 1) + $$096121$i | 0; //@line 33846
             $1842 = _readdir($1837) | 0; //@line 33847
             if (!$1842) {
              $$096$lcssa$i = $$096$$i; //@line 33850
              break;
             } else {
              $$096121$i = $$096$$i; //@line 33853
             }
            }
           }
           _closedir($1837) | 0; //@line 33857
           $$197$i = $$096$lcssa$i; //@line 33858
          }
          HEAP32[$1793 + 56 >> 2] = $$197$i; //@line 33861
          $$298$i = $$197$i; //@line 33862
         }
         $1848 = $2 + 52 | 0; //@line 33864
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1848 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1848, $$298$i); //@line 33870
         $$5$i150 = 0; //@line 33871
        }
       } while (0);
       $$6$i152 = $$5$i150; //@line 33874
      }
      $$0 = $$6$i152; //@line 33876
      STACKTOP = sp; //@line 33877
      return $$0 | 0; //@line 33877
     }
    case 10:
     {
      $1903 = $2 + 48 | 0; //@line 33881
      $1909 = __ZL17get_item_and_pathjjRP6FSItemb($2, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1903 >>> 16 << 2) >> 2] >> 2] & 127]($1903) | 0, $5) | 0; //@line 33887
      if (!($1909 << 16 >> 16)) {
       L553 : do {
        if ((_stat(657423, $6) | 0) < 0) {
         switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
         case 0:
          {
           $$0$i153 = 0; //@line 33898
           break L553;
           break;
          }
         case 21:
         case 2:
          {
           $$0$i153 = -43; //@line 33903
           break L553;
           break;
          }
         case 1:
         case 13:
          {
           $$0$i153 = -54; //@line 33908
           break L553;
           break;
          }
         case 17:
          {
           $$0$i153 = -48; //@line 33913
           break L553;
           break;
          }
         case 39:
         case 16:
          {
           $$0$i153 = -47; //@line 33918
           break L553;
           break;
          }
         case 28:
          {
           $$0$i153 = -34; //@line 33923
           break L553;
           break;
          }
         case 30:
          {
           $$0$i153 = -44; //@line 33928
           break L553;
           break;
          }
         case 24:
          {
           $$0$i153 = -42; //@line 33933
           break L553;
           break;
          }
         case 12:
          {
           $$0$i153 = -108; //@line 33938
           break L553;
           break;
          }
         default:
          {
           $$0$i153 = -36; //@line 33943
           break L553;
          }
         }
        } else {
         __Z9set_finfoPKcjjb(657423, $2 + 32 | 0, $2 + 84 | 0, (HEAP32[$6 + 12 >> 2] & 61440 | 0) == 16384); //@line 33954
         $$0$i153 = 0; //@line 33955
        }
       } while (0);
       $$1$i155 = $$0$i153; //@line 33958
      } else {
       $$1$i155 = $1909; //@line 33960
      }
      $$0 = $$1$i155; //@line 33962
      STACKTOP = sp; //@line 33963
      return $$0 | 0; //@line 33963
     }
    case 48:
     {
      $1921 = $2 + 36 | 0; //@line 33967
      $1926 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1921 >>> 16 << 2) >> 2] >> 2] & 127]($1921) | 0; //@line 33972
      $$$i156 = $1926 >>> 0 < 20 ? $1926 : 20; //@line 33974
      $1928 = $2 + 40 | 0; //@line 33975
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1928 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1928, $$$i156); //@line 33981
      $1934 = $2 + 32 | 0; //@line 33982
      $1939 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1934 >>> 16 << 2) >> 2] >> 2] & 127]($1934) | 0; //@line 33987
      if (!$$$i156) {
       $$0 = 0; //@line 33990
       STACKTOP = sp; //@line 33991
       return $$0 | 0; //@line 33991
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1939 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1939, 2); //@line 33998
      $1947 = $1939 + 2 | 0; //@line 34000
      if ($$$i156 >>> 0 <= 2) {
       $$0 = 0; //@line 34002
       STACKTOP = sp; //@line 34003
       return $$0 | 0; //@line 34003
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1947 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1947, 1040908288); //@line 34010
      $1954 = $1939 + 6 | 0; //@line 34012
      if ($$$i156 >>> 0 <= 6) {
       $$0 = 0; //@line 34014
       STACKTOP = sp; //@line 34015
       return $$0 | 0; //@line 34015
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1954 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1954, 0); //@line 34022
      $1961 = $1939 + 10 | 0; //@line 34024
      if ($$$i156 >>> 0 <= 10) {
       $$0 = 0; //@line 34026
       STACKTOP = sp; //@line 34027
       return $$0 | 0; //@line 34027
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1961 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1961, 0); //@line 34034
      $1968 = $1939 + 14 | 0; //@line 34036
      if ($$$i156 >>> 0 <= 14) {
       $$0 = 0; //@line 34038
       STACKTOP = sp; //@line 34039
       return $$0 | 0; //@line 34039
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1968 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1968, 0); //@line 34046
      $1975 = $1939 + 18 | 0; //@line 34048
      if ($$$i156 >>> 0 <= 18) {
       $$0 = 0; //@line 34050
       STACKTOP = sp; //@line 34051
       return $$0 | 0; //@line 34051
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1975 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1975, 0); //@line 34058
      $$0 = 0; //@line 34059
      STACKTOP = sp; //@line 34060
      return $$0 | 0; //@line 34060
     }
    case 65:
     {
      $1981 = HEAP32[30848] | 0; //@line 34064
      $1983 = $5 + 32 | 0; //@line 34066
      HEAP32[$1983 >> 2] = $1981 + 306; //@line 34067
      $1985 = $5 + 36 | 0; //@line 34069
      HEAP32[$1985 >> 2] = $1981 + 308; //@line 34070
      _Execute68k($1981 + 562 | 0, $5); //@line 34072
      $1988 = (HEAP32[30848] | 0) + 308 | 0; //@line 34074
      $1993 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1988 >>> 16 << 2) >> 2] >> 2] & 127]($1988) | 0; //@line 34079
      $1994 = HEAP32[$5 >> 2] | 0; //@line 34080
      do {
       if (!($1994 & 65535)) {
        $1998 = $1993 + 8 | 0; //@line 34085
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1998 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1998, 16964); //@line 34091
        $2004 = $1993 + 10 | 0; //@line 34092
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2004 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2004, 0); //@line 34098
        $2010 = $1993 + 14 | 0; //@line 34099
        $2012 = __Z13TimeToMacTimel(HEAP32[30843] | 0) | 0; //@line 34101
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2010 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2010, $2012); //@line 34107
        $2018 = $1993 + 94 | 0; //@line 34108
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2018 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2018, 0); //@line 34114
        $2024 = $1993 + 20 | 0; //@line 34115
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2024 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2024, 1); //@line 34121
        $2030 = $1993 + 112 | 0; //@line 34122
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2030 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2030, 1); //@line 34128
        $2036 = $1993 + 26 | 0; //@line 34129
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2036 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2036, 65535); //@line 34135
        $2042 = $1993 + 28 | 0; //@line 34136
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2042 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2042, 16384); //@line 34142
        $2048 = $1993 + 32 | 0; //@line 34143
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2048 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2048, 16384); //@line 34149
        $2054 = $1993 + 38 | 0; //@line 34150
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2054 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2054, HEAP32[383] | 0); //@line 34157
        $2061 = $1993 + 42 | 0; //@line 34158
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2061 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2061, 65535); //@line 34164
        $2067 = $1993 + 44 | 0; //@line 34165
        dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2067 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2067) | 0; //@line 34172
        src = 657390; //@line 34172
        stop = dest + 28 | 0; //@line 34172
        do {
         HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 34172
         dest = dest + 1 | 0; //@line 34172
         src = src + 1 | 0; //@line 34172
        } while ((dest | 0) < (stop | 0));
        $2074 = $1993 + 76 | 0; //@line 34173
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2074 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2074, 25185); //@line 34179
        $2080 = $1993 + 114 | 0; //@line 34180
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2080 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2080, 1); //@line 34186
        $2086 = $1993 + 118 | 0; //@line 34187
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2086 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2086, 1); //@line 34193
        HEAP32[$5 >> 2] = HEAP32[30849]; //@line 34195
        $2093 = HEAP32[30848] | 0; //@line 34196
        HEAP32[$1983 >> 2] = $2093 + 306; //@line 34198
        HEAP32[$1985 >> 2] = $1993; //@line 34199
        _Execute68k($2093 + 578 | 0, $5); //@line 34201
        $2097 = (HEAP32[30848] | 0) + 306 | 0; //@line 34203
        $2102 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2097 >>> 16 << 2) >> 2] >> 2] & 127]($2097) | 0; //@line 34208
        $2103 = HEAP32[$5 >> 2] | 0; //@line 34209
        if (!($2103 & 65535)) {
         HEAP32[$5 >> 2] = HEAP32[30849]; //@line 34214
         HEAP32[$1983 >> 2] = 7; //@line 34215
         _Execute68kTrap(-24529, $5); //@line 34216
         $2108 = $2 + 22 | 0; //@line 34217
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2108 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2108, $2102 << 16 >> 16); //@line 34225
         $$1$i158 = 0; //@line 34226
         break;
        } else {
         $$1$i158 = $2103 & 65535; //@line 34230
         break;
        }
       } else {
        $$1$i158 = $1994 & 65535; //@line 34235
       }
      } while (0);
      $$0 = $$1$i158; //@line 34238
      STACKTOP = sp; //@line 34239
      return $$0 | 0; //@line 34239
     }
    case 11:
     {
      $$0 = 0; //@line 34243
      STACKTOP = sp; //@line 34244
      return $$0 | 0; //@line 34244
     }
    default:
     {
      break L1;
     }
    }
   } while (0);
  }
 } while (0);
 $$0 = -50; //@line 34254
 STACKTOP = sp; //@line 34255
 return $$0 | 0; //@line 34255
}
function __Z16fpuop_arithmeticjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$$0$i$i = 0, $$$047$1$i$i = 0, $$$047$i$i = 0, $$$4$2$i$i = 0, $$$4$4$i$i = 0, $$$4$6$i$i = 0, $$$4$i$i = 0, $$$6$2$i$i = 0, $$$6$4$i$i = 0, $$$6$i$i = 0, $$$7$i$i = 0, $$$9$i$i = 0, $$$i479 = 0, $$$i482 = 0, $$$i485 = 0, $$$i488 = 0, $$$i502 = 0, $$$i505 = 0, $$0$i$i = 0.0, $$0$i$i457 = 0, $$0$i$i459 = 0, $$0$i$i468 = 0, $$0$i$i514 = 0, $$0$i101$i = 0.0, $$0$i104$i = 0.0, $$0$i107$i = 0, $$0$i492 = 0.0, $$0$i92$i = 0.0, $$0$i95$i = 0.0, $$0$i98$i = 0.0, $$0134$i = 0, $$0135$i = 0, $$0136$i = 0, $$0138$i = 0, $$0139$i = 0, $$0372642 = 0, $$0382$in = 0, $$0382$in$ph = 0, $$03963$i$i = 0, $$040$i$i = 0, $$0405058$i$i = 0, $$04051$i$i = 0, $$041$i$i = 0, $$0414859$i$i = 0, $$04149$i$i = 0, $$0603 = 0, $$0604 = 0, $$0605 = 0, $$0606 = 0, $$0607 = 0, $$0608 = 0, $$080$i = 0, $$098$i = 0, $$1$i$i = 0, $$1$i105$i = 0, $$1376 = 0, $$1379 = 0, $$1379$ = 0, $$1383641 = 0, $$145$i = 0, $$1644 = 0, $$2$i$i = 0, $$2377 = 0, $$2384643 = 0, $$2638 = 0, $$3381 = 0, $$3385$in = 0, $$3385$in$ph = 0, $$3640 = 0, $$4$2$i$i = 0, $$4$4$i$i = 0, $$4$6$i$i = 0, $$4$i$i = 0, $$4637 = 0, $$5639 = 0, $$6$2$i$i = 0, $$6$4$i$i = 0, $$6$6$i$i = 0, $$6$7$i$i = 0, $$6$i$i = 0, $$7$i$i = 0, $$cast$i = 0, $$cast$i509 = 0, $$cast107$i = 0, $$cast146$i = 0, $$pre = 0, $$sink = 0.0, $$sink$i = 0, $$sink104$i$sink = 0.0, $$val410 = 0.0, $$val413 = 0.0, $$val414 = 0.0, $$val439 = 0.0, $$val454 = 0.0, $10 = 0, $100 = 0, $1004 = 0, $1009 = 0, $1015 = 0, $1036 = 0, $1042 = 0, $105 = 0, $1054 = 0, $1055 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1066 = 0, $1067 = 0, $1072 = 0, $1073 = 0, $1087 = 0, $1088 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1098 = 0, $11 = 0, $1103 = 0, $1105 = 0, $1116 = 0, $1126 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1136 = 0, $1137 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1169 = 0, $1174 = 0, $1176 = 0, $1187 = 0, $12 = 0.0, $1201 = 0, $1227 = 0, $123 = 0, $1233 = 0, $1236 = 0, $1237 = 0, $1241 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1267 = 0, $1269 = 0, $1271 = 0, $1272 = 0, $1279 = 0, $1284 = 0, $1285 = 0, $1292 = 0, $1295 = 0, $1302 = 0, $1305 = 0, $1322 = 0, $1325 = 0, $1328 = 0, $1335 = 0, $1340 = 0, $1343 = 0, $1350 = 0, $1357 = 0, $1360 = 0, $1366 = 0, $1370 = 0, $1383 = 0, $1388 = 0, $1389 = 0, $1394 = 0, $1395 = 0, $1400 = 0, $1405 = 0, $1407 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $1426 = 0, $143 = 0, $1433 = 0, $1435 = 0, $1438 = 0, $1440 = 0, $1443 = 0, $1451 = 0, $1452 = 0, $1457 = 0, $1458 = 0, $146 = 0, $1463 = 0, $149 = 0, $15 = 0, $1547 = 0, $156 = 0, $1575 = 0, $1576 = 0, $1581 = 0, $1594 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1605 = 0, $1607 = 0.0, $161 = 0, $1612 = 0.0, $1614 = 0.0, $1618 = 0.0, $1620 = 0.0, $1624 = 0.0, $1626 = 0.0, $1628 = 0, $1632 = 0.0, $1633 = 0, $1635 = 0.0, $1636 = 0, $164 = 0, $1640 = 0.0, $1641 = 0, $1643 = 0.0, $1644 = 0, $1648 = 0.0, $1649 = 0, $1651 = 0.0, $1652 = 0, $1653 = 0, $1655 = 0, $1658 = 0, $1659 = 0, $1664 = 0, $1666 = 0, $1675 = 0, $1681 = 0, $1685 = 0, $1690 = 0, $1692 = 0, $1701 = 0, $1707 = 0, $171 = 0, $1713 = 0.0, $1717 = 0, $1718 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1733 = 0, $1734 = 0, $1752 = 0.0, $1754 = 0.0, $1757 = 0.0, $1759 = 0.0, $1762 = 0.0, $1765 = 0.0, $1767 = 0.0, $1769 = 0.0, $1771 = 0.0, $1773 = 0.0, $1775 = 0.0, $1777 = 0.0, $1779 = 0.0, $178 = 0, $1782 = 0.0, $1784 = 0.0, $1786 = 0.0, $1789 = 0.0, $1791 = 0.0, $1793 = 0.0, $1795 = 0.0, $1797 = 0.0, $1799 = 0.0, $181 = 0, $1811 = 0, $1818 = 0, $1819 = 0, $1824 = 0, $1828 = 0.0, $1842 = 0, $1849 = 0, $1850 = 0, $1856 = 0, $1857 = 0, $1862 = 0, $1864 = 0.0, $1865 = 0, $1866 = 0.0, $1869 = 0.0, $187 = 0, $1874 = 0, $1876 = 0.0, $1882 = 0, $1883 = 0, $1885 = 0, $1888 = 0, $1889 = 0, $1894 = 0, $1896 = 0, $1905 = 0, $1911 = 0, $1915 = 0, $1920 = 0, $1922 = 0, $1931 = 0, $1937 = 0, $1942 = 0.0, $1944 = 0, $1945 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1960 = 0, $1961 = 0, $1966 = 0, $1970 = 0.0, $1971 = 0, $1972 = 0.0, $1976 = 0.0, $1981 = 0, $1983 = 0.0, $1989 = 0, $1990 = 0, $1992 = 0, $1995 = 0, $2 = 0, $2001 = 0, $2003 = 0, $2012 = 0, $2018 = 0, $2027 = 0, $2029 = 0, $2038 = 0, $2044 = 0, $2049 = 0, $2052 = 0, $2054 = 0, $2057 = 0, $2063 = 0, $2065 = 0, $2067 = 0, $2069 = 0, $2072 = 0, $2073 = 0, $2075 = 0, $2078 = 0, $2079 = 0, $2083 = 0.0, $2084 = 0, $2086 = 0.0, $2087 = 0, $2089 = 0.0, $2093 = 0.0, $2103 = 0, $2109 = 0, $2115 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $216 = 0.0, $218 = 0, $219 = 0, $220 = 0, $222 = 0, $227 = 0, $239 = 0, $245 = 0, $251 = 0, $252 = 0, $253 = 0, $258 = 0, $262 = 0, $266 = 0, $268 = 0, $271 = 0, $272 = 0, $277 = 0, $279 = 0, $280 = 0, $287 = 0, $288 = 0, $294 = 0, $295 = 0, $3 = 0, $302 = 0, $303 = 0, $309 = 0, $310 = 0, $317 = 0, $318 = 0, $323 = 0, $324 = 0, $329 = 0, $330 = 0, $336 = 0, $337 = 0, $344 = 0, $345 = 0, $351 = 0, $352 = 0, $359 = 0, $360 = 0, $366 = 0, $367 = 0, $373 = 0, $374 = 0, $376 = 0, $377 = 0, $378 = 0, $380 = 0, $383 = 0, $385 = 0, $387 = 0, $390 = 0, $392 = 0, $397 = 0, $405 = 0, $409 = 0, $415 = 0, $421 = 0, $449 = 0, $451 = 0, $460 = 0, $493 = 0, $499 = 0, $500 = 0, $501 = 0, $504 = 0, $513 = 0, $515 = 0, $518 = 0, $519 = 0, $525 = 0.0, $553 = 0, $560 = 0, $569 = 0, $570 = 0, $588 = 0, $597 = 0, $599 = 0, $602 = 0, $603 = 0, $609 = 0.0, $637 = 0, $644 = 0, $653 = 0, $654 = 0, $672 = 0, $675 = 0, $678 = 0, $684 = 0, $687 = 0, $691 = 0, $695 = 0, $698 = 0, $7 = 0, $708 = 0, $709 = 0, $719 = 0, $736 = 0, $745 = 0, $751 = 0, $752 = 0, $754 = 0, $762 = 0, $774 = 0, $777 = 0, $779 = 0, $782 = 0, $783 = 0, $789 = 0.0, $79 = 0, $80 = 0, $809 = 0, $814 = 0, $819 = 0, $824 = 0, $825 = 0, $826 = 0, $839 = 0, $845 = 0, $846 = 0, $848 = 0, $859 = 0, $864 = 0, $870 = 0, $875 = 0, $88 = 0, $884 = 0, $885 = 0, $899 = 0, $90 = 0, $917 = 0, $92 = 0, $923 = 0, $929 = 0, $93 = 0, $942 = 0.0, $944 = 0, $945 = 0, $946 = 0, $948 = 0, $953 = 0, $960 = 0, $961 = 0, $967 = 0, $973 = 0, $985 = 0.0, $987 = 0, $988 = 0, $989 = 0, $991 = 0, $996 = 0, $exp2 = 0.0, $or$cond398 = 0, $or$cond401 = 0, $storemerge = 0, $storemerge671 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 123
 STACKTOP = STACKTOP + 128 | 0; //@line 124
 $vararg_buffer1 = sp + 16 | 0; //@line 125
 $vararg_buffer = sp + 8 | 0; //@line 126
 $2 = sp; //@line 127
 $3 = sp + 20 | 0; //@line 128
 switch ($1 >>> 13 & 7) {
 case 3:
  {
   $7 = 112672 + (($1 >>> 7 & 7) << 3) | 0; //@line 136
   $10 = $1 >>> 10; //@line 139
   $11 = $10 & 7; //@line 140
   if (!($1 & 16384)) {
    $12 = +HEAPF64[$7 >> 3]; //@line 142
    HEAPF64[112672 + ($11 << 3) >> 3] = $12; //@line 144
    HEAPF64[14092] = $12; //@line 145
    STACKTOP = sp; //@line 146
    return;
   }
   $15 = $0 & 7; //@line 149
   L9 : do {
    switch ($0 >>> 3 & 7) {
    case 0:
     {
      switch ($10 & 7) {
      case 6:
       {
        switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
        case 1:
         {
          $$0$i$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 170
          break;
         }
        case 2:
         {
          $$0$i$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 176
          break;
         }
        case 0:
         {
          $$0$i$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 184
          break;
         }
        case 3:
         {
          $$0$i$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 190
          break;
         }
        default:
         {}
        }
        $$sink$i = ~~$$0$i$i & 255 | HEAP32[651008 + ($15 << 2) >> 2] & -256; //@line 203
        break;
       }
      case 4:
       {
        switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
        case 1:
         {
          $$0$i92$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 218
          break;
         }
        case 2:
         {
          $$0$i92$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 224
          break;
         }
        case 0:
         {
          $$0$i92$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 232
          break;
         }
        case 3:
         {
          $$0$i92$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 238
          break;
         }
        default:
         {}
        }
        $$sink$i = ~~$$0$i92$i & 65535 | HEAP32[651008 + ($15 << 2) >> 2] & -65536; //@line 251
        break;
       }
      case 0:
       {
        switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
        case 1:
         {
          $$0$i95$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 266
          break;
         }
        case 2:
         {
          $$0$i95$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 272
          break;
         }
        case 0:
         {
          $$0$i95$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 280
          break;
         }
        case 3:
         {
          $$0$i95$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 286
          break;
         }
        default:
         {}
        }
        $$sink$i = ~~$$0$i95$i; //@line 294
        break;
       }
      case 1:
       {
        $$sink$i = (HEAPF32[tempDoublePtr >> 2] = +HEAPF64[$7 >> 3], HEAP32[tempDoublePtr >> 2] | 0); //@line 301
        break;
       }
      default:
       {
        break L9;
       }
      }
      HEAP32[651008 + ($15 << 2) >> 2] = $$sink$i; //@line 309
      STACKTOP = sp; //@line 310
      return;
     }
    case 1:
     {
      break;
     }
    case 2:
     {
      $$080$i = HEAP32[651040 + ($15 << 2) >> 2] | 0; //@line 319
      label = 41; //@line 320
      break;
     }
    case 3:
     {
      $79 = 651040 + ($15 << 2) | 0; //@line 324
      $80 = HEAP32[$79 >> 2] | 0; //@line 325
      HEAP32[$79 >> 2] = (HEAP32[(($15 | 0) == 7 ? 6704 : 6736) + ($11 << 2) >> 2] | 0) + $80; //@line 331
      $$080$i = $80; //@line 332
      label = 41; //@line 333
      break;
     }
    case 4:
     {
      $88 = 651040 + ($15 << 2) | 0; //@line 341
      $90 = (HEAP32[$88 >> 2] | 0) - (HEAP32[(($15 | 0) == 7 ? 6704 : 6736) + ($11 << 2) >> 2] | 0) | 0; //@line 343
      HEAP32[$88 >> 2] = $90; //@line 344
      $$080$i = $90; //@line 345
      label = 41; //@line 346
      break;
     }
    case 5:
     {
      $92 = HEAP32[651040 + ($15 << 2) >> 2] | 0; //@line 351
      $93 = HEAP32[162769] | 0; //@line 352
      $100 = HEAPU8[$93 >> 0] << 8 | HEAPU8[$93 + 1 >> 0]; //@line 359
      HEAP32[162769] = $93 + 2; //@line 361
      $$080$i = ($100 << 16 >> 16) + $92 | 0; //@line 365
      label = 41; //@line 366
      break;
     }
    case 6:
     {
      $105 = HEAP32[651040 + ($15 << 2) >> 2] | 0; //@line 371
      $106 = HEAP32[162769] | 0; //@line 372
      $113 = HEAPU8[$106 >> 0] << 8 | HEAPU8[$106 + 1 >> 0]; //@line 379
      HEAP32[162769] = $106 + 2; //@line 381
      $$080$i = __Z15get_disp_ea_020jj($105, $113) | 0; //@line 383
      label = 41; //@line 384
      break;
     }
    case 7:
     {
      switch ($0 & 7) {
      case 0:
       {
        $116 = HEAP32[162769] | 0; //@line 392
        $123 = HEAPU8[$116 >> 0] << 8 | HEAPU8[$116 + 1 >> 0]; //@line 399
        HEAP32[162769] = $116 + 2; //@line 401
        $$080$i = $123 << 16 >> 16; //@line 404
        label = 41; //@line 405
        break L9;
        break;
       }
      case 1:
       {
        $126 = HEAP32[162769] | 0; //@line 410
        $143 = HEAPU8[$126 + 1 >> 0] << 16 | HEAPU8[$126 >> 0] << 24 | HEAPU8[$126 + 2 >> 0] << 8 | HEAPU8[$126 + 3 >> 0]; //@line 427
        HEAP32[162769] = $126 + 4; //@line 429
        $$080$i = $143; //@line 430
        label = 41; //@line 431
        break L9;
        break;
       }
      case 2:
       {
        $146 = HEAP32[162769] | 0; //@line 437
        $149 = $146 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 440
        $$cast146$i = $146; //@line 441
        $156 = HEAPU8[$$cast146$i >> 0] << 8 | HEAPU8[$$cast146$i + 1 >> 0]; //@line 448
        HEAP32[162769] = $$cast146$i + 2; //@line 450
        $$080$i = $149 + ($156 << 16 >> 16) | 0; //@line 454
        label = 41; //@line 455
        break L9;
        break;
       }
      case 3:
       {
        $161 = HEAP32[162769] | 0; //@line 461
        $164 = $161 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 464
        $$cast$i = $161; //@line 465
        $171 = HEAPU8[$$cast$i >> 0] << 8 | HEAPU8[$$cast$i + 1 >> 0]; //@line 472
        HEAP32[162769] = $$cast$i + 2; //@line 474
        $$080$i = __Z15get_disp_ea_020jj($164, $171) | 0; //@line 476
        label = 41; //@line 477
        break L9;
        break;
       }
      case 4:
       {
        $178 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 486
        $181 = $178 + (HEAP32[6704 + ($11 << 2) >> 2] | 0) | 0; //@line 489
        $187 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($181 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($181) | 0; //@line 495
        HEAP32[162770] = $187; //@line 496
        HEAP32[162769] = $187; //@line 497
        HEAP32[162768] = $181; //@line 498
        $$080$i = $178; //@line 499
        label = 41; //@line 500
        break L9;
        break;
       }
      default:
       {
        break L9;
       }
      }
      break;
     }
    default:
     {}
    }
   } while (0);
   L52 : do {
    if ((label | 0) == 41) {
     switch ($10 & 7) {
     case 0:
      {
       switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
       case 1:
        {
         $$0$i104$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 532
         break;
        }
       case 2:
        {
         $$0$i104$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 538
         break;
        }
       case 0:
        {
         $$0$i104$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 546
         break;
        }
       case 3:
        {
         $$0$i104$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 552
         break;
        }
       default:
        {}
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$080$i, ~~$$0$i104$i); //@line 565
       STACKTOP = sp; //@line 566
       return;
      }
     case 1:
      {
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$080$i, (HEAPF32[tempDoublePtr >> 2] = +HEAPF64[$7 >> 3], HEAP32[tempDoublePtr >> 2] | 0)); //@line 578
       STACKTOP = sp; //@line 579
       return;
      }
     case 2:
      {
       $216 = +HEAPF64[$7 >> 3]; //@line 583
       HEAPF64[tempDoublePtr >> 3] = $216; //@line 585
       $218 = HEAP32[tempDoublePtr >> 2] | 0; //@line 585
       $219 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 586
       if ($216 == 0.0) {
        $$0134$i = 0; //@line 588
        $$0135$i = 0; //@line 588
        $$0139$i = 0; //@line 588
       } else {
        $220 = _bitshift64Lshr($218 | 0, $219 | 0, 52) | 0; //@line 590
        $222 = $220 & 2047; //@line 592
        $227 = _bitshift64Lshr($218 | 0, $219 | 0, 21) | 0; //@line 599
        $$0134$i = (($222 | 0) == 2047 ? 2147418112 : ($222 << 16) + 1006632960 | 0) | $219 & -2147483648; //@line 606
        $$0135$i = $218 >>> 21 | $227 & 2147481600 | -2147483648; //@line 606
        $$0139$i = $218 << 11; //@line 606
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$080$i, $$0134$i); //@line 613
       $239 = $$080$i + 4 | 0; //@line 614
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($239 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($239, $$0135$i); //@line 620
       $245 = $$080$i + 8 | 0; //@line 621
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($245 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($245, $$0139$i); //@line 627
       STACKTOP = sp; //@line 628
       return;
      }
     case 3:
      {
       HEAPF64[$vararg_buffer >> 3] = +HEAPF64[$7 >> 3]; //@line 633
       _sprintf($3, 106240, $vararg_buffer) | 0; //@line 634
       $251 = HEAP8[$3 >> 0] | 0; //@line 635
       $252 = $251 << 24 >> 24 == 45; //@line 636
       $253 = $3 + 1 | 0; //@line 637
       $$0$i107$i = $252 ? $253 : $3; //@line 641
       $$$0$i$i = ($252 ? HEAP8[$253 >> 0] | 0 : $251) << 24 >> 24 == 43 ? $$0$i107$i + 1 | 0 : $$0$i107$i; //@line 644
       $258 = $$$0$i$i + 1 | 0; //@line 645
       $262 = (HEAP8[$$$0$i$i >> 0] | 0) + -48 | ($252 ? -2147483648 : 0); //@line 649
       $$2$i$i = (HEAP8[$258 >> 0] | 0) == 46 ? $$$0$i$i + 2 | 0 : $258; //@line 653
       $266 = HEAP8[$$2$i$i >> 0] | 0; //@line 654
       $268 = $$2$i$i + 1 | 0; //@line 657
       if (($266 + -48 & 255) < 10) {
        $$4$i$i = $268; //@line 663
        $271 = HEAP8[$268 >> 0] | 0; //@line 663
        $277 = ($266 << 24 >> 24 << 4) + -768 | 0; //@line 663
       } else {
        $$4$i$i = $$2$i$i; //@line 665
        $271 = $266; //@line 665
        $277 = 0; //@line 665
       }
       $272 = ($271 + -48 & 255) < 10; //@line 668
       $$$4$i$i = $272 ? $$4$i$i + 1 | 0 : $$4$i$i; //@line 674
       $279 = HEAP8[$$$4$i$i >> 0] | 0; //@line 676
       $280 = ($279 + -48 & 255) < 10; //@line 678
       $$4$2$i$i = $280 ? $$$4$i$i + 1 | 0 : $$$4$i$i; //@line 684
       $287 = HEAP8[$$4$2$i$i >> 0] | 0; //@line 686
       $288 = ($287 + -48 & 255) < 10; //@line 688
       $$$4$2$i$i = $288 ? $$4$2$i$i + 1 | 0 : $$4$2$i$i; //@line 694
       $294 = HEAP8[$$$4$2$i$i >> 0] | 0; //@line 696
       $295 = ($294 + -48 & 255) < 10; //@line 698
       $$4$4$i$i = $295 ? $$$4$2$i$i + 1 | 0 : $$$4$2$i$i; //@line 704
       $302 = HEAP8[$$4$4$i$i >> 0] | 0; //@line 706
       $303 = ($302 + -48 & 255) < 10; //@line 708
       $$$4$4$i$i = $303 ? $$4$4$i$i + 1 | 0 : $$4$4$i$i; //@line 714
       $309 = HEAP8[$$$4$4$i$i >> 0] | 0; //@line 716
       $310 = ($309 + -48 & 255) < 10; //@line 718
       $$4$6$i$i = $310 ? $$$4$4$i$i + 1 | 0 : $$$4$4$i$i; //@line 724
       $317 = HEAP8[$$4$6$i$i >> 0] | 0; //@line 726
       $318 = ($317 + -48 & 255) < 10; //@line 728
       $$145$i = (((((($280 ? ($279 << 24 >> 24) + 16777168 | 0 : 0) | (($272 ? ($271 << 24 >> 24) + 16777168 | 0 : 0) | $277) << 4) << 4 | ($288 ? ($287 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($295 ? ($294 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($303 ? ($302 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($310 ? ($309 << 24 >> 24) + 268435408 | 0 : 0)) << 4 | ($318 ? ($317 << 24 >> 24) + -48 | 0 : 0); //@line 733
       $$$4$6$i$i = $318 ? $$4$6$i$i + 1 | 0 : $$4$6$i$i; //@line 734
       $323 = HEAP8[$$$4$6$i$i >> 0] | 0; //@line 735
       $324 = ($323 + -48 & 255) < 10; //@line 737
       $$6$i$i = $324 ? $$$4$6$i$i + 1 | 0 : $$$4$6$i$i; //@line 740
       $329 = HEAP8[$$6$i$i >> 0] | 0; //@line 744
       $330 = ($329 + -48 & 255) < 10; //@line 746
       $$$6$i$i = $330 ? $$6$i$i + 1 | 0 : $$6$i$i; //@line 752
       $336 = HEAP8[$$$6$i$i >> 0] | 0; //@line 754
       $337 = ($336 + -48 & 255) < 10; //@line 756
       $$6$2$i$i = $337 ? $$$6$i$i + 1 | 0 : $$$6$i$i; //@line 762
       $344 = HEAP8[$$6$2$i$i >> 0] | 0; //@line 764
       $345 = ($344 + -48 & 255) < 10; //@line 766
       $$$6$2$i$i = $345 ? $$6$2$i$i + 1 | 0 : $$6$2$i$i; //@line 772
       $351 = HEAP8[$$$6$2$i$i >> 0] | 0; //@line 774
       $352 = ($351 + -48 & 255) < 10; //@line 776
       $$6$4$i$i = $352 ? $$$6$2$i$i + 1 | 0 : $$$6$2$i$i; //@line 782
       $359 = HEAP8[$$6$4$i$i >> 0] | 0; //@line 784
       $360 = ($359 + -48 & 255) < 10; //@line 786
       $$$6$4$i$i = $360 ? $$6$4$i$i + 1 | 0 : $$6$4$i$i; //@line 792
       $366 = HEAP8[$$$6$4$i$i >> 0] | 0; //@line 794
       $367 = ($366 + -48 & 255) < 10; //@line 796
       $$6$6$i$i = $367 ? $$$6$4$i$i + 1 | 0 : $$$6$4$i$i; //@line 802
       $373 = ((((((($324 ? ($323 << 24 >> 24 << 4) + 16776448 | 0 : 0) | ($330 ? ($329 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($337 ? ($336 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($345 ? ($344 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($352 ? ($351 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($360 ? ($359 << 24 >> 24) + 16777168 | 0 : 0)) << 4 | ($367 ? ($366 << 24 >> 24) + 268435408 | 0 : 0)) << 4; //@line 803
       $374 = HEAP8[$$6$6$i$i >> 0] | 0; //@line 804
       $376 = $$6$6$i$i + 1 | 0; //@line 807
       if (($374 + -48 & 255) < 10) {
        $$0136$i = $373 | ($374 << 24 >> 24) + -48; //@line 813
        $$6$7$i$i = $376; //@line 813
        $409 = HEAP8[$376 >> 0] | 0; //@line 813
       } else {
        $$0136$i = $373; //@line 815
        $$6$7$i$i = $$6$6$i$i; //@line 815
        $409 = $374; //@line 815
       }
       switch ($409 << 24 >> 24) {
       case 69:
       case 101:
        {
         $377 = $$6$7$i$i + 1 | 0; //@line 819
         $378 = HEAP8[$377 >> 0] | 0; //@line 820
         $380 = $$6$7$i$i + 2 | 0; //@line 822
         if ($378 << 24 >> 24 == 45) {
          $$7$i$i = $380; //@line 826
          $383 = HEAP8[$380 >> 0] | 0; //@line 826
          $405 = $262 | 1073741824; //@line 826
         } else {
          $$7$i$i = $377; //@line 828
          $383 = $378; //@line 828
          $405 = $262; //@line 828
         }
         $$$7$i$i = $383 << 24 >> 24 == 43 ? $$7$i$i + 1 | 0 : $$7$i$i; //@line 832
         $385 = HEAP8[$$$7$i$i >> 0] | 0; //@line 833
         $387 = ($385 + -48 & 255) < 10; //@line 836
         $$$047$i$i = $387 ? ($385 << 24 >> 24) + -48 | 0 : 0; //@line 839
         $$$9$i$i = $387 ? $$$7$i$i + 1 | 0 : $$$7$i$i; //@line 840
         $390 = HEAP8[$$$9$i$i >> 0] | 0; //@line 841
         $392 = ($390 + -48 & 255) < 10; //@line 844
         $$$047$1$i$i = $392 ? $$$047$i$i << 4 | ($390 << 24 >> 24) + -48 : $$$047$i$i; //@line 849
         $397 = HEAP8[($392 ? $$$9$i$i + 1 | 0 : $$$9$i$i) >> 0] | 0; //@line 851
         $$0138$i = (($397 + -48 & 255) < 10 ? $$$047$1$i$i << 4 | ($397 << 24 >> 24) + 65488 : $$$047$1$i$i) << 16 | $405; //@line 861
         break;
        }
       default:
        {
         $$0138$i = $262; //@line 865
        }
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$080$i, $$0138$i); //@line 873
       $415 = $$080$i + 4 | 0; //@line 874
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($415 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($415, $$145$i); //@line 880
       $421 = $$080$i + 8 | 0; //@line 881
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($421 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($421, $$0136$i); //@line 887
       STACKTOP = sp; //@line 888
       return;
      }
     case 4:
      {
       switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
       case 1:
        {
         $$0$i101$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 903
         break;
        }
       case 2:
        {
         $$0$i101$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 909
         break;
        }
       case 0:
        {
         $$0$i101$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 917
         break;
        }
       case 3:
        {
         $$0$i101$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 923
         break;
        }
       default:
        {}
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$080$i, ~~$$0$i101$i << 16 >> 16); //@line 938
       STACKTOP = sp; //@line 939
       return;
      }
     case 5:
      {
       $449 = $7; //@line 943
       $451 = HEAP32[$449 >> 2] | 0; //@line 945
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$080$i, HEAP32[$449 + 4 >> 2] | 0); //@line 954
       $460 = $$080$i + 4 | 0; //@line 955
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($460 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($460, $451); //@line 961
       STACKTOP = sp; //@line 962
       return;
      }
     case 6:
      {
       switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
       case 1:
        {
         $$0$i98$i = +(~~+HEAPF64[$7 >> 3] | 0); //@line 977
         break;
        }
       case 2:
        {
         $$0$i98$i = +Math_floor(+(+HEAPF64[$7 >> 3])); //@line 983
         break;
        }
       case 0:
        {
         $$0$i98$i = +(~~(+HEAPF64[$7 >> 3] + .5) | 0); //@line 991
         break;
        }
       case 3:
        {
         $$0$i98$i = +Math_ceil(+(+HEAPF64[$7 >> 3])); //@line 997
         break;
        }
       default:
        {}
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$080$i >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($$080$i, ~~$$0$i98$i << 24 >> 24); //@line 1012
       STACKTOP = sp; //@line 1013
       return;
      }
     default:
      {
       break L52;
      }
     }
    }
   } while (0);
   $493 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 1027
   $499 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($493 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($493) | 0; //@line 1033
   HEAP32[162770] = $499; //@line 1034
   HEAP32[162769] = $499; //@line 1035
   HEAP32[162768] = $493; //@line 1036
   __Z7op_illgj($0); //@line 1037
   STACKTOP = sp; //@line 1038
   return;
  }
 case 5:
 case 4:
  {
   $500 = $0 & 56; //@line 1042
   $501 = $1 & 8192; //@line 1043
   switch ($500 & 63) {
   case 0:
    {
     $504 = ($1 & 4096 | 0) != 0; //@line 1050
     if (!$501) {
      if ($504) {
       $553 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 1055
       HEAP32[28187] = $553 & 192; //@line 1057
       HEAP32[28188] = $553 & 48; //@line 1059
      }
      if ($1 & 2048 | 0) {
       $560 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 1066
       if (!($560 & 16777216)) {
        HEAPF64[14092] = ($560 & 67108864 | 0) == 0 ? $560 & 134217728 | 0 ? -1.0 : 1.0 : 0.0; //@line 1076
       } else {
        $569 = HEAP32[28185] | 2147483647; //@line 1084
        $570 = 112736; //@line 1085
        HEAP32[$570 >> 2] = -1; //@line 1087
        HEAP32[$570 + 4 >> 2] = $569; //@line 1090
       }
       HEAP32[28191] = $560 & 65280; //@line 1093
       HEAP32[28192] = $560 & 255; //@line 1095
       HEAP32[28190] = $560 & 16711680; //@line 1097
      }
      if (!($1 & 1024)) {
       STACKTOP = sp; //@line 1102
       return;
      }
      HEAP32[28193] = HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 1107
      STACKTOP = sp; //@line 1108
      return;
     }
     if ($504) {
      HEAP32[651008 + (($0 & 7) << 2) >> 2] = (HEAP32[28188] | HEAP32[28187]) & 65535; //@line 1117
     }
     if ($1 & 2048 | 0) {
      $513 = 112736; //@line 1122
      $515 = HEAP32[$513 >> 2] | 0; //@line 1124
      $518 = HEAP32[$513 + 4 >> 2] | 0; //@line 1127
      $519 = $518 & 2147483647; //@line 1128
      HEAP32[tempDoublePtr >> 2] = $515; //@line 1134
      HEAP32[tempDoublePtr + 4 >> 2] = $518; //@line 1134
      $525 = +HEAPF64[tempDoublePtr >> 3]; //@line 1134
      if (($519 | ($515 | 0 - $515) >>> 31) >>> 0 > 2146435072) {
       $$0$i$i457 = 16777216; //@line 1136
      } else {
       if ($525 == 0.0) {
        $$0$i$i457 = 67108864; //@line 1140
       } else {
        if ($525 < 0.0) {
         $$0$i$i457 = 134217728; //@line 1144
        } else {
         $$0$i$i457 = 0; //@line 1146
        }
       }
      }
      HEAP32[651008 + (($0 & 7) << 2) >> 2] = ($518 >> 30 & ~(($515 | 0 - ($519 ^ 2146435072 | $515)) >> 31) | 0 ? $$0$i$i457 | 33554432 : $$0$i$i457) | HEAP32[28191] | HEAP32[28192] | HEAP32[28190]; //@line 1169
     }
     if (!($1 & 1024)) {
      STACKTOP = sp; //@line 1174
      return;
     }
     HEAP32[651008 + (($0 & 7) << 2) >> 2] = HEAP32[28193]; //@line 1179
     STACKTOP = sp; //@line 1180
     return;
    }
   case 8:
    {
     $588 = ($1 & 4096 | 0) != 0; //@line 1186
     if (!$501) {
      if ($588) {
       $637 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1191
       HEAP32[28187] = $637 & 192; //@line 1193
       HEAP32[28188] = $637 & 48; //@line 1195
      }
      if ($1 & 2048 | 0) {
       $644 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1202
       if (!($644 & 16777216)) {
        HEAPF64[14092] = ($644 & 67108864 | 0) == 0 ? $644 & 134217728 | 0 ? -1.0 : 1.0 : 0.0; //@line 1212
       } else {
        $653 = HEAP32[28185] | 2147483647; //@line 1220
        $654 = 112736; //@line 1221
        HEAP32[$654 >> 2] = -1; //@line 1223
        HEAP32[$654 + 4 >> 2] = $653; //@line 1226
       }
       HEAP32[28191] = $644 & 65280; //@line 1229
       HEAP32[28192] = $644 & 255; //@line 1231
       HEAP32[28190] = $644 & 16711680; //@line 1233
      }
      if (!($1 & 1024)) {
       STACKTOP = sp; //@line 1238
       return;
      }
      HEAP32[28193] = HEAP32[651040 + (($0 & 7) << 2) >> 2]; //@line 1243
      STACKTOP = sp; //@line 1244
      return;
     }
     if ($588) {
      HEAP32[651040 + (($0 & 7) << 2) >> 2] = (HEAP32[28188] | HEAP32[28187]) & 65535; //@line 1253
     }
     if ($1 & 2048 | 0) {
      $597 = 112736; //@line 1258
      $599 = HEAP32[$597 >> 2] | 0; //@line 1260
      $602 = HEAP32[$597 + 4 >> 2] | 0; //@line 1263
      $603 = $602 & 2147483647; //@line 1264
      HEAP32[tempDoublePtr >> 2] = $599; //@line 1270
      HEAP32[tempDoublePtr + 4 >> 2] = $602; //@line 1270
      $609 = +HEAPF64[tempDoublePtr >> 3]; //@line 1270
      if (($603 | ($599 | 0 - $599) >>> 31) >>> 0 > 2146435072) {
       $$0$i$i459 = 16777216; //@line 1272
      } else {
       if ($609 == 0.0) {
        $$0$i$i459 = 67108864; //@line 1276
       } else {
        if ($609 < 0.0) {
         $$0$i$i459 = 134217728; //@line 1280
        } else {
         $$0$i$i459 = 0; //@line 1282
        }
       }
      }
      HEAP32[651040 + (($0 & 7) << 2) >> 2] = ($602 >> 30 & ~(($599 | 0 - ($603 ^ 2146435072 | $599)) >> 31) | 0 ? $$0$i$i459 | 33554432 : $$0$i$i459) | HEAP32[28191] | HEAP32[28192] | HEAP32[28190]; //@line 1305
     }
     if (!($1 & 1024)) {
      STACKTOP = sp; //@line 1310
      return;
     }
     HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[28193]; //@line 1315
     STACKTOP = sp; //@line 1316
     return;
    }
   default:
    {
     $672 = ($501 | 0) == 0; //@line 1322
     if (($0 & 63 | 0) == 60) {
      if (!$672) {
       STACKTOP = sp; //@line 1325
       return;
      }
      if ($1 & 4096 | 0) {
       $675 = HEAP32[162769] | 0; //@line 1330
       $678 = HEAPU8[$675 + 3 >> 0] | 0; //@line 1333
       HEAP32[162769] = $675 + 4; //@line 1335
       HEAP32[28187] = $678 & 192; //@line 1337
       HEAP32[28188] = $678 & 48; //@line 1339
      }
      if ($1 & 2048 | 0) {
       $684 = HEAP32[162769] | 0; //@line 1344
       $687 = HEAPU8[$684 >> 0] << 24; //@line 1347
       $691 = HEAPU8[$684 + 1 >> 0] << 16; //@line 1351
       $695 = HEAPU8[$684 + 2 >> 0] << 8; //@line 1355
       $698 = HEAPU8[$684 + 3 >> 0] | 0; //@line 1358
       HEAP32[162769] = $684 + 4; //@line 1360
       if (!($687 & 16777216)) {
        HEAPF64[14092] = ($687 & 67108864 | 0) == 0 ? $687 & 134217728 | 0 ? -1.0 : 1.0 : 0.0; //@line 1370
       } else {
        $708 = HEAP32[28185] | 2147483647; //@line 1378
        $709 = 112736; //@line 1379
        HEAP32[$709 >> 2] = -1; //@line 1381
        HEAP32[$709 + 4 >> 2] = $708; //@line 1384
       }
       HEAP32[28191] = $695; //@line 1386
       HEAP32[28192] = $698; //@line 1387
       HEAP32[28190] = $691; //@line 1388
      }
      if (!($1 & 1024)) {
       STACKTOP = sp; //@line 1393
       return;
      }
      $719 = HEAP32[162769] | 0; //@line 1395
      $736 = HEAPU8[$719 + 1 >> 0] << 16 | HEAPU8[$719 >> 0] << 24 | HEAPU8[$719 + 2 >> 0] << 8 | HEAPU8[$719 + 3 >> 0]; //@line 1412
      HEAP32[162769] = $719 + 4; //@line 1414
      HEAP32[28193] = $736; //@line 1415
      STACKTOP = sp; //@line 1416
      return;
     }
     if ($672) {
      if (!(__ZL9get_fp_adjPj($0, $2) | 0)) {
       $839 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 1427
       $845 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($839 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($839) | 0; //@line 1433
       HEAP32[162770] = $845; //@line 1434
       HEAP32[162769] = $845; //@line 1435
       HEAP32[162768] = $839; //@line 1436
       __Z7op_illgj($0); //@line 1437
       STACKTOP = sp; //@line 1438
       return;
      }
      $846 = ($500 | 0) == 32; //@line 1440
      if ($846) {
       $848 = $1 >>> 10 & 4; //@line 1443
       $$1379 = ($1 & 2048 | 0) == 0 ? $848 : $848 + 4 | 0; //@line 1447
       $$1379$ = ($1 & 1024 | 0) == 0 ? $$1379 : $$1379 + 4 | 0; //@line 1451
       HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) - $$1379$; //@line 1454
       $$3381 = $$1379$; //@line 1455
      } else {
       $$3381 = 0; //@line 1457
      }
      if ($1 & 4096 | 0) {
       $859 = HEAP32[$2 >> 2] | 0; //@line 1462
       $864 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($859 >>> 16 << 2) >> 2] >> 2] & 127]($859) | 0; //@line 1467
       HEAP32[28187] = $864 & 192; //@line 1469
       HEAP32[28188] = $864 & 48; //@line 1471
       HEAP32[$2 >> 2] = $859 + 4; //@line 1473
      }
      if ($1 & 2048 | 0) {
       $870 = HEAP32[$2 >> 2] | 0; //@line 1478
       $875 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($870 >>> 16 << 2) >> 2] >> 2] & 127]($870) | 0; //@line 1483
       if (!($875 & 16777216)) {
        HEAPF64[14092] = ($875 & 67108864 | 0) == 0 ? $875 & 134217728 | 0 ? -1.0 : 1.0 : 0.0; //@line 1493
       } else {
        $884 = HEAP32[28185] | 2147483647; //@line 1501
        $885 = 112736; //@line 1502
        HEAP32[$885 >> 2] = -1; //@line 1504
        HEAP32[$885 + 4 >> 2] = $884; //@line 1507
       }
       HEAP32[28191] = $875 & 65280; //@line 1510
       HEAP32[28192] = $875 & 255; //@line 1512
       HEAP32[28190] = $875 & 16711680; //@line 1514
       HEAP32[$2 >> 2] = $870 + 4; //@line 1516
      }
      if ($1 & 1024 | 0) {
       $899 = HEAP32[$2 >> 2] | 0; //@line 1521
       HEAP32[28193] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($899 >>> 16 << 2) >> 2] >> 2] & 127]($899) | 0; //@line 1527
       HEAP32[$2 >> 2] = $899 + 4; //@line 1529
      }
      if (($500 | 0) == 24) {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[$2 >> 2]; //@line 1536
      }
      if ($846) {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = (HEAP32[$2 >> 2] | 0) - $$3381; //@line 1543
      }
      STACKTOP = sp; //@line 1545
      return;
     }
     if (!(__ZL9get_fp_adjPj($0, $2) | 0)) {
      $745 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 1555
      $751 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($745 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($745) | 0; //@line 1561
      HEAP32[162770] = $751; //@line 1562
      HEAP32[162769] = $751; //@line 1563
      HEAP32[162768] = $745; //@line 1564
      __Z7op_illgj($0); //@line 1565
      STACKTOP = sp; //@line 1566
      return;
     }
     $752 = ($500 | 0) == 32; //@line 1568
     if ($752) {
      $754 = $1 >>> 10 & 4; //@line 1571
      $$1376 = ($1 & 2048 | 0) == 0 ? $754 : $754 + 4 | 0; //@line 1575
      $$2377 = ($1 & 1024 | 0) == 0 ? $$1376 : $$1376 + 4 | 0; //@line 1580
     } else {
      $$2377 = 0; //@line 1582
     }
     $762 = (HEAP32[$2 >> 2] | 0) - $$2377 | 0; //@line 1585
     HEAP32[$2 >> 2] = $762; //@line 1586
     if (!($1 & 4096)) {
      $809 = $762; //@line 1590
     } else {
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($762 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($762, (HEAP32[28188] | HEAP32[28187]) & 65535); //@line 1601
      $774 = $762 + 4 | 0; //@line 1602
      HEAP32[$2 >> 2] = $774; //@line 1603
      $809 = $774; //@line 1604
     }
     if (!($1 & 2048)) {
      $819 = $809; //@line 1609
     } else {
      $777 = 112736; //@line 1611
      $779 = HEAP32[$777 >> 2] | 0; //@line 1613
      $782 = HEAP32[$777 + 4 >> 2] | 0; //@line 1616
      $783 = $782 & 2147483647; //@line 1617
      HEAP32[tempDoublePtr >> 2] = $779; //@line 1623
      HEAP32[tempDoublePtr + 4 >> 2] = $782; //@line 1623
      $789 = +HEAPF64[tempDoublePtr >> 3]; //@line 1623
      if (($783 | ($779 | 0 - $779) >>> 31) >>> 0 > 2146435072) {
       $$0$i$i468 = 16777216; //@line 1625
      } else {
       if ($789 == 0.0) {
        $$0$i$i468 = 67108864; //@line 1629
       } else {
        if ($789 < 0.0) {
         $$0$i$i468 = 134217728; //@line 1633
        } else {
         $$0$i$i468 = 0; //@line 1635
        }
       }
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($809 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($809, ($782 >> 30 & ~(($779 | 0 - ($783 ^ 2146435072 | $779)) >> 31) | 0 ? $$0$i$i468 | 33554432 : $$0$i$i468) | HEAP32[28191] | HEAP32[28192] | HEAP32[28190]); //@line 1661
      $814 = $809 + 4 | 0; //@line 1662
      HEAP32[$2 >> 2] = $814; //@line 1663
      $819 = $814; //@line 1664
     }
     if (!($1 & 1024)) {
      $826 = $819; //@line 1669
     } else {
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($819 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($819, HEAP32[28193] | 0); //@line 1677
      $824 = $819 + 4 | 0; //@line 1678
      HEAP32[$2 >> 2] = $824; //@line 1679
      $826 = $824; //@line 1680
     }
     $825 = $826 - $$2377 | 0; //@line 1682
     HEAP32[$2 >> 2] = $825; //@line 1683
     if (($500 | 0) == 24) {
      HEAP32[651040 + (($0 & 7) << 2) >> 2] = $825; //@line 1688
     }
     if ($752) {
      HEAP32[651040 + (($0 & 7) << 2) >> 2] = $825; //@line 1693
     }
     STACKTOP = sp; //@line 1695
     return;
    }
   }
   break;
  }
 case 7:
 case 6:
  {
   $917 = (__ZL9get_fp_adjPj($0, $2) | 0) == 0; //@line 1704
   L255 : do {
    if (!($1 & 8192)) {
     if ($917) {
      $1036 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 1713
      $1042 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1036 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1036) | 0; //@line 1719
      HEAP32[162770] = $1042; //@line 1720
      HEAP32[162769] = $1042; //@line 1721
      HEAP32[162768] = $1036; //@line 1722
      __Z7op_illgj($0); //@line 1723
      break;
     }
     switch ($1 >>> 11 & 3) {
     case 0:
      {
       $$3385$in$ph = $1; //@line 1731
       label = 196; //@line 1732
       break;
      }
     case 1:
      {
       $$3385$in$ph = HEAP32[651008 + (($1 >>> 4 & 3) << 2) >> 2] | 0; //@line 1740
       label = 196; //@line 1741
       break;
      }
     case 2:
      {
       $$3385$in = $1; //@line 1745
       label = 197; //@line 1746
       break;
      }
     case 3:
      {
       $$3385$in = HEAP32[651008 + (($1 >>> 4 & 3) << 2) >> 2] | 0; //@line 1754
       label = 197; //@line 1755
       break;
      }
     default:
      {}
     }
     if ((label | 0) == 196) {
      $$2638 = 7; //@line 1765
      $$4637 = $$3385$in$ph & 255; //@line 1765
      $1055 = HEAP32[$2 >> 2] | 0; //@line 1765
      while (1) {
       do {
        if (!($$4637 & 128)) {
         $2124 = $1055; //@line 1771
        } else {
         $1054 = $1055 + -4 | 0; //@line 1773
         $1060 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1054 >>> 16 << 2) >> 2] >> 2] & 127]($1054) | 0; //@line 1778
         $1061 = $1055 + -8 | 0; //@line 1779
         $1066 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1061 >>> 16 << 2) >> 2] >> 2] & 127]($1061) | 0; //@line 1784
         $1067 = $1055 + -12 | 0; //@line 1785
         $1072 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1067 >>> 16 << 2) >> 2] >> 2] & 127]($1067) | 0; //@line 1790
         $1073 = 112672 + ($$2638 << 3) | 0; //@line 1791
         if (!($1066 | $1060 | $1072)) {
          HEAPF64[$1073 >> 3] = 0.0; //@line 1796
          $2124 = $1067; //@line 1797
          break;
         }
         if (($1060 | 0) != 0 & (($1066 | 0) != 0 & ($1072 & 2147418112 | 0) == 2147418112)) {
          $1087 = HEAP32[$1073 + 4 >> 2] | 2147483647; //@line 1813
          $1088 = $1073; //@line 1814
          HEAP32[$1088 >> 2] = -1; //@line 1816
          HEAP32[$1088 + 4 >> 2] = $1087; //@line 1819
          $2124 = $1067; //@line 1820
          break;
         } else {
          $1092 = $1072 >>> 16; //@line 1823
          $1093 = $1092 & 32767; //@line 1824
          $1094 = $1093 >>> 0 < 15360; //@line 1825
          $1095 = $1093 >>> 0 > 17406; //@line 1826
          $1098 = _bitshift64Shl($1092 + 1024 & 2047 | 0, 0, 52) | 0; //@line 1829
          $1103 = $1094 ? 0 : $1095 ? 2146435072 : tempRet0; //@line 1834
          $1105 = _bitshift64Shl($1072 >>> 31 | 0, 0, 63) | 0; //@line 1836
          $1116 = $1073; //@line 1847
          HEAP32[$1116 >> 2] = $1066 << 21 | $1060 >>> 11 | $1105 | ($1094 ? 0 : $1095 ? 0 : $1098); //@line 1849
          HEAP32[$1116 + 4 >> 2] = $1066 >>> 11 & 1048575 | tempRet0 | $1103; //@line 1852
          $2124 = $1067; //@line 1853
          break;
         }
        }
       } while (0);
       if (($$2638 | 0) > 0) {
        $$2638 = $$2638 + -1 | 0; //@line 1862
        $$4637 = $$4637 << 1; //@line 1862
        $1055 = $2124; //@line 1862
       } else {
        $storemerge671 = $2124; //@line 1864
        break;
       }
      }
     } else if ((label | 0) == 197) {
      $$3640 = 0; //@line 1872
      $$5639 = $$3385$in & 255; //@line 1872
      $1126 = HEAP32[$2 >> 2] | 0; //@line 1872
      while (1) {
       do {
        if (!($$5639 & 128)) {
         $2125 = $1126; //@line 1878
        } else {
         $1130 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1126 >>> 16 << 2) >> 2] >> 2] & 127]($1126) | 0; //@line 1884
         $1131 = $1126 + 4 | 0; //@line 1885
         $1136 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1131 >>> 16 << 2) >> 2] >> 2] & 127]($1131) | 0; //@line 1890
         $1137 = $1126 + 8 | 0; //@line 1891
         $1142 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1137 >>> 16 << 2) >> 2] >> 2] & 127]($1137) | 0; //@line 1896
         $1143 = $1126 + 12 | 0; //@line 1897
         $1144 = 112672 + ($$3640 << 3) | 0; //@line 1898
         if (!($1136 | $1130 | $1142)) {
          HEAPF64[$1144 >> 3] = 0.0; //@line 1903
          $2125 = $1143; //@line 1904
          break;
         }
         if (($1130 & 2147418112 | 0) == 2147418112 & ($1136 | 0) != 0 & ($1142 | 0) != 0) {
          $1158 = HEAP32[$1144 + 4 >> 2] | 2147483647; //@line 1920
          $1159 = $1144; //@line 1921
          HEAP32[$1159 >> 2] = -1; //@line 1923
          HEAP32[$1159 + 4 >> 2] = $1158; //@line 1926
          $2125 = $1143; //@line 1927
          break;
         } else {
          $1163 = $1130 >>> 16; //@line 1930
          $1164 = $1163 & 32767; //@line 1931
          $1165 = $1164 >>> 0 < 15360; //@line 1932
          $1166 = $1164 >>> 0 > 17406; //@line 1933
          $1169 = _bitshift64Shl($1163 + 1024 & 2047 | 0, 0, 52) | 0; //@line 1936
          $1174 = $1165 ? 0 : $1166 ? 2146435072 : tempRet0; //@line 1941
          $1176 = _bitshift64Shl($1130 >>> 31 | 0, 0, 63) | 0; //@line 1943
          $1187 = $1144; //@line 1954
          HEAP32[$1187 >> 2] = ($1165 ? 0 : $1166 ? 0 : $1169) | $1176 | ($1142 >>> 11 | $1136 << 21); //@line 1956
          HEAP32[$1187 + 4 >> 2] = $1174 | tempRet0 | $1136 >>> 11 & 1048575; //@line 1959
          $2125 = $1143; //@line 1960
          break;
         }
        }
       } while (0);
       $$3640 = $$3640 + 1 | 0; //@line 1966
       if (($$3640 | 0) == 8) {
        $storemerge671 = $2125; //@line 1969
        break;
       } else {
        $$5639 = $$5639 << 1; //@line 1972
        $1126 = $2125; //@line 1972
       }
      }
     }
     HEAP32[$2 >> 2] = $storemerge671; //@line 1976
     switch ($0 & 56) {
     case 24:
      {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[$2 >> 2]; //@line 1985
       break L255;
       break;
      }
     case 32:
      {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[$2 >> 2]; //@line 1993
       break L255;
       break;
      }
     default:
      {
       break L255;
      }
     }
    } else {
     if ($917) {
      $923 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 2008
      $929 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($923 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($923) | 0; //@line 2014
      HEAP32[162770] = $929; //@line 2015
      HEAP32[162769] = $929; //@line 2016
      HEAP32[162768] = $923; //@line 2017
      __Z7op_illgj($0); //@line 2018
      break;
     }
     switch ($1 >>> 11 & 3) {
     case 0:
      {
       $$0382$in$ph = $1; //@line 2026
       label = 175; //@line 2027
       break;
      }
     case 1:
      {
       $$0382$in$ph = HEAP32[651008 + (($1 >>> 4 & 3) << 2) >> 2] | 0; //@line 2035
       label = 175; //@line 2036
       break;
      }
     case 2:
      {
       $$0382$in = $1; //@line 2040
       label = 176; //@line 2041
       break;
      }
     case 3:
      {
       $$0382$in = HEAP32[651008 + (($1 >>> 4 & 3) << 2) >> 2] | 0; //@line 2049
       label = 176; //@line 2050
       break;
      }
     default:
      {}
     }
     if ((label | 0) == 175) {
      $$0372642 = 7; //@line 2060
      $$1383641 = $$0382$in$ph & 255; //@line 2060
      $961 = HEAP32[$2 >> 2] | 0; //@line 2060
      while (1) {
       if (!($$1383641 & 128)) {
        $2122 = $961; //@line 2065
       } else {
        $942 = +HEAPF64[112672 + ($$0372642 << 3) >> 3]; //@line 2068
        HEAPF64[tempDoublePtr >> 3] = $942; //@line 2070
        $944 = HEAP32[tempDoublePtr >> 2] | 0; //@line 2070
        $945 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 2071
        if ($942 == 0.0) {
         $$0603 = 0; //@line 2073
         $$0604 = 0; //@line 2073
         $$0608 = 0; //@line 2073
        } else {
         $946 = _bitshift64Lshr($944 | 0, $945 | 0, 52) | 0; //@line 2075
         $948 = $946 & 2047; //@line 2077
         $953 = _bitshift64Lshr($944 | 0, $945 | 0, 21) | 0; //@line 2084
         $$0603 = (($948 | 0) == 2047 ? 2147418112 : ($948 << 16) + 1006632960 | 0) | $945 & -2147483648; //@line 2091
         $$0604 = $944 >>> 21 | $953 & 2147481600 | -2147483648; //@line 2091
         $$0608 = $944 << 11; //@line 2091
        }
        $960 = $961 + -4 | 0; //@line 2093
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($960 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($960, $$0608); //@line 2099
        $967 = $961 + -8 | 0; //@line 2100
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($967 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($967, $$0604); //@line 2106
        $973 = $961 + -12 | 0; //@line 2107
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($973 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($973, $$0603); //@line 2113
        $2122 = $973; //@line 2114
       }
       if (($$0372642 | 0) > 0) {
        $$0372642 = $$0372642 + -1 | 0; //@line 2120
        $$1383641 = $$1383641 << 1; //@line 2120
        $961 = $2122; //@line 2120
       } else {
        $storemerge = $2122; //@line 2122
        break;
       }
      }
     } else if ((label | 0) == 176) {
      $$1644 = 0; //@line 2130
      $$2384643 = $$0382$in & 255; //@line 2130
      $1004 = HEAP32[$2 >> 2] | 0; //@line 2130
      while (1) {
       if (!($$2384643 & 128)) {
        $2123 = $1004; //@line 2135
       } else {
        $985 = +HEAPF64[112672 + ($$1644 << 3) >> 3]; //@line 2138
        HEAPF64[tempDoublePtr >> 3] = $985; //@line 2140
        $987 = HEAP32[tempDoublePtr >> 2] | 0; //@line 2140
        $988 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 2141
        if ($985 == 0.0) {
         $$0605 = 0; //@line 2143
         $$0606 = 0; //@line 2143
         $$0607 = 0; //@line 2143
        } else {
         $989 = _bitshift64Lshr($987 | 0, $988 | 0, 52) | 0; //@line 2145
         $991 = $989 & 2047; //@line 2147
         $996 = _bitshift64Lshr($987 | 0, $988 | 0, 21) | 0; //@line 2154
         $$0605 = $987 << 11; //@line 2161
         $$0606 = $987 >>> 21 | $996 & 2147481600 | -2147483648; //@line 2161
         $$0607 = (($991 | 0) == 2047 ? 2147418112 : ($991 << 16) + 1006632960 | 0) | $988 & -2147483648; //@line 2161
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1004 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1004, $$0607); //@line 2168
        $1009 = $1004 + 4 | 0; //@line 2169
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1009 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1009, $$0606); //@line 2175
        $1015 = $1004 + 8 | 0; //@line 2176
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1015 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($1015, $$0605); //@line 2182
        $2123 = $1004 + 12 | 0; //@line 2184
       }
       $$1644 = $$1644 + 1 | 0; //@line 2187
       if (($$1644 | 0) == 8) {
        $storemerge = $2123; //@line 2190
        break;
       } else {
        $$2384643 = $$2384643 << 1; //@line 2193
        $1004 = $2123; //@line 2193
       }
      }
     }
     HEAP32[$2 >> 2] = $storemerge; //@line 2197
     switch ($0 & 56) {
     case 24:
      {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[$2 >> 2]; //@line 2206
       break L255;
       break;
      }
     case 32:
      {
       HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[$2 >> 2]; //@line 2214
       break L255;
       break;
      }
     default:
      {
       break L255;
      }
     }
    }
   } while (0);
   STACKTOP = sp; //@line 2224
   return;
  }
 case 2:
 case 0:
  {
   $1201 = $1 >>> 7 & 7; //@line 2229
   if (($1 & 64512 | 0) == 23552) {
    do {
     switch ($1 & 127) {
     case 0:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 3.141592653589793; //@line 2239
       $$val454 = 3.141592653589793; //@line 2240
       break;
      }
     case 11:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = .3010299956639812; //@line 2245
       $$val454 = .3010299956639812; //@line 2246
       break;
      }
     case 12:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 2.718281828459045; //@line 2251
       $$val454 = 2.718281828459045; //@line 2252
       break;
      }
     case 13:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.4426950408889634; //@line 2257
       $$val454 = 1.4426950408889634; //@line 2258
       break;
      }
     case 14:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = .4342944819032518; //@line 2263
       $$val454 = .4342944819032518; //@line 2264
       break;
      }
     case 15:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 0.0; //@line 2269
       $$val454 = 0.0; //@line 2270
       break;
      }
     case 48:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = .6931471805599453; //@line 2275
       $$val454 = .6931471805599453; //@line 2276
       break;
      }
     case 49:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 2.302585092994046; //@line 2281
       $$val454 = 2.302585092994046; //@line 2282
       break;
      }
     case 50:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0; //@line 2287
       $$val454 = 1.0; //@line 2288
       break;
      }
     case 51:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 10.0; //@line 2293
       $$val454 = 10.0; //@line 2294
       break;
      }
     case 52:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 100.0; //@line 2299
       $$val454 = 100.0; //@line 2300
       break;
      }
     case 53:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e4; //@line 2305
       $$val454 = 1.0e4; //@line 2306
       break;
      }
     case 54:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e8; //@line 2311
       $$val454 = 1.0e8; //@line 2312
       break;
      }
     case 55:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e16; //@line 2317
       $$val454 = 1.0e16; //@line 2318
       break;
      }
     case 56:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e+32; //@line 2323
       $$val454 = 1.0e+32; //@line 2324
       break;
      }
     case 57:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e+64; //@line 2329
       $$val454 = 1.0e+64; //@line 2330
       break;
      }
     case 58:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e+128; //@line 2335
       $$val454 = 1.0e+128; //@line 2336
       break;
      }
     case 59:
      {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 1.0e+256; //@line 2341
       $$val454 = 1.0e+256; //@line 2342
       break;
      }
     default:
      {
       $1227 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 2351
       $1233 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1227 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1227) | 0; //@line 2357
       HEAP32[162770] = $1233; //@line 2358
       HEAP32[162769] = $1233; //@line 2359
       HEAP32[162768] = $1227; //@line 2360
       __Z7op_illgj($0); //@line 2361
       $$val454 = +HEAPF64[112672 + ($1201 << 3) >> 3]; //@line 2364
      }
     }
    } while (0);
    HEAPF64[14092] = $$val454; //@line 2368
    STACKTOP = sp; //@line 2369
    return;
   }
   $1236 = $1 >>> 10; //@line 2373
   $1237 = $1236 & 7; //@line 2374
   L352 : do {
    if (!($1 & 16384)) {
     $$sink104$i$sink = +HEAPF64[112672 + ($1237 << 3) >> 3]; //@line 2379
    } else {
     $1241 = $0 & 7; //@line 2382
     L355 : do {
      switch ($0 >>> 3 & 7) {
      case 0:
       {
        switch ($1236 & 7) {
        case 6:
         {
          $$sink104$i$sink = +((HEAP32[651008 + ($1241 << 2) >> 2] & 255) << 24 >> 24); //@line 2396
          break L352;
          break;
         }
        case 4:
         {
          $$sink104$i$sink = +((HEAP32[651008 + ($1241 << 2) >> 2] & 65535) << 16 >> 16); //@line 2405
          break L352;
          break;
         }
        case 0:
         {
          $$sink104$i$sink = +(HEAP32[651008 + ($1241 << 2) >> 2] | 0); //@line 2413
          break L352;
          break;
         }
        case 1:
         {
          $$sink104$i$sink = +HEAPF32[651008 + ($1241 << 2) >> 2]; //@line 2421
          break L352;
          break;
         }
        default:
         {
          break L355;
         }
        }
        break;
       }
      case 1:
       {
        break;
       }
      case 2:
       {
        $$098$i = HEAP32[651040 + ($1241 << 2) >> 2] | 0; //@line 2437
        label = 258; //@line 2438
        break;
       }
      case 3:
       {
        $1258 = 651040 + ($1241 << 2) | 0; //@line 2442
        $1259 = HEAP32[$1258 >> 2] | 0; //@line 2443
        HEAP32[$1258 >> 2] = (HEAP32[(($1241 | 0) == 7 ? 6704 : 6736) + ($1237 << 2) >> 2] | 0) + $1259; //@line 2449
        $$098$i = $1259; //@line 2450
        label = 258; //@line 2451
        break;
       }
      case 4:
       {
        $1267 = 651040 + ($1241 << 2) | 0; //@line 2459
        $1269 = (HEAP32[$1267 >> 2] | 0) - (HEAP32[(($1241 | 0) == 7 ? 6704 : 6736) + ($1237 << 2) >> 2] | 0) | 0; //@line 2461
        HEAP32[$1267 >> 2] = $1269; //@line 2462
        $$098$i = $1269; //@line 2463
        label = 258; //@line 2464
        break;
       }
      case 5:
       {
        $1271 = HEAP32[651040 + ($1241 << 2) >> 2] | 0; //@line 2469
        $1272 = HEAP32[162769] | 0; //@line 2470
        $1279 = HEAPU8[$1272 >> 0] << 8 | HEAPU8[$1272 + 1 >> 0]; //@line 2477
        HEAP32[162769] = $1272 + 2; //@line 2479
        $$098$i = ($1279 << 16 >> 16) + $1271 | 0; //@line 2483
        label = 258; //@line 2484
        break;
       }
      case 6:
       {
        $1284 = HEAP32[651040 + ($1241 << 2) >> 2] | 0; //@line 2489
        $1285 = HEAP32[162769] | 0; //@line 2490
        $1292 = HEAPU8[$1285 >> 0] << 8 | HEAPU8[$1285 + 1 >> 0]; //@line 2497
        HEAP32[162769] = $1285 + 2; //@line 2499
        $$098$i = __Z15get_disp_ea_020jj($1284, $1292) | 0; //@line 2501
        label = 258; //@line 2502
        break;
       }
      case 7:
       {
        switch ($0 & 7) {
        case 0:
         {
          $1295 = HEAP32[162769] | 0; //@line 2510
          $1302 = HEAPU8[$1295 >> 0] << 8 | HEAPU8[$1295 + 1 >> 0]; //@line 2517
          HEAP32[162769] = $1295 + 2; //@line 2519
          $$098$i = $1302 << 16 >> 16; //@line 2522
          label = 258; //@line 2523
          break L355;
          break;
         }
        case 1:
         {
          $1305 = HEAP32[162769] | 0; //@line 2528
          $1322 = HEAPU8[$1305 + 1 >> 0] << 16 | HEAPU8[$1305 >> 0] << 24 | HEAPU8[$1305 + 2 >> 0] << 8 | HEAPU8[$1305 + 3 >> 0]; //@line 2545
          HEAP32[162769] = $1305 + 4; //@line 2547
          $$098$i = $1322; //@line 2548
          label = 258; //@line 2549
          break L355;
          break;
         }
        case 2:
         {
          $1325 = HEAP32[162769] | 0; //@line 2555
          $1328 = $1325 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 2558
          $$cast107$i = $1325; //@line 2559
          $1335 = HEAPU8[$$cast107$i >> 0] << 8 | HEAPU8[$$cast107$i + 1 >> 0]; //@line 2566
          HEAP32[162769] = $$cast107$i + 2; //@line 2568
          $$098$i = $1328 + ($1335 << 16 >> 16) | 0; //@line 2572
          label = 258; //@line 2573
          break L355;
          break;
         }
        case 3:
         {
          $1340 = HEAP32[162769] | 0; //@line 2579
          $1343 = $1340 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 2582
          $$cast$i509 = $1340; //@line 2583
          $1350 = HEAPU8[$$cast$i509 >> 0] << 8 | HEAPU8[$$cast$i509 + 1 >> 0]; //@line 2590
          HEAP32[162769] = $$cast$i509 + 2; //@line 2592
          $$098$i = __Z15get_disp_ea_020jj($1343, $1350) | 0; //@line 2594
          label = 258; //@line 2595
          break L355;
          break;
         }
        case 4:
         {
          $1357 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 2604
          $1360 = $1357 + (HEAP32[6704 + ($1237 << 2) >> 2] | 0) | 0; //@line 2607
          $1366 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1360 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1360) | 0; //@line 2613
          HEAP32[162770] = $1366; //@line 2614
          HEAP32[162769] = $1366; //@line 2615
          HEAP32[162768] = $1360; //@line 2616
          $$098$i = $1357 + (($1237 | 0) == 6 & 1) | 0; //@line 2620
          label = 258; //@line 2621
          break L355;
          break;
         }
        default:
         {
          break L355;
         }
        }
        break;
       }
      default:
       {}
      }
     } while (0);
     L375 : do {
      if ((label | 0) == 258) {
       $1370 = 123608 + ($$098$i >>> 16 << 2) | 0; //@line 2639
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1370 >> 2] | 0) + 24 >> 2] & 127]($$098$i) | 0; //@line 2643
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1370 >> 2] | 0) + 24 >> 2] & 127]($$098$i) | 0; //@line 2647
       switch ($1236 & 7) {
       case 0:
        {
         $$sink104$i$sink = +(FUNCTION_TABLE_ii[HEAP32[HEAP32[$1370 >> 2] >> 2] & 127]($$098$i) | 0); //@line 2656
         break L352;
         break;
        }
       case 1:
        {
         $1383 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1370 >> 2] >> 2] & 127]($$098$i) | 0; //@line 2663
         $$sink104$i$sink = (HEAP32[tempDoublePtr >> 2] = $1383, +HEAPF32[tempDoublePtr >> 2]); //@line 2666
         break L352;
         break;
        }
       case 2:
        {
         $1388 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1370 >> 2] >> 2] & 127]($$098$i) | 0; //@line 2673
         $1389 = $$098$i + 4 | 0; //@line 2674
         $1394 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1389 >>> 16 << 2) >> 2] >> 2] & 127]($1389) | 0; //@line 2679
         $1395 = $$098$i + 8 | 0; //@line 2680
         $1400 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1395 >>> 16 << 2) >> 2] >> 2] & 127]($1395) | 0; //@line 2685
         if (!($1394 | $1388 & 2147418112 | $1400)) {
          $$sink104$i$sink = 0.0; //@line 2691
          break L352;
         }
         $1405 = $1388 >>> 31; //@line 2694
         $1407 = $1388 >>> 16 & 32767; //@line 2696
         do {
          if (($1394 | 0) > -1) {
           if (!($1400 | $1394)) {
            if (($1407 | 0) == 32767) {
             $$04051$i$i = $1394; //@line 2705
             $$04149$i$i = $1400; //@line 2705
             $1438 = 0; //@line 2705
             $1440 = 2146435072; //@line 2705
             break;
            } else {
             $$0405058$i$i = $1394; //@line 2708
             $$0414859$i$i = $1400; //@line 2708
             $2126 = 0; //@line 2708
             $2127 = 0; //@line 2708
             label = 270; //@line 2709
             break;
            }
           }
           if (($1407 | 0) != 0 & (($1394 | 0) > -1 | ($1394 | 0) == -1 & $1400 >>> 0 > 4294967295)) {
            $$03963$i$i = $1407; //@line 2721
            $1416 = $1400; //@line 2721
            $1417 = $1394; //@line 2721
            while (1) {
             $1418 = _bitshift64Shl($1416 | 0, $1417 | 0, 1) | 0; //@line 2723
             $1419 = tempRet0; //@line 2724
             $$03963$i$i = $$03963$i$i + -1 | 0; //@line 2725
             if (!((($1419 | 0) > -1 | ($1419 | 0) == -1 & $1418 >>> 0 > 4294967295) & ($$03963$i$i | 0) != 0)) {
              break;
             } else {
              $1416 = $1418; //@line 2734
              $1417 = $1419; //@line 2734
             }
            }
            $1426 = _bitshift64Lshr($1416 | 0, $1417 | 0, 31) | 0; //@line 2739
            $$040$i$i = $1426; //@line 2741
            $$041$i$i = $1418; //@line 2741
            $$1$i105$i = $$03963$i$i; //@line 2741
            label = 268; //@line 2742
           } else {
            $$040$i$i = $1394; //@line 2744
            $$041$i$i = $1400; //@line 2744
            $$1$i105$i = $1407; //@line 2744
            label = 268; //@line 2745
           }
          } else {
           $$040$i$i = $1394; //@line 2748
           $$041$i$i = $1400; //@line 2748
           $$1$i105$i = $1407; //@line 2748
           label = 268; //@line 2749
          }
         } while (0);
         if ((label | 0) == 268) {
          if ($$1$i105$i >>> 0 < 15360) {
           $$04051$i$i = $$040$i$i; //@line 2755
           $$04149$i$i = $$041$i$i; //@line 2755
           $1438 = 0; //@line 2755
           $1440 = 0; //@line 2755
          } else {
           $1433 = _bitshift64Shl($$1$i105$i + 1024 & 2047 | 0, 0, 52) | 0; //@line 2760
           if ($$1$i105$i >>> 0 > 17406) {
            $$04051$i$i = $$040$i$i; //@line 2763
            $$04149$i$i = $$041$i$i; //@line 2763
            $1438 = 0; //@line 2763
            $1440 = 2146435072; //@line 2763
           } else {
            $$0405058$i$i = $$040$i$i; //@line 2765
            $$0414859$i$i = $$041$i$i; //@line 2765
            $2126 = $1433; //@line 2765
            $2127 = tempRet0; //@line 2765
            label = 270; //@line 2766
           }
          }
         }
         if ((label | 0) == 270) {
          $$04051$i$i = $$0405058$i$i; //@line 2771
          $$04149$i$i = $$0414859$i$i; //@line 2771
          $1438 = $2126; //@line 2771
          $1440 = $2127; //@line 2771
         }
         $1435 = _bitshift64Shl($1405 | 0, 0, 63) | 0; //@line 2773
         $1443 = $1440 | tempRet0 | $$04051$i$i >>> 11 & 1048575; //@line 2779
         HEAP32[tempDoublePtr >> 2] = $1438 | $1435 | ($$04149$i$i >>> 11 | $$04051$i$i << 21); //@line 2784
         HEAP32[tempDoublePtr + 4 >> 2] = $1443; //@line 2784
         $$sink104$i$sink = +HEAPF64[tempDoublePtr >> 3]; //@line 2785
         break L352;
         break;
        }
       case 3:
        {
         $1451 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1370 >> 2] >> 2] & 127]($$098$i) | 0; //@line 2792
         $1452 = $$098$i + 4 | 0; //@line 2793
         $1457 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1452 >>> 16 << 2) >> 2] >> 2] & 127]($1452) | 0; //@line 2798
         $1458 = $$098$i + 8 | 0; //@line 2799
         $1463 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1458 >>> 16 << 2) >> 2] >> 2] & 127]($1458) | 0; //@line 2804
         if (($1451 | 0) < 0) {
          HEAP8[$3 >> 0] = 45; //@line 2808
          $$0$i$i514 = $3 + 1 | 0; //@line 2809
         } else {
          $$0$i$i514 = $3; //@line 2811
         }
         HEAP8[$$0$i$i514 >> 0] = $1451 & 15 | 48; //@line 2817
         HEAP8[$$0$i$i514 + 1 >> 0] = 46; //@line 2819
         HEAP8[$$0$i$i514 + 2 >> 0] = $1457 >>> 28 | 48; //@line 2824
         HEAP8[$$0$i$i514 + 3 >> 0] = $1457 >>> 24 & 15 | 48; //@line 2830
         HEAP8[$$0$i$i514 + 4 >> 0] = $1457 >>> 20 & 15 | 48; //@line 2836
         HEAP8[$$0$i$i514 + 5 >> 0] = $1457 >>> 16 & 15 | 48; //@line 2842
         HEAP8[$$0$i$i514 + 6 >> 0] = $1457 >>> 12 & 15 | 48; //@line 2848
         HEAP8[$$0$i$i514 + 7 >> 0] = $1457 >>> 8 & 15 | 48; //@line 2854
         HEAP8[$$0$i$i514 + 8 >> 0] = $1457 >>> 4 & 15 | 48; //@line 2860
         HEAP8[$$0$i$i514 + 9 >> 0] = $1457 & 15 | 48; //@line 2865
         HEAP8[$$0$i$i514 + 10 >> 0] = $1463 >>> 28 | 48; //@line 2870
         HEAP8[$$0$i$i514 + 11 >> 0] = $1463 >>> 24 & 15 | 48; //@line 2876
         HEAP8[$$0$i$i514 + 12 >> 0] = $1463 >>> 20 & 15 | 48; //@line 2882
         HEAP8[$$0$i$i514 + 13 >> 0] = $1463 >>> 16 & 15 | 48; //@line 2888
         HEAP8[$$0$i$i514 + 14 >> 0] = $1463 >>> 12 & 15 | 48; //@line 2894
         HEAP8[$$0$i$i514 + 15 >> 0] = $1463 >>> 8 & 15 | 48; //@line 2900
         HEAP8[$$0$i$i514 + 16 >> 0] = $1463 >>> 4 & 15 | 48; //@line 2906
         HEAP8[$$0$i$i514 + 17 >> 0] = $1463 & 15 | 48; //@line 2911
         $1547 = $$0$i$i514 + 19 | 0; //@line 2912
         HEAP8[$$0$i$i514 + 18 >> 0] = 69; //@line 2913
         if (!($1451 & 1073741824)) {
          $$1$i$i = $1547; //@line 2917
         } else {
          HEAP8[$1547 >> 0] = 45; //@line 2920
          $$1$i$i = $$0$i$i514 + 20 | 0; //@line 2921
         }
         HEAP8[$$1$i$i >> 0] = $1451 >>> 24 & 15 | 48; //@line 2928
         HEAP8[$$1$i$i + 1 >> 0] = $1451 >>> 20 & 15 | 48; //@line 2934
         HEAP8[$$1$i$i + 2 >> 0] = $1451 >>> 16 & 15 | 48; //@line 2940
         HEAP8[$$1$i$i + 3 >> 0] = 0; //@line 2941
         HEAP32[$vararg_buffer1 >> 2] = $2; //@line 2942
         _sscanf($3, 106246, $vararg_buffer1) | 0; //@line 2943
         $$sink104$i$sink = +HEAPF64[$2 >> 3]; //@line 2945
         break L352;
         break;
        }
       case 4:
        {
         $$sink104$i$sink = +(((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1370 >> 2] | 0) + 4 >> 2] & 127]($$098$i) | 0) & 65535) << 16 >> 16); //@line 2956
         break L352;
         break;
        }
       case 5:
        {
         $1575 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$1370 >> 2] >> 2] & 127]($$098$i) | 0; //@line 2963
         $1576 = $$098$i + 4 | 0; //@line 2964
         $1581 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1576 >>> 16 << 2) >> 2] >> 2] & 127]($1576) | 0; //@line 2969
         HEAP32[tempDoublePtr >> 2] = $1581; //@line 2970
         HEAP32[tempDoublePtr + 4 >> 2] = $1575; //@line 2970
         $$sink104$i$sink = +HEAPF64[tempDoublePtr >> 3]; //@line 2971
         break L352;
         break;
        }
       case 6:
        {
         $$sink104$i$sink = +(((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1370 >> 2] | 0) + 8 >> 2] & 127]($$098$i) | 0) & 255) << 24 >> 24); //@line 2982
         break L352;
         break;
        }
       default:
        {
         break L375;
        }
       }
      }
     } while (0);
     $1594 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 2997
     $1600 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1594 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1594) | 0; //@line 3003
     HEAP32[162770] = $1600; //@line 3004
     HEAP32[162769] = $1600; //@line 3005
     HEAP32[162768] = $1594; //@line 3006
     __Z7op_illgj($0); //@line 3007
     STACKTOP = sp; //@line 3008
     return;
    }
   } while (0);
   HEAPF64[tempDoublePtr >> 3] = $$sink104$i$sink; //@line 3011
   $1601 = HEAP32[tempDoublePtr >> 2] | 0; //@line 3011
   $1602 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 3012
   $1605 = $1 & 127; //@line 3015
   $$pre = $1 & 255; //@line 3016
   L409 : do {
    if (!(HEAP8[112776] | 0)) {
     switch ($$pre & 127) {
     case 0:
      {
       label = 310; //@line 3022
       break;
      }
     case 1:
      {
       label = 311; //@line 3026
       break;
      }
     case 2:
      {
       label = 318; //@line 3030
       break;
      }
     case 3:
      {
       label = 319; //@line 3034
       break;
      }
     case 4:
      {
       label = 320; //@line 3038
       break;
      }
     case 6:
      {
       label = 321; //@line 3042
       break;
      }
     case 8:
      {
       label = 322; //@line 3046
       break;
      }
     case 9:
      {
       label = 323; //@line 3050
       break;
      }
     case 10:
      {
       label = 324; //@line 3054
       break;
      }
     case 12:
      {
       label = 325; //@line 3058
       break;
      }
     case 13:
      {
       label = 326; //@line 3062
       break;
      }
     case 14:
      {
       label = 327; //@line 3066
       break;
      }
     case 15:
      {
       label = 328; //@line 3070
       break;
      }
     case 16:
      {
       label = 329; //@line 3074
       break;
      }
     case 17:
      {
       label = 330; //@line 3078
       break;
      }
     case 18:
      {
       label = 331; //@line 3082
       break;
      }
     case 20:
      {
       label = 332; //@line 3086
       break;
      }
     case 21:
      {
       label = 333; //@line 3090
       break;
      }
     case 22:
      {
       label = 334; //@line 3094
       break;
      }
     case 24:
      {
       label = 335; //@line 3098
       break;
      }
     case 25:
      {
       label = 336; //@line 3102
       break;
      }
     case 26:
      {
       label = 337; //@line 3106
       break;
      }
     case 28:
      {
       label = 338; //@line 3110
       break;
      }
     case 29:
      {
       label = 339; //@line 3114
       break;
      }
     case 30:
      {
       label = 340; //@line 3118
       break;
      }
     case 31:
      {
       label = 344; //@line 3122
       break;
      }
     case 32:
      {
       label = 350; //@line 3126
       break;
      }
     case 33:
      {
       label = 351; //@line 3130
       break;
      }
     case 35:
      {
       label = 352; //@line 3134
       break;
      }
     case 36:
      {
       label = 364; //@line 3138
       break;
      }
     case 37:
      {
       label = 365; //@line 3142
       break;
      }
     case 38:
      {
       label = 366; //@line 3146
       break;
      }
     case 39:
      {
       label = 374; //@line 3150
       break;
      }
     case 40:
      {
       label = 375; //@line 3154
       break;
      }
     case 34:
      {
       label = 376; //@line 3158
       break;
      }
     case 55:
     case 54:
     case 53:
     case 52:
     case 51:
     case 50:
     case 49:
     case 48:
      {
       label = 377; //@line 3162
       break;
      }
     case 56:
      {
       label = 378; //@line 3166
       break;
      }
     case 58:
      {
       label = 379; //@line 3170
       break;
      }
     default:
      {
       label = 380; //@line 3174
      }
     }
    } else {
     do {
      switch ($$pre & 127) {
      case 0:
       {
        label = 310; //@line 3182
        break L409;
        break;
       }
      case 1:
       {
        label = 311; //@line 3187
        break L409;
        break;
       }
      case 2:
       {
        label = 318; //@line 3192
        break L409;
        break;
       }
      case 3:
       {
        label = 319; //@line 3197
        break L409;
        break;
       }
      case 4:
       {
        label = 320; //@line 3202
        break L409;
        break;
       }
      case 6:
       {
        label = 321; //@line 3207
        break L409;
        break;
       }
      case 8:
       {
        label = 322; //@line 3212
        break L409;
        break;
       }
      case 9:
       {
        label = 323; //@line 3217
        break L409;
        break;
       }
      case 10:
       {
        label = 324; //@line 3222
        break L409;
        break;
       }
      case 12:
       {
        label = 325; //@line 3227
        break L409;
        break;
       }
      case 13:
       {
        label = 326; //@line 3232
        break L409;
        break;
       }
      case 14:
       {
        label = 327; //@line 3237
        break L409;
        break;
       }
      case 15:
       {
        label = 328; //@line 3242
        break L409;
        break;
       }
      case 16:
       {
        label = 329; //@line 3247
        break L409;
        break;
       }
      case 17:
       {
        label = 330; //@line 3252
        break L409;
        break;
       }
      case 18:
       {
        label = 331; //@line 3257
        break L409;
        break;
       }
      case 20:
       {
        label = 332; //@line 3262
        break L409;
        break;
       }
      case 21:
       {
        label = 333; //@line 3267
        break L409;
        break;
       }
      case 22:
       {
        label = 334; //@line 3272
        break L409;
        break;
       }
      case 24:
       {
        label = 335; //@line 3277
        break L409;
        break;
       }
      case 25:
       {
        label = 336; //@line 3282
        break L409;
        break;
       }
      case 26:
       {
        label = 337; //@line 3287
        break L409;
        break;
       }
      case 28:
       {
        label = 338; //@line 3292
        break L409;
        break;
       }
      case 29:
       {
        label = 339; //@line 3297
        break L409;
        break;
       }
      case 30:
       {
        label = 340; //@line 3302
        break L409;
        break;
       }
      case 31:
       {
        label = 344; //@line 3307
        break L409;
        break;
       }
      case 32:
       {
        label = 350; //@line 3312
        break L409;
        break;
       }
      case 33:
       {
        label = 351; //@line 3317
        break L409;
        break;
       }
      case 35:
       {
        label = 352; //@line 3322
        break L409;
        break;
       }
      case 36:
       {
        label = 364; //@line 3327
        break L409;
        break;
       }
      case 37:
       {
        label = 365; //@line 3332
        break L409;
        break;
       }
      case 38:
       {
        label = 366; //@line 3337
        break L409;
        break;
       }
      case 39:
       {
        label = 374; //@line 3342
        break L409;
        break;
       }
      case 40:
       {
        label = 375; //@line 3347
        break L409;
        break;
       }
      case 34:
       {
        label = 376; //@line 3352
        break L409;
        break;
       }
      case 55:
      case 54:
      case 53:
      case 52:
      case 51:
      case 50:
      case 49:
      case 48:
       {
        label = 377; //@line 3357
        break L409;
        break;
       }
      case 56:
       {
        label = 378; //@line 3362
        break L409;
        break;
       }
      case 58:
       {
        label = 379; //@line 3367
        break L409;
        break;
       }
      case 64:
       {
        $1607 = $$sink104$i$sink; //@line 3373
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1607; //@line 3375
        HEAPF64[14092] = $1607; //@line 3376
        STACKTOP = sp; //@line 3377
        return;
       }
      case 68:
       {
        HEAPF64[112672 + ($1201 << 3) >> 3] = $$sink104$i$sink; //@line 3382
        HEAPF64[14092] = $$sink104$i$sink; //@line 3383
        STACKTOP = sp; //@line 3384
        return;
       }
      case 65:
       {
        $1612 = +Math_sqrt(+$$sink104$i$sink); //@line 3390
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1612; //@line 3392
        HEAPF64[14092] = $1612; //@line 3393
        STACKTOP = sp; //@line 3394
        return;
       }
      case 69:
       {
        $1614 = +Math_sqrt(+$$sink104$i$sink); //@line 3398
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1614; //@line 3400
        HEAPF64[14092] = $1614; //@line 3401
        STACKTOP = sp; //@line 3402
        return;
       }
      case 88:
       {
        $1618 = +Math_abs(+$$sink104$i$sink); //@line 3408
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1618; //@line 3410
        HEAPF64[14092] = $1618; //@line 3411
        STACKTOP = sp; //@line 3412
        return;
       }
      case 92:
       {
        $1620 = +Math_abs(+$$sink104$i$sink); //@line 3416
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1620; //@line 3418
        HEAPF64[14092] = $1620; //@line 3419
        STACKTOP = sp; //@line 3420
        return;
       }
      case 90:
       {
        $1624 = -$$sink104$i$sink; //@line 3426
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1624; //@line 3428
        HEAPF64[14092] = $1624; //@line 3429
        STACKTOP = sp; //@line 3430
        return;
       }
      case 94:
       {
        $1626 = -$$sink104$i$sink; //@line 3434
        HEAPF64[112672 + ($1201 << 3) >> 3] = $1626; //@line 3436
        HEAPF64[14092] = $1626; //@line 3437
        STACKTOP = sp; //@line 3438
        return;
       }
      case 96:
       {
        $1628 = 112672 + ($1201 << 3) | 0; //@line 3442
        $1632 = +HEAPF64[$1628 >> 3] / $$sink104$i$sink; //@line 3446
        HEAPF64[$1628 >> 3] = $1632; //@line 3447
        HEAPF64[14092] = $1632; //@line 3448
        STACKTOP = sp; //@line 3449
        return;
       }
      case 100:
       {
        $1633 = 112672 + ($1201 << 3) | 0; //@line 3453
        $1635 = +HEAPF64[$1633 >> 3] / $$sink104$i$sink; //@line 3455
        HEAPF64[$1633 >> 3] = $1635; //@line 3456
        HEAPF64[14092] = $1635; //@line 3457
        STACKTOP = sp; //@line 3458
        return;
       }
      case 98:
       {
        $1636 = 112672 + ($1201 << 3) | 0; //@line 3462
        $1640 = $$sink104$i$sink + +HEAPF64[$1636 >> 3]; //@line 3466
        HEAPF64[$1636 >> 3] = $1640; //@line 3467
        HEAPF64[14092] = $1640; //@line 3468
        STACKTOP = sp; //@line 3469
        return;
       }
      case 102:
       {
        $1641 = 112672 + ($1201 << 3) | 0; //@line 3473
        $1643 = $$sink104$i$sink + +HEAPF64[$1641 >> 3]; //@line 3475
        HEAPF64[$1641 >> 3] = $1643; //@line 3476
        HEAPF64[14092] = $1643; //@line 3477
        STACKTOP = sp; //@line 3478
        return;
       }
      case 104:
       {
        $1644 = 112672 + ($1201 << 3) | 0; //@line 3482
        $1648 = +HEAPF64[$1644 >> 3] - $$sink104$i$sink; //@line 3486
        HEAPF64[$1644 >> 3] = $1648; //@line 3487
        HEAPF64[14092] = $1648; //@line 3488
        STACKTOP = sp; //@line 3489
        return;
       }
      case 108:
       {
        $1649 = 112672 + ($1201 << 3) | 0; //@line 3493
        $1651 = +HEAPF64[$1649 >> 3] - $$sink104$i$sink; //@line 3495
        HEAPF64[$1649 >> 3] = $1651; //@line 3496
        HEAPF64[14092] = $1651; //@line 3497
        STACKTOP = sp; //@line 3498
        return;
       }
      case 103:
      case 99:
       {
        $1652 = 112672 + ($1201 << 3) | 0; //@line 3502
        $1653 = $1652; //@line 3503
        $1655 = HEAP32[$1653 >> 2] | 0; //@line 3505
        $1658 = HEAP32[$1653 + 4 >> 2] | 0; //@line 3508
        $1659 = _bitshift64Lshr($1655 | 0, $1658 | 0, 63) | 0; //@line 3509
        HEAP32[162825] = $1659; //@line 3511
        $1664 = ($1655 | 0) == 0 & ($1658 & 2147483647 | 0) == 0; //@line 3515
        HEAP32[162826] = $1664 & 1; //@line 3517
        $1666 = $1658 & 2147483647; //@line 3518
        $1675 = ($1658 >> 30 & ~(($1655 | 0 - ($1666 ^ 2146435072 | $1655)) >> 31) | 0) != 0; //@line 3527
        HEAP32[162827] = $1675 & 1; //@line 3529
        $1681 = ($1666 | ($1655 | 0 - $1655) >>> 31) >>> 0 > 2146435072; //@line 3534
        HEAP32[162828] = $1681 & 1; //@line 3536
        $$$i505 = ($1681 | ($1664 | $1675)) ^ 1; //@line 3539
        HEAP32[162829] = $$$i505 & 1; //@line 3541
        $1685 = _bitshift64Lshr($1601 | 0, $1602 | 0, 63) | 0; //@line 3542
        HEAP32[162830] = $1685; //@line 3544
        $1690 = ($1601 | 0) == 0 & ($1602 & 2147483647 | 0) == 0; //@line 3548
        HEAP32[162831] = $1690 & 1; //@line 3550
        $1692 = $1602 & 2147483647; //@line 3551
        $1701 = ($1602 >> 30 & ~(($1601 | 0 - ($1692 ^ 2146435072 | $1601)) >> 31) | 0) != 0; //@line 3560
        HEAP32[162832] = $1701 & 1; //@line 3562
        $1707 = ($1692 | ($1601 | 0 - $1601) >>> 31) >>> 0 > 2146435072; //@line 3567
        HEAP32[162833] = $1707 & 1; //@line 3569
        $$$i502 = ($1707 | ($1690 | $1701)) ^ 1; //@line 3572
        HEAP32[162834] = $$$i502 & 1; //@line 3574
        do {
         if ($$$i505 & $$$i502) {
          HEAP32[tempDoublePtr >> 2] = $1655; //@line 3578
          HEAP32[tempDoublePtr + 4 >> 2] = $1658; //@line 3578
          $1713 = $$sink104$i$sink * +HEAPF64[tempDoublePtr >> 3]; //@line 3580
          $$sink = ($1605 | 0) == 99 ? $1713 : $1713; //@line 3583
          HEAPF64[$1652 >> 3] = $$sink; //@line 3584
          $$val439 = $$sink; //@line 3585
         } else {
          if ($1707 | $1681 | $1664 & $1701 | $1675 & $1690) {
           $1717 = $1658 | 2147483647; //@line 3593
           $1718 = $1652; //@line 3594
           HEAP32[$1718 >> 2] = -1; //@line 3596
           HEAP32[$1718 + 4 >> 2] = $1717; //@line 3599
           HEAP32[tempDoublePtr >> 2] = -1; //@line 3600
           HEAP32[tempDoublePtr + 4 >> 2] = $1717; //@line 3600
           $$val439 = +HEAPF64[tempDoublePtr >> 3]; //@line 3601
           break;
          }
          $1724 = ($1659 | 0) == 0; //@line 3605
          $1725 = ($1685 | 0) != 0; //@line 3606
          $or$cond398 = $1724 & $1725 | ($1724 | $1725) ^ 1; //@line 3610
          if ($1690 | $1664) {
           if ($or$cond398) {
            HEAPF64[$1652 >> 3] = -0.0; //@line 3613
            $$val439 = -0.0; //@line 3614
            break;
           } else {
            HEAPF64[$1652 >> 3] = 0.0; //@line 3617
            $$val439 = 0.0; //@line 3618
            break;
           }
          } else {
           $1726 = $1658 & 524288; //@line 3622
           if ($or$cond398) {
            $1727 = $1726 | -1048576; //@line 3624
            $1728 = $1652; //@line 3625
            HEAP32[$1728 >> 2] = 0; //@line 3627
            HEAP32[$1728 + 4 >> 2] = $1727; //@line 3630
            HEAP32[tempDoublePtr >> 2] = 0; //@line 3631
            HEAP32[tempDoublePtr + 4 >> 2] = $1727; //@line 3631
            $$val439 = +HEAPF64[tempDoublePtr >> 3]; //@line 3632
            break;
           } else {
            $1733 = $1726 | 2146435072; //@line 3635
            $1734 = $1652; //@line 3636
            HEAP32[$1734 >> 2] = 0; //@line 3638
            HEAP32[$1734 + 4 >> 2] = $1733; //@line 3641
            HEAP32[tempDoublePtr >> 2] = 0; //@line 3642
            HEAP32[tempDoublePtr + 4 >> 2] = $1733; //@line 3642
            $$val439 = +HEAPF64[tempDoublePtr >> 3]; //@line 3643
            break;
           }
          }
         }
        } while (0);
        HEAPF64[14092] = $$val439; //@line 3649
        STACKTOP = sp; //@line 3650
        return;
       }
      default:
       {
        label = 380; //@line 3654
        break L409;
       }
      }
     } while (0);
    }
   } while (0);
   switch (label | 0) {
   case 310:
    {
     HEAPF64[112672 + ($1201 << 3) >> 3] = $$sink104$i$sink; //@line 3664
     HEAPF64[14092] = $$sink104$i$sink; //@line 3665
     STACKTOP = sp; //@line 3666
     return;
    }
   case 311:
    {
     switch ((HEAP32[28188] | HEAP32[28187]) >>> 4 & 3) {
     case 1:
      {
       $$0$i492 = +(~~$$sink104$i$sink | 0); //@line 3680
       break;
      }
     case 2:
      {
       $$0$i492 = +Math_floor(+$$sink104$i$sink); //@line 3685
       break;
      }
     case 0:
      {
       $$0$i492 = +(~~($$sink104$i$sink + .5) | 0); //@line 3692
       break;
      }
     case 3:
      {
       $$0$i492 = +Math_ceil(+$$sink104$i$sink); //@line 3697
       break;
      }
     default:
      {}
     }
     $1752 = +(~~$$0$i492 | 0); //@line 3705
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1752; //@line 3707
     HEAPF64[14092] = $1752; //@line 3708
     STACKTOP = sp; //@line 3709
     return;
    }
   case 318:
    {
     $1754 = +_sinh($$sink104$i$sink); //@line 3713
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1754; //@line 3715
     HEAPF64[14092] = $1754; //@line 3716
     STACKTOP = sp; //@line 3717
     return;
    }
   case 319:
    {
     $1757 = +(~~$$sink104$i$sink | 0); //@line 3722
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1757; //@line 3724
     HEAPF64[14092] = $1757; //@line 3725
     STACKTOP = sp; //@line 3726
     return;
    }
   case 320:
    {
     $1759 = +Math_sqrt(+$$sink104$i$sink); //@line 3730
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1759; //@line 3732
     HEAPF64[14092] = $1759; //@line 3733
     STACKTOP = sp; //@line 3734
     return;
    }
   case 321:
    {
     $1762 = +Math_log(+($$sink104$i$sink + 1.0)); //@line 3739
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1762; //@line 3741
     HEAPF64[14092] = $1762; //@line 3742
     STACKTOP = sp; //@line 3743
     return;
    }
   case 322:
    {
     $1765 = +Math_exp(+$$sink104$i$sink) + -1.0; //@line 3748
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1765; //@line 3750
     HEAPF64[14092] = $1765; //@line 3751
     STACKTOP = sp; //@line 3752
     return;
    }
   case 323:
    {
     $1767 = +_tanh($$sink104$i$sink); //@line 3756
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1767; //@line 3758
     HEAPF64[14092] = $1767; //@line 3759
     STACKTOP = sp; //@line 3760
     return;
    }
   case 324:
    {
     $1769 = +Math_atan(+$$sink104$i$sink); //@line 3764
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1769; //@line 3766
     HEAPF64[14092] = $1769; //@line 3767
     STACKTOP = sp; //@line 3768
     return;
    }
   case 325:
    {
     $1771 = +Math_asin(+$$sink104$i$sink); //@line 3772
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1771; //@line 3774
     HEAPF64[14092] = $1771; //@line 3775
     STACKTOP = sp; //@line 3776
     return;
    }
   case 326:
    {
     $1773 = +_atanh($$sink104$i$sink); //@line 3780
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1773; //@line 3782
     HEAPF64[14092] = $1773; //@line 3783
     STACKTOP = sp; //@line 3784
     return;
    }
   case 327:
    {
     $1775 = +Math_sin(+$$sink104$i$sink); //@line 3788
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1775; //@line 3790
     HEAPF64[14092] = $1775; //@line 3791
     STACKTOP = sp; //@line 3792
     return;
    }
   case 328:
    {
     $1777 = +Math_tan(+$$sink104$i$sink); //@line 3796
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1777; //@line 3798
     HEAPF64[14092] = $1777; //@line 3799
     STACKTOP = sp; //@line 3800
     return;
    }
   case 329:
    {
     $1779 = +Math_exp(+$$sink104$i$sink); //@line 3804
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1779; //@line 3806
     HEAPF64[14092] = $1779; //@line 3807
     STACKTOP = sp; //@line 3808
     return;
    }
   case 330:
    {
     $exp2 = +_llvm_exp2_f64(+$$sink104$i$sink); //@line 3812
     HEAPF64[112672 + ($1201 << 3) >> 3] = $exp2; //@line 3814
     HEAPF64[14092] = $exp2; //@line 3815
     STACKTOP = sp; //@line 3816
     return;
    }
   case 331:
    {
     $1782 = +Math_pow(10.0, +$$sink104$i$sink); //@line 3820
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1782; //@line 3822
     HEAPF64[14092] = $1782; //@line 3823
     STACKTOP = sp; //@line 3824
     return;
    }
   case 332:
    {
     $1784 = +Math_log(+$$sink104$i$sink); //@line 3828
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1784; //@line 3830
     HEAPF64[14092] = $1784; //@line 3831
     STACKTOP = sp; //@line 3832
     return;
    }
   case 333:
    {
     $1786 = +_log10($$sink104$i$sink); //@line 3836
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1786; //@line 3838
     HEAPF64[14092] = $1786; //@line 3839
     STACKTOP = sp; //@line 3840
     return;
    }
   case 334:
    {
     $1789 = +Math_log(+$$sink104$i$sink) / .6931471805599453; //@line 3845
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1789; //@line 3847
     HEAPF64[14092] = $1789; //@line 3848
     STACKTOP = sp; //@line 3849
     return;
    }
   case 335:
    {
     $1791 = +Math_abs(+$$sink104$i$sink); //@line 3853
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1791; //@line 3855
     HEAPF64[14092] = $1791; //@line 3856
     STACKTOP = sp; //@line 3857
     return;
    }
   case 336:
    {
     $1793 = +_cosh($$sink104$i$sink); //@line 3861
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1793; //@line 3863
     HEAPF64[14092] = $1793; //@line 3864
     STACKTOP = sp; //@line 3865
     return;
    }
   case 337:
    {
     $1795 = -$$sink104$i$sink; //@line 3869
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1795; //@line 3871
     HEAPF64[14092] = $1795; //@line 3872
     STACKTOP = sp; //@line 3873
     return;
    }
   case 338:
    {
     $1797 = +Math_acos(+$$sink104$i$sink); //@line 3877
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1797; //@line 3879
     HEAPF64[14092] = $1797; //@line 3880
     STACKTOP = sp; //@line 3881
     return;
    }
   case 339:
    {
     $1799 = +Math_cos(+$$sink104$i$sink); //@line 3885
     HEAPF64[112672 + ($1201 << 3) >> 3] = $1799; //@line 3887
     HEAPF64[14092] = $1799; //@line 3888
     STACKTOP = sp; //@line 3889
     return;
    }
   case 340:
    {
     if (!($1602 >> 30 & ~(($1601 | 0 - ($1602 & 2147483647 ^ 2146435072 | $1601)) >> 31))) {
      $1824 = _bitshift64Lshr($1601 | 0, $1602 | 0, 52) | 0; //@line 3904
      $1828 = +(($1824 & 2047) + -1023 | 0); //@line 3908
      HEAPF64[112672 + ($1201 << 3) >> 3] = $1828; //@line 3910
      $$val414 = $1828; //@line 3911
     } else {
      $1811 = 112672 + ($1201 << 3) | 0; //@line 3913
      $1818 = HEAP32[$1811 + 4 >> 2] | 2147483647; //@line 3920
      $1819 = $1811; //@line 3921
      HEAP32[$1819 >> 2] = -1; //@line 3923
      HEAP32[$1819 + 4 >> 2] = $1818; //@line 3926
      HEAP32[tempDoublePtr >> 2] = -1; //@line 3927
      HEAP32[tempDoublePtr + 4 >> 2] = $1818; //@line 3927
      $$val414 = +HEAPF64[tempDoublePtr >> 3]; //@line 3928
     }
     HEAPF64[14092] = $$val414; //@line 3930
     STACKTOP = sp; //@line 3931
     return;
    }
   case 344:
    {
     do {
      if ($$sink104$i$sink == 0.0) {
       HEAPF64[112672 + ($1201 << 3) >> 3] = 0.0; //@line 3939
       $$val413 = 0.0; //@line 3940
      } else {
       $1842 = 112672 + ($1201 << 3) | 0; //@line 3952
       if (!($1602 >> 30 & ~(($1601 | 0 - ($1602 & 2147483647 ^ 2146435072 | $1601)) >> 31))) {
        $1856 = $1602 & -2146435073 | 1072693248; //@line 3955
        $1857 = $1842; //@line 3956
        HEAP32[$1857 >> 2] = $1601; //@line 3958
        HEAP32[$1857 + 4 >> 2] = $1856; //@line 3961
        HEAP32[tempDoublePtr >> 2] = $1601; //@line 3962
        HEAP32[tempDoublePtr + 4 >> 2] = $1856; //@line 3962
        $$val413 = +HEAPF64[tempDoublePtr >> 3]; //@line 3963
        break;
       } else {
        $1849 = HEAP32[$1842 + 4 >> 2] | 2147483647; //@line 3972
        $1850 = $1842; //@line 3973
        HEAP32[$1850 >> 2] = -1; //@line 3975
        HEAP32[$1850 + 4 >> 2] = $1849; //@line 3978
        HEAP32[tempDoublePtr >> 2] = -1; //@line 3979
        HEAP32[tempDoublePtr + 4 >> 2] = $1849; //@line 3979
        $$val413 = +HEAPF64[tempDoublePtr >> 3]; //@line 3980
        break;
       }
      }
     } while (0);
     HEAPF64[14092] = $$val413; //@line 3985
     STACKTOP = sp; //@line 3986
     return;
    }
   case 350:
    {
     $1862 = 112672 + ($1201 << 3) | 0; //@line 3990
     $1864 = +HEAPF64[$1862 >> 3] / $$sink104$i$sink; //@line 3992
     HEAPF64[$1862 >> 3] = $1864; //@line 3993
     HEAPF64[14092] = $1864; //@line 3994
     STACKTOP = sp; //@line 3995
     return;
    }
   case 351:
    {
     $1865 = 112672 + ($1201 << 3) | 0; //@line 3999
     $1866 = +HEAPF64[$1865 >> 3]; //@line 4000
     $1869 = +(~~($1866 / $$sink104$i$sink) | 0); //@line 4003
     HEAPF64[tempDoublePtr >> 3] = $1866; //@line 4004
     HEAP32[tempDoublePtr >> 2] ^ $1601; //@line 4006
     $1874 = (HEAP32[tempDoublePtr + 4 >> 2] ^ $1602 | 0) < 0 ? 8388608 : 0; //@line 4009
     $1876 = $1866 - $$sink104$i$sink * $1869; //@line 4011
     HEAPF64[$1865 >> 3] = $1876; //@line 4012
     HEAPF64[14092] = $1876; //@line 4013
     HEAP32[28190] = ~~+Math_abs(+$1869) >>> 0 << 16 & 8323072 | $1874; //@line 4019
     STACKTOP = sp; //@line 4020
     return;
    }
   case 352:
    {
     $1882 = 112672 + ($1201 << 3) | 0; //@line 4024
     $1883 = $1882; //@line 4025
     $1885 = HEAP32[$1883 >> 2] | 0; //@line 4027
     $1888 = HEAP32[$1883 + 4 >> 2] | 0; //@line 4030
     $1889 = _bitshift64Lshr($1885 | 0, $1888 | 0, 63) | 0; //@line 4031
     HEAP32[162825] = $1889; //@line 4033
     $1894 = ($1885 | 0) == 0 & ($1888 & 2147483647 | 0) == 0; //@line 4037
     HEAP32[162826] = $1894 & 1; //@line 4039
     $1896 = $1888 & 2147483647; //@line 4040
     $1905 = ($1888 >> 30 & ~(($1885 | 0 - ($1896 ^ 2146435072 | $1885)) >> 31) | 0) != 0; //@line 4049
     HEAP32[162827] = $1905 & 1; //@line 4051
     $1911 = ($1896 | ($1885 | 0 - $1885) >>> 31) >>> 0 > 2146435072; //@line 4056
     HEAP32[162828] = $1911 & 1; //@line 4058
     $$$i488 = ($1911 | ($1894 | $1905)) ^ 1; //@line 4061
     HEAP32[162829] = $$$i488 & 1; //@line 4063
     $1915 = _bitshift64Lshr($1601 | 0, $1602 | 0, 63) | 0; //@line 4064
     HEAP32[162830] = $1915; //@line 4066
     $1920 = ($1601 | 0) == 0 & ($1602 & 2147483647 | 0) == 0; //@line 4070
     HEAP32[162831] = $1920 & 1; //@line 4072
     $1922 = $1602 & 2147483647; //@line 4073
     $1931 = ($1602 >> 30 & ~(($1601 | 0 - ($1922 ^ 2146435072 | $1601)) >> 31) | 0) != 0; //@line 4082
     HEAP32[162832] = $1931 & 1; //@line 4084
     $1937 = ($1922 | ($1601 | 0 - $1601) >>> 31) >>> 0 > 2146435072; //@line 4089
     HEAP32[162833] = $1937 & 1; //@line 4091
     $$$i485 = ($1937 | ($1920 | $1931)) ^ 1; //@line 4094
     HEAP32[162834] = $$$i485 & 1; //@line 4096
     do {
      if ($$$i488 & $$$i485) {
       HEAP32[tempDoublePtr >> 2] = $1885; //@line 4100
       HEAP32[tempDoublePtr + 4 >> 2] = $1888; //@line 4100
       $1942 = $$sink104$i$sink * +HEAPF64[tempDoublePtr >> 3]; //@line 4101
       HEAPF64[$1882 >> 3] = $1942; //@line 4102
       $$val410 = $1942; //@line 4103
      } else {
       if ($1937 | $1911 | $1894 & $1931 | $1905 & $1920) {
        $1944 = $1888 | 2147483647; //@line 4111
        $1945 = $1882; //@line 4112
        HEAP32[$1945 >> 2] = -1; //@line 4114
        HEAP32[$1945 + 4 >> 2] = $1944; //@line 4117
        HEAP32[tempDoublePtr >> 2] = -1; //@line 4118
        HEAP32[tempDoublePtr + 4 >> 2] = $1944; //@line 4118
        $$val410 = +HEAPF64[tempDoublePtr >> 3]; //@line 4119
        break;
       }
       $1951 = ($1889 | 0) == 0; //@line 4123
       $1952 = ($1915 | 0) != 0; //@line 4124
       $or$cond401 = $1951 & $1952 | ($1951 | $1952) ^ 1; //@line 4128
       if ($1920 | $1894) {
        if ($or$cond401) {
         HEAPF64[$1882 >> 3] = -0.0; //@line 4131
         $$val410 = -0.0; //@line 4132
         break;
        } else {
         HEAPF64[$1882 >> 3] = 0.0; //@line 4135
         $$val410 = 0.0; //@line 4136
         break;
        }
       } else {
        $1953 = $1888 & 524288; //@line 4140
        if ($or$cond401) {
         $1954 = $1953 | -1048576; //@line 4142
         $1955 = $1882; //@line 4143
         HEAP32[$1955 >> 2] = 0; //@line 4145
         HEAP32[$1955 + 4 >> 2] = $1954; //@line 4148
         HEAP32[tempDoublePtr >> 2] = 0; //@line 4149
         HEAP32[tempDoublePtr + 4 >> 2] = $1954; //@line 4149
         $$val410 = +HEAPF64[tempDoublePtr >> 3]; //@line 4150
         break;
        } else {
         $1960 = $1953 | 2146435072; //@line 4153
         $1961 = $1882; //@line 4154
         HEAP32[$1961 >> 2] = 0; //@line 4156
         HEAP32[$1961 + 4 >> 2] = $1960; //@line 4159
         HEAP32[tempDoublePtr >> 2] = 0; //@line 4160
         HEAP32[tempDoublePtr + 4 >> 2] = $1960; //@line 4160
         $$val410 = +HEAPF64[tempDoublePtr >> 3]; //@line 4161
         break;
        }
       }
      }
     } while (0);
     HEAPF64[14092] = $$val410; //@line 4167
     STACKTOP = sp; //@line 4168
     return;
    }
   case 364:
    {
     $1966 = 112672 + ($1201 << 3) | 0; //@line 4172
     $1970 = +HEAPF64[$1966 >> 3] / $$sink104$i$sink; //@line 4176
     HEAPF64[$1966 >> 3] = $1970; //@line 4177
     HEAPF64[14092] = $1970; //@line 4178
     STACKTOP = sp; //@line 4179
     return;
    }
   case 365:
    {
     $1971 = 112672 + ($1201 << 3) | 0; //@line 4183
     $1972 = +HEAPF64[$1971 >> 3]; //@line 4184
     $1976 = +(~~($1972 / $$sink104$i$sink + .5) | 0); //@line 4188
     HEAPF64[tempDoublePtr >> 3] = $1972; //@line 4189
     HEAP32[tempDoublePtr >> 2] ^ $1601; //@line 4191
     $1981 = (HEAP32[tempDoublePtr + 4 >> 2] ^ $1602 | 0) < 0 ? 8388608 : 0; //@line 4194
     $1983 = $1972 - $$sink104$i$sink * $1976; //@line 4196
     HEAPF64[$1971 >> 3] = $1983; //@line 4197
     HEAPF64[14092] = $1983; //@line 4198
     HEAP32[28190] = ~~+Math_abs(+$1976) >>> 0 << 16 & 8323072 | $1981; //@line 4204
     STACKTOP = sp; //@line 4205
     return;
    }
   case 366:
    {
     $1989 = 112672 + ($1201 << 3) | 0; //@line 4209
     $1990 = $1989; //@line 4210
     $1992 = HEAP32[$1990 >> 2] | 0; //@line 4212
     $1995 = HEAP32[$1990 + 4 >> 2] | 0; //@line 4215
     HEAP32[162825] = _bitshift64Lshr($1992 | 0, $1995 | 0, 63) | 0; //@line 4218
     $2001 = ($1992 | 0) == 0 & ($1995 & 2147483647 | 0) == 0; //@line 4222
     HEAP32[162826] = $2001 & 1; //@line 4224
     $2003 = $1995 & 2147483647; //@line 4225
     $2012 = ($1995 >> 30 & ~(($1992 | 0 - ($2003 ^ 2146435072 | $1992)) >> 31) | 0) != 0; //@line 4234
     HEAP32[162827] = $2012 & 1; //@line 4236
     $2018 = ($2003 | ($1992 | 0 - $1992) >>> 31) >>> 0 > 2146435072; //@line 4241
     HEAP32[162828] = $2018 & 1; //@line 4243
     $$$i482 = ($2018 | ($2001 | $2012)) ^ 1; //@line 4246
     HEAP32[162829] = $$$i482 & 1; //@line 4248
     HEAP32[162830] = _bitshift64Lshr($1601 | 0, $1602 | 0, 63) | 0; //@line 4251
     $2027 = ($1601 | 0) == 0 & ($1602 & 2147483647 | 0) == 0; //@line 4255
     HEAP32[162831] = $2027 & 1; //@line 4257
     $2029 = $1602 & 2147483647; //@line 4258
     $2038 = ($1602 >> 30 & ~(($1601 | 0 - ($2029 ^ 2146435072 | $1601)) >> 31) | 0) != 0; //@line 4267
     HEAP32[162832] = $2038 & 1; //@line 4269
     $2044 = ($2029 | ($1601 | 0 - $1601) >>> 31) >>> 0 > 2146435072; //@line 4274
     HEAP32[162833] = $2044 & 1; //@line 4276
     $$$i479 = ($2044 | ($2027 | $2038)) ^ 1; //@line 4279
     HEAP32[162834] = $$$i479 & 1; //@line 4281
     if ($$$i482 & $$$i479) {
      $2049 = _bitshift64Lshr($1992 | 0, $1995 | 0, 52) | 0; //@line 4285
      $2052 = ($2049 & 2047) + ~~$$sink104$i$sink | 0; //@line 4288
      if ($2052 >>> 0 < 15360) {
       $2063 = 0; //@line 4291
       $2065 = 0; //@line 4291
      } else {
       $2054 = $2052 >>> 0 > 17406; //@line 4293
       $2057 = _bitshift64Shl($2052 + 1024 & 2047 | 0, 0, 52) | 0; //@line 4296
       $2063 = $2054 ? 0 : $2057; //@line 4300
       $2065 = $2054 ? 2146435072 : tempRet0; //@line 4300
      }
      $2069 = $1992 | $2063; //@line 4305
      $2072 = $1995 & -2146435073 | $2065; //@line 4305
      label = 372; //@line 4306
     } else {
      if ($2038) {
       $2069 = -1; //@line 4310
       $2072 = $1995 | 2147483647; //@line 4310
       label = 372; //@line 4311
      } else {
       $2075 = $1992; //@line 4313
       $2078 = $1995; //@line 4313
      }
     }
     if ((label | 0) == 372) {
      $2067 = $1989; //@line 4317
      HEAP32[$2067 >> 2] = $2069; //@line 4319
      HEAP32[$2067 + 4 >> 2] = $2072; //@line 4322
      $2075 = $2069; //@line 4323
      $2078 = $2072; //@line 4323
     }
     $2073 = 112736; //@line 4325
     HEAP32[$2073 >> 2] = $2075; //@line 4327
     HEAP32[$2073 + 4 >> 2] = $2078; //@line 4330
     STACKTOP = sp; //@line 4331
     return;
    }
   case 374:
    {
     $2079 = 112672 + ($1201 << 3) | 0; //@line 4335
     $2083 = $$sink104$i$sink * +HEAPF64[$2079 >> 3]; //@line 4339
     HEAPF64[$2079 >> 3] = $2083; //@line 4340
     HEAPF64[14092] = $2083; //@line 4341
     STACKTOP = sp; //@line 4342
     return;
    }
   case 375:
    {
     $2084 = 112672 + ($1201 << 3) | 0; //@line 4346
     $2086 = +HEAPF64[$2084 >> 3] - $$sink104$i$sink; //@line 4348
     HEAPF64[$2084 >> 3] = $2086; //@line 4349
     HEAPF64[14092] = $2086; //@line 4350
     STACKTOP = sp; //@line 4351
     return;
    }
   case 376:
    {
     $2087 = 112672 + ($1201 << 3) | 0; //@line 4355
     $2089 = $$sink104$i$sink + +HEAPF64[$2087 >> 3]; //@line 4357
     HEAPF64[$2087 >> 3] = $2089; //@line 4358
     HEAPF64[14092] = $2089; //@line 4359
     STACKTOP = sp; //@line 4360
     return;
    }
   case 377:
    {
     HEAPF64[112672 + (($1 & 7) << 3) >> 3] = +Math_cos(+$$sink104$i$sink); //@line 4367
     $2093 = +Math_sin(+$$sink104$i$sink); //@line 4368
     HEAPF64[112672 + ($1201 << 3) >> 3] = $2093; //@line 4370
     HEAPF64[14092] = $2093; //@line 4371
     STACKTOP = sp; //@line 4372
     return;
    }
   case 378:
    {
     HEAPF64[14092] = 1.0; //@line 4376
     HEAP32[28191] = 0; //@line 4377
     HEAP32[28192] = 0; //@line 4378
     HEAP32[28190] = 0; //@line 4379
     HEAPF64[14092] = +HEAPF64[112672 + ($1201 << 3) >> 3] - $$sink104$i$sink; //@line 4383
     STACKTOP = sp; //@line 4384
     return;
    }
   case 379:
    {
     HEAP32[28191] = 0; //@line 4388
     HEAP32[28192] = 0; //@line 4389
     HEAP32[28190] = 0; //@line 4390
     HEAPF64[14092] = $$sink104$i$sink; //@line 4391
     STACKTOP = sp; //@line 4392
     return;
    }
   case 380:
    {
     $2103 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 4401
     $2109 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2103 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2103) | 0; //@line 4407
     HEAP32[162770] = $2109; //@line 4408
     HEAP32[162769] = $2109; //@line 4409
     HEAP32[162768] = $2103; //@line 4410
     __Z7op_illgj($0); //@line 4411
     STACKTOP = sp; //@line 4412
     return;
    }
   }
   break;
  }
 default:
  {
   $2115 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 4424
   $2121 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2115 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2115) | 0; //@line 4430
   HEAP32[162770] = $2121; //@line 4431
   HEAP32[162769] = $2121; //@line 4432
   HEAP32[162768] = $2115; //@line 4433
   __Z7op_illgj($0); //@line 4434
   STACKTOP = sp; //@line 4435
   return;
  }
 }
}
function __Z8PatchROMv() {
 var $$0 = 0, $$018$i$i$i = 0, $$020$i$i$i = 0, $$02235$i$i = 0, $$02334$i$i = 0, $$0292$i = 0, $$030$lcssa$i$i = 0, $$03034$i$i = 0, $$031$i$i = 0, $$032$i$i = 0, $$043$i = 0, $$043$i$i = 0, $$043$i22 = 0, $$043$i392$i = 0, $$043$i407$i = 0, $$043$i422$i = 0, $$043$i437$i = 0, $$043$i452$i = 0, $$043$i7 = 0, $$048$i = 0, $$048$i$i = 0, $$048$i21 = 0, $$048$i391$i = 0, $$048$i406$i = 0, $$048$i421$i = 0, $$048$i436$i = 0, $$048$i451$i = 0, $$048$i6 = 0, $$051$off0$i = 0, $$051$off0$i$i = 0, $$051$off0$i15 = 0, $$051$off0$i30 = 0, $$051$off0$i400$i = 0, $$051$off0$i415$i = 0, $$051$off0$i430$i = 0, $$051$off0$i445$i = 0, $$051$off0$i460$i = 0, $$05673$i = 0, $$05673$i$i = 0, $$05673$i11 = 0, $$05673$i26 = 0, $$05673$i396$i = 0, $$05673$i411$i = 0, $$05673$i426$i = 0, $$05673$i441$i = 0, $$05673$i456$i = 0, $$057$i = 0, $$057$i$i = 0, $$057$i20 = 0, $$057$i390$i = 0, $$057$i405$i = 0, $$057$i420$i = 0, $$057$i435$i = 0, $$057$i450$i = 0, $$057$i5 = 0, $$09$i$i = 0, $$09$i297$i = 0, $$09$i300$i = 0, $$09$i303$i = 0, $$09$i306$i = 0, $$09$i309$i = 0, $$09$i312$i = 0, $$09$i315$i = 0, $$09$i318$i = 0, $$09$i321$i = 0, $$09$i324$i = 0, $$09$i327$i = 0, $$09$i330$i = 0, $$09$i333$i = 0, $$09$i336$i = 0, $$09$i339$i = 0, $$09$i342$i = 0, $$09$i345$lcssa$i = 0, $$09$i351$i = 0, $$09$i354$lcssa$i = 0, $$09$i357$i = 0, $$09$i360$i = 0, $$09$i363$i = 0, $$09$i366$i = 0, $$09$i369$i = 0, $$09$i373$i = 0, $$09$i379$i = 0, $$1293$ph$i = 0, $$131$i$i = 0, $$14475$i = 0, $$14475$i$i = 0, $$14475$i24 = 0, $$14475$i394$i = 0, $$14475$i409$i = 0, $$14475$i424$i = 0, $$14475$i439$i = 0, $$14475$i454$i = 0, $$14475$i9 = 0, $$14974$i = 0, $$14974$i$i = 0, $$14974$i10 = 0, $$14974$i25 = 0, $$14974$i395$i = 0, $$14974$i410$i = 0, $$14974$i425$i = 0, $$14974$i440$i = 0, $$14974$i455$i = 0, $$15872$i = 0, $$15872$i$i = 0, $$15872$i12 = 0, $$15872$i27 = 0, $$15872$i397$i = 0, $$15872$i412$i = 0, $$15872$i427$i = 0, $$15872$i442$i = 0, $$15872$i457$i = 0, $$2$i = 0, $$2$i383$i = 0, $$2$i387$i = 0, $$2$i41 = 0, $$245$i = 0, $$245$i$i = 0, $$245$i16 = 0, $$245$i31 = 0, $$245$i401$i = 0, $$245$i416$i = 0, $$245$i431$i = 0, $$245$i446$i = 0, $$245$i461$i = 0, $$3$i = 0, $$4$i = 0, $$461$i = 0, $$461$i$i = 0, $$461$i14 = 0, $$461$i29 = 0, $$461$i399$i = 0, $$461$i414$i = 0, $$461$i429$i = 0, $$461$i444$i = 0, $$461$i459$i = 0, $$5$ph$i = 0, $$5$ph$i$i = 0, $$5$ph$i18 = 0, $$5$ph$i33 = 0, $$5$ph$i403$i = 0, $$5$ph$i418$i = 0, $$5$ph$i433$i = 0, $$5$ph$i448$i = 0, $$5$ph$i463$i = 0, $$sink = 0, $$sink$i = 0, $$sink295$in$i = 0, $$sink296$i = 0, $$sink45$in = 0, $$sink46 = 0, $1000 = 0, $1003 = 0, $1005 = 0, $1007 = 0, $1009 = 0, $1013 = 0, $1014 = 0, $102 = 0, $1021 = 0, $1022 = 0, $1028 = 0, $103 = 0, $1033 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1042 = 0, $1043 = 0, $1048 = 0, $1049 = 0, $1058 = 0, $1066 = 0, $1068 = 0, $1069 = 0, $1072 = 0, $1075 = 0, $1077 = 0, $1078 = 0, $1084 = 0, $1089 = 0, $109 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1098 = 0, $1099 = 0, $11 = 0, $1104 = 0, $1105 = 0, $1114 = 0, $112 = 0, $1153 = 0, $1154 = 0, $1160 = 0, $1165 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1174 = 0, $1175 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1190 = 0, $1199 = 0, $1204 = 0, $1216 = 0, $1218 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1244 = 0, $1249 = 0, $125 = 0, $1251 = 0, $1256 = 0, $1261 = 0, $1264 = 0, $1267 = 0, $1269 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1295 = 0, $1300 = 0, $1302 = 0, $1307 = 0, $1312 = 0, $1315 = 0, $1317 = 0, $132 = 0, $1321 = 0, $1323 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1349 = 0, $135 = 0, $1354 = 0, $1356 = 0, $1361 = 0, $1366 = 0, $1369 = 0, $1371 = 0, $1373 = 0, $1375 = 0, $1377 = 0, $1379 = 0, $1383 = 0, $1385 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1411 = 0, $1416 = 0, $1418 = 0, $1423 = 0, $1428 = 0, $143 = 0, $1431 = 0, $1433 = 0, $1435 = 0, $1437 = 0, $1439 = 0, $1441 = 0, $1443 = 0, $1445 = 0, $1450 = 0, $1452 = 0, $1459 = 0, $146 = 0, $1461 = 0, $1468 = 0, $1469 = 0, $1470 = 0, $1487 = 0, $1492 = 0, $1494 = 0, $1499 = 0, $1504 = 0, $1507 = 0, $1509 = 0, $151 = 0, $1511 = 0, $1515 = 0, $1536 = 0, $1538 = 0, $1540 = 0, $1542 = 0, $1544 = 0, $1546 = 0, $155 = 0, $1550 = 0, $1552 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $157 = 0, $1578 = 0, $1583 = 0, $1585 = 0, $1590 = 0, $1595 = 0, $1598 = 0, $1602 = 0, $1606 = 0, $1607 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $163 = 0, $1633 = 0, $1638 = 0, $164 = 0, $1640 = 0, $1645 = 0, $1650 = 0, $1653 = 0, $1655 = 0, $1659 = 0, $1661 = 0, $1663 = 0, $1670 = 0, $1674 = 0, $1675 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $170 = 0, $1701 = 0, $1706 = 0, $1708 = 0, $171 = 0, $1713 = 0, $1718 = 0, $1721 = 0, $1723 = 0, $1727 = 0, $1729 = 0, $1731 = 0, $1738 = 0, $1739 = 0, $1745 = 0, $1750 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1759 = 0, $1760 = 0, $1765 = 0, $1766 = 0, $177 = 0, $1775 = 0, $178 = 0, $1783 = 0, $1784 = 0, $179 = 0, $1790 = 0, $1798 = 0, $1803 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1812 = 0, $1813 = 0, $1818 = 0, $1819 = 0, $1828 = 0, $185 = 0, $1859 = 0, $1870 = 0, $1881 = 0, $1884 = 0, $19 = 0, $193 = 0, $2 = 0, $203 = 0, $210 = 0, $215 = 0, $223 = 0, $228 = 0, $233 = 0, $245 = 0, $249 = 0, $26 = 0, $263 = 0, $275 = 0, $281 = 0, $294 = 0, $307 = 0, $314 = 0, $32 = 0, $321 = 0, $328 = 0, $34 = 0, $349 = 0, $35 = 0, $351 = 0, $353 = 0, $355 = 0, $357 = 0, $359 = 0, $363 = 0, $364 = 0, $367 = 0, $370 = 0, $372 = 0, $374 = 0, $381 = 0, $400 = 0, $41 = 0, $410 = 0, $414 = 0, $416 = 0, $420 = 0, $425 = 0, $432 = 0, $441 = 0, $457 = 0, $462 = 0, $48 = 0, $49 = 0, $493 = 0, $501 = 0, $502 = 0, $507 = 0, $514 = 0, $524 = 0, $526 = 0, $528 = 0, $530 = 0, $533 = 0, $537 = 0, $539 = 0, $54 = 0, $55 = 0, $553 = 0, $555 = 0, $568 = 0, $569 = 0, $577 = 0, $578 = 0, $588 = 0, $589 = 0, $597 = 0, $599 = 0, $606 = 0, $607 = 0, $608 = 0, $61 = 0, $625 = 0, $63 = 0, $630 = 0, $632 = 0, $637 = 0, $64 = 0, $642 = 0, $645 = 0, $651 = 0, $652 = 0, $658 = 0, $662 = 0, $667 = 0, $668 = 0, $674 = 0, $675 = 0, $676 = 0, $680 = 0, $692 = 0, $695 = 0, $697 = 0, $698 = 0, $705 = 0, $710 = 0, $712 = 0, $739 = 0, $746 = 0, $747 = 0, $75 = 0, $752 = 0, $754 = 0, $756 = 0, $760 = 0, $761 = 0, $766 = 0, $768 = 0, $773 = 0, $774 = 0, $779 = 0, $781 = 0, $786 = 0, $792 = 0, $794 = 0, $796 = 0, $798 = 0, $802 = 0, $803 = 0, $809 = 0, $81 = 0, $810 = 0, $812 = 0, $814 = 0, $816 = 0, $82 = 0, $820 = 0, $845 = 0, $846 = 0, $851 = 0, $856 = 0, $858 = 0, $869 = 0, $870 = 0, $879 = 0, $88 = 0, $89 = 0, $912 = 0, $927 = 0, $934 = 0, $936 = 0, $938 = 0, $940 = 0, $944 = 0, $95 = 0, $955 = 0, $956 = 0, $96 = 0, $964 = 0, $965 = 0, $972 = 0, $973 = 0, $980 = 0, $982 = 0, $983 = 0, $988 = 0, $990 = 0, $995 = 0, $996 = 0, $997 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer13 = 0, $vararg_buffer23 = 0, $vararg_buffer26 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 2907
 STACKTOP = STACKTOP + 128 | 0; //@line 2908
 $vararg_buffer26 = sp + 104 | 0; //@line 2909
 $vararg_buffer23 = sp + 96 | 0; //@line 2910
 $vararg_buffer13 = sp + 64 | 0; //@line 2911
 $vararg_buffer10 = sp + 32 | 0; //@line 2912
 $vararg_buffer7 = sp + 24 | 0; //@line 2913
 $vararg_buffer4 = sp + 16 | 0; //@line 2914
 $vararg_buffer1 = sp + 8 | 0; //@line 2915
 $vararg_buffer = sp; //@line 2916
 if (!(HEAP8[651928] | 0)) {
  label = 21; //@line 2920
 } else {
  _puts(90716) | 0; //@line 2922
  $2 = HEAP32[30896] | 0; //@line 2923
  HEAP32[$vararg_buffer >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 2929
  _printf(90727, $vararg_buffer) | 0; //@line 2930
  HEAP32[$vararg_buffer1 >> 2] = HEAPU16[325960]; //@line 2933
  _printf(90747, $vararg_buffer1) | 0; //@line 2934
  $11 = (HEAP32[30896] | 0) + 18 | 0; //@line 2936
  HEAP32[$vararg_buffer4 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($11) | 0; //@line 2943
  _printf(90767, $vararg_buffer4) | 0; //@line 2944
  $19 = (HEAP32[30896] | 0) + 26 | 0; //@line 2946
  HEAP32[$vararg_buffer7 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19) | 0; //@line 2952
  _printf(90787, $vararg_buffer7) | 0; //@line 2953
  $26 = (HEAP32[30896] | 0) + 34 | 0; //@line 2955
  HEAP32[$vararg_buffer10 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($26 >>> 16 << 2) >> 2] >> 2] & 127]($26) | 0; //@line 2961
  _printf(90807, $vararg_buffer10) | 0; //@line 2962
  $32 = HEAP16[325960] | 0; //@line 2963
  if ($32 << 16 >> 16 == 1660) {
   _puts(90828) | 0; //@line 2966
   _puts(90843) | 0; //@line 2967
   _puts(90869) | 0; //@line 2968
   $34 = HEAP32[30896] | 0; //@line 2969
   $35 = $34 + 26 | 0; //@line 2970
   $41 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($35 >>> 16 << 2) >> 2] >> 2] & 127]($35) | 0) + $34 | 0; //@line 2976
   $$031$i$i = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($41 >>> 16 << 2) >> 2] >> 2] & 127]($41) | 0; //@line 2982
   do {
    $48 = (HEAP32[30896] | 0) + $$031$i$i | 0; //@line 2985
    $49 = $48 + 12 | 0; //@line 2986
    $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($49 >>> 16 << 2) >> 2] >> 2] & 127]($49) | 0; //@line 2991
    $55 = $48 + 23 | 0; //@line 2992
    $61 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0; //@line 2998
    if (($61 | 0) > 0) {
     $63 = $48 + 24 | 0; //@line 3001
     $$03034$i$i = 0; //@line 3002
     do {
      $64 = $63 + $$03034$i$i | 0; //@line 3004
      HEAP8[$vararg_buffer10 + $$03034$i$i >> 0] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($64 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($64) | 0; //@line 3013
      $$03034$i$i = $$03034$i$i + 1 | 0; //@line 3014
     } while (($$03034$i$i | 0) != ($61 | 0));
     $$030$lcssa$i$i = $61; //@line 3017
    } else {
     $$030$lcssa$i$i = 0; //@line 3024
    }
    HEAP8[$vararg_buffer10 + $$030$lcssa$i$i >> 0] = 0; //@line 3027
    $75 = $48 + 16 | 0; //@line 3028
    $81 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($75 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($75) | 0; //@line 3034
    $82 = $48 + 17 | 0; //@line 3035
    $88 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($82) | 0; //@line 3041
    $89 = $48 + 18 | 0; //@line 3042
    $95 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($89 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($89) | 0; //@line 3048
    $96 = $48 + 19 | 0; //@line 3049
    $102 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($96 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($96) | 0; //@line 3055
    $103 = $48 + 20 | 0; //@line 3056
    $109 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($103 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($103) | 0; //@line 3062
    $112 = $54 + -8 + (HEAP32[30896] | 0) | 0; //@line 3065
    $117 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($112 >>> 16 << 2) >> 2] >> 2] & 127]($112) | 0; //@line 3070
    HEAP32[$vararg_buffer13 >> 2] = $54; //@line 3071
    HEAP32[$vararg_buffer13 + 4 >> 2] = $81; //@line 3073
    HEAP32[$vararg_buffer13 + 8 >> 2] = $88; //@line 3075
    HEAP32[$vararg_buffer13 + 12 >> 2] = $95; //@line 3077
    HEAP32[$vararg_buffer13 + 16 >> 2] = $102; //@line 3079
    HEAP32[$vararg_buffer13 + 20 >> 2] = $109; //@line 3081
    HEAP32[$vararg_buffer13 + 24 >> 2] = $117; //@line 3083
    HEAP32[$vararg_buffer13 + 28 >> 2] = $vararg_buffer10; //@line 3085
    _printf(90918, $vararg_buffer13) | 0; //@line 3086
    $118 = $48 + 8 | 0; //@line 3087
    $$031$i$i = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($118 >>> 16 << 2) >> 2] >> 2] & 127]($118) | 0; //@line 3092
   } while (($$031$i$i | 0) != 0);
   _putchar(10) | 0; //@line 3100
   $$02235$i$i = 0; //@line 3101
   $$02334$i$i = 12288; //@line 3101
   while (1) {
    $125 = (HEAP32[30896] | 0) + $$02334$i$i | 0; //@line 3104
    if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($125 >>> 16 << 2) >> 2] >> 2] & 127]($125) | 0) == -603978491) {
     label = 10; //@line 3112
     break;
    }
    $$02235$i$i = $$02235$i$i + 2 | 0; //@line 3115
    if (($$02235$i$i | 0) >= 8192) {
     break;
    } else {
     $$02334$i$i = $$02334$i$i + 2 | 0; //@line 3119
    }
   }
   L15 : do {
    if ((label | 0) == 10) {
     $132 = $$02334$i$i + -16 | 0; //@line 3126
     if ($132 | 0) {
      $$032$i$i = $132; //@line 3129
      while (1) {
       $135 = (HEAP32[30896] | 0) + $$032$i$i | 0; //@line 3132
       if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($135 >>> 16 << 2) >> 2] >> 2] & 127]($135) | 0) == ($132 - $$032$i$i | 0)) {
        break;
       }
       $143 = $$032$i$i + -4 | 0; //@line 3143
       if (!$143) {
        break L15;
       } else {
        $$032$i$i = $143; //@line 3148
       }
      }
      HEAP32[$vararg_buffer23 >> 2] = $$032$i$i; //@line 3151
      _printf(90942, $vararg_buffer23) | 0; //@line 3152
      _puts(90968) | 0; //@line 3153
      _puts(90869) | 0; //@line 3154
      $146 = (HEAP32[30896] | 0) + $$032$i$i | 0; //@line 3156
      $151 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($146 >>> 16 << 2) >> 2] >> 2] & 127]($146) | 0; //@line 3161
      if ($151 | 0) {
       $$131$i$i = $$032$i$i; //@line 3164
       $155 = $151; //@line 3164
       do {
        $156 = $$131$i$i + $155 + (HEAP32[30896] | 0) | 0; //@line 3168
        $157 = $156 + 18 | 0; //@line 3169
        $163 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($157 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($157) | 0; //@line 3175
        $164 = $156 + 16 | 0; //@line 3176
        $170 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($164 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($164) | 0; //@line 3182
        $171 = $156 + 20 | 0; //@line 3183
        $177 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($171 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($171) | 0; //@line 3189
        $178 = $163 & 255; //@line 3190
        $179 = $178 + 6 | 0; //@line 3191
        $$020$i$i$i = 0; //@line 3192
        while (1) {
         if ((HEAP32[1e3 + ($$020$i$i$i << 3) + 4 >> 2] | 0) == ($179 | 0)) {
          label = 16; //@line 3198
          break;
         }
         $185 = $$020$i$i$i + 1 | 0; //@line 3201
         if (($185 | 0) == 59) {
          $$018$i$i$i = 90997; //@line 3204
          break;
         } else {
          $$020$i$i$i = $185; //@line 3207
         }
        }
        if ((label | 0) == 16) {
         label = 0; //@line 3211
         $$018$i$i$i = HEAP32[1e3 + ($$020$i$i$i << 3) >> 2] | 0; //@line 3214
        }
        HEAP32[$vararg_buffer26 >> 2] = $156 - (HEAP32[30896] | 0); //@line 3220
        HEAP32[$vararg_buffer26 + 4 >> 2] = $178; //@line 3222
        HEAP32[$vararg_buffer26 + 8 >> 2] = $170 & 65535; //@line 3224
        HEAP32[$vararg_buffer26 + 12 >> 2] = $177 & 65535; //@line 3226
        HEAP32[$vararg_buffer26 + 16 >> 2] = $$018$i$i$i; //@line 3228
        _printf(91005, $vararg_buffer26) | 0; //@line 3229
        $$131$i$i = $$131$i$i + 4 | 0; //@line 3230
        $193 = (HEAP32[30896] | 0) + $$131$i$i | 0; //@line 3232
        $155 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($193 >>> 16 << 2) >> 2] >> 2] & 127]($193) | 0; //@line 3237
       } while (($155 | 0) != 0);
      }
     }
    }
   } while (0);
   _putchar(10) | 0; //@line 3249
   label = 21; //@line 3250
  } else {
   $203 = $32; //@line 3252
  }
 }
 if ((label | 0) == 21) {
  $203 = HEAP16[325960] | 0; //@line 3257
 }
 switch ($203 << 16 >> 16) {
 case 630:
  {
   HEAP16[(HEAP32[30897] | 0) + 7232 >> 1] = _htons(24606) | 0; //@line 3264
   HEAP16[(HEAP32[30897] | 0) + 7276 >> 1] = _htons(31744) | 0; //@line 3268
   $210 = HEAP32[30897] | 0; //@line 3269
   HEAP16[$210 + 80 >> 1] = _htons(20081) | 0; //@line 3273
   HEAP16[$210 + 82 >> 1] = _htons(20081) | 0; //@line 3275
   $215 = HEAP32[30897] | 0; //@line 3276
   HEAP16[$215 + 106 >> 1] = _htons(20081) | 0; //@line 3280
   HEAP16[$215 + 108 >> 1] = _htons(20081) | 0; //@line 3282
   HEAP16[(HEAP32[30897] | 0) + 13156 >> 1] = _htons(20081) | 0; //@line 3286
   $223 = HEAP32[30897] | 0; //@line 3287
   HEAP16[$223 + 41664 >> 1] = _htons(28932) | 0; //@line 3291
   HEAP16[$223 + 41666 >> 1] = _htons(20181) | 0; //@line 3293
   $228 = HEAP32[30897] | 0; //@line 3294
   HEAP16[$228 + 286 >> 1] = _htons(20081) | 0; //@line 3298
   HEAP16[$228 + 288 >> 1] = _htons(20081) | 0; //@line 3300
   $233 = HEAP32[30897] | 0; //@line 3301
   HEAP16[$233 + 260138 >> 1] = _htons(28938) | 0; //@line 3305
   HEAP16[$233 + 260140 >> 1] = _htons(20081) | 0; //@line 3308
   HEAP16[$233 + 260142 >> 1] = _htons(20081) | 0; //@line 3311
   HEAP16[$233 + 260144 >> 1] = _htons(20081) | 0; //@line 3313
   HEAP16[(HEAP32[30897] | 0) + 3418 >> 1] = _htons(24606) | 0; //@line 3317
   HEAP32[28207] = 214656; //@line 3318
   $245 = HEAP32[30897] | 0; //@line 3319
   dest = $245 + 214656 | 0; //@line 3321
   src = 91029; //@line 3321
   stop = dest + 86 | 0; //@line 3321
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3321
    dest = dest + 1 | 0; //@line 3321
    src = src + 1 | 0; //@line 3321
   } while ((dest | 0) < (stop | 0));
   dest = $245 + 214912 | 0; //@line 3323
   src = 91115; //@line 3323
   stop = dest + 86 | 0; //@line 3323
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3323
    dest = dest + 1 | 0; //@line 3323
    src = src + 1 | 0; //@line 3323
   } while ((dest | 0) < (stop | 0));
   dest = $245 + 215168 | 0; //@line 3325
   src = 91201; //@line 3325
   stop = dest + 90 | 0; //@line 3325
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3325
    dest = dest + 1 | 0; //@line 3325
    src = src + 1 | 0; //@line 3325
   } while ((dest | 0) < (stop | 0));
   $249 = HEAP32[30896] | 0; //@line 3326
   HEAP32[28483] = $249 + 215680; //@line 3328
   _memcpy($245 + 215680 | 0, 93682, 258) | 0; //@line 3330
   HEAP32[28484] = $249 + 216192; //@line 3332
   _memcpy($245 + 216192 | 0, 93940, 258) | 0; //@line 3334
   HEAP32[28488] = $249 + 216704; //@line 3336
   _memcpy($245 + 216704 | 0, 94272, 258) | 0; //@line 3338
   HEAP32[28492] = $249 + 217216; //@line 3340
   _memcpy($245 + 217216 | 0, 94883, 258) | 0; //@line 3342
   HEAP32[28208] = 203694; //@line 3343
   HEAP16[$245 + 203706 >> 1] = _htons(28939) | 0; //@line 3347
   HEAP16[$245 + 203708 >> 1] = _htons(20085) | 0; //@line 3349
   $263 = HEAP32[28208] | 0; //@line 3351
   dest = (HEAP32[30897] | 0) + $263 + 256 | 0; //@line 3354
   src = 91291; //@line 3354
   stop = dest + 98 | 0; //@line 3354
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3354
    dest = dest + 1 | 0; //@line 3354
    src = src + 1 | 0; //@line 3354
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $263 + 512 | 0; //@line 3358
   src = 91389; //@line 3358
   stop = dest + 100 | 0; //@line 3358
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3358
    dest = dest + 1 | 0; //@line 3358
    src = src + 1 | 0; //@line 3358
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $263 + 768 | 0; //@line 3362
   src = 91489; //@line 3362
   stop = dest + 98 | 0; //@line 3362
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3362
    dest = dest + 1 | 0; //@line 3362
    src = src + 1 | 0; //@line 3362
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $263 + 1024 | 0; //@line 3366
   src = 91587; //@line 3366
   stop = dest + 100 | 0; //@line 3366
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3366
    dest = dest + 1 | 0; //@line 3366
    src = src + 1 | 0; //@line 3366
   } while ((dest | 0) < (stop | 0));
   $275 = HEAP32[30897] | 0; //@line 3367
   dest = $275 + 14464 | 0; //@line 3369
   src = 91687; //@line 3369
   stop = dest + 54 | 0; //@line 3369
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 3369
    dest = dest + 1 | 0; //@line 3369
    src = src + 1 | 0; //@line 3369
   } while ((dest | 0) < (stop | 0));
   HEAP16[$275 + 108892 >> 1] = _htons(28964) | 0; //@line 3373
   HEAP16[$275 + 108894 >> 1] = _htons(20085) | 0; //@line 3375
   $281 = HEAP32[30897] | 0; //@line 3376
   HEAP16[$281 + 108906 >> 1] = _htons(16615) | 0; //@line 3380
   HEAP16[$281 + 108908 >> 1] = _htons(124) | 0; //@line 3383
   HEAP16[$281 + 108910 >> 1] = _htons(1792) | 0; //@line 3386
   HEAP16[$281 + 108912 >> 1] = _htons(28965) | 0; //@line 3389
   HEAP16[$281 + 108914 >> 1] = _htons(18143) | 0; //@line 3392
   HEAP16[$281 + 108916 >> 1] = _htons(20085) | 0; //@line 3394
   $294 = HEAP32[30897] | 0; //@line 3395
   HEAP16[$294 + 108932 >> 1] = _htons(16615) | 0; //@line 3399
   HEAP16[$294 + 108934 >> 1] = _htons(124) | 0; //@line 3402
   HEAP16[$294 + 108936 >> 1] = _htons(1792) | 0; //@line 3405
   HEAP16[$294 + 108938 >> 1] = _htons(28966) | 0; //@line 3408
   HEAP16[$294 + 108940 >> 1] = _htons(18143) | 0; //@line 3411
   $307 = $294 + 108944 | 0; //@line 3413
   HEAP16[$294 + 108942 >> 1] = _htons(20085) | 0; //@line 3414
   HEAP32[28205] = $307 - (HEAP32[30897] | 0); //@line 3418
   HEAP16[$307 >> 1] = _htons(28967) | 0; //@line 3421
   $314 = $294 + 108948 | 0; //@line 3423
   HEAP16[$294 + 108946 >> 1] = _htons(20085) | 0; //@line 3424
   HEAP32[28206] = $314 - (HEAP32[30897] | 0); //@line 3428
   HEAP16[$314 >> 1] = _htons(28982) | 0; //@line 3431
   HEAP16[$294 + 108950 >> 1] = _htons(20085) | 0; //@line 3433
   $321 = HEAP32[30897] | 0; //@line 3434
   HEAP16[$321 + 107014 >> 1] = _htons(28968) | 0; //@line 3438
   HEAP16[$321 + 107016 >> 1] = _htons(11849) | 0; //@line 3441
   HEAP16[$321 + 107018 >> 1] = _htons(20176) | 0; //@line 3443
   $328 = HEAP32[30897] | 0; //@line 3444
   HEAP16[$328 + 59200 >> 1] = _htons(20217) | 0; //@line 3448
   HEAP16[$328 + 59202 >> 1] = _htons(((HEAP32[30896] | 0) + 768 + (HEAP32[28207] | 0) | 0) >>> 16 & 65535) | 0; //@line 3457
   HEAP16[$328 + 59204 >> 1] = _htons((HEAP32[30896] | 0) + 768 + (HEAP32[28207] | 0) & 65535) | 0; //@line 3464
   $349 = (HEAP32[30897] | 0) + (HEAP32[28207] | 0) + 768 | 0; //@line 3468
   $351 = $349 + 2 | 0; //@line 3470
   HEAP16[$349 >> 1] = _htons(12035) | 0; //@line 3471
   $353 = $351 + 2 | 0; //@line 3473
   HEAP16[$351 >> 1] = _htons(8312) | 0; //@line 3474
   $355 = $353 + 2 | 0; //@line 3476
   HEAP16[$353 >> 1] = _htons(2032) | 0; //@line 3477
   $357 = $355 + 2 | 0; //@line 3479
   HEAP16[$355 >> 1] = _htons(20112) | 0; //@line 3480
   $359 = $357 + 2 | 0; //@line 3482
   HEAP16[$357 >> 1] = _htons(8735) | 0; //@line 3483
   HEAP16[$359 >> 1] = _htons(28972) | 0; //@line 3486
   HEAP16[$359 + 2 >> 1] = _htons(20085) | 0; //@line 3488
   $363 = HEAP32[30896] | 0; //@line 3489
   $364 = HEAP32[28207] | 0; //@line 3490
   HEAP32[28202] = $363 + 3072 + $364; //@line 3493
   $367 = $363 + 75668 | 0; //@line 3494
   $370 = (HEAP32[30897] | 0) + $364 + 3072 | 0; //@line 3497
   $372 = $370 + 2 | 0; //@line 3499
   HEAP16[$370 >> 1] = _htons(28970) | 0; //@line 3500
   $374 = $372 + 2 | 0; //@line 3502
   HEAP16[$372 >> 1] = _htons(20217) | 0; //@line 3503
   HEAP16[$374 >> 1] = _htons($367 >>> 16 & 65535) | 0; //@line 3508
   HEAP16[$374 + 2 >> 1] = _htons($367 & 65535) | 0; //@line 3511
   $381 = HEAP32[30897] | 0; //@line 3512
   HEAP16[$381 + 11066 >> 1] = _htons(22664) | 0; //@line 3516
   HEAP16[$381 + 11068 >> 1] = _htons(22664) | 0; //@line 3519
   HEAP16[$381 + 11070 >> 1] = _htons(20081) | 0; //@line 3522
   HEAP16[$381 + 11072 >> 1] = _htons(20081) | 0; //@line 3525
   HEAP16[$381 + 11074 >> 1] = _htons(20081) | 0; //@line 3528
   HEAP16[$381 + 11076 >> 1] = _htons(20081) | 0; //@line 3531
   HEAP16[$381 + 11078 >> 1] = _htons(20081) | 0; //@line 3534
   HEAP16[$381 + 11080 >> 1] = _htons(20081) | 0; //@line 3537
   HEAP16[$381 + 11082 >> 1] = _htons(20081) | 0; //@line 3539
   $400 = HEAP32[30897] | 0; //@line 3540
   HEAP16[$400 + 11236 >> 1] = _htons(20081) | 0; //@line 3544
   HEAP16[$400 + 11238 >> 1] = _htons(20081) | 0; //@line 3547
   HEAP16[$400 + 11240 >> 1] = _htons(28969) | 0; //@line 3550
   $$sink = _htons(19072) | 0; //@line 3553
   $$sink45$in = $400 + 11242 | 0; //@line 3553
   $$sink46 = $400 + 11244 | 0; //@line 3553
   break;
  }
 case 1660:
  {
   $410 = HEAP32[30897] | 0; //@line 3557
   $$09$i$i = 13312; //@line 3558
   while (1) {
    if (!(_memcmp($410 + $$09$i$i | 0, 91741, 8) | 0)) {
     break;
    }
    $414 = $$09$i$i + 1 | 0; //@line 3566
    if ($414 >>> 0 < 15360) {
     $$09$i$i = $414; //@line 3569
    } else {
     $$0 = 0; //@line 3571
     label = 246; //@line 3572
     break;
    }
   }
   if ((label | 0) == 246) {
    STACKTOP = sp; //@line 3577
    return $$0 | 0; //@line 3577
   }
   $416 = $$09$i$i + -16 | 0; //@line 3579
   HEAP32[28201] = $416; //@line 3580
   $420 = $$09$i$i + -4 + (HEAP32[30896] | 0) | 0; //@line 3584
   $425 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($420 >>> 16 << 2) >> 2] >> 2] & 127]($420) | 0; //@line 3589
   HEAP8[$410 + $416 + $425 >> 0] = 3; //@line 3591
   dest = $410 + ($$09$i$i + -15 + $425) | 0; //@line 3595
   stop = dest + 15 | 0; //@line 3595
   do {
    HEAP8[dest >> 0] = 8; //@line 3595
    dest = dest + 1 | 0; //@line 3595
   } while ((dest | 0) < (stop | 0));
   $432 = (HEAP32[30897] | 0) + (HEAP32[28201] | 0) + 18 | 0; //@line 3599
   HEAP8[$432 >> 0] = __Z14PrefsFindInt32PKc(91749) | 0; //@line 3602
   if (!(HEAP32[30881] | 0)) {
    HEAP8[(HEAP32[30897] | 0) + (HEAP32[28201] | 0) + 22 >> 0] = 4; //@line 3610
   }
   $441 = HEAP32[30897] | 0; //@line 3612
   HEAP16[$441 + 140 >> 1] = _htons(28931) | 0; //@line 3616
   HEAP16[$441 + 142 >> 1] = _htons(20217) | 0; //@line 3619
   HEAP16[$441 + 144 >> 1] = _htons(((HEAP32[30896] | 0) + 186 | 0) >>> 16 & 65535) | 0; //@line 3626
   HEAP16[$441 + 146 >> 1] = _htons((HEAP32[30896] | 0) + 186 & 65535) | 0; //@line 3631
   $457 = HEAP32[30897] | 0; //@line 3632
   HEAP16[$457 + 194 >> 1] = _htons(20081) | 0; //@line 3636
   HEAP16[$457 + 196 >> 1] = _htons(20081) | 0; //@line 3638
   $462 = HEAP32[30897] | 0; //@line 3639
   HEAP16[$462 + 198 >> 1] = _htons(20081) | 0; //@line 3643
   HEAP16[$462 + 200 >> 1] = _htons(20081) | 0; //@line 3646
   HEAP16[$462 + 202 >> 1] = _htons(20081) | 0; //@line 3649
   HEAP16[$462 + 204 >> 1] = _htons(20081) | 0; //@line 3652
   HEAP16[$462 + 206 >> 1] = _htons(20081) | 0; //@line 3655
   HEAP16[$462 + 208 >> 1] = _htons(20081) | 0; //@line 3658
   HEAP16[$462 + 210 >> 1] = _htons(20081) | 0; //@line 3661
   HEAP16[$462 + 212 >> 1] = _htons(20081) | 0; //@line 3664
   HEAP16[$462 + 214 >> 1] = _htons(20081) | 0; //@line 3667
   HEAP16[$462 + 216 >> 1] = _htons(20081) | 0; //@line 3670
   HEAP16[$462 + 218 >> 1] = _htons(20081) | 0; //@line 3673
   HEAP16[$462 + 220 >> 1] = _htons(20081) | 0; //@line 3676
   HEAP16[$462 + 222 >> 1] = _htons(20081) | 0; //@line 3679
   HEAP16[$462 + 224 >> 1] = _htons(20081) | 0; //@line 3682
   HEAP16[$462 + 226 >> 1] = _htons(20081) | 0; //@line 3684
   $493 = HEAP32[30897] | 0; //@line 3685
   HEAP16[$493 + 1984 >> 1] = _htons((HEAP32[30880] | 0) + 32256 & 65535) | 0; //@line 3692
   HEAP16[$493 + 1986 >> 1] = _htons(20085) | 0; //@line 3694
   $501 = HEAP32[30897] | 0; //@line 3695
   $$09$i297$i = 2560; //@line 3696
   while (1) {
    $502 = $501 + $$09$i297$i | 0; //@line 3698
    if (!(_memcmp($502, 91757, 6) | 0)) {
     label = 32; //@line 3702
     break;
    }
    $$09$i297$i = $$09$i297$i + 1 | 0; //@line 3705
    if ($$09$i297$i >>> 0 >= 2816) {
     $514 = $501; //@line 3710
     break;
    }
   }
   if ((label | 0) == 32) {
    $507 = $502 + 2 | 0; //@line 3715
    HEAP16[$507 >> 1] = _htons(20081) | 0; //@line 3718
    HEAP16[$507 + 2 >> 1] = _htons(20081) | 0; //@line 3720
    $514 = HEAP32[30897] | 0; //@line 3722
   }
   L51 : do {
    if ((HEAP32[30898] | 0) >>> 0 < 524289) {
     $$09$i300$i = 16384; //@line 3728
     while (1) {
      if (!(_memcmp($514 + $$09$i300$i | 0, 91763, 7) | 0)) {
       $$0292$i = $$09$i300$i; //@line 3734
       break L51;
      }
      $$09$i300$i = $$09$i300$i + 1 | 0; //@line 3737
      if ($$09$i300$i >>> 0 >= 327680) {
       $$0 = 0; //@line 3742
       break;
      }
     }
     STACKTOP = sp; //@line 3746
     return $$0 | 0; //@line 3746
    } else {
     $$09$i303$i = 524288; //@line 3748
     while (1) {
      if (!(_memcmp($514 + $$09$i303$i | 0, 91770, 7) | 0)) {
       $$0292$i = $$09$i303$i; //@line 3754
       break L51;
      }
      $$09$i303$i = $$09$i303$i + 1 | 0; //@line 3757
      if ($$09$i303$i >>> 0 >= 589824) {
       $$0 = 0; //@line 3762
       break;
      }
     }
     STACKTOP = sp; //@line 3766
     return $$0 | 0; //@line 3766
    }
   } while (0);
   $524 = $514 + $$0292$i | 0; //@line 3769
   $526 = $524 + 2 | 0; //@line 3771
   HEAP16[$524 >> 1] = _htons(20081) | 0; //@line 3772
   $528 = $526 + 2 | 0; //@line 3774
   HEAP16[$526 >> 1] = _htons(20081) | 0; //@line 3775
   $530 = $528 + 2 | 0; //@line 3777
   HEAP16[$528 >> 1] = _htons(20081) | 0; //@line 3778
   HEAP16[$530 >> 1] = _htons(20081) | 0; //@line 3781
   $533 = $530 + 2 + 2 | 0; //@line 3782
   HEAP16[$533 >> 1] = _htons(28672) | 0; //@line 3785
   HEAP16[$533 + 2 >> 1] = _htons(20081) | 0; //@line 3787
   $537 = HEAP32[30898] | 0; //@line 3788
   $539 = HEAP32[30897] | 0; //@line 3790
   L61 : do {
    if ($537 >>> 0 < 524289) {
     $$09$i306$i = 16384; //@line 3793
     while (1) {
      if (!(_memcmp($539 + $$09$i306$i | 0, 91777, 5) | 0)) {
       $$1293$ph$i = $$09$i306$i; //@line 3799
       label = 43; //@line 3800
       break L61;
      }
      $$09$i306$i = $$09$i306$i + 1 | 0; //@line 3803
      if ($$09$i306$i >>> 0 >= 327680) {
       $553 = $537; //@line 3808
       $555 = $539; //@line 3808
       break;
      }
     }
    } else {
     $$09$i309$i = 524288; //@line 3813
     while (1) {
      if (!(_memcmp($539 + $$09$i309$i | 0, 91777, 5) | 0)) {
       $$1293$ph$i = $$09$i309$i; //@line 3819
       label = 43; //@line 3820
       break L61;
      }
      $$09$i309$i = $$09$i309$i + 1 | 0; //@line 3823
      if ($$09$i309$i >>> 0 >= 589824) {
       $553 = $537; //@line 3828
       $555 = $539; //@line 3828
       break;
      }
     }
    }
   } while (0);
   if ((label | 0) == 43) {
    HEAP8[$539 + $$1293$ph$i + 4 >> 0] = 96; //@line 3837
    $553 = HEAP32[30898] | 0; //@line 3840
    $555 = HEAP32[30897] | 0; //@line 3840
   }
   L71 : do {
    if ($553 >>> 0 < 524289) {
     $$09$i312$i = 16384; //@line 3845
     while (1) {
      if (!(_memcmp($555 + $$09$i312$i | 0, 91782, 14) | 0)) {
       $$2$i = $$09$i312$i; //@line 3851
       break L71;
      }
      $$09$i312$i = $$09$i312$i + 1 | 0; //@line 3854
      if ($$09$i312$i >>> 0 >= 327680) {
       $$0 = 0; //@line 3859
       break;
      }
     }
     STACKTOP = sp; //@line 3863
     return $$0 | 0; //@line 3863
    } else {
     $$09$i315$i = 524288; //@line 3865
     while (1) {
      if (!(_memcmp($555 + $$09$i315$i | 0, 91782, 14) | 0)) {
       $$2$i = $$09$i315$i; //@line 3871
       break L71;
      }
      $$09$i315$i = $$09$i315$i + 1 | 0; //@line 3874
      if ($$09$i315$i >>> 0 >= 589824) {
       $$0 = 0; //@line 3879
       break;
      }
     }
     STACKTOP = sp; //@line 3883
     return $$0 | 0; //@line 3883
    }
   } while (0);
   HEAP16[$555 + $$2$i + 6 >> 1] = _htons(20081) | 0; //@line 3889
   $568 = HEAP32[30897] | 0; //@line 3890
   $$09$i318$i = 262144; //@line 3891
   while (1) {
    $569 = $568 + $$09$i318$i | 0; //@line 3893
    if (!(_memcmp($569, 91796, 12) | 0)) {
     label = 52; //@line 3897
     break;
    }
    $$09$i318$i = $$09$i318$i + 1 | 0; //@line 3900
    if ($$09$i318$i >>> 0 >= 327680) {
     $578 = $568; //@line 3905
     break;
    }
   }
   if ((label | 0) == 52) {
    HEAP16[$569 >> 1] = _htons(28933) | 0; //@line 3912
    HEAP16[$569 + 2 >> 1] = _htons(20182) | 0; //@line 3914
    $578 = HEAP32[30897] | 0; //@line 3916
   }
   $$09$i321$i = 262144; //@line 3918
   do {
    $577 = $578 + $$09$i321$i | 0; //@line 3920
    if (!(_memcmp($577, 91808, 16) | 0)) {
     label = 56; //@line 3924
     break;
    }
    $$09$i321$i = $$09$i321$i + 1 | 0; //@line 3927
   } while ($$09$i321$i >>> 0 < 327680);
   if ((label | 0) == 56) {
    HEAP16[$577 >> 1] = _htons(28933) | 0; //@line 3938
    HEAP16[$577 + 2 >> 1] = _htons(20182) | 0; //@line 3940
   }
   L93 : do {
    if ((HEAP32[30898] | 0) >>> 0 > 524288) {
     $588 = HEAP32[30897] | 0; //@line 3946
     $$09$i324$i = 524288; //@line 3947
     while (1) {
      $589 = $588 + $$09$i324$i | 0; //@line 3949
      if (!(_memcmp($589, 91824, 12) | 0)) {
       break;
      }
      $$09$i324$i = $$09$i324$i + 1 | 0; //@line 3955
      if ($$09$i324$i >>> 0 >= 589824) {
       break L93;
      }
     }
     HEAP16[$589 >> 1] = _htons(28934) | 0; //@line 3965
     HEAP16[$589 + 2 >> 1] = _htons(20085) | 0; //@line 3967
    }
   } while (0);
   $597 = HEAP32[30897] | 0; //@line 3970
   $599 = (HEAP32[30896] | 0) + 34 | 0; //@line 3972
   $$043$i$i = $597 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($599 >>> 16 << 2) >> 2] >> 2] & 127]($599) | 0) | 0; //@line 3979
   $$048$i$i = -22528; //@line 3979
   $$057$i$i = 0; //@line 3979
   L100 : while (1) {
    $$05673$i$i = 0; //@line 3981
    $$14475$i$i = $$043$i$i; //@line 3981
    $$14974$i$i = $$048$i$i; //@line 3981
    $$15872$i$i = $$057$i$i; //@line 3981
    while (1) {
     $606 = $$14475$i$i + 1 | 0; //@line 3983
     $607 = HEAP8[$$14475$i$i >> 0] | 0; //@line 3984
     $608 = $607 & 255; //@line 3985
     L104 : do {
      switch ($607 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i$i = 0; //@line 3989
        $$245$i$i = $606; //@line 3989
        $$461$i$i = $$15872$i$i; //@line 3989
        break;
       }
      case -1:
       {
        $625 = HEAPU8[$$14475$i$i + 2 >> 0] << 16 | HEAPU8[$606 >> 0] << 24 | HEAPU8[$$14475$i$i + 3 >> 0] << 8 | HEAPU8[$$14475$i$i + 4 >> 0]; //@line 4009
        $$051$off0$i$i = $625; //@line 4011
        $$245$i$i = $$14475$i$i + 5 | 0; //@line 4011
        $$461$i$i = $625; //@line 4011
        break;
       }
      default:
       {
        if (!($608 & 128)) {
         $637 = HEAPU8[$606 >> 0] | $608 << 8; //@line 4022
         $642 = ($637 << 17 >> 16) + $$15872$i$i | 0; //@line 4028
         if (!(($637 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i$i = 0; //@line 4030
          break L100;
         } else {
          $$051$off0$i$i = $642; //@line 4033
          $$245$i$i = $$14475$i$i + 2 | 0; //@line 4033
          $$461$i$i = $642; //@line 4033
          break L104;
         }
        } else {
         $630 = $608 << 1 & 254; //@line 4038
         $632 = $630 + $$15872$i$i | 0; //@line 4040
         if (!$630) {
          $$5$ph$i$i = 0; //@line 4042
          break L100;
         } else {
          $$051$off0$i$i = $632; //@line 4045
          $$245$i$i = $606; //@line 4045
          $$461$i$i = $632; //@line 4045
          break L104;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i$i << 16 >> 16 == -24493) {
      $$5$ph$i$i = $$051$off0$i$i; //@line 4054
      break L100;
     }
     $645 = $$05673$i$i + 1 | 0; //@line 4058
     if (($645 | 0) < 1024) {
      $$05673$i$i = $645; //@line 4061
      $$14475$i$i = $$245$i$i; //@line 4061
      $$14974$i$i = $$14974$i$i + 1 << 16 >> 16; //@line 4061
      $$15872$i$i = $$461$i$i; //@line 4061
     } else {
      $$043$i$i = $$245$i$i; //@line 4063
      $$048$i$i = -24576; //@line 4063
      $$057$i$i = $$461$i$i; //@line 4063
      continue L100;
     }
    }
   }
   $651 = (_ntohs(HEAP16[(HEAP32[30897] | 0) + $$5$ph$i$i >> 1] | 0) | 0) << 16 >> 16 == 20181; //@line 4072
   $652 = HEAP32[30897] | 0; //@line 4073
   L113 : do {
    if ($651) {
     $$09$i327$i = 720896; //@line 4076
     while (1) {
      if (!(_memcmp($652 + $$09$i327$i | 0, 91836, 8) | 0)) {
       $$3$i = $$09$i327$i; //@line 4082
       break L113;
      }
      $$09$i327$i = $$09$i327$i + 1 | 0; //@line 4085
      if ($$09$i327$i >>> 0 >= 753664) {
       $$0 = 0; //@line 4090
       break;
      }
     }
     STACKTOP = sp; //@line 4094
     return $$0 | 0; //@line 4094
    } else {
     $$3$i = $$5$ph$i$i; //@line 4096
    }
   } while (0);
   $658 = $652 + $$3$i | 0; //@line 4099
   HEAP16[$658 >> 1] = _htons(28932) | 0; //@line 4102
   HEAP16[$658 + 2 >> 1] = _htons(20181) | 0; //@line 4104
   $662 = HEAP32[30897] | 0; //@line 4105
   HEAP16[$662 + 270 >> 1] = _htons(28935) | 0; //@line 4109
   HEAP16[$662 + 272 >> 1] = _htons(20081) | 0; //@line 4111
   $667 = HEAP32[30897] | 0; //@line 4112
   $$09$i330$i = 2560; //@line 4113
   while (1) {
    $668 = $667 + $$09$i330$i | 0; //@line 4115
    if (!(_memcmp($668, 91844, 8) | 0)) {
     break;
    }
    $$09$i330$i = $$09$i330$i + 1 | 0; //@line 4121
    if ($$09$i330$i >>> 0 >= 2688) {
     $$0 = 0; //@line 4126
     label = 246; //@line 4127
     break;
    }
   }
   if ((label | 0) == 246) {
    STACKTOP = sp; //@line 4132
    return $$0 | 0; //@line 4132
   }
   HEAP16[$668 >> 1] = _htons(20085) | 0; //@line 4135
   $674 = HEAP32[30897] | 0; //@line 4136
   $675 = $674 + 16946 | 0; //@line 4137
   $676 = $674 + 16948 | 0; //@line 4138
   if ((_ntohs(HEAP16[$676 >> 1] | 0) | 0) << 16 >> 16 == 20721) {
    $680 = $674 + 16950 | 0; //@line 4143
    if ((_ntohs(HEAP16[$680 >> 1] | 0) | 0) << 16 >> 16 == -24319) {
     HEAP16[$675 >> 1] = _htons(20081) | 0; //@line 4149
     HEAP16[$676 >> 1] = _htons(20081) | 0; //@line 4151
     HEAP16[$680 >> 1] = _htons(20081) | 0; //@line 4154
     HEAP16[$674 + 16952 >> 1] = _htons(20081) | 0; //@line 4157
     HEAP16[$674 + 16954 >> 1] = _htons(20081) | 0; //@line 4159
    }
   }
   $692 = (HEAP32[30897] | 0) + 2496 | 0; //@line 4163
   HEAP16[$692 >> 1] = _htons(20085) | 0; //@line 4165
   $695 = (HEAP32[30897] | 0) + 2464 | 0; //@line 4167
   HEAP16[$695 >> 1] = _htons(20085) | 0; //@line 4169
   $697 = HEAP32[30897] | 0; //@line 4170
   $$09$i333$i = 16384; //@line 4171
   while (1) {
    $698 = $697 + $$09$i333$i | 0; //@line 4173
    if (!(_memcmp($698, 91852, 8) | 0)) {
     label = 83; //@line 4177
     break;
    }
    $$09$i333$i = $$09$i333$i + 1 | 0; //@line 4180
    if ($$09$i333$i >>> 0 >= 20480) {
     $705 = $697; //@line 4185
     break;
    }
   }
   if ((label | 0) == 83) {
    HEAP16[$698 >> 1] = _htons(20182) | 0; //@line 4191
    $705 = HEAP32[30897] | 0; //@line 4193
   }
   HEAP16[$705 + 400 >> 1] = _htons(20081) | 0; //@line 4198
   HEAP16[$705 + 402 >> 1] = _htons(20081) | 0; //@line 4200
   $710 = (HEAP32[30897] | 0) + 40780 | 0; //@line 4202
   HEAP16[$710 >> 1] = _htons(20085) | 0; //@line 4204
   $712 = HEAP32[30897] | 0; //@line 4205
   HEAP16[$712 + 2048 >> 1] = _htons(12796) | 0; //@line 4209
   HEAP16[$712 + 2050 >> 1] = _htons(1e4) | 0; //@line 4212
   HEAP16[$712 + 2052 >> 1] = _htons(3328) | 0; //@line 4215
   HEAP16[$712 + 2054 >> 1] = _htons(12796) | 0; //@line 4218
   HEAP16[$712 + 2056 >> 1] = _htons(1e4) | 0; //@line 4221
   HEAP16[$712 + 2058 >> 1] = _htons(3330) | 0; //@line 4224
   HEAP16[$712 + 2060 >> 1] = _htons(12796) | 0; //@line 4227
   HEAP16[$712 + 2062 >> 1] = _htons(1e4) | 0; //@line 4230
   HEAP16[$712 + 2064 >> 1] = _htons(2852) | 0; //@line 4233
   HEAP16[$712 + 2066 >> 1] = _htons(12796) | 0; //@line 4236
   HEAP16[$712 + 2068 >> 1] = _htons(1e4) | 0; //@line 4239
   HEAP16[$712 + 2070 >> 1] = _htons(3306) | 0; //@line 4242
   HEAP16[$712 + 2072 >> 1] = _htons(20085) | 0; //@line 4244
   $739 = HEAP32[30897] | 0; //@line 4245
   HEAP16[$739 + 45282 >> 1] = _htons(19679) | 0; //@line 4249
   HEAP16[$739 + 45284 >> 1] = _htons(7999) | 0; //@line 4252
   HEAP16[$739 + 45286 >> 1] = _htons(20085) | 0; //@line 4254
   $746 = HEAP32[30897] | 0; //@line 4255
   $$09$i336$i = 262144; //@line 4256
   while (1) {
    $747 = $746 + $$09$i336$i | 0; //@line 4258
    if (!(_memcmp($747, 91860, 10) | 0)) {
     label = 87; //@line 4262
     break;
    }
    $$09$i336$i = $$09$i336$i + 1 | 0; //@line 4265
    if ($$09$i336$i >>> 0 >= 327680) {
     $761 = $746; //@line 4270
     break;
    }
   }
   if ((label | 0) == 87) {
    $752 = $747 + 8 | 0; //@line 4275
    $754 = $752 + 2 | 0; //@line 4277
    HEAP16[$752 >> 1] = _htons(20081) | 0; //@line 4278
    $756 = $754 + 2 | 0; //@line 4280
    HEAP16[$754 >> 1] = _htons(20081) | 0; //@line 4281
    HEAP16[$756 >> 1] = _htons(20081) | 0; //@line 4284
    HEAP16[$756 + 2 >> 1] = _htons(20081) | 0; //@line 4286
    $761 = HEAP32[30897] | 0; //@line 4288
   }
   $$09$i339$i = 16384; //@line 4290
   do {
    $760 = $761 + $$09$i339$i | 0; //@line 4292
    if (!(_memcmp($760, 91870, 8) | 0)) {
     label = 91; //@line 4296
     break;
    }
    $$09$i339$i = $$09$i339$i + 1 | 0; //@line 4299
   } while ($$09$i339$i >>> 0 < 20480);
   if ((label | 0) == 91) {
    $766 = $760 + 6 | 0; //@line 4308
    $768 = $766 + 2 | 0; //@line 4310
    HEAP16[$766 >> 1] = _htons(28672) | 0; //@line 4311
    HEAP16[$768 >> 1] = _htons(-20416) | 0; //@line 4314
    HEAP16[$768 + 2 >> 1] = _htons(20182) | 0; //@line 4316
   }
   if (!(__Z14InstallSlotROMv() | 0)) {
    $$0 = 0; //@line 4320
    STACKTOP = sp; //@line 4321
    return $$0 | 0; //@line 4321
   }
   $773 = HEAP32[30897] | 0; //@line 4323
   $$09$i342$i = 20480; //@line 4324
   while (1) {
    $774 = $773 + $$09$i342$i | 0; //@line 4326
    if (!(_memcmp($774, 91878, 8) | 0)) {
     label = 96; //@line 4330
     break;
    }
    $$09$i342$i = $$09$i342$i + 1 | 0; //@line 4333
    if ($$09$i342$i >>> 0 >= 24576) {
     $786 = $773; //@line 4338
     break;
    }
   }
   if ((label | 0) == 96) {
    $779 = $774 + 6 | 0; //@line 4343
    $781 = $779 + 2 | 0; //@line 4345
    HEAP16[$779 >> 1] = _htons(20081) | 0; //@line 4346
    HEAP16[$781 >> 1] = _htons(20081) | 0; //@line 4349
    HEAP16[$781 + 2 >> 1] = _htons(20081) | 0; //@line 4351
    $786 = HEAP32[30897] | 0; //@line 4353
   }
   if (!(_memcmp($786 + 550 | 0, 91886, 2) | 0)) {
    $$09$i345$lcssa$i = 550; //@line 4359
   } else {
    if (!(_memcmp($786 + 551 | 0, 91886, 2) | 0)) {
     $$09$i345$lcssa$i = 551; //@line 4365
    } else {
     if (!(_memcmp($786 + 552 | 0, 91886, 2) | 0)) {
      $$09$i345$lcssa$i = 552; //@line 4371
     } else {
      if (!(_memcmp($786 + 553 | 0, 91886, 2) | 0)) {
       $$09$i345$lcssa$i = 553; //@line 4377
      } else {
       $$0 = 0; //@line 4379
       STACKTOP = sp; //@line 4380
       return $$0 | 0; //@line 4380
      }
     }
    }
   }
   $792 = $786 + $$09$i345$lcssa$i | 0; //@line 4385
   $794 = $792 + 2 | 0; //@line 4387
   HEAP16[$792 >> 1] = _htons(20081) | 0; //@line 4388
   $796 = $794 + 2 | 0; //@line 4390
   HEAP16[$794 >> 1] = _htons(20081) | 0; //@line 4391
   $798 = $796 + 2 | 0; //@line 4393
   HEAP16[$796 >> 1] = _htons(20081) | 0; //@line 4394
   HEAP16[$798 >> 1] = _htons(20081) | 0; //@line 4397
   HEAP16[$798 + 2 >> 1] = _htons(20081) | 0; //@line 4399
   $802 = HEAP32[30897] | 0; //@line 4400
   $803 = $802 + 560 | 0; //@line 4401
   do {
    if (!(_memcmp($803, 91886, 2) | 0)) {
     $$4$i = 560; //@line 4406
     $810 = $802; //@line 4406
    } else {
     if (!(_memcmp($802 + 561 | 0, 91886, 2) | 0)) {
      $$4$i = 561; //@line 4412
      $810 = $802; //@line 4412
     } else {
      if (!(_memcmp($802 + 562 | 0, 91886, 2) | 0)) {
       $$4$i = 562; //@line 4418
       $810 = $802; //@line 4418
      } else {
       if (!(_memcmp($802 + 563 | 0, 91886, 2) | 0)) {
        $$4$i = 563; //@line 4424
        $810 = $802; //@line 4424
       } else {
        if ((_ntohs(HEAP16[$803 >> 1] | 0) | 0) << 16 >> 16 == 24832) {
         $$4$i = 560; //@line 4431
         $810 = HEAP32[30897] | 0; //@line 4431
         break;
        } else {
         $$0 = 0; //@line 4434
         STACKTOP = sp; //@line 4435
         return $$0 | 0; //@line 4435
        }
       }
      }
     }
    }
   } while (0);
   $809 = $810 + $$4$i | 0; //@line 4442
   $812 = $809 + 2 | 0; //@line 4444
   HEAP16[$809 >> 1] = _htons(20081) | 0; //@line 4445
   $814 = $812 + 2 | 0; //@line 4447
   HEAP16[$812 >> 1] = _htons(20081) | 0; //@line 4448
   $816 = $814 + 2 | 0; //@line 4450
   HEAP16[$814 >> 1] = _htons(20081) | 0; //@line 4451
   HEAP16[$816 >> 1] = _htons(20081) | 0; //@line 4454
   HEAP16[$816 + 2 >> 1] = _htons(20081) | 0; //@line 4456
   $820 = HEAP32[30897] | 0; //@line 4457
   HEAP16[$820 + 1168 >> 1] = _htons(8248) | 0; //@line 4461
   HEAP16[$820 + 1170 >> 1] = _htons(268) | 0; //@line 4464
   HEAP16[$820 + 1172 >> 1] = _htons(-12104) | 0; //@line 4467
   HEAP16[$820 + 1174 >> 1] = _htons(678) | 0; //@line 4470
   HEAP16[$820 + 1176 >> 1] = _htons(-7544) | 0; //@line 4473
   HEAP16[$820 + 1178 >> 1] = _htons(2176) | 0; //@line 4476
   HEAP16[$820 + 1180 >> 1] = _htons(0) | 0; //@line 4479
   HEAP16[$820 + 1182 >> 1] = _htons(1088) | 0; //@line 4482
   HEAP16[$820 + 1184 >> 1] = _htons(1024) | 0; //@line 4485
   HEAP16[$820 + 1186 >> 1] = _htons(8256) | 0; //@line 4488
   HEAP16[$820 + 1188 >> 1] = _htons(28937) | 0; //@line 4491
   HEAP16[$820 + 1190 >> 1] = _htons(20085) | 0; //@line 4493
   $845 = HEAP32[30897] | 0; //@line 4494
   $$09$i351$i = 311296; //@line 4495
   while (1) {
    $846 = $845 + $$09$i351$i | 0; //@line 4497
    if (!(_memcmp($846, 91888, 20) | 0)) {
     label = 104; //@line 4501
     break;
    }
    $$09$i351$i = $$09$i351$i + 1 | 0; //@line 4504
    if ($$09$i351$i >>> 0 >= 311424) {
     $856 = $845; //@line 4509
     break;
    }
   }
   if ((label | 0) == 104) {
    $851 = $846 + 16 | 0; //@line 4514
    HEAP16[$851 >> 1] = _htons(20081) | 0; //@line 4517
    HEAP16[$851 + 2 >> 1] = _htons(20081) | 0; //@line 4519
    $856 = HEAP32[30897] | 0; //@line 4521
   }
   HEAP16[$856 + 4418 >> 1] = _htons(28938) | 0; //@line 4525
   $858 = HEAP32[30897] | 0; //@line 4526
   HEAP16[$858 + 4420 >> 1] = _htons(20081) | 0; //@line 4530
   HEAP16[$858 + 4422 >> 1] = _htons(20081) | 0; //@line 4533
   HEAP16[$858 + 4424 >> 1] = _htons(20081) | 0; //@line 4536
   HEAP16[$858 + 4426 >> 1] = _htons(20081) | 0; //@line 4538
   HEAP16[$858 + 4432 >> 1] = _htons(20081) | 0; //@line 4541
   $869 = HEAP32[30897] | 0; //@line 4542
   $870 = $869 + 43176 | 0; //@line 4543
   if (!(HEAP16[$870 >> 1] | 0)) {
    HEAP16[$869 + 732266 >> 1] = _htons(20081) | 0; //@line 4550
    HEAP16[$869 + 732268 >> 1] = _htons(20081) | 0; //@line 4553
    HEAP16[$869 + 732270 >> 1] = _htons(20081) | 0; //@line 4555
    $879 = HEAP32[30897] | 0; //@line 4556
    HEAP16[$879 + 732462 >> 1] = _htons(20081) | 0; //@line 4560
    HEAP16[$879 + 732464 >> 1] = _htons(20081) | 0; //@line 4563
    HEAP16[$879 + 732466 >> 1] = _htons(20081) | 0; //@line 4566
    HEAP16[$879 + 732468 >> 1] = _htons(20081) | 0; //@line 4569
    HEAP16[$879 + 732470 >> 1] = _htons(20081) | 0; //@line 4572
    HEAP16[$879 + 732472 >> 1] = _htons(20081) | 0; //@line 4575
    HEAP16[$879 + 732474 >> 1] = _htons(20081) | 0; //@line 4578
    HEAP16[$879 + 732476 >> 1] = _htons(20081) | 0; //@line 4581
    HEAP16[$879 + 732478 >> 1] = _htons(20081) | 0; //@line 4584
    HEAP16[$879 + 732480 >> 1] = _htons(20081) | 0; //@line 4587
    HEAP16[$879 + 732482 >> 1] = _htons(20081) | 0; //@line 4590
    HEAP16[$879 + 732484 >> 1] = _htons(20081) | 0; //@line 4592
    $$sink$i = _htons(20081) | 0; //@line 4596
    $$sink295$in$i = $879 + 732490 | 0; //@line 4596
    $$sink296$i = $879 + 732492 | 0; //@line 4596
   } else {
    HEAP16[$870 >> 1] = _htons(20081) | 0; //@line 4600
    HEAP16[$869 + 43178 >> 1] = _htons(20081) | 0; //@line 4603
    HEAP16[$869 + 43180 >> 1] = _htons(20081) | 0; //@line 4605
    $912 = HEAP32[30897] | 0; //@line 4606
    HEAP16[$912 + 42594 >> 1] = _htons(20081) | 0; //@line 4610
    HEAP16[$912 + 42596 >> 1] = _htons(20081) | 0; //@line 4613
    HEAP16[$912 + 42598 >> 1] = _htons(20081) | 0; //@line 4616
    HEAP16[$912 + 42600 >> 1] = _htons(20081) | 0; //@line 4619
    HEAP16[$912 + 42602 >> 1] = _htons(20081) | 0; //@line 4621
    $$sink$i = _htons(20081) | 0; //@line 4625
    $$sink295$in$i = $912 + 42608 | 0; //@line 4625
    $$sink296$i = $912 + 42610 | 0; //@line 4625
   }
   HEAP16[$$sink295$in$i >> 1] = $$sink$i; //@line 4627
   HEAP16[$$sink296$i >> 1] = _htons(20081) | 0; //@line 4629
   $927 = HEAP32[30897] | 0; //@line 4630
   if (!(_memcmp($927 + 750 | 0, 91886, 2) | 0)) {
    $$09$i354$lcssa$i = 750; //@line 4635
   } else {
    if (!(_memcmp($927 + 751 | 0, 91886, 2) | 0)) {
     $$09$i354$lcssa$i = 751; //@line 4641
    } else {
     if (!(_memcmp($927 + 752 | 0, 91886, 2) | 0)) {
      $$09$i354$lcssa$i = 752; //@line 4647
     } else {
      if (!(_memcmp($927 + 753 | 0, 91886, 2) | 0)) {
       $$09$i354$lcssa$i = 753; //@line 4653
      } else {
       $$0 = 0; //@line 4655
       STACKTOP = sp; //@line 4656
       return $$0 | 0; //@line 4656
      }
     }
    }
   }
   $934 = $927 + $$09$i354$lcssa$i | 0; //@line 4661
   $936 = $934 + 2 | 0; //@line 4663
   HEAP16[$934 >> 1] = _htons(20081) | 0; //@line 4664
   $938 = $936 + 2 | 0; //@line 4666
   HEAP16[$936 >> 1] = _htons(20081) | 0; //@line 4667
   $940 = $938 + 2 | 0; //@line 4669
   HEAP16[$938 >> 1] = _htons(20081) | 0; //@line 4670
   HEAP16[$940 >> 1] = _htons(20081) | 0; //@line 4673
   HEAP16[$940 + 2 >> 1] = _htons(20081) | 0; //@line 4675
   $944 = HEAP32[30897] | 0; //@line 4676
   HEAP16[$944 + 23416 >> 1] = _htons(20081) | 0; //@line 4680
   HEAP16[$944 + 23418 >> 1] = _htons(20081) | 0; //@line 4683
   HEAP16[$944 + 23420 >> 1] = _htons(9217) | 0; //@line 4686
   HEAP16[$944 + 23422 >> 1] = _htons(24670) | 0; //@line 4688
   L187 : do {
    if ((HEAP32[30898] | 0) >>> 0 > 524288) {
     $955 = HEAP32[30897] | 0; //@line 4693
     $$09$i357$i = 573440; //@line 4694
     while (1) {
      $956 = $955 + $$09$i357$i | 0; //@line 4696
      if (!(_memcmp($956, 91908, 8) | 0)) {
       break;
      }
      $$09$i357$i = $$09$i357$i + 1 | 0; //@line 4702
      if ($$09$i357$i >>> 0 >= 577536) {
       break L187;
      }
     }
     HEAP16[$956 >> 1] = _htons(9217) | 0; //@line 4712
     HEAP16[$956 + 2 >> 1] = _htons(20085) | 0; //@line 4714
    }
   } while (0);
   $964 = HEAP32[30897] | 0; //@line 4717
   $$09$i360$i = 40960; //@line 4718
   while (1) {
    $965 = $964 + $$09$i360$i | 0; //@line 4720
    if (!(_memcmp($965, 91916, 8) | 0)) {
     break;
    }
    $$09$i360$i = $$09$i360$i + 1 | 0; //@line 4726
    if ($$09$i360$i >>> 0 >= 41984) {
     $$0 = 0; //@line 4731
     label = 246; //@line 4732
     break;
    }
   }
   if ((label | 0) == 246) {
    STACKTOP = sp; //@line 4737
    return $$0 | 0; //@line 4737
   }
   HEAP16[$965 + 4 >> 1] = _htons(20085) | 0; //@line 4741
   $972 = HEAP32[30897] | 0; //@line 4742
   $$09$i363$i = 262144; //@line 4743
   do {
    $973 = $972 + $$09$i363$i | 0; //@line 4745
    if (!(_memcmp($973, 91924, 12) | 0)) {
     label = 121; //@line 4749
     break;
    }
    $$09$i363$i = $$09$i363$i + 1 | 0; //@line 4752
   } while ($$09$i363$i >>> 0 < 278528);
   if ((label | 0) == 121) {
    HEAP16[$973 + 4 >> 1] = _htons(20085) | 0; //@line 4763
   }
   $980 = HEAP32[30898] | 0; //@line 4765
   L206 : do {
    if ($980 >>> 0 > 524288) {
     $982 = HEAP32[30897] | 0; //@line 4769
     $$09$i366$i = 552960; //@line 4770
     while (1) {
      $983 = $982 + $$09$i366$i | 0; //@line 4772
      if (!(_memcmp($983, 91936, 10) | 0)) {
       label = 126; //@line 4776
       break;
      }
      $$09$i366$i = $$09$i366$i + 1 | 0; //@line 4779
      if ($$09$i366$i >>> 0 >= 555008) {
       $995 = $980; //@line 4784
       break;
      }
     }
     if ((label | 0) == 126) {
      $988 = $983 + 4 | 0; //@line 4789
      $990 = $988 + 2 | 0; //@line 4791
      HEAP16[$988 >> 1] = _htons(28976) | 0; //@line 4792
      HEAP16[$990 >> 1] = _htons(28672) | 0; //@line 4795
      HEAP16[$990 + 2 >> 1] = _htons(20085) | 0; //@line 4797
      $995 = HEAP32[30898] | 0; //@line 4799
     }
     if ($995 | 0) {
      $996 = HEAP32[30897] | 0; //@line 4803
      $$09$i369$i = 0; //@line 4804
      while (1) {
       $997 = $996 + $$09$i369$i | 0; //@line 4806
       if (!(_memcmp($997, 91946, 12) | 0)) {
        break;
       }
       $1000 = $$09$i369$i + 1 | 0; //@line 4812
       if ($1000 >>> 0 < $995 >>> 0) {
        $$09$i369$i = $1000; //@line 4815
       } else {
        break L206;
       }
      }
      if ($$09$i369$i | 0) {
       $1003 = $997 + 8 | 0; //@line 4822
       $1005 = $1003 + 2 | 0; //@line 4824
       HEAP16[$1003 >> 1] = _htons(20081) | 0; //@line 4825
       $1007 = $1005 + 2 | 0; //@line 4827
       HEAP16[$1005 >> 1] = _htons(-2824) | 0; //@line 4828
       $1009 = $1007 + 2 | 0; //@line 4830
       HEAP16[$1007 >> 1] = _htons(20081) | 0; //@line 4831
       HEAP16[$1009 >> 1] = _htons(28672) | 0; //@line 4834
       HEAP16[$1009 + 2 >> 1] = _htons(20085) | 0; //@line 4836
      }
     }
    }
   } while (0);
   $1013 = HEAP32[30897] | 0; //@line 4841
   $$09$i373$i = 323840; //@line 4842
   do {
    $1014 = $1013 + $$09$i373$i | 0; //@line 4844
    if (!(_memcmp($1014, 91958, 12) | 0)) {
     label = 136; //@line 4848
     break;
    }
    $$09$i373$i = $$09$i373$i + 1 | 0; //@line 4851
   } while ($$09$i373$i >>> 0 < 323968);
   if ((label | 0) == 136) {
    HEAP16[$1014 + 10 >> 1] = _htons(20081) | 0; //@line 4862
   }
   $1021 = HEAP32[30896] | 0; //@line 4864
   $1022 = $1021 + 26 | 0; //@line 4865
   $1028 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1022 >>> 16 << 2) >> 2] >> 2] & 127]($1022) | 0) + $1021 | 0; //@line 4871
   $1033 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1028 >>> 16 << 2) >> 2] >> 2] & 127]($1028) | 0; //@line 4876
   HEAP32[28209] = $1033; //@line 4877
   $1036 = $1033; //@line 4878
   do {
    $1035 = (HEAP32[30896] | 0) + $1036 | 0; //@line 4881
    $1037 = $1035 + 12 | 0; //@line 4882
    $1042 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1037 >>> 16 << 2) >> 2] >> 2] & 127]($1037) | 0; //@line 4887
    $1043 = $1035 + 16 | 0; //@line 4888
    $1048 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1043 >>> 16 << 2) >> 2] >> 2] & 127]($1043) | 0; //@line 4893
    $1049 = $1035 + 20 | 0; //@line 4894
    if (($1048 | 0) == 1146246738 & ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1049 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1049) | 0) & 65535 | 0) == 51) {
     label = 140; //@line 4906
     break;
    }
    $1058 = $1035 + 8 | 0; //@line 4909
    $1036 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1058 >>> 16 << 2) >> 2] >> 2] & 127]($1058) | 0; //@line 4914
    HEAP32[28209] = $1036; //@line 4915
   } while (($1036 | 0) != 0);
   L230 : do {
    if ((label | 0) == 140) {
     if ($1042 | 0) {
      $1066 = $1042 + 65536 | 0; //@line 4927
      if ($1042 >>> 0 < 4294901760) {
       $1068 = HEAP32[30897] | 0; //@line 4930
       $$09$i379$i = $1042; //@line 4931
       while (1) {
        $1069 = $1068 + $$09$i379$i | 0; //@line 4933
        if (!(_memcmp($1069, 91970, 12) | 0)) {
         break;
        }
        $1072 = $$09$i379$i + 1 | 0; //@line 4939
        if ($1072 >>> 0 < $1066 >>> 0) {
         $$09$i379$i = $1072; //@line 4942
        } else {
         break L230;
        }
       }
       if ($$09$i379$i | 0) {
        $1075 = $1069 + 8 | 0; //@line 4949
        HEAP16[$1075 >> 1] = 0; //@line 4951
        HEAP16[$1075 + 2 >> 1] = 0; //@line 4952
       }
      }
     }
    }
   } while (0);
   $1077 = HEAP32[30896] | 0; //@line 4958
   $1078 = $1077 + 26 | 0; //@line 4959
   $1084 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1078 >>> 16 << 2) >> 2] >> 2] & 127]($1078) | 0) + $1077 | 0; //@line 4965
   $1089 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1084 >>> 16 << 2) >> 2] >> 2] & 127]($1084) | 0; //@line 4970
   HEAP32[28209] = $1089; //@line 4971
   $1092 = $1089; //@line 4972
   while (1) {
    $1091 = (HEAP32[30896] | 0) + $1092 | 0; //@line 4975
    $1093 = $1091 + 12 | 0; //@line 4976
    $1098 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1093 >>> 16 << 2) >> 2] >> 2] & 127]($1093) | 0; //@line 4981
    $1099 = $1091 + 16 | 0; //@line 4982
    $1104 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1099 >>> 16 << 2) >> 2] >> 2] & 127]($1099) | 0; //@line 4987
    $1105 = $1091 + 20 | 0; //@line 4988
    if (($1104 | 0) == 1146246738 & ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1105 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1105) | 0) & 65535 | 0) == 4) {
     $$2$i383$i = $1098; //@line 5000
     break;
    }
    $1114 = $1091 + 8 | 0; //@line 5003
    $1092 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1114 >>> 16 << 2) >> 2] >> 2] & 127]($1114) | 0; //@line 5008
    HEAP32[28209] = $1092; //@line 5009
    if (!$1092) {
     $$2$i383$i = 0; //@line 5012
     break;
    }
   }
   HEAP32[28207] = $$2$i383$i; //@line 5018
   dest = (HEAP32[30897] | 0) + $$2$i383$i | 0; //@line 5021
   src = 91029; //@line 5021
   stop = dest + 86 | 0; //@line 5021
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5021
    dest = dest + 1 | 0; //@line 5021
    src = src + 1 | 0; //@line 5021
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $$2$i383$i + 256 | 0; //@line 5025
   src = 91115; //@line 5025
   stop = dest + 86 | 0; //@line 5025
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5025
    dest = dest + 1 | 0; //@line 5025
    src = src + 1 | 0; //@line 5025
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $$2$i383$i + 512 | 0; //@line 5029
   src = 91201; //@line 5029
   stop = dest + 90 | 0; //@line 5029
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5029
    dest = dest + 1 | 0; //@line 5029
    src = src + 1 | 0; //@line 5029
   } while ((dest | 0) < (stop | 0));
   HEAP32[28483] = $$2$i383$i + 1024 + (HEAP32[30896] | 0); //@line 5033
   _memcpy((HEAP32[30897] | 0) + $$2$i383$i + 1024 | 0, 93682, 258) | 0; //@line 5037
   HEAP32[28484] = $$2$i383$i + 1536 + (HEAP32[30896] | 0); //@line 5041
   _memcpy((HEAP32[30897] | 0) + $$2$i383$i + 1536 | 0, 93940, 258) | 0; //@line 5045
   HEAP32[28488] = $$2$i383$i + 2048 + (HEAP32[30896] | 0); //@line 5049
   _memcpy((HEAP32[30897] | 0) + $$2$i383$i + 2048 | 0, 94272, 258) | 0; //@line 5053
   HEAP32[28492] = $$2$i383$i + 2560 + (HEAP32[30896] | 0); //@line 5057
   _memcpy((HEAP32[30897] | 0) + $$2$i383$i + 2560 | 0, 94883, 258) | 0; //@line 5061
   $1153 = HEAP32[30896] | 0; //@line 5062
   $1154 = $1153 + 26 | 0; //@line 5063
   $1160 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1154 >>> 16 << 2) >> 2] >> 2] & 127]($1154) | 0) + $1153 | 0; //@line 5069
   $1165 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1160 >>> 16 << 2) >> 2] >> 2] & 127]($1160) | 0; //@line 5074
   HEAP32[28209] = $1165; //@line 5075
   $1168 = $1165; //@line 5076
   while (1) {
    $1167 = (HEAP32[30896] | 0) + $1168 | 0; //@line 5079
    $1169 = $1167 + 12 | 0; //@line 5080
    $1174 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1169 >>> 16 << 2) >> 2] >> 2] & 127]($1169) | 0; //@line 5085
    $1175 = $1167 + 16 | 0; //@line 5086
    $1180 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1175 >>> 16 << 2) >> 2] >> 2] & 127]($1175) | 0; //@line 5091
    $1181 = $1167 + 20 | 0; //@line 5092
    if (($1180 | 0) == 1397051972 & ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1181 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1181) | 0) & 65535 | 0) == 0) {
     $$2$i387$i = $1174; //@line 5104
     break;
    }
    $1190 = $1167 + 8 | 0; //@line 5107
    $1168 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1190 >>> 16 << 2) >> 2] >> 2] & 127]($1190) | 0; //@line 5112
    HEAP32[28209] = $1168; //@line 5113
    if (!$1168) {
     $$2$i387$i = 0; //@line 5116
     break;
    }
   }
   HEAP32[28208] = $$2$i387$i; //@line 5122
   $1199 = (HEAP32[30897] | 0) + $$2$i387$i + 12 | 0; //@line 5125
   HEAP16[$1199 >> 1] = _htons(28939) | 0; //@line 5128
   HEAP16[$1199 + 2 >> 1] = _htons(20085) | 0; //@line 5130
   $1204 = HEAP32[28208] | 0; //@line 5132
   dest = (HEAP32[30897] | 0) + $1204 + 256 | 0; //@line 5135
   src = 91291; //@line 5135
   stop = dest + 98 | 0; //@line 5135
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5135
    dest = dest + 1 | 0; //@line 5135
    src = src + 1 | 0; //@line 5135
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $1204 + 512 | 0; //@line 5139
   src = 91389; //@line 5139
   stop = dest + 100 | 0; //@line 5139
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5139
    dest = dest + 1 | 0; //@line 5139
    src = src + 1 | 0; //@line 5139
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $1204 + 768 | 0; //@line 5143
   src = 91489; //@line 5143
   stop = dest + 98 | 0; //@line 5143
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5143
    dest = dest + 1 | 0; //@line 5143
    src = src + 1 | 0; //@line 5143
   } while ((dest | 0) < (stop | 0));
   dest = (HEAP32[30897] | 0) + $1204 + 1024 | 0; //@line 5147
   src = 91587; //@line 5147
   stop = dest + 100 | 0; //@line 5147
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5147
    dest = dest + 1 | 0; //@line 5147
    src = src + 1 | 0; //@line 5147
   } while ((dest | 0) < (stop | 0));
   $1216 = HEAP32[30897] | 0; //@line 5148
   $1218 = (HEAP32[30896] | 0) + 34 | 0; //@line 5150
   $$043$i392$i = $1216 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1218 >>> 16 << 2) >> 2] >> 2] & 127]($1218) | 0) | 0; //@line 5157
   $$048$i391$i = -22528; //@line 5157
   $$057$i390$i = 0; //@line 5157
   L248 : while (1) {
    $$05673$i396$i = 0; //@line 5159
    $$14475$i394$i = $$043$i392$i; //@line 5159
    $$14974$i395$i = $$048$i391$i; //@line 5159
    $$15872$i397$i = $$057$i390$i; //@line 5159
    while (1) {
     $1225 = $$14475$i394$i + 1 | 0; //@line 5161
     $1226 = HEAP8[$$14475$i394$i >> 0] | 0; //@line 5162
     $1227 = $1226 & 255; //@line 5163
     L252 : do {
      switch ($1226 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i400$i = 0; //@line 5167
        $$245$i401$i = $1225; //@line 5167
        $$461$i399$i = $$15872$i397$i; //@line 5167
        break;
       }
      case -1:
       {
        $1244 = HEAPU8[$$14475$i394$i + 2 >> 0] << 16 | HEAPU8[$1225 >> 0] << 24 | HEAPU8[$$14475$i394$i + 3 >> 0] << 8 | HEAPU8[$$14475$i394$i + 4 >> 0]; //@line 5187
        $$051$off0$i400$i = $1244; //@line 5189
        $$245$i401$i = $$14475$i394$i + 5 | 0; //@line 5189
        $$461$i399$i = $1244; //@line 5189
        break;
       }
      default:
       {
        if (!($1227 & 128)) {
         $1256 = HEAPU8[$1225 >> 0] | $1227 << 8; //@line 5200
         $1261 = ($1256 << 17 >> 16) + $$15872$i397$i | 0; //@line 5206
         if (!(($1256 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i403$i = 0; //@line 5208
          break L248;
         } else {
          $$051$off0$i400$i = $1261; //@line 5211
          $$245$i401$i = $$14475$i394$i + 2 | 0; //@line 5211
          $$461$i399$i = $1261; //@line 5211
          break L252;
         }
        } else {
         $1249 = $1227 << 1 & 254; //@line 5216
         $1251 = $1249 + $$15872$i397$i | 0; //@line 5218
         if (!$1249) {
          $$5$ph$i403$i = 0; //@line 5220
          break L248;
         } else {
          $$051$off0$i400$i = $1251; //@line 5223
          $$245$i401$i = $1225; //@line 5223
          $$461$i399$i = $1251; //@line 5223
          break L252;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i395$i << 16 >> 16 == -24452) {
      $$5$ph$i403$i = $$051$off0$i400$i; //@line 5232
      break L248;
     }
     $1264 = $$05673$i396$i + 1 | 0; //@line 5236
     if (($1264 | 0) < 1024) {
      $$05673$i396$i = $1264; //@line 5239
      $$14475$i394$i = $$245$i401$i; //@line 5239
      $$14974$i395$i = $$14974$i395$i + 1 << 16 >> 16; //@line 5239
      $$15872$i397$i = $$461$i399$i; //@line 5239
     } else {
      $$043$i392$i = $$245$i401$i; //@line 5241
      $$048$i391$i = -24576; //@line 5241
      $$057$i390$i = $$461$i399$i; //@line 5241
      continue L248;
     }
    }
   }
   dest = $1216 + $$5$ph$i403$i | 0; //@line 5247
   src = 91687; //@line 5247
   stop = dest + 54 | 0; //@line 5247
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 5247
    dest = dest + 1 | 0; //@line 5247
    src = src + 1 | 0; //@line 5247
   } while ((dest | 0) < (stop | 0));
   $1267 = HEAP32[30897] | 0; //@line 5248
   $1269 = (HEAP32[30896] | 0) + 34 | 0; //@line 5250
   $$043$i407$i = $1267 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1269 >>> 16 << 2) >> 2] >> 2] & 127]($1269) | 0) | 0; //@line 5257
   $$048$i406$i = -22528; //@line 5257
   $$057$i405$i = 0; //@line 5257
   L261 : while (1) {
    $$05673$i411$i = 0; //@line 5259
    $$14475$i409$i = $$043$i407$i; //@line 5259
    $$14974$i410$i = $$048$i406$i; //@line 5259
    $$15872$i412$i = $$057$i405$i; //@line 5259
    while (1) {
     $1276 = $$14475$i409$i + 1 | 0; //@line 5261
     $1277 = HEAP8[$$14475$i409$i >> 0] | 0; //@line 5262
     $1278 = $1277 & 255; //@line 5263
     L265 : do {
      switch ($1277 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i415$i = 0; //@line 5267
        $$245$i416$i = $1276; //@line 5267
        $$461$i414$i = $$15872$i412$i; //@line 5267
        break;
       }
      case -1:
       {
        $1295 = HEAPU8[$$14475$i409$i + 2 >> 0] << 16 | HEAPU8[$1276 >> 0] << 24 | HEAPU8[$$14475$i409$i + 3 >> 0] << 8 | HEAPU8[$$14475$i409$i + 4 >> 0]; //@line 5287
        $$051$off0$i415$i = $1295; //@line 5289
        $$245$i416$i = $$14475$i409$i + 5 | 0; //@line 5289
        $$461$i414$i = $1295; //@line 5289
        break;
       }
      default:
       {
        if (!($1278 & 128)) {
         $1307 = HEAPU8[$1276 >> 0] | $1278 << 8; //@line 5300
         $1312 = ($1307 << 17 >> 16) + $$15872$i412$i | 0; //@line 5306
         if (!(($1307 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i418$i = 0; //@line 5308
          break L261;
         } else {
          $$051$off0$i415$i = $1312; //@line 5311
          $$245$i416$i = $$14475$i409$i + 2 | 0; //@line 5311
          $$461$i414$i = $1312; //@line 5311
          break L265;
         }
        } else {
         $1300 = $1278 << 1 & 254; //@line 5316
         $1302 = $1300 + $$15872$i412$i | 0; //@line 5318
         if (!$1300) {
          $$5$ph$i418$i = 0; //@line 5320
          break L261;
         } else {
          $$051$off0$i415$i = $1302; //@line 5323
          $$245$i416$i = $1276; //@line 5323
          $$461$i414$i = $1302; //@line 5323
          break L265;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i410$i << 16 >> 16 == -24488) {
      $$5$ph$i418$i = $$051$off0$i415$i; //@line 5332
      break L261;
     }
     $1315 = $$05673$i411$i + 1 | 0; //@line 5336
     if (($1315 | 0) < 1024) {
      $$05673$i411$i = $1315; //@line 5339
      $$14475$i409$i = $$245$i416$i; //@line 5339
      $$14974$i410$i = $$14974$i410$i + 1 << 16 >> 16; //@line 5339
      $$15872$i412$i = $$461$i414$i; //@line 5339
     } else {
      $$043$i407$i = $$245$i416$i; //@line 5341
      $$048$i406$i = -24576; //@line 5341
      $$057$i405$i = $$461$i414$i; //@line 5341
      continue L261;
     }
    }
   }
   $1317 = $1267 + $$5$ph$i418$i | 0; //@line 5346
   HEAP16[$1317 >> 1] = _htons(28964) | 0; //@line 5349
   HEAP16[$1317 + 2 >> 1] = _htons(20085) | 0; //@line 5351
   $1321 = HEAP32[30897] | 0; //@line 5352
   $1323 = (HEAP32[30896] | 0) + 34 | 0; //@line 5354
   $$043$i422$i = $1321 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1323 >>> 16 << 2) >> 2] >> 2] & 127]($1323) | 0) | 0; //@line 5361
   $$048$i421$i = -22528; //@line 5361
   $$057$i420$i = 0; //@line 5361
   L274 : while (1) {
    $$05673$i426$i = 0; //@line 5363
    $$14475$i424$i = $$043$i422$i; //@line 5363
    $$14974$i425$i = $$048$i421$i; //@line 5363
    $$15872$i427$i = $$057$i420$i; //@line 5363
    while (1) {
     $1330 = $$14475$i424$i + 1 | 0; //@line 5365
     $1331 = HEAP8[$$14475$i424$i >> 0] | 0; //@line 5366
     $1332 = $1331 & 255; //@line 5367
     L278 : do {
      switch ($1331 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i430$i = 0; //@line 5371
        $$245$i431$i = $1330; //@line 5371
        $$461$i429$i = $$15872$i427$i; //@line 5371
        break;
       }
      case -1:
       {
        $1349 = HEAPU8[$$14475$i424$i + 2 >> 0] << 16 | HEAPU8[$1330 >> 0] << 24 | HEAPU8[$$14475$i424$i + 3 >> 0] << 8 | HEAPU8[$$14475$i424$i + 4 >> 0]; //@line 5391
        $$051$off0$i430$i = $1349; //@line 5393
        $$245$i431$i = $$14475$i424$i + 5 | 0; //@line 5393
        $$461$i429$i = $1349; //@line 5393
        break;
       }
      default:
       {
        if (!($1332 & 128)) {
         $1361 = HEAPU8[$1330 >> 0] | $1332 << 8; //@line 5404
         $1366 = ($1361 << 17 >> 16) + $$15872$i427$i | 0; //@line 5410
         if (!(($1361 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i433$i = 0; //@line 5412
          break L274;
         } else {
          $$051$off0$i430$i = $1366; //@line 5415
          $$245$i431$i = $$14475$i424$i + 2 | 0; //@line 5415
          $$461$i429$i = $1366; //@line 5415
          break L278;
         }
        } else {
         $1354 = $1332 << 1 & 254; //@line 5420
         $1356 = $1354 + $$15872$i427$i | 0; //@line 5422
         if (!$1354) {
          $$5$ph$i433$i = 0; //@line 5424
          break L274;
         } else {
          $$051$off0$i430$i = $1356; //@line 5427
          $$245$i431$i = $1330; //@line 5427
          $$461$i429$i = $1356; //@line 5427
          break L278;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i425$i << 16 >> 16 == -24487) {
      $$5$ph$i433$i = $$051$off0$i430$i; //@line 5436
      break L274;
     }
     $1369 = $$05673$i426$i + 1 | 0; //@line 5440
     if (($1369 | 0) < 1024) {
      $$05673$i426$i = $1369; //@line 5443
      $$14475$i424$i = $$245$i431$i; //@line 5443
      $$14974$i425$i = $$14974$i425$i + 1 << 16 >> 16; //@line 5443
      $$15872$i427$i = $$461$i429$i; //@line 5443
     } else {
      $$043$i422$i = $$245$i431$i; //@line 5445
      $$048$i421$i = -24576; //@line 5445
      $$057$i420$i = $$461$i429$i; //@line 5445
      continue L274;
     }
    }
   }
   $1371 = $1321 + $$5$ph$i433$i | 0; //@line 5450
   $1373 = $1371 + 2 | 0; //@line 5452
   HEAP16[$1371 >> 1] = _htons(16615) | 0; //@line 5453
   $1375 = $1373 + 2 | 0; //@line 5455
   HEAP16[$1373 >> 1] = _htons(124) | 0; //@line 5456
   $1377 = $1375 + 2 | 0; //@line 5458
   HEAP16[$1375 >> 1] = _htons(1792) | 0; //@line 5459
   $1379 = $1377 + 2 | 0; //@line 5461
   HEAP16[$1377 >> 1] = _htons(28965) | 0; //@line 5462
   HEAP16[$1379 >> 1] = _htons(18143) | 0; //@line 5465
   HEAP16[$1379 + 2 >> 1] = _htons(20085) | 0; //@line 5467
   $1383 = HEAP32[30897] | 0; //@line 5468
   $1385 = (HEAP32[30896] | 0) + 34 | 0; //@line 5470
   $$043$i437$i = $1383 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1385 >>> 16 << 2) >> 2] >> 2] & 127]($1385) | 0) | 0; //@line 5477
   $$048$i436$i = -22528; //@line 5477
   $$057$i435$i = 0; //@line 5477
   L287 : while (1) {
    $$05673$i441$i = 0; //@line 5479
    $$14475$i439$i = $$043$i437$i; //@line 5479
    $$14974$i440$i = $$048$i436$i; //@line 5479
    $$15872$i442$i = $$057$i435$i; //@line 5479
    while (1) {
     $1392 = $$14475$i439$i + 1 | 0; //@line 5481
     $1393 = HEAP8[$$14475$i439$i >> 0] | 0; //@line 5482
     $1394 = $1393 & 255; //@line 5483
     L291 : do {
      switch ($1393 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i445$i = 0; //@line 5487
        $$245$i446$i = $1392; //@line 5487
        $$461$i444$i = $$15872$i442$i; //@line 5487
        break;
       }
      case -1:
       {
        $1411 = HEAPU8[$$14475$i439$i + 2 >> 0] << 16 | HEAPU8[$1392 >> 0] << 24 | HEAPU8[$$14475$i439$i + 3 >> 0] << 8 | HEAPU8[$$14475$i439$i + 4 >> 0]; //@line 5507
        $$051$off0$i445$i = $1411; //@line 5509
        $$245$i446$i = $$14475$i439$i + 5 | 0; //@line 5509
        $$461$i444$i = $1411; //@line 5509
        break;
       }
      default:
       {
        if (!($1394 & 128)) {
         $1423 = HEAPU8[$1392 >> 0] | $1394 << 8; //@line 5520
         $1428 = ($1423 << 17 >> 16) + $$15872$i442$i | 0; //@line 5526
         if (!(($1423 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i448$i = 0; //@line 5528
          break L287;
         } else {
          $$051$off0$i445$i = $1428; //@line 5531
          $$245$i446$i = $$14475$i439$i + 2 | 0; //@line 5531
          $$461$i444$i = $1428; //@line 5531
          break L291;
         }
        } else {
         $1416 = $1394 << 1 & 254; //@line 5536
         $1418 = $1416 + $$15872$i442$i | 0; //@line 5538
         if (!$1416) {
          $$5$ph$i448$i = 0; //@line 5540
          break L287;
         } else {
          $$051$off0$i445$i = $1418; //@line 5543
          $$245$i446$i = $1392; //@line 5543
          $$461$i444$i = $1418; //@line 5543
          break L291;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i440$i << 16 >> 16 == -24486) {
      $$5$ph$i448$i = $$051$off0$i445$i; //@line 5552
      break L287;
     }
     $1431 = $$05673$i441$i + 1 | 0; //@line 5556
     if (($1431 | 0) < 1024) {
      $$05673$i441$i = $1431; //@line 5559
      $$14475$i439$i = $$245$i446$i; //@line 5559
      $$14974$i440$i = $$14974$i440$i + 1 << 16 >> 16; //@line 5559
      $$15872$i442$i = $$461$i444$i; //@line 5559
     } else {
      $$043$i437$i = $$245$i446$i; //@line 5561
      $$048$i436$i = -24576; //@line 5561
      $$057$i435$i = $$461$i444$i; //@line 5561
      continue L287;
     }
    }
   }
   $1433 = $1383 + $$5$ph$i448$i | 0; //@line 5566
   $1435 = $1433 + 2 | 0; //@line 5568
   HEAP16[$1433 >> 1] = _htons(16615) | 0; //@line 5569
   $1437 = $1435 + 2 | 0; //@line 5571
   HEAP16[$1435 >> 1] = _htons(124) | 0; //@line 5572
   $1439 = $1437 + 2 | 0; //@line 5574
   HEAP16[$1437 >> 1] = _htons(1792) | 0; //@line 5575
   $1441 = $1439 + 2 | 0; //@line 5577
   HEAP16[$1439 >> 1] = _htons(28966) | 0; //@line 5578
   $1443 = $1441 + 2 | 0; //@line 5580
   HEAP16[$1441 >> 1] = _htons(18143) | 0; //@line 5581
   $1445 = $1443 + 2 | 0; //@line 5583
   HEAP16[$1443 >> 1] = _htons(20085) | 0; //@line 5584
   HEAP32[28205] = $1445 - (HEAP32[30897] | 0); //@line 5588
   $1450 = $1445 + 2 | 0; //@line 5590
   HEAP16[$1445 >> 1] = _htons(28967) | 0; //@line 5591
   $1452 = $1450 + 2 | 0; //@line 5593
   HEAP16[$1450 >> 1] = _htons(20085) | 0; //@line 5594
   HEAP32[28206] = $1452 - (HEAP32[30897] | 0); //@line 5598
   HEAP16[$1452 >> 1] = _htons(28982) | 0; //@line 5601
   HEAP16[$1452 + 2 >> 1] = _htons(20085) | 0; //@line 5603
   $1459 = HEAP32[30897] | 0; //@line 5604
   $1461 = (HEAP32[30896] | 0) + 34 | 0; //@line 5606
   $$043$i452$i = $1459 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1461 >>> 16 << 2) >> 2] >> 2] & 127]($1461) | 0) | 0; //@line 5613
   $$048$i451$i = -22528; //@line 5613
   $$057$i450$i = 0; //@line 5613
   L300 : while (1) {
    $$05673$i456$i = 0; //@line 5615
    $$14475$i454$i = $$043$i452$i; //@line 5615
    $$14974$i455$i = $$048$i451$i; //@line 5615
    $$15872$i457$i = $$057$i450$i; //@line 5615
    while (1) {
     $1468 = $$14475$i454$i + 1 | 0; //@line 5617
     $1469 = HEAP8[$$14475$i454$i >> 0] | 0; //@line 5618
     $1470 = $1469 & 255; //@line 5619
     L304 : do {
      switch ($1469 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i460$i = 0; //@line 5623
        $$245$i461$i = $1468; //@line 5623
        $$461$i459$i = $$15872$i457$i; //@line 5623
        break;
       }
      case -1:
       {
        $1487 = HEAPU8[$$14475$i454$i + 2 >> 0] << 16 | HEAPU8[$1468 >> 0] << 24 | HEAPU8[$$14475$i454$i + 3 >> 0] << 8 | HEAPU8[$$14475$i454$i + 4 >> 0]; //@line 5643
        $$051$off0$i460$i = $1487; //@line 5645
        $$245$i461$i = $$14475$i454$i + 5 | 0; //@line 5645
        $$461$i459$i = $1487; //@line 5645
        break;
       }
      default:
       {
        if (!($1470 & 128)) {
         $1499 = HEAPU8[$1468 >> 0] | $1470 << 8; //@line 5656
         $1504 = ($1499 << 17 >> 16) + $$15872$i457$i | 0; //@line 5662
         if (!(($1499 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i463$i = 0; //@line 5664
          break L300;
         } else {
          $$051$off0$i460$i = $1504; //@line 5667
          $$245$i461$i = $$14475$i454$i + 2 | 0; //@line 5667
          $$461$i459$i = $1504; //@line 5667
          break L304;
         }
        } else {
         $1492 = $1470 << 1 & 254; //@line 5672
         $1494 = $1492 + $$15872$i457$i | 0; //@line 5674
         if (!$1492) {
          $$5$ph$i463$i = 0; //@line 5676
          break L300;
         } else {
          $$051$off0$i460$i = $1494; //@line 5679
          $$245$i461$i = $1468; //@line 5679
          $$461$i459$i = $1494; //@line 5679
          break L304;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i455$i << 16 >> 16 == -22507) {
      $$5$ph$i463$i = $$051$off0$i460$i; //@line 5688
      break L300;
     }
     $1507 = $$05673$i456$i + 1 | 0; //@line 5692
     if (($1507 | 0) < 1024) {
      $$05673$i456$i = $1507; //@line 5695
      $$14475$i454$i = $$245$i461$i; //@line 5695
      $$14974$i455$i = $$14974$i455$i + 1 << 16 >> 16; //@line 5695
      $$15872$i457$i = $$461$i459$i; //@line 5695
     } else {
      $$043$i452$i = $$245$i461$i; //@line 5697
      $$048$i451$i = -24576; //@line 5697
      $$057$i450$i = $$461$i459$i; //@line 5697
      continue L300;
     }
    }
   }
   $1509 = $1459 + $$5$ph$i463$i | 0; //@line 5702
   $1511 = $1509 + 2 | 0; //@line 5704
   HEAP16[$1509 >> 1] = _htons(28968) | 0; //@line 5705
   HEAP16[$1511 >> 1] = _htons(11849) | 0; //@line 5708
   HEAP16[$1511 + 2 >> 1] = _htons(20176) | 0; //@line 5710
   $1515 = HEAP32[30897] | 0; //@line 5711
   HEAP16[$1515 + 112884 >> 1] = _htons(20217) | 0; //@line 5715
   HEAP16[$1515 + 112886 >> 1] = _htons(((HEAP32[30896] | 0) + 768 + (HEAP32[28207] | 0) | 0) >>> 16 & 65535) | 0; //@line 5724
   HEAP16[$1515 + 112888 >> 1] = _htons((HEAP32[30896] | 0) + 768 + (HEAP32[28207] | 0) & 65535) | 0; //@line 5731
   $1536 = (HEAP32[30897] | 0) + (HEAP32[28207] | 0) + 768 | 0; //@line 5735
   $1538 = $1536 + 2 | 0; //@line 5737
   HEAP16[$1536 >> 1] = _htons(12035) | 0; //@line 5738
   $1540 = $1538 + 2 | 0; //@line 5740
   HEAP16[$1538 >> 1] = _htons(8312) | 0; //@line 5741
   $1542 = $1540 + 2 | 0; //@line 5743
   HEAP16[$1540 >> 1] = _htons(2032) | 0; //@line 5744
   $1544 = $1542 + 2 | 0; //@line 5746
   HEAP16[$1542 >> 1] = _htons(20112) | 0; //@line 5747
   $1546 = $1544 + 2 | 0; //@line 5749
   HEAP16[$1544 >> 1] = _htons(8735) | 0; //@line 5750
   HEAP16[$1546 >> 1] = _htons(28972) | 0; //@line 5753
   HEAP16[$1546 + 2 >> 1] = _htons(20085) | 0; //@line 5755
   $1550 = HEAP32[30897] | 0; //@line 5756
   $1552 = (HEAP32[30896] | 0) + 34 | 0; //@line 5758
   $$043$i = $1550 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1552 >>> 16 << 2) >> 2] >> 2] & 127]($1552) | 0) | 0; //@line 5765
   $$048$i = -22528; //@line 5765
   $$057$i = 0; //@line 5765
   L313 : while (1) {
    $$05673$i = 0; //@line 5767
    $$14475$i = $$043$i; //@line 5767
    $$14974$i = $$048$i; //@line 5767
    $$15872$i = $$057$i; //@line 5767
    while (1) {
     $1559 = $$14475$i + 1 | 0; //@line 5769
     $1560 = HEAP8[$$14475$i >> 0] | 0; //@line 5770
     $1561 = $1560 & 255; //@line 5771
     L317 : do {
      switch ($1560 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i = 0; //@line 5775
        $$245$i = $1559; //@line 5775
        $$461$i = $$15872$i; //@line 5775
        break;
       }
      case -1:
       {
        $1578 = HEAPU8[$$14475$i + 2 >> 0] << 16 | HEAPU8[$1559 >> 0] << 24 | HEAPU8[$$14475$i + 3 >> 0] << 8 | HEAPU8[$$14475$i + 4 >> 0]; //@line 5795
        $$051$off0$i = $1578; //@line 5797
        $$245$i = $$14475$i + 5 | 0; //@line 5797
        $$461$i = $1578; //@line 5797
        break;
       }
      default:
       {
        if (!($1561 & 128)) {
         $1590 = HEAPU8[$1559 >> 0] | $1561 << 8; //@line 5808
         $1595 = ($1590 << 17 >> 16) + $$15872$i | 0; //@line 5814
         if (!(($1590 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i = 0; //@line 5816
          break L313;
         } else {
          $$051$off0$i = $1595; //@line 5819
          $$245$i = $$14475$i + 2 | 0; //@line 5819
          $$461$i = $1595; //@line 5819
          break L317;
         }
        } else {
         $1583 = $1561 << 1 & 254; //@line 5824
         $1585 = $1583 + $$15872$i | 0; //@line 5826
         if (!$1583) {
          $$5$ph$i = 0; //@line 5828
          break L313;
         } else {
          $$051$off0$i = $1585; //@line 5831
          $$245$i = $1559; //@line 5831
          $$461$i = $1585; //@line 5831
          break L317;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i << 16 >> 16 == -24485) {
      $$5$ph$i = $$051$off0$i; //@line 5840
      break L313;
     }
     $1598 = $$05673$i + 1 | 0; //@line 5844
     if (($1598 | 0) < 1024) {
      $$05673$i = $1598; //@line 5847
      $$14475$i = $$245$i; //@line 5847
      $$14974$i = $$14974$i + 1 << 16 >> 16; //@line 5847
      $$15872$i = $$461$i; //@line 5847
     } else {
      $$043$i = $$245$i; //@line 5849
      $$048$i = -24576; //@line 5849
      $$057$i = $$461$i; //@line 5849
      continue L313;
     }
    }
   }
   HEAP16[$1550 + $$5$ph$i >> 1] = _htons(28930) | 0; //@line 5856
   $1602 = HEAP32[30896] | 0; //@line 5857
   HEAP32[28202] = $1602 + 3072 + (HEAP32[28207] | 0); //@line 5861
   $1606 = HEAP32[30897] | 0; //@line 5862
   $1607 = $1602 + 34 | 0; //@line 5863
   $$043$i7 = $1606 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1607 >>> 16 << 2) >> 2] >> 2] & 127]($1607) | 0) | 0; //@line 5870
   $$048$i6 = -22528; //@line 5870
   $$057$i5 = 0; //@line 5870
   L326 : while (1) {
    $$05673$i11 = 0; //@line 5872
    $$14475$i9 = $$043$i7; //@line 5872
    $$14974$i10 = $$048$i6; //@line 5872
    $$15872$i12 = $$057$i5; //@line 5872
    while (1) {
     $1614 = $$14475$i9 + 1 | 0; //@line 5874
     $1615 = HEAP8[$$14475$i9 >> 0] | 0; //@line 5875
     $1616 = $1615 & 255; //@line 5876
     L330 : do {
      switch ($1615 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i15 = 0; //@line 5880
        $$245$i16 = $1614; //@line 5880
        $$461$i14 = $$15872$i12; //@line 5880
        break;
       }
      case -1:
       {
        $1633 = HEAPU8[$$14475$i9 + 2 >> 0] << 16 | HEAPU8[$1614 >> 0] << 24 | HEAPU8[$$14475$i9 + 3 >> 0] << 8 | HEAPU8[$$14475$i9 + 4 >> 0]; //@line 5900
        $$051$off0$i15 = $1633; //@line 5902
        $$245$i16 = $$14475$i9 + 5 | 0; //@line 5902
        $$461$i14 = $1633; //@line 5902
        break;
       }
      default:
       {
        if (!($1616 & 128)) {
         $1645 = HEAPU8[$1614 >> 0] | $1616 << 8; //@line 5913
         $1650 = ($1645 << 17 >> 16) + $$15872$i12 | 0; //@line 5919
         if (!(($1645 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i18 = 0; //@line 5921
          break L326;
         } else {
          $$051$off0$i15 = $1650; //@line 5924
          $$245$i16 = $$14475$i9 + 2 | 0; //@line 5924
          $$461$i14 = $1650; //@line 5924
          break L330;
         }
        } else {
         $1638 = $1616 << 1 & 254; //@line 5929
         $1640 = $1638 + $$15872$i12 | 0; //@line 5931
         if (!$1638) {
          $$5$ph$i18 = 0; //@line 5933
          break L326;
         } else {
          $$051$off0$i15 = $1640; //@line 5936
          $$245$i16 = $1614; //@line 5936
          $$461$i14 = $1640; //@line 5936
          break L330;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i10 << 16 >> 16 == -22018) {
      $$5$ph$i18 = $$051$off0$i15; //@line 5945
      break L326;
     }
     $1653 = $$05673$i11 + 1 | 0; //@line 5949
     if (($1653 | 0) < 1024) {
      $$05673$i11 = $1653; //@line 5952
      $$14475$i9 = $$245$i16; //@line 5952
      $$14974$i10 = $$14974$i10 + 1 << 16 >> 16; //@line 5952
      $$15872$i12 = $$461$i14; //@line 5952
     } else {
      $$043$i7 = $$245$i16; //@line 5954
      $$048$i6 = -24576; //@line 5954
      $$057$i5 = $$461$i14; //@line 5954
      continue L326;
     }
    }
   }
   $1655 = $$5$ph$i18 + $1602 | 0; //@line 5959
   $1659 = (HEAP32[30897] | 0) + (HEAP32[28207] | 0) + 3072 | 0; //@line 5963
   $1661 = $1659 + 2 | 0; //@line 5965
   HEAP16[$1659 >> 1] = _htons(28970) | 0; //@line 5966
   $1663 = $1661 + 2 | 0; //@line 5968
   HEAP16[$1661 >> 1] = _htons(20217) | 0; //@line 5969
   HEAP16[$1663 >> 1] = _htons($1655 >>> 16 & 65535) | 0; //@line 5974
   HEAP16[$1663 + 2 >> 1] = _htons($1655 & 65535) | 0; //@line 5977
   $1670 = HEAP32[30896] | 0; //@line 5978
   HEAP32[28203] = $1670 + 3328 + (HEAP32[28207] | 0); //@line 5982
   $1674 = HEAP32[30897] | 0; //@line 5983
   $1675 = $1670 + 34 | 0; //@line 5984
   $$043$i22 = $1674 + (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1675 >>> 16 << 2) >> 2] >> 2] & 127]($1675) | 0) | 0; //@line 5991
   $$048$i21 = -22528; //@line 5991
   $$057$i20 = 0; //@line 5991
   L339 : while (1) {
    $$05673$i26 = 0; //@line 5993
    $$14475$i24 = $$043$i22; //@line 5993
    $$14974$i25 = $$048$i21; //@line 5993
    $$15872$i27 = $$057$i20; //@line 5993
    while (1) {
     $1682 = $$14475$i24 + 1 | 0; //@line 5995
     $1683 = HEAP8[$$14475$i24 >> 0] | 0; //@line 5996
     $1684 = $1683 & 255; //@line 5997
     L343 : do {
      switch ($1683 << 24 >> 24) {
      case -128:
       {
        $$051$off0$i30 = 0; //@line 6001
        $$245$i31 = $1682; //@line 6001
        $$461$i29 = $$15872$i27; //@line 6001
        break;
       }
      case -1:
       {
        $1701 = HEAPU8[$$14475$i24 + 2 >> 0] << 16 | HEAPU8[$1682 >> 0] << 24 | HEAPU8[$$14475$i24 + 3 >> 0] << 8 | HEAPU8[$$14475$i24 + 4 >> 0]; //@line 6021
        $$051$off0$i30 = $1701; //@line 6023
        $$245$i31 = $$14475$i24 + 5 | 0; //@line 6023
        $$461$i29 = $1701; //@line 6023
        break;
       }
      default:
       {
        if (!($1684 & 128)) {
         $1713 = HEAPU8[$1682 >> 0] | $1684 << 8; //@line 6034
         $1718 = ($1713 << 17 >> 16) + $$15872$i27 | 0; //@line 6040
         if (!(($1713 << 1 & 65535) << 16 >> 16)) {
          $$5$ph$i33 = 0; //@line 6042
          break L339;
         } else {
          $$051$off0$i30 = $1718; //@line 6045
          $$245$i31 = $$14475$i24 + 2 | 0; //@line 6045
          $$461$i29 = $1718; //@line 6045
          break L343;
         }
        } else {
         $1706 = $1684 << 1 & 254; //@line 6050
         $1708 = $1706 + $$15872$i27 | 0; //@line 6052
         if (!$1706) {
          $$5$ph$i33 = 0; //@line 6054
          break L339;
         } else {
          $$051$off0$i30 = $1708; //@line 6057
          $$245$i31 = $1682; //@line 6057
          $$461$i29 = $1708; //@line 6057
          break L343;
         }
        }
       }
      }
     } while (0);
     if ($$14974$i25 << 16 >> 16 == -22019) {
      $$5$ph$i33 = $$051$off0$i30; //@line 6066
      break L339;
     }
     $1721 = $$05673$i26 + 1 | 0; //@line 6070
     if (($1721 | 0) < 1024) {
      $$05673$i26 = $1721; //@line 6073
      $$14475$i24 = $$245$i31; //@line 6073
      $$14974$i25 = $$14974$i25 + 1 << 16 >> 16; //@line 6073
      $$15872$i27 = $$461$i29; //@line 6073
     } else {
      $$043$i22 = $$245$i31; //@line 6075
      $$048$i21 = -24576; //@line 6075
      $$057$i20 = $$461$i29; //@line 6075
      continue L339;
     }
    }
   }
   $1723 = $$5$ph$i33 + $1670 | 0; //@line 6080
   $1727 = (HEAP32[30897] | 0) + (HEAP32[28207] | 0) + 3328 | 0; //@line 6084
   $1729 = $1727 + 2 | 0; //@line 6086
   HEAP16[$1727 >> 1] = _htons(28971) | 0; //@line 6087
   $1731 = $1729 + 2 | 0; //@line 6089
   HEAP16[$1729 >> 1] = _htons(20217) | 0; //@line 6090
   HEAP16[$1731 >> 1] = _htons($1723 >>> 16 & 65535) | 0; //@line 6095
   HEAP16[$1731 + 2 >> 1] = _htons($1723 & 65535) | 0; //@line 6098
   $1738 = HEAP32[30896] | 0; //@line 6099
   $1739 = $1738 + 26 | 0; //@line 6100
   $1745 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1739 >>> 16 << 2) >> 2] >> 2] & 127]($1739) | 0) + $1738 | 0; //@line 6106
   $1750 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1745 >>> 16 << 2) >> 2] >> 2] & 127]($1745) | 0; //@line 6111
   HEAP32[28209] = $1750; //@line 6112
   $1753 = $1750; //@line 6113
   while (1) {
    $1752 = (HEAP32[30896] | 0) + $1753 | 0; //@line 6116
    $1754 = $1752 + 12 | 0; //@line 6117
    $1759 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1754 >>> 16 << 2) >> 2] >> 2] & 127]($1754) | 0; //@line 6122
    $1760 = $1752 + 16 | 0; //@line 6123
    $1765 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1760 >>> 16 << 2) >> 2] >> 2] & 127]($1760) | 0; //@line 6128
    $1766 = $1752 + 20 | 0; //@line 6129
    if (($1765 | 0) == 1346454347 & ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1766 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1766) | 0) & 65535 | 0) == 4) {
     break;
    }
    $1775 = $1752 + 8 | 0; //@line 6143
    $1753 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1775 >>> 16 << 2) >> 2] >> 2] & 127]($1775) | 0; //@line 6148
    HEAP32[28209] = $1753; //@line 6149
    if (!$1753) {
     $$0 = 0; //@line 6152
     label = 246; //@line 6153
     break;
    }
   }
   if ((label | 0) == 246) {
    STACKTOP = sp; //@line 6160
    return $$0 | 0; //@line 6160
   }
   if (!$1759) {
    $$0 = 0; //@line 6164
    STACKTOP = sp; //@line 6165
    return $$0 | 0; //@line 6165
   }
   $1783 = HEAP32[30896] | 0; //@line 6167
   $1784 = $1783 + 26 | 0; //@line 6168
   $1790 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1784 >>> 16 << 2) >> 2] >> 2] & 127]($1784) | 0) + $1783 | 0; //@line 6174
   FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1790 >>> 16 << 2) >> 2] >> 2] & 127]($1790) | 0; //@line 6179
   $1798 = (HEAP32[30896] | 0) + 8 + (HEAP32[28209] | 0) | 0; //@line 6183
   $1803 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1798 >>> 16 << 2) >> 2] >> 2] & 127]($1798) | 0; //@line 6188
   HEAP32[28209] = $1803; //@line 6189
   $1806 = $1803; //@line 6190
   while (1) {
    $1805 = (HEAP32[30896] | 0) + $1806 | 0; //@line 6193
    $1807 = $1805 + 12 | 0; //@line 6194
    $1812 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1807 >>> 16 << 2) >> 2] >> 2] & 127]($1807) | 0; //@line 6199
    $1813 = $1805 + 16 | 0; //@line 6200
    $1818 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1813 >>> 16 << 2) >> 2] >> 2] & 127]($1813) | 0; //@line 6205
    $1819 = $1805 + 20 | 0; //@line 6206
    if (($1818 | 0) == 1346454347 & ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1819 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1819) | 0) & 65535 | 0) == 4) {
     $$2$i41 = $1812; //@line 6218
     break;
    }
    $1828 = $1805 + 8 | 0; //@line 6221
    $1806 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1828 >>> 16 << 2) >> 2] >> 2] & 127]($1828) | 0; //@line 6226
    HEAP32[28209] = $1806; //@line 6227
    if (!$1806) {
     $$2$i41 = 0; //@line 6230
     break;
    }
   }
   if (!(HEAP32[30881] | $$2$i41)) {
    _puts(91982) | 0; //@line 6240
   }
   $1859 = HEAP32[30897] | 0; //@line 6242
   HEAP16[$1859 + 39876 >> 1] = _htons(28674) | 0; //@line 6246
   HEAP16[$1859 + 39878 >> 1] = _htons(20081) | 0; //@line 6249
   HEAP16[$1859 + 39880 >> 1] = _htons(20081) | 0; //@line 6252
   HEAP16[$1859 + 39882 >> 1] = _htons(20081) | 0; //@line 6255
   HEAP16[$1859 + 39884 >> 1] = _htons(20081) | 0; //@line 6257
   $1870 = HEAP32[30897] | 0; //@line 6258
   HEAP16[$1870 + 41622 >> 1] = _htons(20081) | 0; //@line 6262
   HEAP16[$1870 + 41624 >> 1] = _htons(20081) | 0; //@line 6265
   HEAP16[$1870 + 41626 >> 1] = _htons(28969) | 0; //@line 6268
   $$sink = _htons(19072) | 0; //@line 6271
   $$sink45$in = $1870 + 41628 | 0; //@line 6271
   $$sink46 = $1870 + 41630 | 0; //@line 6271
   break;
  }
 default:
  {
   $$0 = 0; //@line 6275
   STACKTOP = sp; //@line 6276
   return $$0 | 0; //@line 6276
  }
 }
 HEAP16[$$sink45$in >> 1] = $$sink; //@line 6279
 HEAP16[$$sink46 >> 1] = _htons(26612) | 0; //@line 6281
 $1881 = HEAP32[28204] | 0; //@line 6282
 if ($1881 | 0) {
  $1884 = (HEAP32[30897] | 0) + $1881 | 0; //@line 6286
  HEAP16[$1884 >> 1] = _htons(28929) | 0; //@line 6288
 }
 $$0 = 1; //@line 6290
 STACKTOP = sp; //@line 6291
 return $$0 | 0; //@line 6291
}
function _read_table68k() {
 var $$0$i607615$i = 0, $$0$i609643$i = 0, $$0$i611645$i = 0, $$0$i613$i = 0, $$0501795$i = 0, $$0502794$i = 0, $$0510$i = 0, $$0513$i = 0, $$0527618$ph$i = 0, $$0527618636$i = 0, $$0544$lcssa$i = 0, $$0544755$i = 0, $$0544755$i$us = 0, $$0547752$i = 0, $$0549$lcssa$i = 0, $$0549754$i = 0, $$0549754$i$us = 0, $$0551$lcssa$i = 0, $$0551753$i = 0, $$0551753$i$us = 0, $$0559751$i = 0, $$0561750$i = 0, $$0562749$i = 0, $$074 = 0, $$1$lcssa$i = 0, $$10$i = 0, $$10617$i = 0, $$10617$ph$i = 0, $$10617637$i = 0, $$10626$i = 0, $$11$i = 0, $$12774$i = 0, $$13$i = 0, $$14$i = 0, $$1504642$i = 0, $$1508$i = 0, $$1508621$i = 0, $$1508621$ph$i = 0, $$1508621633$i = 0, $$1508630$i = 0, $$1511$i = 0, $$1511$ph$i = 0, $$1514$i = 0, $$1514620$i = 0, $$1514620$ph$i = 0, $$1514620634$i = 0, $$1514629$i = 0, $$1517641$i = 0, $$1523$i = 0, $$1528$i = 0, $$1532640$i = 0, $$1539$i = 0, $$1545$i = 0, $$1545$i$us = 0, $$1548$i = 0, $$1550$i = 0, $$1550$i$us = 0, $$1552$i = 0, $$1552$i$us = 0, $$1560$i = 0, $$1566748$i = 0, $$1568$1$i = 0, $$1568$2$i = 0, $$1568$3$i = 0, $$1568$4$i = 0, $$1568$i = 0, $$1574$1$i = 0, $$1574$2$i = 0, $$1574$3$i = 0, $$1574$4$i = 0, $$1574$i = 0, $$15771$i = 0, $$16$i = 0, $$173 = 0, $$1756$i = 0, $$1756$i$us = 0, $$2$i = 0, $$2$i$us = 0, $$2505$i = 0, $$2505$ph$i = 0, $$2509$i = 0, $$2512$i = 0, $$2515$i = 0, $$2518$i = 0, $$2524$i = 0, $$2533$i = 0, $$2540$i = 0, $$2553$i = 0, $$2564$i = 0, $$2569780$i = 0, $$3$i = 0, $$3$i$us = 0, $$3506$i = 0, $$3519$i = 0, $$3525$i = 0, $$3525619$i = 0, $$3525619$ph$i = 0, $$3525619635$i = 0, $$3525628$i = 0, $$3534$i = 0, $$3541$i = 0, $$3554$i = 0, $$3570$i = 0, $$4520$i = 0, $$4520$ph$i = 0, $$4526$i = 0, $$4535$i = 0, $$4535$ph$i = 0, $$4542$i = 0, $$4542638$i = 0, $$4555768$i = 0, $$4777$i = 0, $$5$i = 0, $$5521$i = 0, $$5543$i = 0, $$5556$i = 0, $$5572$i = 0, $$6537$i = 0, $$6557$i = 0, $$7$i = 0, $$7558$i = 0, $$8765$i = 0, $$9$i = 0, $$hi = 0, $$hi13 = 0, $$hi18 = 0, $$hi24 = 0, $$hi30 = 0, $$hi38 = 0, $$hi8 = 0, $$sink$i = 0, $$sink$i$us = 0, $$sink104$i = 0, $$sink598$i = 0, $$sink602$i = 0, $$sink656$i = 0, $0 = 0, $1 = 0, $10 = 0, $101 = 0, $104 = 0, $11 = 0, $110 = 0, $112 = 0, $114 = 0, $117 = 0, $12 = 0, $121 = 0, $127 = 0, $128 = 0, $13 = 0, $131 = 0, $135 = 0, $138 = 0, $14 = 0, $140 = 0, $144 = 0, $149 = 0, $15 = 0, $153 = 0, $157 = 0, $16 = 0, $160 = 0, $163 = 0, $169 = 0, $17 = 0, $170 = 0, $173 = 0, $174 = 0, $18 = 0, $182 = 0, $187 = 0, $189 = 0, $19 = 0, $195 = 0, $2 = 0, $20 = 0, $21 = 0, $212 = 0, $213 = 0, $218 = 0, $219 = 0, $22 = 0, $226 = 0, $23 = 0, $234 = 0, $236 = 0, $24 = 0, $244 = 0, $25 = 0, $251 = 0, $252 = 0, $253 = 0, $258 = 0, $259 = 0, $26 = 0, $266 = 0, $27 = 0, $274 = 0, $276 = 0, $28 = 0, $284 = 0, $29 = 0, $291 = 0, $295 = 0, $3 = 0, $30 = 0, $300 = 0, $31 = 0, $310 = 0, $312 = 0, $319 = 0, $32 = 0, $33 = 0, $332 = 0, $333 = 0, $338 = 0, $339 = 0, $34 = 0, $35 = 0, $353 = 0, $355 = 0, $36 = 0, $362 = 0, $37 = 0, $370 = 0, $371 = 0, $376 = 0, $377 = 0, $38 = 0, $39 = 0, $391 = 0, $393 = 0, $4 = 0, $40 = 0, $400 = 0, $409 = 0, $41 = 0, $411 = 0, $412 = 0, $418 = 0, $42 = 0, $421 = 0, $423 = 0, $428 = 0, $43 = 0, $430 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $439 = 0, $44 = 0, $45 = 0, $452 = 0, $453 = 0, $46 = 0, $463 = 0, $467 = 0, $468 = 0, $47 = 0, $470 = 0, $471 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $488 = 0, $49 = 0, $498 = 0, $5 = 0, $50 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $51 = 0, $52 = 0, $521 = 0, $522 = 0, $523 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $63 = 0, $64 = 0, $65 = 0, $67 = 0, $68 = 0, $71 = 0, $74 = 0, $75 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $90 = 0, $91 = 0, $94 = 0, $trunc594$1$i = 0, $trunc594$2$i = 0, $trunc594$3$i = 0, $trunc594$4$i = 0, $trunc594$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 52818
 STACKTOP = STACKTOP + 384 | 0; //@line 52819
 $vararg_buffer1 = sp + 8 | 0; //@line 52820
 $vararg_buffer = sp; //@line 52821
 $0 = sp + 256 | 0; //@line 52822
 $1 = sp + 176 | 0; //@line 52823
 $2 = sp + 96 | 0; //@line 52824
 $3 = sp + 16 | 0; //@line 52825
 $4 = sp + 320 | 0; //@line 52826
 $5 = _malloc(1048576) | 0; //@line 52827
 HEAP32[162823] = $5; //@line 52828
 $$074 = 0; //@line 52829
 do {
  $53 = $5 + ($$074 << 4) + 9 | 0; //@line 52831
  $$hi = $53 + 4 | 0; //@line 52833
  $54 = (HEAPU8[$53 >> 0] | HEAPU8[$53 + 1 >> 0] << 8 | HEAPU8[$53 + 2 >> 0] << 16 | HEAPU8[$53 + 3 >> 0] << 24) & -16711681; //@line 52841
  $55 = ((HEAPU8[$$hi >> 0] | HEAPU8[$$hi + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi + 2 >> 0] << 16) & 16777215; //@line 52842
  HEAP8[$53 >> 0] = $54; //@line 52843
  HEAP8[$53 + 1 >> 0] = $54 >> 8; //@line 52843
  HEAP8[$53 + 2 >> 0] = $54 >> 16; //@line 52843
  HEAP8[$53 + 3 >> 0] = $54 >> 24; //@line 52843
  $$hi8 = $53 + 4 | 0; //@line 52844
  $56 = $55 & 65535; //@line 52845
  HEAP8[$$hi8 >> 0] = $56; //@line 52846
  HEAP8[$$hi8 + 1 >> 0] = $56 >> 8; //@line 52846
  $57 = _bitshift64Lshr($55 | 0, 0, 16) | 0; //@line 52847
  HEAP8[$$hi8 + 2 >> 0] = $57; //@line 52851
  HEAP32[$5 + ($$074 << 4) >> 2] = -1; //@line 52853
  $$074 = $$074 + 1 | 0; //@line 52854
 } while (($$074 | 0) != 65536);
 $6 = HEAP32[21986] | 0; //@line 52862
 if (($6 | 0) <= 0) {
  STACKTOP = sp; //@line 52865
  return;
 }
 $8 = $0 + 56 | 0; //@line 52867
 $9 = $0 + 36 | 0; //@line 52868
 $10 = $0 + 40 | 0; //@line 52869
 $11 = $0 + 44 | 0; //@line 52870
 $12 = $0 + 48 | 0; //@line 52871
 $13 = $0 + 52 | 0; //@line 52872
 $14 = $0 + 60 | 0; //@line 52873
 $15 = $0 + 4 | 0; //@line 52874
 $16 = $0 + 24 | 0; //@line 52875
 $17 = $2 + 28 | 0; //@line 52876
 $18 = $2 + 68 | 0; //@line 52877
 $19 = $2 + 12 | 0; //@line 52878
 $20 = $1 + 24 | 0; //@line 52879
 $21 = $1 + 72 | 0; //@line 52880
 $22 = $1 + 12 | 0; //@line 52881
 $23 = $2 + 8 | 0; //@line 52882
 $24 = $0 + 32 | 0; //@line 52883
 $25 = $0 + 28 | 0; //@line 52884
 $26 = HEAP32[22038] | 0; //@line 52885
 $27 = $2 + 60 | 0; //@line 52886
 $28 = $3 + 60 | 0; //@line 52887
 $29 = $2 + 64 | 0; //@line 52888
 $30 = $3 + 64 | 0; //@line 52889
 $31 = $2 + 20 | 0; //@line 52890
 $32 = $2 + 32 | 0; //@line 52891
 $33 = $2 + 36 | 0; //@line 52892
 $34 = $2 + 40 | 0; //@line 52893
 $35 = $2 + 56 | 0; //@line 52894
 $36 = $2 + 52 | 0; //@line 52895
 $37 = $3 + 56 | 0; //@line 52896
 $38 = $2 + 48 | 0; //@line 52897
 $39 = $2 + 44 | 0; //@line 52898
 $40 = $3 + 48 | 0; //@line 52899
 $41 = $3 + 20 | 0; //@line 52900
 $42 = $3 + 28 | 0; //@line 52901
 $43 = $3 + 32 | 0; //@line 52902
 $44 = $3 + 36 | 0; //@line 52903
 $45 = $3 + 40 | 0; //@line 52904
 $46 = $2 + 72 | 0; //@line 52905
 $47 = $3 + 72 | 0; //@line 52906
 $48 = $2 + 76 | 0; //@line 52907
 $49 = $3 + 76 | 0; //@line 52908
 $50 = $2 + 16 | 0; //@line 52909
 $51 = $2 + 24 | 0; //@line 52910
 $52 = $3 + 24 | 0; //@line 52911
 $$173 = 0; //@line 52912
 $522 = $6; //@line 52912
 L7 : while (1) {
  dest = $0; //@line 52915
  src = 76360 + ($$173 << 6) | 0; //@line 52915
  stop = dest + 64 | 0; //@line 52915
  do {
   HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 52915
   dest = dest + 4 | 0; //@line 52915
   src = src + 4 | 0; //@line 52915
  } while ((dest | 0) < (stop | 0));
  $63 = HEAP8[$8 >> 0] | 0; //@line 52916
  $trunc594$i = HEAP8[$9 >> 0] | 0; //@line 52917
  switch (($trunc594$i & 255) >>> 3 & 7) {
  case 6:
  case 1:
   {
    $$1574$i = 0; //@line 52922
    break;
   }
  default:
   {
    $$1574$i = 16; //@line 52926
   }
  }
  switch ($trunc594$i & 7) {
  case 4:
  case 1:
   {
    $$1568$i = 0; //@line 52932
    break;
   }
  default:
   {
    $$1568$i = 16; //@line 52936
   }
  }
  $trunc594$1$i = HEAP8[$10 >> 0] | 0; //@line 52939
  switch (($trunc594$1$i & 255) >>> 3 & 7) {
  case 6:
  case 1:
   {
    $$1574$1$i = $$1574$i; //@line 52944
    break;
   }
  default:
   {
    $$1574$1$i = $$1574$i | 8; //@line 52949
   }
  }
  switch ($trunc594$1$i & 7) {
  case 4:
  case 1:
   {
    $$1568$1$i = $$1568$i; //@line 52955
    break;
   }
  default:
   {
    $$1568$1$i = $$1568$i | 8; //@line 52960
   }
  }
  $trunc594$2$i = HEAP8[$11 >> 0] | 0; //@line 52963
  switch (($trunc594$2$i & 255) >>> 3 & 7) {
  case 6:
  case 1:
   {
    $$1574$2$i = $$1574$1$i; //@line 52968
    break;
   }
  default:
   {
    $$1574$2$i = $$1574$1$i | 4; //@line 52973
   }
  }
  switch ($trunc594$2$i & 7) {
  case 4:
  case 1:
   {
    $$1568$2$i = $$1568$1$i; //@line 52979
    break;
   }
  default:
   {
    $$1568$2$i = $$1568$1$i | 4; //@line 52984
   }
  }
  $trunc594$3$i = HEAP8[$12 >> 0] | 0; //@line 52987
  switch (($trunc594$3$i & 255) >>> 3 & 7) {
  case 6:
  case 1:
   {
    $$1574$3$i = $$1574$2$i; //@line 52992
    break;
   }
  default:
   {
    $$1574$3$i = $$1574$2$i | 2; //@line 52997
   }
  }
  switch ($trunc594$3$i & 7) {
  case 4:
  case 1:
   {
    $$1568$3$i = $$1568$2$i; //@line 53003
    break;
   }
  default:
   {
    $$1568$3$i = $$1568$2$i | 2; //@line 53008
   }
  }
  $trunc594$4$i = HEAP8[$13 >> 0] | 0; //@line 53011
  switch (($trunc594$4$i & 255) >>> 3 & 7) {
  case 6:
  case 1:
   {
    $$1574$4$i = $$1574$3$i; //@line 53016
    break;
   }
  default:
   {
    $$1574$4$i = $$1574$3$i | 1; //@line 53021
   }
  }
  switch ($trunc594$4$i & 7) {
  case 4:
  case 1:
   {
    $$1568$4$i = $$1568$3$i; //@line 53027
    break;
   }
  default:
   {
    $$1568$4$i = $$1568$3$i | 1; //@line 53032
   }
  }
  $128 = HEAP32[$14 >> 2] | 0; //@line 53035
  $65 = HEAP32[$15 >> 2] | 0; //@line 53036
  if (($65 | 0) == 31) {
   $521 = $522; //@line 53039
  } else {
   $64 = 1 << $65; //@line 53041
   $67 = HEAP32[$0 >> 2] & 65535; //@line 53043
   $68 = HEAP32[$16 >> 2] | 0; //@line 53044
   $71 = HEAP32[$24 >> 2] << 28 & 805306368; //@line 53047
   $74 = _bitshift64Shl(HEAP32[$25 >> 2] & 7 | 0, 0, 48) | 0; //@line 53050
   $75 = tempRet0; //@line 53051
   $79 = _bitshift64Shl($63 & 7 | 0, 0, 51) | 0; //@line 53055
   $80 = tempRet0; //@line 53056
   $81 = $$1574$4$i & 255 | $79; //@line 53057
   $82 = $64 & 65535; //@line 53058
   $83 = $74 | $71; //@line 53059
   $$0501795$i = -1; //@line 53060
   $$0502794$i = 0; //@line 53060
   $$2569780$i = $$1568$4$i; //@line 53060
   while (1) {
    dest = $2; //@line 53062
    stop = dest + 80 | 0; //@line 53062
    do {
     HEAP32[dest >> 2] = 0; //@line 53062
     dest = dest + 4 | 0; //@line 53062
    } while ((dest | 0) < (stop | 0));
    dest = $1; //@line 53063
    stop = dest + 80 | 0; //@line 53063
    do {
     HEAP32[dest >> 2] = 0; //@line 53063
     dest = dest + 4 | 0; //@line 53063
    } while ((dest | 0) < (stop | 0));
    $$0547752$i = 0; //@line 53064
    $$0559751$i = $82; //@line 53064
    $$0561750$i = 32768; //@line 53064
    $$0562749$i = $67; //@line 53064
    $$1566748$i = 0; //@line 53064
    while (1) {
     $84 = $$0561750$i & 65535; //@line 53066
     if (!($84 & $68)) {
      $90 = HEAP8[$0 + 8 + $$0547752$i >> 0] | 0; //@line 53073
      $91 = ($$0559751$i & 65535) >>> 1; //@line 53074
      $94 = ($91 & 65535 & $$0502794$i | 0) != 0; //@line 53077
      HEAP32[$3 + ($90 << 2) >> 2] = 15 - $$1566748$i; //@line 53085
      $101 = $1 + ($90 << 2) | 0; //@line 53086
      HEAP32[$101 >> 2] = (HEAP32[$101 >> 2] | 0) + 1; //@line 53089
      $104 = $2 + ($90 << 2) | 0; //@line 53090
      HEAP32[$104 >> 2] = HEAP32[$104 >> 2] << 1 | $94 & 1; //@line 53094
      $$1548$i = $$0547752$i + 1 | 0; //@line 53095
      $$1560$i = $91; //@line 53095
      $$2564$i = $94 ? ($$0562749$i & 65535 | $$0561750$i) & 65535 : $$0562749$i; //@line 53095
     } else {
      $$1548$i = $$0547752$i; //@line 53097
      $$1560$i = $$0559751$i; //@line 53097
      $$2564$i = $$0562749$i; //@line 53097
     }
     $$1566748$i = $$1566748$i + 1 | 0; //@line 53099
     if (($$1566748$i | 0) == 16) {
      break;
     } else {
      $$0547752$i = $$1548$i; //@line 53105
      $$0559751$i = $$1560$i; //@line 53105
      $$0561750$i = $84 >>> 1; //@line 53105
      $$0562749$i = $$2564$i; //@line 53105
     }
    }
    $110 = HEAP32[$17 >> 2] | 0; //@line 53108
    if (!$110) {
     HEAP32[$17 >> 2] = 8; //@line 53111
     $523 = 8; //@line 53112
    } else {
     $523 = $110; //@line 53114
    }
    $112 = HEAP32[$18 >> 2] | 0; //@line 53116
    $114 = HEAP32[$19 >> 2] | 0; //@line 53118
    L52 : do {
     if (($112 | 0) == 3 | ($114 | 0) == 1) {
      $$5572$i = $$2569780$i; //@line 53123
      $$7$i = $$0501795$i; //@line 53123
     } else {
      $117 = (HEAP32[$20 >> 2] | 0) == 0; //@line 53126
      if (!$117) {
       switch (HEAP32[$51 >> 2] | 0) {
       case 255:
       case 0:
        {
         $$5572$i = $$2569780$i; //@line 53131
         $$7$i = $$0501795$i; //@line 53131
         break L52;
         break;
        }
       default:
        {}
       }
      }
      $121 = HEAP32[$46 >> 2] | 0; //@line 53141
      if ((HEAP32[$21 >> 2] | 0) != 0 & ($121 | 0) == 0) {
       $$5572$i = $$2569780$i; //@line 53145
       $$7$i = $$0501795$i; //@line 53145
      } else {
       if (!$117) {
        HEAP32[$31 >> 2] = HEAP32[$51 >> 2]; //@line 53149
        HEAP32[$41 >> 2] = HEAP32[$52 >> 2]; //@line 53151
       }
       if (HEAP32[$22 >> 2] | 0) {
        HEAP32[$23 >> 2] = $114; //@line 53156
       }
       $127 = HEAP8[$128 >> 0] | 0; //@line 53158
       L64 : do {
        if (!($127 << 24 >> 24)) {
         $$0544$lcssa$i = 2; //@line 53162
         $$0549$lcssa$i = 0; //@line 53162
         $$0551$lcssa$i = 0; //@line 53162
         $$1$lcssa$i = $$0501795$i; //@line 53162
        } else {
         if ($112 >>> 0 < 3) {
          $$0544755$i$us = 2; //@line 53166
          $$0549754$i$us = 0; //@line 53166
          $$0551753$i$us = 0; //@line 53166
          $$1756$i$us = $$0501795$i; //@line 53166
          $131 = $127; //@line 53166
         } else {
          $$0544755$i = 2; //@line 53168
          $$0549754$i = 0; //@line 53168
          $$0551753$i = 0; //@line 53168
          $$1756$i = $$0501795$i; //@line 53168
          $149 = $127; //@line 53168
          while (1) {
           if (_isspace($149 << 24 >> 24) | 0) {
            $$0544$lcssa$i = $$0544755$i; //@line 53174
            $$0549$lcssa$i = $$0549754$i; //@line 53174
            $$0551$lcssa$i = $$0551753$i; //@line 53174
            $$1$lcssa$i = $$1756$i; //@line 53174
            break L64;
           }
           L70 : do {
            if ($149 << 24 >> 24 == 46) {
             $153 = $$0551753$i + 1 | 0; //@line 53180
             switch (HEAP8[$128 + $153 >> 0] | 0) {
             case 122:
              {
               label = 44; //@line 53186
               break L7;
               break;
              }
             case 66:
              {
               $$1545$i = 0; //@line 53191
               $$1550$i = $$0549754$i; //@line 53191
               $$1552$i = $153; //@line 53191
               $$3$i = $$1756$i; //@line 53191
               break L70;
               break;
              }
             case 87:
              {
               $$1545$i = 1; //@line 53196
               $$1550$i = $$0549754$i; //@line 53196
               $$1552$i = $153; //@line 53196
               $$3$i = $$1756$i; //@line 53196
               break L70;
               break;
              }
             case 76:
              {
               $$1545$i = 2; //@line 53201
               $$1550$i = $$0549754$i; //@line 53201
               $$1552$i = $153; //@line 53201
               $$3$i = $$1756$i; //@line 53201
               break L70;
               break;
              }
             default:
              {
               label = 45; //@line 53206
               break L7;
              }
             }
            } else {
             $157 = $4 + $$0549754$i | 0; //@line 53211
             HEAP8[$157 >> 0] = $149; //@line 53212
             if ($149 << 24 >> 24 == 102) {
              switch (HEAP32[$50 >> 2] | 0) {
              case 0:
               {
                $$sink$i = 82; //@line 53218
                break;
               }
              case 1:
               {
                $$sink$i = 76; //@line 53222
                break;
               }
              default:
               {
                label = 49; //@line 53226
                break L7;
               }
              }
              HEAP8[$157 >> 0] = $$sink$i; //@line 53230
              $$2$i = -1; //@line 53231
             } else {
              $$2$i = $$1756$i; //@line 53233
             }
             $160 = $$0549754$i + 1 | 0; //@line 53235
             if ($160 >>> 0 > 62) {
              label = 52; //@line 53238
              break L7;
             } else {
              $$1545$i = $$0544755$i; //@line 53241
              $$1550$i = $160; //@line 53241
              $$1552$i = $$0551753$i; //@line 53241
              $$3$i = $$2$i; //@line 53241
             }
            }
           } while (0);
           $163 = $$1552$i + 1 | 0; //@line 53245
           $149 = HEAP8[$128 + $163 >> 0] | 0; //@line 53247
           if (!($149 << 24 >> 24)) {
            $$0544$lcssa$i = $$1545$i; //@line 53250
            $$0549$lcssa$i = $$1550$i; //@line 53250
            $$0551$lcssa$i = $163; //@line 53250
            $$1$lcssa$i = $$3$i; //@line 53250
            break L64;
           } else {
            $$0544755$i = $$1545$i; //@line 53253
            $$0549754$i = $$1550$i; //@line 53253
            $$0551753$i = $163; //@line 53253
            $$1756$i = $$3$i; //@line 53253
           }
          }
         }
         while (1) {
          if (_isspace($131 << 24 >> 24) | 0) {
           $$0544$lcssa$i = $$0544755$i$us; //@line 53262
           $$0549$lcssa$i = $$0549754$i$us; //@line 53262
           $$0551$lcssa$i = $$0551753$i$us; //@line 53262
           $$1$lcssa$i = $$1756$i$us; //@line 53262
           break L64;
          }
          L86 : do {
           if ($131 << 24 >> 24 == 46) {
            $140 = $$0551753$i$us + 1 | 0; //@line 53268
            switch (HEAP8[$128 + $140 >> 0] | 0) {
            case 66:
             {
              $$1545$i$us = 0; //@line 53274
              $$1550$i$us = $$0549754$i$us; //@line 53274
              $$1552$i$us = $140; //@line 53274
              $$3$i$us = $$1756$i$us; //@line 53274
              break L86;
              break;
             }
            case 87:
             {
              $$1545$i$us = 1; //@line 53279
              $$1550$i$us = $$0549754$i$us; //@line 53279
              $$1552$i$us = $140; //@line 53279
              $$3$i$us = $$1756$i$us; //@line 53279
              break L86;
              break;
             }
            case 76:
             {
              $$1545$i$us = 2; //@line 53284
              $$1550$i$us = $$0549754$i$us; //@line 53284
              $$1552$i$us = $140; //@line 53284
              $$3$i$us = $$1756$i$us; //@line 53284
              break L86;
              break;
             }
            case 122:
             {
              $$1545$i$us = $112; //@line 53289
              $$1550$i$us = $$0549754$i$us; //@line 53289
              $$1552$i$us = $140; //@line 53289
              $$3$i$us = $$1756$i$us; //@line 53289
              break L86;
              break;
             }
            default:
             {
              label = 45; //@line 53294
              break L7;
             }
            }
           } else {
            $135 = $4 + $$0549754$i$us | 0; //@line 53299
            HEAP8[$135 >> 0] = $131; //@line 53300
            if ($131 << 24 >> 24 == 102) {
             switch (HEAP32[$50 >> 2] | 0) {
             case 0:
              {
               $$sink$i$us = 82; //@line 53306
               break;
              }
             case 1:
              {
               $$sink$i$us = 76; //@line 53310
               break;
              }
             default:
              {
               label = 49; //@line 53314
               break L7;
              }
             }
             HEAP8[$135 >> 0] = $$sink$i$us; //@line 53318
             $$2$i$us = -1; //@line 53319
            } else {
             $$2$i$us = $$1756$i$us; //@line 53321
            }
            $138 = $$0549754$i$us + 1 | 0; //@line 53323
            if ($138 >>> 0 > 62) {
             label = 52; //@line 53326
             break L7;
            } else {
             $$1545$i$us = $$0544755$i$us; //@line 53329
             $$1550$i$us = $138; //@line 53329
             $$1552$i$us = $$0551753$i$us; //@line 53329
             $$3$i$us = $$2$i$us; //@line 53329
            }
           }
          } while (0);
          $144 = $$1552$i$us + 1 | 0; //@line 53333
          $131 = HEAP8[$128 + $144 >> 0] | 0; //@line 53335
          if (!($131 << 24 >> 24)) {
           $$0544$lcssa$i = $$1545$i$us; //@line 53338
           $$0549$lcssa$i = $$1550$i$us; //@line 53338
           $$0551$lcssa$i = $144; //@line 53338
           $$1$lcssa$i = $$3$i$us; //@line 53338
           break;
          } else {
           $$0544755$i$us = $$1545$i$us; //@line 53341
           $$0549754$i$us = $$1550$i$us; //@line 53341
           $$0551753$i$us = $144; //@line 53341
           $$1756$i$us = $$3$i$us; //@line 53341
          }
         }
        }
       } while (0);
       HEAP8[$4 + $$0549$lcssa$i >> 0] = 0; //@line 53347
       $$2553$i = $$0551$lcssa$i; //@line 53348
       while (1) {
        $169 = HEAP8[$128 + $$2553$i >> 0] | 0; //@line 53351
        $170 = $169 << 24 >> 24; //@line 53352
        if (!($169 << 24 >> 24)) {
         $$1528$i = 0; //@line 53355
         $$2509$i = -1; //@line 53355
         $$2512$i = 16; //@line 53355
         $$2515$i = 16; //@line 53355
         $$3506$i = -1; //@line 53355
         $$4526$i = -1; //@line 53355
         $$5521$i = -1; //@line 53355
         $$5543$i = 0; //@line 53355
         $$6537$i = 0; //@line 53355
         $467 = 0; //@line 53355
         $468 = 0; //@line 53355
         $470 = 0; //@line 53355
         $471 = 0; //@line 53355
         break;
        }
        $173 = $$2553$i + 1 | 0; //@line 53360
        if (!(_isspace($170) | 0)) {
         label = 57; //@line 53362
         break;
        } else {
         $$2553$i = $173; //@line 53365
        }
       }
       do {
        if ((label | 0) == 57) {
         label = 0; //@line 53370
         L106 : do {
          switch ($170 | 0) {
          case 68:
           {
            $174 = $$2553$i + 2 | 0; //@line 53374
            switch (HEAP8[$128 + $173 >> 0] | 0) {
            case 114:
             {
              $$0527618$ph$i = 0; //@line 53382
              $$10617$ph$i = $174; //@line 53382
              $$1508621$ph$i = HEAP32[$27 >> 2] | 0; //@line 53382
              $$1514620$ph$i = 0; //@line 53382
              $$3525619$ph$i = HEAP32[$28 >> 2] | 0; //@line 53382
              label = 124; //@line 53383
              break L106;
              break;
             }
            case 82:
             {
              $$0527618$ph$i = 0; //@line 53390
              $$10617$ph$i = $174; //@line 53390
              $$1508621$ph$i = HEAP32[$29 >> 2] | 0; //@line 53390
              $$1514620$ph$i = 0; //@line 53390
              $$3525619$ph$i = HEAP32[$30 >> 2] | 0; //@line 53390
              label = 124; //@line 53391
              break L106;
              break;
             }
            default:
             {
              label = 61; //@line 53396
              break L7;
             }
            }
            break;
           }
          case 65:
           {
            $182 = $$2553$i + 2 | 0; //@line 53403
            switch (HEAP8[$128 + $173 >> 0] | 0) {
            case 114:
             {
              $$sink598$i = 15; //@line 53409
              break;
             }
            case 82:
             {
              $$sink598$i = 16; //@line 53413
              break;
             }
            default:
             {
              label = 64; //@line 53417
              break L7;
             }
            }
            $187 = HEAP32[$2 + ($$sink598$i << 2) >> 2] | 0; //@line 53422
            $189 = HEAP32[$3 + ($$sink598$i << 2) >> 2] | 0; //@line 53424
            switch (HEAP8[$128 + $182 >> 0] | 0) {
            case 112:
             {
              $$0527618$ph$i = 0; //@line 53431
              $$10617$ph$i = $$2553$i + 3 | 0; //@line 53431
              $$1508621$ph$i = $187; //@line 53431
              $$1514620$ph$i = 4; //@line 53431
              $$3525619$ph$i = $189; //@line 53431
              label = 124; //@line 53432
              break L106;
              break;
             }
            case 80:
             {
              $$0527618$ph$i = 0; //@line 53438
              $$10617$ph$i = $$2553$i + 3 | 0; //@line 53438
              $$1508621$ph$i = $187; //@line 53438
              $$1514620$ph$i = 3; //@line 53438
              $$3525619$ph$i = $189; //@line 53438
              label = 124; //@line 53439
              break L106;
              break;
             }
            default:
             {
              $$10617$i = $182; //@line 53444
              $$1508621$i = $187; //@line 53444
              $$1514620$i = 1; //@line 53444
              $$3525619$i = $189; //@line 53444
              $$4542$i = 1; //@line 53444
              label = 125; //@line 53445
              break L106;
             }
            }
            break;
           }
          case 76:
           {
            $$10626$i = $173; //@line 53452
            $$1508630$i = -1; //@line 53452
            $$1514629$i = 8; //@line 53452
            $$3525628$i = -1; //@line 53452
            label = 123; //@line 53453
            break;
           }
          case 35:
           {
            $195 = $$2553$i + 2 | 0; //@line 53457
            do {
             switch (HEAP8[$128 + $173 >> 0] | 0) {
             case 122:
              {
               $$10626$i = $195; //@line 53464
               $$1508630$i = -1; //@line 53464
               $$1514629$i = 11; //@line 53464
               $$3525628$i = -1; //@line 53464
               label = 123; //@line 53465
               break L106;
               break;
              }
             case 48:
              {
               $$10626$i = $195; //@line 53470
               $$1508630$i = -1; //@line 53470
               $$1514629$i = 12; //@line 53470
               $$3525628$i = -1; //@line 53470
               label = 123; //@line 53471
               break L106;
               break;
              }
             case 49:
              {
               $$10626$i = $195; //@line 53476
               $$1508630$i = -1; //@line 53476
               $$1514629$i = 13; //@line 53476
               $$3525628$i = -1; //@line 53476
               label = 123; //@line 53477
               break L106;
               break;
              }
             case 50:
              {
               $$10626$i = $195; //@line 53482
               $$1508630$i = -1; //@line 53482
               $$1514629$i = 14; //@line 53482
               $$3525628$i = -1; //@line 53482
               label = 123; //@line 53483
               break L106;
               break;
              }
             case 105:
              {
               $$0527618$ph$i = 1; //@line 53492
               $$10617$ph$i = $195; //@line 53492
               $$1508621$ph$i = HEAP32[$31 >> 2] << 24 >> 24; //@line 53492
               $$1514620$ph$i = 15; //@line 53492
               $$3525619$ph$i = HEAP32[$41 >> 2] | 0; //@line 53492
               label = 124; //@line 53493
               break L106;
               break;
              }
             case 106:
              {
               $$0527618$ph$i = 3; //@line 53499
               $$10617$ph$i = $195; //@line 53499
               $$1508621$ph$i = $523; //@line 53499
               $$1514620$ph$i = 15; //@line 53499
               $$3525619$ph$i = HEAP32[$42 >> 2] | 0; //@line 53499
               label = 124; //@line 53500
               break L106;
               break;
              }
             case 74:
              {
               $$0527618$ph$i = 2; //@line 53507
               $$10617$ph$i = $195; //@line 53507
               $$1508621$ph$i = HEAP32[$32 >> 2] | 0; //@line 53507
               $$1514620$ph$i = 15; //@line 53507
               $$3525619$ph$i = HEAP32[$43 >> 2] | 0; //@line 53507
               label = 124; //@line 53508
               break L106;
               break;
              }
             case 107:
              {
               $$0527618$ph$i = 4; //@line 53515
               $$10617$ph$i = $195; //@line 53515
               $$1508621$ph$i = HEAP32[$33 >> 2] | 0; //@line 53515
               $$1514620$ph$i = 15; //@line 53515
               $$3525619$ph$i = HEAP32[$44 >> 2] | 0; //@line 53515
               label = 124; //@line 53516
               break L106;
               break;
              }
             case 75:
              {
               $$0527618$ph$i = 5; //@line 53523
               $$10617$ph$i = $195; //@line 53523
               $$1508621$ph$i = HEAP32[$34 >> 2] | 0; //@line 53523
               $$1514620$ph$i = 15; //@line 53523
               $$3525619$ph$i = HEAP32[$45 >> 2] | 0; //@line 53523
               label = 124; //@line 53524
               break L106;
               break;
              }
             case 69:
              {
               $$0527618$ph$i = 6; //@line 53530
               $$10617$ph$i = $195; //@line 53530
               $$1508621$ph$i = $121; //@line 53530
               $$1514620$ph$i = 15; //@line 53530
               $$3525619$ph$i = HEAP32[$47 >> 2] | 0; //@line 53530
               label = 124; //@line 53531
               break L106;
               break;
              }
             case 112:
              {
               $$0527618$ph$i = 7; //@line 53538
               $$10617$ph$i = $195; //@line 53538
               $$1508621$ph$i = HEAP32[$48 >> 2] | 0; //@line 53538
               $$1514620$ph$i = 15; //@line 53538
               $$3525619$ph$i = HEAP32[$49 >> 2] | 0; //@line 53538
               label = 124; //@line 53539
               break L106;
               break;
              }
             default:
              {
               label = 79; //@line 53544
               break L7;
              }
             }
            } while (0);
            break;
           }
          case 100:
           {
            $212 = HEAP32[$35 >> 2] | 0; //@line 53552
            $213 = HEAP32[$36 >> 2] | 0; //@line 53553
            L131 : do {
             switch ($213 | 0) {
             case 7:
              {
               switch ($212 | 0) {
               case 7:
               case 6:
               case 5:
                {
                 $$5572$i = $$2569780$i; //@line 53559
                 $$7$i = $$1$lcssa$i; //@line 53559
                 break L52;
                 break;
                }
               case 0:
                {
                 $$0$i613$i = 7; //@line 53564
                 $$1523$i = -1; //@line 53564
                 $$1539$i = 0; //@line 53564
                 break L131;
                 break;
                }
               case 1:
                {
                 $$0$i613$i = 8; //@line 53569
                 $$1523$i = -1; //@line 53569
                 $$1539$i = 0; //@line 53569
                 break L131;
                 break;
                }
               case 2:
                {
                 $$0$i613$i = 9; //@line 53574
                 $$1523$i = -1; //@line 53574
                 $$1539$i = 0; //@line 53574
                 break L131;
                 break;
                }
               case 3:
                {
                 $$0$i613$i = 10; //@line 53579
                 $$1523$i = -1; //@line 53579
                 $$1539$i = 0; //@line 53579
                 break L131;
                 break;
                }
               case 4:
                {
                 $$0$i613$i = 11; //@line 53584
                 $$1523$i = -1; //@line 53584
                 $$1539$i = 0; //@line 53584
                 break L131;
                 break;
                }
               default:
                {
                 label = 86; //@line 53589
                 break L7;
                }
               }
               break;
              }
             case 1:
             case 2:
             case 3:
             case 4:
             case 5:
             case 6:
             case 0:
              {
               $$0$i613$i = $213; //@line 53597
               $$1523$i = HEAP32[$37 >> 2] | 0; //@line 53597
               $$1539$i = 1; //@line 53597
               break;
              }
             default:
              {
               label = 86; //@line 53601
               break L7;
              }
             }
            } while (0);
            do {
             if ((HEAP8[$128 + $173 >> 0] | 0) == 91) {
              $218 = $$2553$i + 2 | 0; //@line 53611
              $219 = $128 + $218 | 0; //@line 53612
              if ((HEAP8[$219 >> 0] | 0) == 33) {
               $$3554$i = $218; //@line 53616
               while (1) {
                if ((__ZL13mode_from_strPKc($128 + ($$3554$i + 1) | 0) | 0) == ($$0$i613$i | 0)) {
                 $$5572$i = $$2569780$i; //@line 53623
                 $$7$i = $$1$lcssa$i; //@line 53623
                 break L52;
                }
                $226 = $$3554$i + 5 | 0; //@line 53626
                if ((HEAP8[$128 + $226 >> 0] | 0) == 44) {
                 $$3554$i = $226; //@line 53631
                } else {
                 break;
                }
               }
               $$0513$i = $$0$i613$i; //@line 53637
               $$6557$i = $$3554$i + 6 | 0; //@line 53637
               break;
              }
              $234 = (HEAP8[$128 + ($$2553$i + 6) >> 0] | 0) == 45; //@line 53643
              $236 = (__ZL13mode_from_strPKc($219) | 0) == ($$0$i613$i | 0); //@line 53645
              if ($234) {
               if (!$236) {
                $$5572$i = $$2569780$i; //@line 53648
                $$7$i = $$1$lcssa$i; //@line 53648
                break L52;
               }
               $$0513$i = __ZL13mode_from_strPKc($219 + 5 | 0) | 0; //@line 53654
               $$6557$i = $$2553$i + 12 | 0; //@line 53654
               break;
              }
              if ($236) {
               $$5556$i = $218; //@line 53658
              } else {
               $$4555768$i = $218; //@line 53660
               while (1) {
                if ((HEAP8[$128 + ($$4555768$i + 4) >> 0] | 0) == 93) {
                 $$5572$i = $$2569780$i; //@line 53667
                 $$7$i = $$1$lcssa$i; //@line 53667
                 break L52;
                }
                $244 = $$4555768$i + 5 | 0; //@line 53670
                if ((__ZL13mode_from_strPKc($128 + $244 | 0) | 0) == ($$0$i613$i | 0)) {
                 $$5556$i = $244; //@line 53675
                 break;
                } else {
                 $$4555768$i = $244; //@line 53678
                }
               }
              }
              while (1) {
               $251 = $$5556$i + 1 | 0; //@line 53686
               if ((HEAP8[$128 + $$5556$i >> 0] | 0) == 93) {
                $$10$i = $251; //@line 53688
                $$1508$i = $212; //@line 53688
                $$1514$i = $$0$i613$i; //@line 53688
                $$3525$i = $$1523$i; //@line 53688
                $$3541$i = $$1539$i; //@line 53688
                label = 122; //@line 53689
                break L106;
               } else {
                $$5556$i = $251; //@line 53692
               }
              }
             } else {
              $$0513$i = $$0$i613$i; //@line 53696
              $$6557$i = $173; //@line 53696
             }
            } while (0);
            if (($$0513$i + -9 | 0) >>> 0 < 3) {
             $$5572$i = $$2569780$i; //@line 53702
             $$7$i = $$1$lcssa$i; //@line 53702
             break L52;
            } else {
             $$10$i = $$6557$i; //@line 53705
             $$1508$i = $212; //@line 53705
             $$1514$i = $$0513$i; //@line 53705
             $$3525$i = $$1523$i; //@line 53705
             $$3541$i = $$1539$i; //@line 53705
             label = 122; //@line 53706
            }
            break;
           }
          case 115:
           {
            $252 = HEAP32[$38 >> 2] | 0; //@line 53711
            $253 = HEAP32[$39 >> 2] | 0; //@line 53712
            L160 : do {
             switch ($253 | 0) {
             case 7:
              {
               switch ($252 | 0) {
               case 7:
               case 6:
               case 5:
                {
                 $$5572$i = $$2569780$i; //@line 53718
                 $$7$i = $$1$lcssa$i; //@line 53718
                 break L52;
                 break;
                }
               case 0:
                {
                 $$0$i607615$i = 7; //@line 53723
                 $$2524$i = -1; //@line 53723
                 $$2540$i = 0; //@line 53723
                 break L160;
                 break;
                }
               case 1:
                {
                 $$0$i607615$i = 8; //@line 53728
                 $$2524$i = -1; //@line 53728
                 $$2540$i = 0; //@line 53728
                 break L160;
                 break;
                }
               case 2:
                {
                 $$0$i607615$i = 9; //@line 53733
                 $$2524$i = -1; //@line 53733
                 $$2540$i = 0; //@line 53733
                 break L160;
                 break;
                }
               case 3:
                {
                 $$0$i607615$i = 10; //@line 53738
                 $$2524$i = -1; //@line 53738
                 $$2540$i = 0; //@line 53738
                 break L160;
                 break;
                }
               case 4:
                {
                 $$0$i607615$i = 11; //@line 53743
                 $$2524$i = -1; //@line 53743
                 $$2540$i = 0; //@line 53743
                 break L160;
                 break;
                }
               default:
                {
                 label = 107; //@line 53748
                 break L7;
                }
               }
               break;
              }
             case 1:
             case 2:
             case 3:
             case 4:
             case 5:
             case 6:
             case 0:
              {
               $$0$i607615$i = $253; //@line 53756
               $$2524$i = HEAP32[$40 >> 2] | 0; //@line 53756
               $$2540$i = 1; //@line 53756
               break;
              }
             default:
              {
               label = 107; //@line 53760
               break L7;
              }
             }
            } while (0);
            if ((HEAP8[$128 + $173 >> 0] | 0) == 91) {
             $258 = $$2553$i + 2 | 0; //@line 53769
             $259 = $128 + $258 | 0; //@line 53770
             if ((HEAP8[$259 >> 0] | 0) == 33) {
              $$7558$i = $258; //@line 53774
              while (1) {
               if ((__ZL13mode_from_strPKc($128 + ($$7558$i + 1) | 0) | 0) == ($$0$i607615$i | 0)) {
                $$5572$i = $$2569780$i; //@line 53781
                $$7$i = $$1$lcssa$i; //@line 53781
                break L52;
               }
               $266 = $$7558$i + 5 | 0; //@line 53784
               if ((HEAP8[$128 + $266 >> 0] | 0) == 44) {
                $$7558$i = $266; //@line 53789
               } else {
                break;
               }
              }
              $$10$i = $$7558$i + 6 | 0; //@line 53795
              $$1508$i = $252; //@line 53795
              $$1514$i = $$0$i607615$i; //@line 53795
              $$3525$i = $$2524$i; //@line 53795
              $$3541$i = $$2540$i; //@line 53795
              label = 122; //@line 53796
              break L106;
             }
             $274 = (HEAP8[$128 + ($$2553$i + 6) >> 0] | 0) == 45; //@line 53802
             $276 = (__ZL13mode_from_strPKc($259) | 0) == ($$0$i607615$i | 0); //@line 53804
             if ($274) {
              if (!$276) {
               $$5572$i = $$2569780$i; //@line 53807
               $$7$i = $$1$lcssa$i; //@line 53807
               break L52;
              }
              $$10$i = $$2553$i + 12 | 0; //@line 53813
              $$1508$i = $252; //@line 53813
              $$1514$i = __ZL13mode_from_strPKc($259 + 5 | 0) | 0; //@line 53813
              $$3525$i = $$2524$i; //@line 53813
              $$3541$i = $$2540$i; //@line 53813
              label = 122; //@line 53814
              break L106;
             }
             if ($276) {
              $$9$i = $258; //@line 53818
             } else {
              $$8765$i = $258; //@line 53820
              while (1) {
               if ((HEAP8[$128 + ($$8765$i + 4) >> 0] | 0) == 93) {
                $$5572$i = $$2569780$i; //@line 53827
                $$7$i = $$1$lcssa$i; //@line 53827
                break L52;
               }
               $284 = $$8765$i + 5 | 0; //@line 53830
               if ((__ZL13mode_from_strPKc($128 + $284 | 0) | 0) == ($$0$i607615$i | 0)) {
                $$9$i = $284; //@line 53835
                break;
               } else {
                $$8765$i = $284; //@line 53838
               }
              }
             }
             while (1) {
              $291 = $$9$i + 1 | 0; //@line 53846
              if ((HEAP8[$128 + $$9$i >> 0] | 0) == 93) {
               $$10$i = $291; //@line 53848
               $$1508$i = $252; //@line 53848
               $$1514$i = $$0$i607615$i; //@line 53848
               $$3525$i = $$2524$i; //@line 53848
               $$3541$i = $$2540$i; //@line 53848
               label = 122; //@line 53849
               break;
              } else {
               $$9$i = $291; //@line 53852
              }
             }
            } else {
             $$10$i = $173; //@line 53856
             $$1508$i = $252; //@line 53856
             $$1514$i = $$0$i607615$i; //@line 53856
             $$3525$i = $$2524$i; //@line 53856
             $$3541$i = $$2540$i; //@line 53856
             label = 122; //@line 53857
            }
            break;
           }
          default:
           {
            label = 121; //@line 53862
            break L7;
           }
          }
         } while (0);
         if ((label | 0) == 122) {
          label = 0; //@line 53868
          switch ($$1514$i | 0) {
          case 0:
          case 1:
          case 2:
          case 3:
          case 4:
          case 5:
          case 6:
          case 15:
           {
            $$10617$i = $$10$i; //@line 53871
            $$1508621$i = $$1508$i; //@line 53871
            $$1514620$i = $$1514$i; //@line 53871
            $$3525619$i = $$3525$i; //@line 53871
            $$4542$i = $$3541$i; //@line 53871
            label = 125; //@line 53872
            break;
           }
          default:
           {
            $$10626$i = $$10$i; //@line 53876
            $$1508630$i = $$1508$i; //@line 53876
            $$1514629$i = $$1514$i; //@line 53876
            $$3525628$i = $$3525$i; //@line 53876
            label = 123; //@line 53877
           }
          }
         } else if ((label | 0) == 124) {
          label = 0; //@line 53882
          $$0527618636$i = $$0527618$ph$i; //@line 53884
          $$10617637$i = $$10617$ph$i; //@line 53884
          $$1508621633$i = $$1508621$ph$i; //@line 53884
          $$1514620634$i = $$1514620$ph$i; //@line 53884
          $$3525619635$i = $$3525619$ph$i; //@line 53884
          $$4542638$i = 1; //@line 53884
          $409 = ($$0544$lcssa$i | 0) == 0; //@line 53884
         }
         if ((label | 0) == 123) {
          label = 0; //@line 53887
          $$0527618636$i = 0; //@line 53889
          $$10617637$i = $$10626$i; //@line 53889
          $$1508621633$i = $$1508630$i; //@line 53889
          $$1514620634$i = $$1514629$i; //@line 53889
          $$3525619635$i = $$3525628$i; //@line 53889
          $$4542638$i = 0; //@line 53889
          $409 = ($$0544$lcssa$i | 0) == 0; //@line 53889
         } else if ((label | 0) == 125) {
          label = 0; //@line 53892
          $295 = ($$0544$lcssa$i | 0) == 0; //@line 53894
          if ($295 & ($$1514620$i | 0) == 1) {
           $$5572$i = $$2569780$i; //@line 53897
           $$7$i = $$1$lcssa$i; //@line 53897
           break L52;
          } else {
           $$0527618636$i = 0; //@line 53900
           $$10617637$i = $$10617$i; //@line 53900
           $$1508621633$i = $$1508621$i; //@line 53900
           $$1514620634$i = $$1514620$i; //@line 53900
           $$3525619635$i = $$3525619$i; //@line 53900
           $$4542638$i = $$4542$i; //@line 53900
           $409 = $295; //@line 53900
          }
         }
         if ((HEAP8[$128 + $$10617637$i >> 0] | 0) == 44) {
          $300 = $$10617637$i + 2 | 0; //@line 53908
          L194 : do {
           switch (HEAP8[$128 + ($$10617637$i + 1) >> 0] | 0) {
           case 68:
            {
             switch (HEAP8[$128 + $300 >> 0] | 0) {
             case 114:
              {
               $$sink602$i = 15; //@line 53920
               break;
              }
             case 82:
              {
               $$sink602$i = 16; //@line 53924
               break;
              }
             default:
              {
               label = 130; //@line 53928
               break L7;
              }
             }
             $310 = HEAP32[$3 + ($$sink602$i << 2) >> 2] | 0; //@line 53935
             if ($310 >>> 0 > 31) {
              label = 132; //@line 53938
              break L7;
             } else {
              $$1511$ph$i = 0; //@line 53941
              $$2505$ph$i = HEAP32[$2 + ($$sink602$i << 2) >> 2] | 0; //@line 53941
              $$4520$ph$i = $310; //@line 53941
              $$4535$ph$i = 1; //@line 53941
              label = 190; //@line 53942
             }
             break;
            }
           case 65:
            {
             $312 = $$10617637$i + 3 | 0; //@line 53947
             switch (HEAP8[$128 + $300 >> 0] | 0) {
             case 114:
              {
               $$sink656$i = 15; //@line 53953
               label = 136; //@line 53954
               break;
              }
             case 82:
              {
               $$sink656$i = 16; //@line 53958
               label = 136; //@line 53959
               break;
              }
             case 120:
              {
               $$1504642$i = 0; //@line 53963
               $$1517641$i = 0; //@line 53963
               $$1532640$i = 0; //@line 53963
               break;
              }
             default:
              {
               label = 135; //@line 53967
               break L7;
              }
             }
             if ((label | 0) == 136) {
              label = 0; //@line 53972
              $319 = HEAP32[$3 + ($$sink656$i << 2) >> 2] | 0; //@line 53976
              if ($319 >>> 0 > 31) {
               label = 137; //@line 53979
               break L7;
              } else {
               $$1504642$i = HEAP32[$2 + ($$sink656$i << 2) >> 2] | 0; //@line 53982
               $$1517641$i = $319; //@line 53982
               $$1532640$i = 1; //@line 53982
              }
             }
             switch (HEAP8[$128 + $312 >> 0] | 0) {
             case 112:
              {
               $$1511$ph$i = 4; //@line 53990
               $$2505$ph$i = $$1504642$i; //@line 53990
               $$4520$ph$i = $$1517641$i; //@line 53990
               $$4535$ph$i = $$1532640$i; //@line 53990
               label = 190; //@line 53991
               break L194;
               break;
              }
             case 80:
              {
               break;
              }
             default:
              {
               $$1511$i = 1; //@line 53999
               $$2505$i = $$1504642$i; //@line 53999
               $$4520$i = $$1517641$i; //@line 53999
               $$4535$i = $$1532640$i; //@line 53999
               label = 191; //@line 54000
               break L194;
              }
             }
             $$1511$ph$i = 3; //@line 54004
             $$2505$ph$i = $$1504642$i; //@line 54004
             $$4520$ph$i = $$1517641$i; //@line 54004
             $$4535$ph$i = $$1532640$i; //@line 54004
             label = 190; //@line 54005
             break;
            }
           case 76:
            {
             $$1511$ph$i = 8; //@line 54009
             $$2505$ph$i = -1; //@line 54009
             $$4520$ph$i = -1; //@line 54009
             $$4535$ph$i = 0; //@line 54009
             label = 190; //@line 54010
             break;
            }
           case 35:
            {
             switch (HEAP8[$128 + $300 >> 0] | 0) {
             case 122:
              {
               $$1511$ph$i = 11; //@line 54019
               $$2505$ph$i = -1; //@line 54019
               $$4520$ph$i = -1; //@line 54019
               $$4535$ph$i = 0; //@line 54019
               label = 190; //@line 54020
               break L194;
               break;
              }
             case 48:
              {
               $$1511$ph$i = 12; //@line 54025
               $$2505$ph$i = -1; //@line 54025
               $$4520$ph$i = -1; //@line 54025
               $$4535$ph$i = 0; //@line 54025
               label = 190; //@line 54026
               break L194;
               break;
              }
             case 49:
              {
               $$1511$ph$i = 13; //@line 54031
               $$2505$ph$i = -1; //@line 54031
               $$4520$ph$i = -1; //@line 54031
               $$4535$ph$i = 0; //@line 54031
               label = 190; //@line 54032
               break L194;
               break;
              }
             case 50:
              {
               $$1511$ph$i = 14; //@line 54037
               $$2505$ph$i = -1; //@line 54037
               $$4520$ph$i = -1; //@line 54037
               $$4535$ph$i = 0; //@line 54037
               label = 190; //@line 54038
               break L194;
               break;
              }
             case 105:
              {
               $$1511$ph$i = 15; //@line 54046
               $$2505$ph$i = HEAP32[$31 >> 2] << 24 >> 24; //@line 54046
               $$4520$ph$i = -1; //@line 54046
               $$4535$ph$i = 0; //@line 54046
               label = 190; //@line 54047
               break L194;
               break;
              }
             case 106:
              {
               $$1511$ph$i = 15; //@line 54052
               $$2505$ph$i = $523; //@line 54052
               $$4520$ph$i = -1; //@line 54052
               $$4535$ph$i = 0; //@line 54052
               label = 190; //@line 54053
               break L194;
               break;
              }
             case 74:
              {
               $$1511$ph$i = 15; //@line 54059
               $$2505$ph$i = HEAP32[$32 >> 2] | 0; //@line 54059
               $$4520$ph$i = -1; //@line 54059
               $$4535$ph$i = 0; //@line 54059
               label = 190; //@line 54060
               break L194;
               break;
              }
             case 107:
              {
               $$1511$ph$i = 15; //@line 54066
               $$2505$ph$i = HEAP32[$33 >> 2] | 0; //@line 54066
               $$4520$ph$i = -1; //@line 54066
               $$4535$ph$i = 0; //@line 54066
               label = 190; //@line 54067
               break L194;
               break;
              }
             case 75:
              {
               $$1511$ph$i = 15; //@line 54073
               $$2505$ph$i = HEAP32[$34 >> 2] | 0; //@line 54073
               $$4520$ph$i = -1; //@line 54073
               $$4535$ph$i = 0; //@line 54073
               label = 190; //@line 54074
               break L194;
               break;
              }
             default:
              {
               label = 149; //@line 54079
               break L7;
              }
             }
             break;
            }
           case 100:
            {
             $332 = HEAP32[$35 >> 2] | 0; //@line 54086
             $333 = HEAP32[$36 >> 2] | 0; //@line 54087
             L217 : do {
              switch ($333 | 0) {
              case 7:
               {
                switch ($332 | 0) {
                case 7:
                case 6:
                case 5:
                 {
                  $$5572$i = $$2569780$i; //@line 54093
                  $$7$i = $$1$lcssa$i; //@line 54093
                  break L52;
                  break;
                 }
                case 0:
                 {
                  $$0$i609643$i = 7; //@line 54098
                  $$2518$i = -1; //@line 54098
                  $$2533$i = 0; //@line 54098
                  break L217;
                  break;
                 }
                case 1:
                 {
                  $$0$i609643$i = 8; //@line 54103
                  $$2518$i = -1; //@line 54103
                  $$2533$i = 0; //@line 54103
                  break L217;
                  break;
                 }
                case 2:
                 {
                  $$0$i609643$i = 9; //@line 54108
                  $$2518$i = -1; //@line 54108
                  $$2533$i = 0; //@line 54108
                  break L217;
                  break;
                 }
                case 3:
                 {
                  $$0$i609643$i = 10; //@line 54113
                  $$2518$i = -1; //@line 54113
                  $$2533$i = 0; //@line 54113
                  break L217;
                  break;
                 }
                case 4:
                 {
                  $$0$i609643$i = 11; //@line 54118
                  $$2518$i = -1; //@line 54118
                  $$2533$i = 0; //@line 54118
                  break L217;
                  break;
                 }
                default:
                 {
                  label = 156; //@line 54123
                  break L7;
                 }
                }
                break;
               }
              case 1:
              case 2:
              case 3:
              case 4:
              case 5:
              case 6:
              case 0:
               {
                $$0$i609643$i = $333; //@line 54131
                $$2518$i = HEAP32[$37 >> 2] | 0; //@line 54131
                $$2533$i = 1; //@line 54131
                break;
               }
              default:
               {
                label = 156; //@line 54135
                break L7;
               }
              }
             } while (0);
             L226 : do {
              if ((HEAP8[$128 + $300 >> 0] | 0) == 91) {
               $338 = $$10617637$i + 3 | 0; //@line 54145
               $339 = $128 + $338 | 0; //@line 54146
               if ((HEAP8[$339 >> 0] | 0) == 33) {
                $$11$i = $338; //@line 54150
                while (1) {
                 if ((__ZL13mode_from_strPKc($128 + ($$11$i + 1) | 0) | 0) == ($$0$i609643$i | 0)) {
                  $$5572$i = $$2569780$i; //@line 54157
                  $$7$i = $$1$lcssa$i; //@line 54157
                  break L52;
                 }
                 $$11$i = $$11$i + 5 | 0; //@line 54160
                 if ((HEAP8[$128 + $$11$i >> 0] | 0) != 44) {
                  $$0510$i = $$0$i609643$i; //@line 54167
                  break L226;
                 }
                }
               }
               $353 = (HEAP8[$128 + ($$10617637$i + 7) >> 0] | 0) == 45; //@line 54175
               $355 = (__ZL13mode_from_strPKc($339) | 0) == ($$0$i609643$i | 0); //@line 54177
               if ($353) {
                if (!$355) {
                 $$5572$i = $$2569780$i; //@line 54180
                 $$7$i = $$1$lcssa$i; //@line 54180
                 break L52;
                }
                $$0510$i = __ZL13mode_from_strPKc($339 + 5 | 0) | 0; //@line 54185
                break;
               }
               if ($355) {
                $$13$i = $338; //@line 54189
               } else {
                $$12774$i = $338; //@line 54191
                while (1) {
                 if ((HEAP8[$128 + ($$12774$i + 4) >> 0] | 0) == 93) {
                  $$5572$i = $$2569780$i; //@line 54198
                  $$7$i = $$1$lcssa$i; //@line 54198
                  break L52;
                 }
                 $362 = $$12774$i + 5 | 0; //@line 54201
                 if ((__ZL13mode_from_strPKc($128 + $362 | 0) | 0) == ($$0$i609643$i | 0)) {
                  $$13$i = $362; //@line 54206
                  break;
                 } else {
                  $$12774$i = $362; //@line 54209
                 }
                }
               }
               while (1) {
                if ((HEAP8[$128 + $$13$i >> 0] | 0) == 93) {
                 $$1511$i = $$0$i609643$i; //@line 54219
                 $$2505$i = $332; //@line 54219
                 $$4520$i = $$2518$i; //@line 54219
                 $$4535$i = $$2533$i; //@line 54219
                 label = 191; //@line 54220
                 break L194;
                } else {
                 $$13$i = $$13$i + 1 | 0; //@line 54223
                }
               }
              } else {
               $$0510$i = $$0$i609643$i; //@line 54227
              }
             } while (0);
             if (($$0510$i + -9 | 0) >>> 0 < 3) {
              $$5572$i = $$2569780$i; //@line 54233
              $$7$i = $$1$lcssa$i; //@line 54233
              break L52;
             } else {
              $$1511$i = $$0510$i; //@line 54236
              $$2505$i = $332; //@line 54236
              $$4520$i = $$2518$i; //@line 54236
              $$4535$i = $$2533$i; //@line 54236
              label = 191; //@line 54237
             }
             break;
            }
           case 115:
            {
             $370 = HEAP32[$38 >> 2] | 0; //@line 54242
             $371 = HEAP32[$39 >> 2] | 0; //@line 54243
             L245 : do {
              switch ($371 | 0) {
              case 7:
               {
                switch ($370 | 0) {
                case 7:
                case 6:
                case 5:
                 {
                  $$5572$i = $$2569780$i; //@line 54249
                  $$7$i = $$1$lcssa$i; //@line 54249
                  break L52;
                  break;
                 }
                case 0:
                 {
                  $$0$i611645$i = 7; //@line 54254
                  $$3519$i = -1; //@line 54254
                  $$3534$i = 0; //@line 54254
                  break L245;
                  break;
                 }
                case 1:
                 {
                  $$0$i611645$i = 8; //@line 54259
                  $$3519$i = -1; //@line 54259
                  $$3534$i = 0; //@line 54259
                  break L245;
                  break;
                 }
                case 2:
                 {
                  $$0$i611645$i = 9; //@line 54264
                  $$3519$i = -1; //@line 54264
                  $$3534$i = 0; //@line 54264
                  break L245;
                  break;
                 }
                case 3:
                 {
                  $$0$i611645$i = 10; //@line 54269
                  $$3519$i = -1; //@line 54269
                  $$3534$i = 0; //@line 54269
                  break L245;
                  break;
                 }
                case 4:
                 {
                  $$0$i611645$i = 11; //@line 54274
                  $$3519$i = -1; //@line 54274
                  $$3534$i = 0; //@line 54274
                  break L245;
                  break;
                 }
                default:
                 {
                  label = 176; //@line 54279
                  break L7;
                 }
                }
                break;
               }
              case 1:
              case 2:
              case 3:
              case 4:
              case 5:
              case 6:
              case 0:
               {
                $$0$i611645$i = $371; //@line 54287
                $$3519$i = HEAP32[$40 >> 2] | 0; //@line 54287
                $$3534$i = 1; //@line 54287
                break;
               }
              default:
               {
                label = 176; //@line 54291
                break L7;
               }
              }
             } while (0);
             if ((HEAP8[$128 + $300 >> 0] | 0) == 91) {
              $376 = $$10617637$i + 3 | 0; //@line 54300
              $377 = $128 + $376 | 0; //@line 54301
              if ((HEAP8[$377 >> 0] | 0) == 33) {
               $$14$i = $376; //@line 54305
               while (1) {
                if ((__ZL13mode_from_strPKc($128 + ($$14$i + 1) | 0) | 0) == ($$0$i611645$i | 0)) {
                 $$5572$i = $$2569780$i; //@line 54312
                 $$7$i = $$1$lcssa$i; //@line 54312
                 break L52;
                }
                $$14$i = $$14$i + 5 | 0; //@line 54315
                if ((HEAP8[$128 + $$14$i >> 0] | 0) != 44) {
                 $$1511$i = $$0$i611645$i; //@line 54322
                 $$2505$i = $370; //@line 54322
                 $$4520$i = $$3519$i; //@line 54322
                 $$4535$i = $$3534$i; //@line 54322
                 label = 191; //@line 54323
                 break L194;
                }
               }
              }
              $391 = (HEAP8[$128 + ($$10617637$i + 7) >> 0] | 0) == 45; //@line 54331
              $393 = (__ZL13mode_from_strPKc($377) | 0) == ($$0$i611645$i | 0); //@line 54333
              if ($391) {
               if (!$393) {
                $$5572$i = $$2569780$i; //@line 54336
                $$7$i = $$1$lcssa$i; //@line 54336
                break L52;
               }
               $$1511$i = __ZL13mode_from_strPKc($377 + 5 | 0) | 0; //@line 54341
               $$2505$i = $370; //@line 54341
               $$4520$i = $$3519$i; //@line 54341
               $$4535$i = $$3534$i; //@line 54341
               label = 191; //@line 54342
               break L194;
              }
              if ($393) {
               $$16$i = $376; //@line 54346
              } else {
               $$15771$i = $376; //@line 54348
               while (1) {
                if ((HEAP8[$128 + ($$15771$i + 4) >> 0] | 0) == 93) {
                 $$5572$i = $$2569780$i; //@line 54355
                 $$7$i = $$1$lcssa$i; //@line 54355
                 break L52;
                }
                $400 = $$15771$i + 5 | 0; //@line 54358
                if ((__ZL13mode_from_strPKc($128 + $400 | 0) | 0) == ($$0$i611645$i | 0)) {
                 $$16$i = $400; //@line 54363
                 break;
                } else {
                 $$15771$i = $400; //@line 54366
                }
               }
              }
              while (1) {
               if ((HEAP8[$128 + $$16$i >> 0] | 0) == 93) {
                $$1511$i = $$0$i611645$i; //@line 54376
                $$2505$i = $370; //@line 54376
                $$4520$i = $$3519$i; //@line 54376
                $$4535$i = $$3534$i; //@line 54376
                label = 191; //@line 54377
                break;
               } else {
                $$16$i = $$16$i + 1 | 0; //@line 54380
               }
              }
             } else {
              $$1511$i = $$0$i611645$i; //@line 54384
              $$2505$i = $370; //@line 54384
              $$4520$i = $$3519$i; //@line 54384
              $$4535$i = $$3534$i; //@line 54384
              label = 191; //@line 54385
             }
             break;
            }
           default:
            {
             label = 189; //@line 54390
             break L7;
            }
           }
          } while (0);
          if ((label | 0) == 190) {
           label = 0; //@line 54396
           $$1528$i = $$0527618636$i; //@line 54399
           $$2509$i = $$1508621633$i; //@line 54399
           $$2512$i = $$1511$ph$i; //@line 54399
           $$2515$i = $$1514620634$i; //@line 54399
           $$3506$i = $$2505$ph$i; //@line 54399
           $$4526$i = $$3525619635$i; //@line 54399
           $$5521$i = $$4520$ph$i; //@line 54399
           $$5543$i = $$4542638$i; //@line 54399
           $$6537$i = $$1511$ph$i >>> 0 < 7 ? $$4535$ph$i : 0; //@line 54399
           $467 = 0; //@line 54399
           $468 = 0; //@line 54399
           $470 = 16384; //@line 54399
           $471 = 8192; //@line 54399
           break;
          } else if ((label | 0) == 191) {
           label = 0; //@line 54403
           if ($409 & ($$1511$i | 0) == 1) {
            $$5572$i = $$2569780$i; //@line 54409
            $$7$i = $$1$lcssa$i; //@line 54409
            break L52;
           } else {
            $$1528$i = $$0527618636$i; //@line 54412
            $$2509$i = $$1508621633$i; //@line 54412
            $$2512$i = $$1511$i; //@line 54412
            $$2515$i = $$1514620634$i; //@line 54412
            $$3506$i = $$2505$i; //@line 54412
            $$4526$i = $$3525619635$i; //@line 54412
            $$5521$i = $$4520$i; //@line 54412
            $$5543$i = $$4542638$i; //@line 54412
            $$6537$i = $$1511$i >>> 0 < 7 ? $$4535$i : 0; //@line 54412
            $467 = 0; //@line 54412
            $468 = 0; //@line 54412
            $470 = 16384; //@line 54412
            $471 = 8192; //@line 54412
            break;
           }
          }
         } else {
          $$1528$i = $$0527618636$i; //@line 54417
          $$2509$i = $$1508621633$i; //@line 54417
          $$2512$i = 16; //@line 54417
          $$2515$i = $$1514620634$i; //@line 54417
          $$3506$i = -1; //@line 54417
          $$4526$i = $$3525619635$i; //@line 54417
          $$5521$i = -1; //@line 54417
          $$5543$i = $$4542638$i; //@line 54417
          $$6537$i = 0; //@line 54417
          $467 = 0; //@line 54417
          $468 = 0; //@line 54417
          $470 = 0; //@line 54417
          $471 = 8192; //@line 54417
         }
        }
       } while (0);
       $411 = $$2564$i & 65535; //@line 54422
       $412 = (HEAP32[162823] | 0) + ($411 << 4) + 9 | 0; //@line 54423
       $$hi13 = $412 + 4 | 0; //@line 54425
       (HEAPU8[$$hi13 >> 0] | HEAPU8[$$hi13 + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi13 + 2 >> 0] << 16; //@line 54432
       if (!(0 == 0 ? ((HEAPU8[$412 >> 0] | HEAPU8[$412 + 1 >> 0] << 8 | HEAPU8[$412 + 2 >> 0] << 16 | HEAPU8[$412 + 3 >> 0] << 24) & 16711680 | 0) == 0 : 0)) {
        HEAP32[$vararg_buffer1 >> 2] = $411; //@line 54438
        HEAP32[$vararg_buffer1 + 4 >> 2] = $128; //@line 54440
        _fprintf($26, 106158, $vararg_buffer1) | 0; //@line 54441
       }
       if (($$1$lcssa$i | 0) == -1) {
        $418 = HEAP32[1431] | 0; //@line 54445
        if (!(_strcmp($4, $418) | 0)) {
         $$5$i = 0; //@line 54449
        } else {
         $$4777$i = 0; //@line 54451
         $421 = $418; //@line 54451
         while (1) {
          if (!(HEAP8[$421 >> 0] | 0)) {
           label = 197; //@line 54456
           break L7;
          }
          $423 = $$4777$i + 1 | 0; //@line 54459
          $421 = HEAP32[5720 + ($423 << 3) + 4 >> 2] | 0; //@line 54461
          if (!(_strcmp($4, $421) | 0)) {
           $$5$i = $423; //@line 54465
           break;
          } else {
           $$4777$i = $423; //@line 54468
          }
         }
        }
       } else {
        $$5$i = $$1$lcssa$i; //@line 54473
       }
       $$sink104$i = HEAP32[162823] | 0; //@line 54477
       $428 = $$sink104$i + ($411 << 4) + 9 | 0; //@line 54478
       $$hi18 = $428 + 4 | 0; //@line 54480
       $430 = HEAP32[5720 + ($$5$i << 3) >> 2] << 16 & 16711680; //@line 54489
       $432 = ((HEAPU8[$$hi18 >> 0] | HEAPU8[$$hi18 + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi18 + 2 >> 0] << 16) & 16777215; //@line 54491
       $433 = (HEAPU8[$428 >> 0] | HEAPU8[$428 + 1 >> 0] << 8 | HEAPU8[$428 + 2 >> 0] << 16 | HEAPU8[$428 + 3 >> 0] << 24) & -16711681 | $430; //@line 54492
       HEAP8[$428 >> 0] = $433; //@line 54493
       HEAP8[$428 + 1 >> 0] = $433 >> 8; //@line 54493
       HEAP8[$428 + 2 >> 0] = $433 >> 16; //@line 54493
       HEAP8[$428 + 3 >> 0] = $433 >> 24; //@line 54493
       $$hi24 = $428 + 4 | 0; //@line 54494
       $434 = $432 & 65535; //@line 54495
       HEAP8[$$hi24 >> 0] = $434; //@line 54496
       HEAP8[$$hi24 + 1 >> 0] = $434 >> 8; //@line 54496
       $435 = _bitshift64Lshr($432 | 0, 0, 16) | 0; //@line 54497
       HEAP8[$$hi24 + 2 >> 0] = $435; //@line 54501
       $439 = HEAP32[$23 >> 2] << 24; //@line 54503
       HEAP8[$$sink104$i + ($411 << 4) + 5 >> 0] = $$2509$i; //@line 54515
       HEAP8[$$sink104$i + ($411 << 4) + 4 >> 0] = $$3506$i; //@line 54518
       $452 = _bitshift64Shl($$2512$i & 31 | 0, 0, 40) | 0; //@line 54521
       $453 = tempRet0; //@line 54522
       HEAP8[$$sink104$i + ($411 << 4) + 7 >> 0] = $$5543$i | 0 ? $$4526$i & 255 : -1; //@line 54527
       HEAP8[$$sink104$i + ($411 << 4) + 6 >> 0] = $$6537$i | 0 ? $$5521$i & 255 : -1; //@line 54532
       $463 = _bitshift64Shl($$1528$i & 7 | 0, 0, 37) | 0; //@line 54534
       $477 = $467 | $468 | $463 | $452 | $433 & 16777215; //@line 54544
       $478 = $470 | $471 | tempRet0 | $$2515$i & 31 | $453 | $432 & 16285696; //@line 54545
       $479 = $477 | $439 & 251658240; //@line 54546
       $481 = $83 | ($479 | ((($430 >>> 16) + -21 | 0) >>> 0 < 4 ? ($$2512$i | 0) == 0 ? 2 : 0 : $$0544$lcssa$i) << 30); //@line 54548
       $482 = $75 | $478; //@line 54549
       HEAP8[$428 >> 0] = $481; //@line 54550
       HEAP8[$428 + 1 >> 0] = $481 >> 8; //@line 54550
       HEAP8[$428 + 2 >> 0] = $481 >> 16; //@line 54550
       HEAP8[$428 + 3 >> 0] = $481 >> 24; //@line 54550
       $$hi30 = $428 + 4 | 0; //@line 54551
       $483 = $482 & 65535; //@line 54552
       HEAP8[$$hi30 >> 0] = $483; //@line 54553
       HEAP8[$$hi30 + 1 >> 0] = $483 >> 8; //@line 54553
       $484 = _bitshift64Lshr($482 | 0, 0, 16) | 0; //@line 54554
       HEAP8[$$hi30 + 2 >> 0] = $484; //@line 54558
       $488 = _bitshift64Lshr($477 | 0, $478 & 16777215 | 0, 16) | 0; //@line 54560
       L283 : do {
        switch (($488 & 255) << 24 >> 24) {
        case 102:
        case 58:
        case 55:
        case 59:
         {
          do {
           switch ((_bitshift64Lshr($479 | 0, $478 & 16777215 | 0, 24) | 0) & 15) {
           case 1:
           case 0:
            {
             $$3570$i = 0; //@line 54574
             break L283;
             break;
            }
           case 2:
            {
             $$3570$i = 5; //@line 54579
             break L283;
             break;
            }
           case 3:
            {
             $$3570$i = 5; //@line 54584
             break L283;
             break;
            }
           case 4:
            {
             $$3570$i = 1; //@line 54589
             break L283;
             break;
            }
           case 5:
            {
             $$3570$i = 1; //@line 54594
             break L283;
             break;
            }
           case 6:
            {
             $$3570$i = 4; //@line 54599
             break L283;
             break;
            }
           case 7:
            {
             $$3570$i = 4; //@line 54604
             break L283;
             break;
            }
           case 8:
            {
             $$3570$i = 2; //@line 54609
             break L283;
             break;
            }
           case 9:
            {
             $$3570$i = 2; //@line 54614
             break L283;
             break;
            }
           case 10:
            {
             $$3570$i = 8; //@line 54619
             break L283;
             break;
            }
           case 11:
            {
             $$3570$i = 8; //@line 54624
             break L283;
             break;
            }
           case 12:
            {
             $$3570$i = 10; //@line 54629
             break L283;
             break;
            }
           case 13:
            {
             $$3570$i = 10; //@line 54634
             break L283;
             break;
            }
           case 14:
            {
             $$3570$i = 14; //@line 54639
             break L283;
             break;
            }
           case 15:
            {
             $$3570$i = 14; //@line 54644
             break L283;
             break;
            }
           default:
            {
             label = 215; //@line 54649
             break L7;
            }
           }
          } while (0);
          break;
         }
        default:
         {
          $$3570$i = $$2569780$i; //@line 54657
         }
        }
       } while (0);
       $498 = _bitshift64Shl($$3570$i & 255 | 0, 0, 8) | 0; //@line 54664
       $502 = $81 | $481 & -65536 | $498; //@line 54668
       $503 = $80 | $482 & 13107199 | tempRet0; //@line 54669
       HEAP8[$428 >> 0] = $502; //@line 54670
       HEAP8[$428 + 1 >> 0] = $502 >> 8; //@line 54670
       HEAP8[$428 + 2 >> 0] = $502 >> 16; //@line 54670
       HEAP8[$428 + 3 >> 0] = $502 >> 24; //@line 54670
       $$hi38 = $428 + 4 | 0; //@line 54671
       $504 = $503 & 65535; //@line 54672
       HEAP8[$$hi38 >> 0] = $504; //@line 54673
       HEAP8[$$hi38 + 1 >> 0] = $504 >> 8; //@line 54673
       $505 = _bitshift64Lshr($503 | 0, 0, 16) | 0; //@line 54674
       HEAP8[$$hi38 + 2 >> 0] = $505; //@line 54678
       $$5572$i = $$3570$i; //@line 54679
       $$7$i = $$5$i; //@line 54679
      }
     }
    } while (0);
    $$0502794$i = $$0502794$i + 1 | 0; //@line 54683
    if (($$0502794$i | 0) >= ($64 | 0)) {
     break;
    } else {
     $$0501795$i = $$7$i; //@line 54686
     $$2569780$i = $$5572$i; //@line 54686
    }
   }
   $521 = HEAP32[21986] | 0; //@line 54692
  }
  $$173 = $$173 + 1 | 0; //@line 54694
  if (($$173 | 0) >= ($521 | 0)) {
   label = 236; //@line 54699
   break;
  } else {
   $522 = $521; //@line 54697
  }
 }
 switch (label | 0) {
 case 44:
  {
   _abort(); //@line 54705
   break;
  }
 case 45:
  {
   _abort(); //@line 54710
   break;
  }
 case 49:
  {
   _abort(); //@line 54715
   break;
  }
 case 52:
  {
   HEAP8[$4 + 63 >> 0] = 0; //@line 54721
   HEAP32[$vararg_buffer >> 2] = $4; //@line 54722
   _fprintf($26, 106133, $vararg_buffer) | 0; //@line 54723
   _abort(); //@line 54724
   break;
  }
 case 61:
  {
   _abort(); //@line 54729
   break;
  }
 case 64:
  {
   _abort(); //@line 54734
   break;
  }
 case 79:
  {
   _abort(); //@line 54739
   break;
  }
 case 86:
  {
   _abort(); //@line 54744
   break;
  }
 case 107:
  {
   _abort(); //@line 54749
   break;
  }
 case 121:
  {
   _abort(); //@line 54754
   break;
  }
 case 130:
  {
   _abort(); //@line 54759
   break;
  }
 case 132:
  {
   _abort(); //@line 54764
   break;
  }
 case 135:
  {
   _abort(); //@line 54769
   break;
  }
 case 137:
  {
   _abort(); //@line 54774
   break;
  }
 case 149:
  {
   _abort(); //@line 54779
   break;
  }
 case 156:
  {
   _abort(); //@line 54784
   break;
  }
 case 176:
  {
   _abort(); //@line 54789
   break;
  }
 case 189:
  {
   _abort(); //@line 54794
   break;
  }
 case 197:
  {
   _abort(); //@line 54799
   break;
  }
 case 215:
  {
   break;
  }
 case 236:
  {
   STACKTOP = sp; //@line 54808
   return;
  }
 }
}
function __Z14InstallSlotROMv() {
 var $$0$i93 = 0, $$0158 = 0, $$023$lcssa$i = 0, $$02324$i = 0, $$025$i = 0, $$pre218 = 0, $$pre219 = 0, $$sink159 = 0, $0 = 0, $1 = 0, $100 = 0, $1118 = 0, $112 = 0, $1120 = 0, $114 = 0, $1140 = 0, $1142 = 0, $1144 = 0, $1145 = 0, $1147 = 0, $1151 = 0, $1162 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $1215 = 0, $1217 = 0, $1253 = 0, $1255 = 0, $1291 = 0, $1293 = 0, $13 = 0, $1329 = 0, $1331 = 0, $134 = 0, $136 = 0, $1367 = 0, $1369 = 0, $1405 = 0, $1407 = 0, $1419 = 0, $1421 = 0, $1433 = 0, $1435 = 0, $1455 = 0, $1457 = 0, $1469 = 0, $1471 = 0, $1483 = 0, $1485 = 0, $150 = 0, $1511 = 0, $1512 = 0, $1530 = 0, $1531 = 0, $1549 = 0, $1550 = 0, $1568 = 0, $1569 = 0, $1587 = 0, $1588 = 0, $16 = 0, $1606 = 0, $1607 = 0, $1619 = 0, $1622 = 0, $1630 = 0, $1637 = 0, $1651 = 0, $1672 = 0, $1675 = 0, $1678 = 0, $1708 = 0, $1710 = 0, $1722 = 0, $1724 = 0, $1760 = 0, $1776 = 0, $1845 = 0, $1848 = 0, $1851 = 0, $186 = 0, $1897 = 0, $1909 = 0, $1913 = 0, $1927 = 0, $1943 = 0, $1946 = 0, $1947 = 0, $1949 = 0, $2 = 0, $202 = 0, $2021 = 0, $2025 = 0, $2143 = 0, $2145 = 0, $2165 = 0, $2167 = 0, $2179 = 0, $2181 = 0, $2225 = 0, $2227 = 0, $2239 = 0, $2241 = 0, $2244 = 0, $2249 = 0, $2250 = 0, $2262 = 0, $2267 = 0, $2268 = 0, $2280 = 0, $2282 = 0, $2302 = 0, $2304 = 0, $2318 = 0, $2366 = 0, $2368 = 0, $2370 = 0, $2372 = 0, $2374 = 0, $2382 = 0, $2391 = 0, $2393 = 0, $261 = 0, $264 = 0, $267 = 0, $3 = 0, $313 = 0, $37 = 0, $373 = 0, $377 = 0, $40 = 0, $43 = 0, $503 = 0, $505 = 0, $525 = 0, $578 = 0, $581 = 0, $584 = 0, $6 = 0, $66 = 0, $69 = 0, $7 = 0, $71 = 0, $72 = 0, $8 = 0, $86 = 0, $98 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 6416
 STACKTOP = STACKTOP + 288 | 0; //@line 6417
 $vararg_buffer = sp; //@line 6418
 $0 = sp + 8 | 0; //@line 6419
 $1 = sp + 24 | 0; //@line 6420
 $2 = HEAP32[30549] | 0; //@line 6421
 HEAP32[$0 >> 2] = 0; //@line 6422
 $3 = $0 + 4 | 0; //@line 6423
 HEAP32[$3 >> 2] = 0; //@line 6424
 HEAP32[$0 + 8 >> 2] = 0; //@line 6426
 HEAP8[651929] = 0; //@line 6427
 HEAP8[651930] = 1; //@line 6428
 HEAP8[651931] = 0; //@line 6429
 HEAP8[651932] = 0; //@line 6430
 HEAP8[651933] = 0; //@line 6431
 HEAP8[651934] = 0; //@line 6432
 HEAP8[651935] = 0; //@line 6433
 HEAP8[651936] = 0; //@line 6434
 HEAP8[651937] = 66; //@line 6435
 HEAP8[651938] = 97; //@line 6436
 HEAP8[651939] = 115; //@line 6437
 HEAP8[651940] = 105; //@line 6438
 HEAP8[651941] = 108; //@line 6439
 HEAP8[651942] = 105; //@line 6440
 HEAP8[651943] = 115; //@line 6441
 HEAP8[651944] = 107; //@line 6442
 HEAP8[651945] = 32; //@line 6443
 HEAP8[651946] = 73; //@line 6444
 HEAP8[651947] = 73; //@line 6445
 HEAP8[651948] = 32; //@line 6446
 HEAP8[651949] = 83; //@line 6447
 HEAP8[651950] = 108; //@line 6448
 HEAP8[651951] = 111; //@line 6449
 HEAP8[651952] = 116; //@line 6450
 HEAP8[651953] = 32; //@line 6451
 HEAP8[651954] = 82; //@line 6452
 HEAP8[651955] = 79; //@line 6453
 HEAP8[651956] = 77; //@line 6454
 HEAP8[651957] = 0; //@line 6455
 HEAP8[651958] = 0; //@line 6456
 HEAP8[651959] = 67; //@line 6457
 HEAP8[651960] = 104; //@line 6458
 HEAP8[651961] = 114; //@line 6459
 HEAP8[651962] = 105; //@line 6460
 HEAP8[651963] = 115; //@line 6461
 HEAP8[651964] = 116; //@line 6462
 HEAP8[651965] = 105; //@line 6463
 HEAP8[651966] = 97; //@line 6464
 HEAP8[651967] = 110; //@line 6465
 HEAP8[651968] = 32; //@line 6466
 HEAP8[651969] = 66; //@line 6467
 HEAP8[651970] = 97; //@line 6468
 HEAP8[651971] = 117; //@line 6469
 HEAP8[651972] = 101; //@line 6470
 HEAP8[651973] = 114; //@line 6471
 HEAP8[651974] = 0; //@line 6472
 HEAP32[28210] = 46; //@line 6473
 HEAP32[$vararg_buffer >> 2] = 1; //@line 6474
 HEAP32[$vararg_buffer + 4 >> 2] = 0; //@line 6476
 _sprintf($1, 92795, $vararg_buffer) | 0; //@line 6477
 $$0$i93 = $1; //@line 6479
 $8 = HEAP32[28210] | 0; //@line 6479
 while (1) {
  $6 = HEAP8[$$0$i93 >> 0] | 0; //@line 6482
  $7 = $8 + 1 | 0; //@line 6483
  HEAP8[651929 + $8 >> 0] = $6; //@line 6485
  if (!($6 << 24 >> 24)) {
   break;
  } else {
   $$0$i93 = $$0$i93 + 1 | 0; //@line 6490
   $8 = $7; //@line 6490
  }
 }
 HEAP32[28210] = $7; //@line 6493
 if (!($7 & 1)) {
  $16 = $7; //@line 6497
 } else {
  $13 = $8 + 2 | 0; //@line 6499
  HEAP32[28210] = $13; //@line 6501
  HEAP8[651929 + $7 >> 0] = 0; //@line 6502
  $16 = $13; //@line 6503
 }
 HEAP8[651929 + $16 >> 0] = 66; //@line 6507
 HEAP8[651929 + ($16 + 1) >> 0] = 97; //@line 6510
 HEAP8[651929 + ($16 + 2) >> 0] = 115; //@line 6513
 HEAP8[651929 + ($16 + 3) >> 0] = 105; //@line 6516
 HEAP8[651929 + ($16 + 4) >> 0] = 108; //@line 6519
 HEAP8[651929 + ($16 + 5) >> 0] = 105; //@line 6522
 HEAP8[651929 + ($16 + 6) >> 0] = 115; //@line 6525
 HEAP8[651929 + ($16 + 7) >> 0] = 107; //@line 6528
 HEAP8[651929 + ($16 + 8) >> 0] = 73; //@line 6531
 HEAP8[651929 + ($16 + 9) >> 0] = 73; //@line 6534
 HEAP8[651929 + ($16 + 10) >> 0] = 0; //@line 6536
 $37 = $16 + 11 | 0; //@line 6537
 HEAP32[28210] = $37; //@line 6538
 if (!($37 & 1)) {
  $43 = $37; //@line 6542
 } else {
  $40 = $16 + 12 | 0; //@line 6544
  HEAP32[28210] = $40; //@line 6546
  HEAP8[651929 + $37 >> 0] = 0; //@line 6547
  $43 = $40; //@line 6548
 }
 HEAP8[651929 + $43 >> 0] = 79; //@line 6552
 HEAP8[651929 + ($43 + 1) >> 0] = 99; //@line 6555
 HEAP8[651929 + ($43 + 2) >> 0] = 116; //@line 6558
 HEAP8[651929 + ($43 + 3) >> 0] = 32; //@line 6561
 HEAP8[651929 + ($43 + 4) >> 0] = 32; //@line 6564
 HEAP8[651929 + ($43 + 5) >> 0] = 56; //@line 6567
 HEAP8[651929 + ($43 + 6) >> 0] = 32; //@line 6570
 HEAP8[651929 + ($43 + 7) >> 0] = 50; //@line 6573
 HEAP8[651929 + ($43 + 8) >> 0] = 48; //@line 6576
 HEAP8[651929 + ($43 + 9) >> 0] = 49; //@line 6579
 HEAP8[651929 + ($43 + 10) >> 0] = 55; //@line 6582
 HEAP8[651929 + ($43 + 11) >> 0] = 0; //@line 6584
 $66 = $43 + 12 | 0; //@line 6585
 HEAP32[28210] = $66; //@line 6586
 if (!($66 & 1)) {
  $72 = $66; //@line 6590
 } else {
  $69 = $43 + 13 | 0; //@line 6592
  HEAP32[28210] = $69; //@line 6594
  HEAP8[651929 + $66 >> 0] = 0; //@line 6595
  $72 = $69; //@line 6596
 }
 $71 = 30 - $72 | 0; //@line 6598
 HEAP8[651929 + $72 >> 0] = 1; //@line 6601
 HEAP8[651929 + ($72 + 1) >> 0] = $71 >>> 16; //@line 6606
 HEAP8[651929 + ($72 + 2) >> 0] = $71 >>> 8; //@line 6611
 HEAP8[651929 + ($72 + 3) >> 0] = $71; //@line 6615
 $86 = 42 - $72 | 0; //@line 6616
 HEAP8[651929 + ($72 + 4) >> 0] = 3; //@line 6619
 HEAP8[651929 + ($72 + 5) >> 0] = $86 >>> 16; //@line 6624
 HEAP8[651929 + ($72 + 6) >> 0] = $86 >>> 8; //@line 6629
 $98 = $72 + 8 | 0; //@line 6631
 HEAP8[651929 + ($72 + 7) >> 0] = $86; //@line 6633
 $100 = $16 - $98 | 0; //@line 6634
 HEAP8[651929 + $98 >> 0] = 4; //@line 6637
 HEAP8[651929 + ($72 + 9) >> 0] = $100 >>> 16; //@line 6642
 HEAP8[651929 + ($72 + 10) >> 0] = $100 >>> 8; //@line 6647
 $112 = $72 + 12 | 0; //@line 6649
 HEAP8[651929 + ($72 + 11) >> 0] = $100; //@line 6651
 $114 = $43 - $112 | 0; //@line 6652
 HEAP8[651929 + $112 >> 0] = 5; //@line 6655
 HEAP8[651929 + ($72 + 13) >> 0] = $114 >>> 16; //@line 6660
 HEAP8[651929 + ($72 + 14) >> 0] = $114 >>> 8; //@line 6665
 HEAP8[651929 + ($72 + 15) >> 0] = $114; //@line 6669
 HEAP8[651929 + ($72 + 16) >> 0] = -1; //@line 6672
 HEAP8[651929 + ($72 + 17) >> 0] = 0; //@line 6675
 HEAP8[651929 + ($72 + 18) >> 0] = 0; //@line 6678
 $134 = $72 + 20 | 0; //@line 6679
 HEAP8[651929 + ($72 + 19) >> 0] = 0; //@line 6681
 $136 = -20 - $72 | 0; //@line 6682
 HEAP8[651929 + $134 >> 0] = 1; //@line 6685
 HEAP8[651929 + ($72 + 21) >> 0] = $136 >>> 16; //@line 6690
 HEAP8[651929 + ($72 + 22) >> 0] = $136 >>> 8; //@line 6695
 HEAP8[651929 + ($72 + 23) >> 0] = $136; //@line 6699
 $150 = -16 - $72 | 0; //@line 6700
 HEAP8[651929 + ($72 + 24) >> 0] = 2; //@line 6703
 HEAP8[651929 + ($72 + 25) >> 0] = $150 >>> 16; //@line 6708
 HEAP8[651929 + ($72 + 26) >> 0] = $150 >>> 8; //@line 6713
 HEAP8[651929 + ($72 + 27) >> 0] = $150; //@line 6717
 HEAP8[651929 + ($72 + 28) >> 0] = 32; //@line 6720
 HEAP8[651929 + ($72 + 29) >> 0] = 0; //@line 6723
 HEAP8[651929 + ($72 + 30) >> 0] = 66; //@line 6726
 HEAP8[651929 + ($72 + 31) >> 0] = 50; //@line 6729
 HEAP8[651929 + ($72 + 32) >> 0] = 36; //@line 6732
 HEAP8[651929 + ($72 + 33) >> 0] = -1; //@line 6735
 HEAP8[651929 + ($72 + 34) >> 0] = -1; //@line 6738
 HEAP8[651929 + ($72 + 35) >> 0] = -32; //@line 6741
 HEAP8[651929 + ($72 + 36) >> 0] = -1; //@line 6744
 HEAP8[651929 + ($72 + 37) >> 0] = 0; //@line 6747
 HEAP8[651929 + ($72 + 38) >> 0] = 0; //@line 6750
 $186 = $72 + 40 | 0; //@line 6751
 HEAP8[651929 + ($72 + 39) >> 0] = 0; //@line 6753
 HEAP8[651929 + $186 >> 0] = 0; //@line 6756
 HEAP8[651929 + ($72 + 41) >> 0] = 3; //@line 6759
 HEAP8[651929 + ($72 + 42) >> 0] = 0; //@line 6762
 HEAP8[651929 + ($72 + 43) >> 0] = 1; //@line 6765
 HEAP8[651929 + ($72 + 44) >> 0] = 0; //@line 6768
 HEAP8[651929 + ($72 + 45) >> 0] = 1; //@line 6771
 HEAP8[651929 + ($72 + 46) >> 0] = 66; //@line 6774
 $202 = $72 + 48 | 0; //@line 6775
 HEAP8[651929 + ($72 + 47) >> 0] = 50; //@line 6777
 HEAP8[651929 + $202 >> 0] = 68; //@line 6780
 HEAP8[651929 + ($72 + 49) >> 0] = 105; //@line 6783
 HEAP8[651929 + ($72 + 50) >> 0] = 115; //@line 6786
 HEAP8[651929 + ($72 + 51) >> 0] = 112; //@line 6789
 HEAP8[651929 + ($72 + 52) >> 0] = 108; //@line 6792
 HEAP8[651929 + ($72 + 53) >> 0] = 97; //@line 6795
 HEAP8[651929 + ($72 + 54) >> 0] = 121; //@line 6798
 HEAP8[651929 + ($72 + 55) >> 0] = 95; //@line 6801
 HEAP8[651929 + ($72 + 56) >> 0] = 86; //@line 6804
 HEAP8[651929 + ($72 + 57) >> 0] = 105; //@line 6807
 HEAP8[651929 + ($72 + 58) >> 0] = 100; //@line 6810
 HEAP8[651929 + ($72 + 59) >> 0] = 101; //@line 6813
 HEAP8[651929 + ($72 + 60) >> 0] = 111; //@line 6816
 HEAP8[651929 + ($72 + 61) >> 0] = 95; //@line 6819
 HEAP8[651929 + ($72 + 62) >> 0] = 65; //@line 6822
 HEAP8[651929 + ($72 + 63) >> 0] = 112; //@line 6825
 HEAP8[651929 + ($72 + 64) >> 0] = 112; //@line 6828
 HEAP8[651929 + ($72 + 65) >> 0] = 108; //@line 6831
 HEAP8[651929 + ($72 + 66) >> 0] = 101; //@line 6834
 HEAP8[651929 + ($72 + 67) >> 0] = 95; //@line 6837
 HEAP8[651929 + ($72 + 68) >> 0] = 66; //@line 6840
 HEAP8[651929 + ($72 + 69) >> 0] = 97; //@line 6843
 HEAP8[651929 + ($72 + 70) >> 0] = 115; //@line 6846
 HEAP8[651929 + ($72 + 71) >> 0] = 105; //@line 6849
 HEAP8[651929 + ($72 + 72) >> 0] = 108; //@line 6852
 HEAP8[651929 + ($72 + 73) >> 0] = 105; //@line 6855
 HEAP8[651929 + ($72 + 74) >> 0] = 115; //@line 6858
 HEAP8[651929 + ($72 + 75) >> 0] = 107; //@line 6861
 HEAP8[651929 + ($72 + 76) >> 0] = 0; //@line 6863
 $261 = $72 + 77 | 0; //@line 6864
 HEAP32[28210] = $261; //@line 6865
 if (!($261 & 1)) {
  $267 = $261; //@line 6869
 } else {
  $264 = $72 + 78 | 0; //@line 6871
  HEAP32[28210] = $264; //@line 6873
  HEAP8[651929 + $261 >> 0] = 0; //@line 6874
  $267 = $264; //@line 6875
 }
 HEAP8[651929 + $267 >> 0] = 0; //@line 6879
 HEAP8[651929 + ($267 + 1) >> 0] = 0; //@line 6882
 HEAP8[651929 + ($267 + 2) >> 0] = 0; //@line 6885
 HEAP8[651929 + ($267 + 3) >> 0] = 114; //@line 6888
 HEAP8[651929 + ($267 + 4) >> 0] = 76; //@line 6891
 HEAP8[651929 + ($267 + 5) >> 0] = 0; //@line 6894
 HEAP8[651929 + ($267 + 6) >> 0] = 0; //@line 6897
 HEAP8[651929 + ($267 + 7) >> 0] = 0; //@line 6900
 HEAP8[651929 + ($267 + 8) >> 0] = 0; //@line 6903
 HEAP8[651929 + ($267 + 9) >> 0] = 0; //@line 6906
 HEAP8[651929 + ($267 + 10) >> 0] = 0; //@line 6909
 HEAP8[651929 + ($267 + 11) >> 0] = 0; //@line 6912
 HEAP8[651929 + ($267 + 12) >> 0] = 0; //@line 6915
 HEAP8[651929 + ($267 + 13) >> 0] = 50; //@line 6918
 HEAP8[651929 + ($267 + 14) >> 0] = 0; //@line 6921
 HEAP8[651929 + ($267 + 15) >> 0] = 54; //@line 6924
 HEAP8[651929 + ($267 + 16) >> 0] = 0; //@line 6927
 HEAP8[651929 + ($267 + 17) >> 0] = 58; //@line 6930
 HEAP8[651929 + ($267 + 18) >> 0] = 0; //@line 6933
 HEAP8[651929 + ($267 + 19) >> 0] = 70; //@line 6936
 HEAP8[651929 + ($267 + 20) >> 0] = 0; //@line 6939
 HEAP8[651929 + ($267 + 21) >> 0] = 108; //@line 6942
 HEAP8[651929 + ($267 + 22) >> 0] = 29; //@line 6945
 $313 = $267 + 53 | 0; //@line 6946
 HEAP8[651929 + ($267 + 23) >> 0] = 46; //@line 6949
 HEAP8[651929 + ($267 + 24) >> 0] = 68; //@line 6952
 HEAP8[651929 + ($267 + 25) >> 0] = 105; //@line 6955
 HEAP8[651929 + ($267 + 26) >> 0] = 115; //@line 6958
 HEAP8[651929 + ($267 + 27) >> 0] = 112; //@line 6961
 HEAP8[651929 + ($267 + 28) >> 0] = 108; //@line 6964
 HEAP8[651929 + ($267 + 29) >> 0] = 97; //@line 6967
 HEAP8[651929 + ($267 + 30) >> 0] = 121; //@line 6970
 HEAP8[651929 + ($267 + 31) >> 0] = 95; //@line 6973
 HEAP8[651929 + ($267 + 32) >> 0] = 86; //@line 6976
 HEAP8[651929 + ($267 + 33) >> 0] = 105; //@line 6979
 HEAP8[651929 + ($267 + 34) >> 0] = 100; //@line 6982
 HEAP8[651929 + ($267 + 35) >> 0] = 101; //@line 6985
 HEAP8[651929 + ($267 + 36) >> 0] = 111; //@line 6988
 HEAP8[651929 + ($267 + 37) >> 0] = 95; //@line 6991
 HEAP8[651929 + ($267 + 38) >> 0] = 65; //@line 6994
 HEAP8[651929 + ($267 + 39) >> 0] = 112; //@line 6997
 HEAP8[651929 + ($267 + 40) >> 0] = 112; //@line 7000
 HEAP8[651929 + ($267 + 41) >> 0] = 108; //@line 7003
 HEAP8[651929 + ($267 + 42) >> 0] = 101; //@line 7006
 HEAP8[651929 + ($267 + 43) >> 0] = 95; //@line 7009
 HEAP8[651929 + ($267 + 44) >> 0] = 66; //@line 7012
 HEAP8[651929 + ($267 + 45) >> 0] = 97; //@line 7015
 HEAP8[651929 + ($267 + 46) >> 0] = 115; //@line 7018
 HEAP8[651929 + ($267 + 47) >> 0] = 105; //@line 7021
 HEAP8[651929 + ($267 + 48) >> 0] = 108; //@line 7024
 HEAP8[651929 + ($267 + 49) >> 0] = 105; //@line 7027
 HEAP8[651929 + ($267 + 50) >> 0] = 115; //@line 7030
 HEAP8[651929 + ($267 + 51) >> 0] = 107; //@line 7033
 HEAP8[651929 + ($267 + 52) >> 0] = 0; //@line 7035
 $373 = $267 + 52 | 0; //@line 7036
 HEAP32[28210] = $373; //@line 7037
 if (!($373 & 1)) {
  $377 = $373; //@line 7041
 } else {
  HEAP32[28210] = $313; //@line 7044
  HEAP8[651929 + $373 >> 0] = 0; //@line 7045
  $377 = $313; //@line 7046
 }
 HEAP8[651929 + $377 >> 0] = 0; //@line 7050
 HEAP8[651929 + ($377 + 1) >> 0] = 1; //@line 7053
 HEAP8[651929 + ($377 + 2) >> 0] = 113; //@line 7056
 HEAP8[651929 + ($377 + 3) >> 0] = 24; //@line 7059
 HEAP8[651929 + ($377 + 4) >> 0] = 78; //@line 7062
 HEAP8[651929 + ($377 + 5) >> 0] = 117; //@line 7065
 HEAP8[651929 + ($377 + 6) >> 0] = 112; //@line 7068
 HEAP8[651929 + ($377 + 7) >> 0] = -1; //@line 7071
 HEAP8[651929 + ($377 + 8) >> 0] = 96; //@line 7074
 HEAP8[651929 + ($377 + 9) >> 0] = 14; //@line 7077
 HEAP8[651929 + ($377 + 10) >> 0] = 113; //@line 7080
 HEAP8[651929 + ($377 + 11) >> 0] = 25; //@line 7083
 HEAP8[651929 + ($377 + 12) >> 0] = 12; //@line 7086
 HEAP8[651929 + ($377 + 13) >> 0] = 104; //@line 7089
 HEAP8[651929 + ($377 + 14) >> 0] = 0; //@line 7092
 HEAP8[651929 + ($377 + 15) >> 0] = 1; //@line 7095
 HEAP8[651929 + ($377 + 16) >> 0] = 0; //@line 7098
 HEAP8[651929 + ($377 + 17) >> 0] = 26; //@line 7101
 HEAP8[651929 + ($377 + 18) >> 0] = 102; //@line 7104
 HEAP8[651929 + ($377 + 19) >> 0] = 4; //@line 7107
 HEAP8[651929 + ($377 + 20) >> 0] = 78; //@line 7110
 HEAP8[651929 + ($377 + 21) >> 0] = 117; //@line 7113
 HEAP8[651929 + ($377 + 22) >> 0] = 113; //@line 7116
 HEAP8[651929 + ($377 + 23) >> 0] = 26; //@line 7119
 HEAP8[651929 + ($377 + 24) >> 0] = 50; //@line 7122
 HEAP8[651929 + ($377 + 25) >> 0] = 40; //@line 7125
 HEAP8[651929 + ($377 + 26) >> 0] = 0; //@line 7128
 HEAP8[651929 + ($377 + 27) >> 0] = 6; //@line 7131
 HEAP8[651929 + ($377 + 28) >> 0] = 8; //@line 7134
 HEAP8[651929 + ($377 + 29) >> 0] = 1; //@line 7137
 HEAP8[651929 + ($377 + 30) >> 0] = 0; //@line 7140
 HEAP8[651929 + ($377 + 31) >> 0] = 9; //@line 7143
 HEAP8[651929 + ($377 + 32) >> 0] = 103; //@line 7146
 HEAP8[651929 + ($377 + 33) >> 0] = 12; //@line 7149
 HEAP8[651929 + ($377 + 34) >> 0] = 74; //@line 7152
 HEAP8[651929 + ($377 + 35) >> 0] = 64; //@line 7155
 HEAP8[651929 + ($377 + 36) >> 0] = 111; //@line 7158
 HEAP8[651929 + ($377 + 37) >> 0] = 2; //@line 7161
 HEAP8[651929 + ($377 + 38) >> 0] = 66; //@line 7164
 HEAP8[651929 + ($377 + 39) >> 0] = 64; //@line 7167
 HEAP8[651929 + ($377 + 40) >> 0] = 49; //@line 7170
 HEAP8[651929 + ($377 + 41) >> 0] = 64; //@line 7173
 HEAP8[651929 + ($377 + 42) >> 0] = 0; //@line 7176
 HEAP8[651929 + ($377 + 43) >> 0] = 16; //@line 7179
 HEAP8[651929 + ($377 + 44) >> 0] = 78; //@line 7182
 HEAP8[651929 + ($377 + 45) >> 0] = 117; //@line 7185
 HEAP8[651929 + ($377 + 46) >> 0] = 74; //@line 7188
 HEAP8[651929 + ($377 + 47) >> 0] = 64; //@line 7191
 HEAP8[651929 + ($377 + 48) >> 0] = 111; //@line 7194
 HEAP8[651929 + ($377 + 49) >> 0] = 4; //@line 7197
 HEAP8[651929 + ($377 + 50) >> 0] = 66; //@line 7200
 HEAP8[651929 + ($377 + 51) >> 0] = 64; //@line 7203
 HEAP8[651929 + ($377 + 52) >> 0] = 78; //@line 7206
 HEAP8[651929 + ($377 + 53) >> 0] = 117; //@line 7209
 HEAP8[651929 + ($377 + 54) >> 0] = 47; //@line 7212
 HEAP8[651929 + ($377 + 55) >> 0] = 56; //@line 7215
 HEAP8[651929 + ($377 + 56) >> 0] = 8; //@line 7218
 HEAP8[651929 + ($377 + 57) >> 0] = -4; //@line 7221
 HEAP8[651929 + ($377 + 58) >> 0] = 78; //@line 7224
 HEAP8[651929 + ($377 + 59) >> 0] = 117; //@line 7227
 HEAP8[651929 + ($377 + 60) >> 0] = 112; //@line 7230
 HEAP8[651929 + ($377 + 61) >> 0] = -24; //@line 7233
 HEAP8[651929 + ($377 + 62) >> 0] = 78; //@line 7236
 $503 = $377 + 64 | 0; //@line 7237
 HEAP8[651929 + ($377 + 63) >> 0] = 117; //@line 7239
 $505 = $267 - $503 | 0; //@line 7240
 HEAP8[651929 + $503 >> 0] = 2; //@line 7243
 HEAP8[651929 + ($377 + 65) >> 0] = $505 >>> 16; //@line 7248
 HEAP8[651929 + ($377 + 66) >> 0] = $505 >>> 8; //@line 7253
 HEAP8[651929 + ($377 + 67) >> 0] = $505; //@line 7257
 HEAP8[651929 + ($377 + 68) >> 0] = -1; //@line 7260
 HEAP8[651929 + ($377 + 69) >> 0] = 0; //@line 7263
 HEAP8[651929 + ($377 + 70) >> 0] = 0; //@line 7266
 $525 = $377 + 72 | 0; //@line 7267
 HEAP8[651929 + ($377 + 71) >> 0] = 0; //@line 7269
 HEAP8[651929 + $525 >> 0] = 0; //@line 7272
 HEAP8[651929 + ($377 + 73) >> 0] = 0; //@line 7275
 HEAP8[651929 + ($377 + 74) >> 0] = 1; //@line 7278
 HEAP8[651929 + ($377 + 75) >> 0] = 38; //@line 7281
 HEAP8[651929 + ($377 + 76) >> 0] = 32; //@line 7284
 HEAP8[651929 + ($377 + 77) >> 0] = 0; //@line 7287
 HEAP8[651929 + ($377 + 78) >> 0] = 77; //@line 7290
 HEAP8[651929 + ($377 + 79) >> 0] = 97; //@line 7293
 HEAP8[651929 + ($377 + 80) >> 0] = 99; //@line 7296
 HEAP8[651929 + ($377 + 81) >> 0] = 32; //@line 7299
 HEAP8[651929 + ($377 + 82) >> 0] = 72; //@line 7302
 HEAP8[651929 + ($377 + 83) >> 0] = 105; //@line 7305
 HEAP8[651929 + ($377 + 84) >> 0] = 82; //@line 7308
 HEAP8[651929 + ($377 + 85) >> 0] = 101; //@line 7311
 HEAP8[651929 + ($377 + 86) >> 0] = 115; //@line 7314
 HEAP8[651929 + ($377 + 87) >> 0] = 32; //@line 7317
 HEAP8[651929 + ($377 + 88) >> 0] = 83; //@line 7320
 HEAP8[651929 + ($377 + 89) >> 0] = 116; //@line 7323
 HEAP8[651929 + ($377 + 90) >> 0] = 100; //@line 7326
 HEAP8[651929 + ($377 + 91) >> 0] = 32; //@line 7329
 HEAP8[651929 + ($377 + 92) >> 0] = 71; //@line 7332
 HEAP8[651929 + ($377 + 93) >> 0] = 97; //@line 7335
 HEAP8[651929 + ($377 + 94) >> 0] = 109; //@line 7338
 HEAP8[651929 + ($377 + 95) >> 0] = 109; //@line 7341
 HEAP8[651929 + ($377 + 96) >> 0] = 97; //@line 7344
 HEAP8[651929 + ($377 + 97) >> 0] = 0; //@line 7346
 $578 = $377 + 98 | 0; //@line 7347
 HEAP32[28210] = $578; //@line 7348
 if (!($578 & 1)) {
  $584 = $578; //@line 7352
 } else {
  $581 = $377 + 99 | 0; //@line 7354
  HEAP32[28210] = $581; //@line 7356
  HEAP8[651929 + $578 >> 0] = 0; //@line 7357
  $584 = $581; //@line 7358
 }
 HEAP8[651929 + $584 >> 0] = 0; //@line 7362
 HEAP8[651929 + ($584 + 1) >> 0] = 0; //@line 7365
 HEAP8[651929 + ($584 + 2) >> 0] = 0; //@line 7368
 HEAP8[651929 + ($584 + 3) >> 0] = 0; //@line 7371
 HEAP8[651929 + ($584 + 4) >> 0] = 0; //@line 7374
 HEAP8[651929 + ($584 + 5) >> 0] = 0; //@line 7377
 HEAP8[651929 + ($584 + 6) >> 0] = 0; //@line 7380
 HEAP8[651929 + ($584 + 7) >> 0] = 1; //@line 7383
 HEAP8[651929 + ($584 + 8) >> 0] = 1; //@line 7386
 HEAP8[651929 + ($584 + 9) >> 0] = 0; //@line 7389
 HEAP8[651929 + ($584 + 10) >> 0] = 0; //@line 7392
 HEAP8[651929 + ($584 + 11) >> 0] = 8; //@line 7395
 HEAP8[651929 + ($584 + 12) >> 0] = 0; //@line 7398
 HEAP8[651929 + ($584 + 13) >> 0] = 5; //@line 7401
 HEAP8[651929 + ($584 + 14) >> 0] = 9; //@line 7404
 HEAP8[651929 + ($584 + 15) >> 0] = 11; //@line 7407
 HEAP8[651929 + ($584 + 16) >> 0] = 14; //@line 7410
 HEAP8[651929 + ($584 + 17) >> 0] = 16; //@line 7413
 HEAP8[651929 + ($584 + 18) >> 0] = 19; //@line 7416
 HEAP8[651929 + ($584 + 19) >> 0] = 21; //@line 7419
 HEAP8[651929 + ($584 + 20) >> 0] = 23; //@line 7422
 HEAP8[651929 + ($584 + 21) >> 0] = 25; //@line 7425
 HEAP8[651929 + ($584 + 22) >> 0] = 27; //@line 7428
 HEAP8[651929 + ($584 + 23) >> 0] = 29; //@line 7431
 HEAP8[651929 + ($584 + 24) >> 0] = 30; //@line 7434
 HEAP8[651929 + ($584 + 25) >> 0] = 32; //@line 7437
 HEAP8[651929 + ($584 + 26) >> 0] = 34; //@line 7440
 HEAP8[651929 + ($584 + 27) >> 0] = 36; //@line 7443
 HEAP8[651929 + ($584 + 28) >> 0] = 37; //@line 7446
 HEAP8[651929 + ($584 + 29) >> 0] = 39; //@line 7449
 HEAP8[651929 + ($584 + 30) >> 0] = 40; //@line 7452
 HEAP8[651929 + ($584 + 31) >> 0] = 42; //@line 7455
 HEAP8[651929 + ($584 + 32) >> 0] = 44; //@line 7458
 HEAP8[651929 + ($584 + 33) >> 0] = 45; //@line 7461
 HEAP8[651929 + ($584 + 34) >> 0] = 47; //@line 7464
 HEAP8[651929 + ($584 + 35) >> 0] = 48; //@line 7467
 HEAP8[651929 + ($584 + 36) >> 0] = 49; //@line 7470
 HEAP8[651929 + ($584 + 37) >> 0] = 51; //@line 7473
 HEAP8[651929 + ($584 + 38) >> 0] = 52; //@line 7476
 HEAP8[651929 + ($584 + 39) >> 0] = 54; //@line 7479
 HEAP8[651929 + ($584 + 40) >> 0] = 55; //@line 7482
 HEAP8[651929 + ($584 + 41) >> 0] = 56; //@line 7485
 HEAP8[651929 + ($584 + 42) >> 0] = 58; //@line 7488
 HEAP8[651929 + ($584 + 43) >> 0] = 59; //@line 7491
 HEAP8[651929 + ($584 + 44) >> 0] = 60; //@line 7494
 HEAP8[651929 + ($584 + 45) >> 0] = 62; //@line 7497
 HEAP8[651929 + ($584 + 46) >> 0] = 63; //@line 7500
 HEAP8[651929 + ($584 + 47) >> 0] = 64; //@line 7503
 HEAP8[651929 + ($584 + 48) >> 0] = 66; //@line 7506
 HEAP8[651929 + ($584 + 49) >> 0] = 67; //@line 7509
 HEAP8[651929 + ($584 + 50) >> 0] = 68; //@line 7512
 HEAP8[651929 + ($584 + 51) >> 0] = 69; //@line 7515
 HEAP8[651929 + ($584 + 52) >> 0] = 71; //@line 7518
 HEAP8[651929 + ($584 + 53) >> 0] = 72; //@line 7521
 HEAP8[651929 + ($584 + 54) >> 0] = 73; //@line 7524
 HEAP8[651929 + ($584 + 55) >> 0] = 74; //@line 7527
 HEAP8[651929 + ($584 + 56) >> 0] = 75; //@line 7530
 HEAP8[651929 + ($584 + 57) >> 0] = 77; //@line 7533
 HEAP8[651929 + ($584 + 58) >> 0] = 78; //@line 7536
 HEAP8[651929 + ($584 + 59) >> 0] = 79; //@line 7539
 HEAP8[651929 + ($584 + 60) >> 0] = 80; //@line 7542
 HEAP8[651929 + ($584 + 61) >> 0] = 81; //@line 7545
 HEAP8[651929 + ($584 + 62) >> 0] = 82; //@line 7548
 HEAP8[651929 + ($584 + 63) >> 0] = 84; //@line 7551
 HEAP8[651929 + ($584 + 64) >> 0] = 85; //@line 7554
 HEAP8[651929 + ($584 + 65) >> 0] = 86; //@line 7557
 HEAP8[651929 + ($584 + 66) >> 0] = 87; //@line 7560
 HEAP8[651929 + ($584 + 67) >> 0] = 88; //@line 7563
 HEAP8[651929 + ($584 + 68) >> 0] = 89; //@line 7566
 HEAP8[651929 + ($584 + 69) >> 0] = 90; //@line 7569
 HEAP8[651929 + ($584 + 70) >> 0] = 91; //@line 7572
 HEAP8[651929 + ($584 + 71) >> 0] = 92; //@line 7575
 HEAP8[651929 + ($584 + 72) >> 0] = 94; //@line 7578
 HEAP8[651929 + ($584 + 73) >> 0] = 95; //@line 7581
 HEAP8[651929 + ($584 + 74) >> 0] = 96; //@line 7584
 HEAP8[651929 + ($584 + 75) >> 0] = 97; //@line 7587
 HEAP8[651929 + ($584 + 76) >> 0] = 98; //@line 7590
 HEAP8[651929 + ($584 + 77) >> 0] = 99; //@line 7593
 HEAP8[651929 + ($584 + 78) >> 0] = 100; //@line 7596
 HEAP8[651929 + ($584 + 79) >> 0] = 101; //@line 7599
 HEAP8[651929 + ($584 + 80) >> 0] = 102; //@line 7602
 HEAP8[651929 + ($584 + 81) >> 0] = 103; //@line 7605
 HEAP8[651929 + ($584 + 82) >> 0] = 104; //@line 7608
 HEAP8[651929 + ($584 + 83) >> 0] = 105; //@line 7611
 HEAP8[651929 + ($584 + 84) >> 0] = 106; //@line 7614
 HEAP8[651929 + ($584 + 85) >> 0] = 107; //@line 7617
 HEAP8[651929 + ($584 + 86) >> 0] = 108; //@line 7620
 HEAP8[651929 + ($584 + 87) >> 0] = 109; //@line 7623
 HEAP8[651929 + ($584 + 88) >> 0] = 110; //@line 7626
 HEAP8[651929 + ($584 + 89) >> 0] = 111; //@line 7629
 HEAP8[651929 + ($584 + 90) >> 0] = 112; //@line 7632
 HEAP8[651929 + ($584 + 91) >> 0] = 113; //@line 7635
 HEAP8[651929 + ($584 + 92) >> 0] = 114; //@line 7638
 HEAP8[651929 + ($584 + 93) >> 0] = 115; //@line 7641
 HEAP8[651929 + ($584 + 94) >> 0] = 116; //@line 7644
 HEAP8[651929 + ($584 + 95) >> 0] = 117; //@line 7647
 HEAP8[651929 + ($584 + 96) >> 0] = 118; //@line 7650
 HEAP8[651929 + ($584 + 97) >> 0] = 119; //@line 7653
 HEAP8[651929 + ($584 + 98) >> 0] = 120; //@line 7656
 HEAP8[651929 + ($584 + 99) >> 0] = 121; //@line 7659
 HEAP8[651929 + ($584 + 100) >> 0] = 122; //@line 7662
 HEAP8[651929 + ($584 + 101) >> 0] = 123; //@line 7665
 HEAP8[651929 + ($584 + 102) >> 0] = 124; //@line 7668
 HEAP8[651929 + ($584 + 103) >> 0] = 125; //@line 7671
 HEAP8[651929 + ($584 + 104) >> 0] = 126; //@line 7674
 HEAP8[651929 + ($584 + 105) >> 0] = 127; //@line 7677
 HEAP8[651929 + ($584 + 106) >> 0] = -128; //@line 7680
 HEAP8[651929 + ($584 + 107) >> 0] = -127; //@line 7683
 HEAP8[651929 + ($584 + 108) >> 0] = -127; //@line 7686
 HEAP8[651929 + ($584 + 109) >> 0] = -126; //@line 7689
 HEAP8[651929 + ($584 + 110) >> 0] = -125; //@line 7692
 HEAP8[651929 + ($584 + 111) >> 0] = -124; //@line 7695
 HEAP8[651929 + ($584 + 112) >> 0] = -123; //@line 7698
 HEAP8[651929 + ($584 + 113) >> 0] = -122; //@line 7701
 HEAP8[651929 + ($584 + 114) >> 0] = -121; //@line 7704
 HEAP8[651929 + ($584 + 115) >> 0] = -120; //@line 7707
 HEAP8[651929 + ($584 + 116) >> 0] = -119; //@line 7710
 HEAP8[651929 + ($584 + 117) >> 0] = -118; //@line 7713
 HEAP8[651929 + ($584 + 118) >> 0] = -117; //@line 7716
 HEAP8[651929 + ($584 + 119) >> 0] = -116; //@line 7719
 HEAP8[651929 + ($584 + 120) >> 0] = -116; //@line 7722
 HEAP8[651929 + ($584 + 121) >> 0] = -115; //@line 7725
 HEAP8[651929 + ($584 + 122) >> 0] = -114; //@line 7728
 HEAP8[651929 + ($584 + 123) >> 0] = -113; //@line 7731
 HEAP8[651929 + ($584 + 124) >> 0] = -112; //@line 7734
 HEAP8[651929 + ($584 + 125) >> 0] = -111; //@line 7737
 HEAP8[651929 + ($584 + 126) >> 0] = -110; //@line 7740
 HEAP8[651929 + ($584 + 127) >> 0] = -109; //@line 7743
 HEAP8[651929 + ($584 + 128) >> 0] = -108; //@line 7746
 HEAP8[651929 + ($584 + 129) >> 0] = -107; //@line 7749
 HEAP8[651929 + ($584 + 130) >> 0] = -107; //@line 7752
 HEAP8[651929 + ($584 + 131) >> 0] = -106; //@line 7755
 HEAP8[651929 + ($584 + 132) >> 0] = -105; //@line 7758
 HEAP8[651929 + ($584 + 133) >> 0] = -104; //@line 7761
 HEAP8[651929 + ($584 + 134) >> 0] = -103; //@line 7764
 HEAP8[651929 + ($584 + 135) >> 0] = -102; //@line 7767
 HEAP8[651929 + ($584 + 136) >> 0] = -101; //@line 7770
 HEAP8[651929 + ($584 + 137) >> 0] = -101; //@line 7773
 HEAP8[651929 + ($584 + 138) >> 0] = -100; //@line 7776
 HEAP8[651929 + ($584 + 139) >> 0] = -99; //@line 7779
 HEAP8[651929 + ($584 + 140) >> 0] = -98; //@line 7782
 HEAP8[651929 + ($584 + 141) >> 0] = -97; //@line 7785
 HEAP8[651929 + ($584 + 142) >> 0] = -96; //@line 7788
 HEAP8[651929 + ($584 + 143) >> 0] = -95; //@line 7791
 HEAP8[651929 + ($584 + 144) >> 0] = -95; //@line 7794
 HEAP8[651929 + ($584 + 145) >> 0] = -94; //@line 7797
 HEAP8[651929 + ($584 + 146) >> 0] = -93; //@line 7800
 HEAP8[651929 + ($584 + 147) >> 0] = -92; //@line 7803
 HEAP8[651929 + ($584 + 148) >> 0] = -91; //@line 7806
 HEAP8[651929 + ($584 + 149) >> 0] = -90; //@line 7809
 HEAP8[651929 + ($584 + 150) >> 0] = -90; //@line 7812
 HEAP8[651929 + ($584 + 151) >> 0] = -89; //@line 7815
 HEAP8[651929 + ($584 + 152) >> 0] = -88; //@line 7818
 HEAP8[651929 + ($584 + 153) >> 0] = -87; //@line 7821
 HEAP8[651929 + ($584 + 154) >> 0] = -86; //@line 7824
 HEAP8[651929 + ($584 + 155) >> 0] = -85; //@line 7827
 HEAP8[651929 + ($584 + 156) >> 0] = -85; //@line 7830
 HEAP8[651929 + ($584 + 157) >> 0] = -84; //@line 7833
 HEAP8[651929 + ($584 + 158) >> 0] = -83; //@line 7836
 HEAP8[651929 + ($584 + 159) >> 0] = -82; //@line 7839
 HEAP8[651929 + ($584 + 160) >> 0] = -81; //@line 7842
 HEAP8[651929 + ($584 + 161) >> 0] = -80; //@line 7845
 HEAP8[651929 + ($584 + 162) >> 0] = -80; //@line 7848
 HEAP8[651929 + ($584 + 163) >> 0] = -79; //@line 7851
 HEAP8[651929 + ($584 + 164) >> 0] = -78; //@line 7854
 HEAP8[651929 + ($584 + 165) >> 0] = -77; //@line 7857
 HEAP8[651929 + ($584 + 166) >> 0] = -76; //@line 7860
 HEAP8[651929 + ($584 + 167) >> 0] = -76; //@line 7863
 HEAP8[651929 + ($584 + 168) >> 0] = -75; //@line 7866
 HEAP8[651929 + ($584 + 169) >> 0] = -74; //@line 7869
 HEAP8[651929 + ($584 + 170) >> 0] = -73; //@line 7872
 HEAP8[651929 + ($584 + 171) >> 0] = -72; //@line 7875
 HEAP8[651929 + ($584 + 172) >> 0] = -72; //@line 7878
 HEAP8[651929 + ($584 + 173) >> 0] = -71; //@line 7881
 HEAP8[651929 + ($584 + 174) >> 0] = -70; //@line 7884
 HEAP8[651929 + ($584 + 175) >> 0] = -69; //@line 7887
 HEAP8[651929 + ($584 + 176) >> 0] = -68; //@line 7890
 HEAP8[651929 + ($584 + 177) >> 0] = -68; //@line 7893
 HEAP8[651929 + ($584 + 178) >> 0] = -67; //@line 7896
 HEAP8[651929 + ($584 + 179) >> 0] = -66; //@line 7899
 HEAP8[651929 + ($584 + 180) >> 0] = -65; //@line 7902
 HEAP8[651929 + ($584 + 181) >> 0] = -64; //@line 7905
 HEAP8[651929 + ($584 + 182) >> 0] = -64; //@line 7908
 HEAP8[651929 + ($584 + 183) >> 0] = -63; //@line 7911
 HEAP8[651929 + ($584 + 184) >> 0] = -62; //@line 7914
 HEAP8[651929 + ($584 + 185) >> 0] = -61; //@line 7917
 HEAP8[651929 + ($584 + 186) >> 0] = -61; //@line 7920
 HEAP8[651929 + ($584 + 187) >> 0] = -60; //@line 7923
 HEAP8[651929 + ($584 + 188) >> 0] = -59; //@line 7926
 HEAP8[651929 + ($584 + 189) >> 0] = -58; //@line 7929
 HEAP8[651929 + ($584 + 190) >> 0] = -57; //@line 7932
 HEAP8[651929 + ($584 + 191) >> 0] = -57; //@line 7935
 HEAP8[651929 + ($584 + 192) >> 0] = -56; //@line 7938
 HEAP8[651929 + ($584 + 193) >> 0] = -55; //@line 7941
 HEAP8[651929 + ($584 + 194) >> 0] = -54; //@line 7944
 HEAP8[651929 + ($584 + 195) >> 0] = -54; //@line 7947
 HEAP8[651929 + ($584 + 196) >> 0] = -53; //@line 7950
 HEAP8[651929 + ($584 + 197) >> 0] = -52; //@line 7953
 HEAP8[651929 + ($584 + 198) >> 0] = -51; //@line 7956
 HEAP8[651929 + ($584 + 199) >> 0] = -51; //@line 7959
 HEAP8[651929 + ($584 + 200) >> 0] = -50; //@line 7962
 HEAP8[651929 + ($584 + 201) >> 0] = -49; //@line 7965
 HEAP8[651929 + ($584 + 202) >> 0] = -48; //@line 7968
 HEAP8[651929 + ($584 + 203) >> 0] = -48; //@line 7971
 HEAP8[651929 + ($584 + 204) >> 0] = -47; //@line 7974
 HEAP8[651929 + ($584 + 205) >> 0] = -46; //@line 7977
 HEAP8[651929 + ($584 + 206) >> 0] = -45; //@line 7980
 HEAP8[651929 + ($584 + 207) >> 0] = -45; //@line 7983
 HEAP8[651929 + ($584 + 208) >> 0] = -44; //@line 7986
 HEAP8[651929 + ($584 + 209) >> 0] = -43; //@line 7989
 HEAP8[651929 + ($584 + 210) >> 0] = -42; //@line 7992
 HEAP8[651929 + ($584 + 211) >> 0] = -42; //@line 7995
 HEAP8[651929 + ($584 + 212) >> 0] = -41; //@line 7998
 HEAP8[651929 + ($584 + 213) >> 0] = -40; //@line 8001
 HEAP8[651929 + ($584 + 214) >> 0] = -39; //@line 8004
 HEAP8[651929 + ($584 + 215) >> 0] = -39; //@line 8007
 HEAP8[651929 + ($584 + 216) >> 0] = -38; //@line 8010
 HEAP8[651929 + ($584 + 217) >> 0] = -37; //@line 8013
 HEAP8[651929 + ($584 + 218) >> 0] = -36; //@line 8016
 HEAP8[651929 + ($584 + 219) >> 0] = -36; //@line 8019
 HEAP8[651929 + ($584 + 220) >> 0] = -35; //@line 8022
 HEAP8[651929 + ($584 + 221) >> 0] = -34; //@line 8025
 HEAP8[651929 + ($584 + 222) >> 0] = -33; //@line 8028
 HEAP8[651929 + ($584 + 223) >> 0] = -33; //@line 8031
 HEAP8[651929 + ($584 + 224) >> 0] = -32; //@line 8034
 HEAP8[651929 + ($584 + 225) >> 0] = -31; //@line 8037
 HEAP8[651929 + ($584 + 226) >> 0] = -31; //@line 8040
 HEAP8[651929 + ($584 + 227) >> 0] = -30; //@line 8043
 HEAP8[651929 + ($584 + 228) >> 0] = -29; //@line 8046
 HEAP8[651929 + ($584 + 229) >> 0] = -28; //@line 8049
 HEAP8[651929 + ($584 + 230) >> 0] = -28; //@line 8052
 HEAP8[651929 + ($584 + 231) >> 0] = -27; //@line 8055
 HEAP8[651929 + ($584 + 232) >> 0] = -26; //@line 8058
 HEAP8[651929 + ($584 + 233) >> 0] = -25; //@line 8061
 HEAP8[651929 + ($584 + 234) >> 0] = -25; //@line 8064
 HEAP8[651929 + ($584 + 235) >> 0] = -24; //@line 8067
 HEAP8[651929 + ($584 + 236) >> 0] = -23; //@line 8070
 HEAP8[651929 + ($584 + 237) >> 0] = -23; //@line 8073
 HEAP8[651929 + ($584 + 238) >> 0] = -22; //@line 8076
 HEAP8[651929 + ($584 + 239) >> 0] = -21; //@line 8079
 HEAP8[651929 + ($584 + 240) >> 0] = -20; //@line 8082
 HEAP8[651929 + ($584 + 241) >> 0] = -20; //@line 8085
 HEAP8[651929 + ($584 + 242) >> 0] = -19; //@line 8088
 HEAP8[651929 + ($584 + 243) >> 0] = -18; //@line 8091
 HEAP8[651929 + ($584 + 244) >> 0] = -18; //@line 8094
 HEAP8[651929 + ($584 + 245) >> 0] = -17; //@line 8097
 HEAP8[651929 + ($584 + 246) >> 0] = -16; //@line 8100
 HEAP8[651929 + ($584 + 247) >> 0] = -15; //@line 8103
 HEAP8[651929 + ($584 + 248) >> 0] = -15; //@line 8106
 HEAP8[651929 + ($584 + 249) >> 0] = -14; //@line 8109
 HEAP8[651929 + ($584 + 250) >> 0] = -13; //@line 8112
 HEAP8[651929 + ($584 + 251) >> 0] = -13; //@line 8115
 HEAP8[651929 + ($584 + 252) >> 0] = -12; //@line 8118
 HEAP8[651929 + ($584 + 253) >> 0] = -11; //@line 8121
 HEAP8[651929 + ($584 + 254) >> 0] = -11; //@line 8124
 HEAP8[651929 + ($584 + 255) >> 0] = -10; //@line 8127
 HEAP8[651929 + ($584 + 256) >> 0] = -9; //@line 8130
 HEAP8[651929 + ($584 + 257) >> 0] = -8; //@line 8133
 HEAP8[651929 + ($584 + 258) >> 0] = -8; //@line 8136
 HEAP8[651929 + ($584 + 259) >> 0] = -7; //@line 8139
 HEAP8[651929 + ($584 + 260) >> 0] = -6; //@line 8142
 HEAP8[651929 + ($584 + 261) >> 0] = -6; //@line 8145
 HEAP8[651929 + ($584 + 262) >> 0] = -5; //@line 8148
 HEAP8[651929 + ($584 + 263) >> 0] = -4; //@line 8151
 HEAP8[651929 + ($584 + 264) >> 0] = -4; //@line 8154
 HEAP8[651929 + ($584 + 265) >> 0] = -3; //@line 8157
 HEAP8[651929 + ($584 + 266) >> 0] = -2; //@line 8160
 $1118 = $584 + 268 | 0; //@line 8161
 HEAP8[651929 + ($584 + 267) >> 0] = -1; //@line 8163
 $1120 = $525 - $1118 | 0; //@line 8164
 HEAP8[651929 + $1118 >> 0] = -128; //@line 8167
 HEAP8[651929 + ($584 + 269) >> 0] = $1120 >>> 16; //@line 8172
 HEAP8[651929 + ($584 + 270) >> 0] = $1120 >>> 8; //@line 8177
 HEAP8[651929 + ($584 + 271) >> 0] = $1120; //@line 8181
 HEAP8[651929 + ($584 + 272) >> 0] = -1; //@line 8184
 HEAP8[651929 + ($584 + 273) >> 0] = 0; //@line 8187
 HEAP8[651929 + ($584 + 274) >> 0] = 0; //@line 8190
 $1140 = $584 + 276 | 0; //@line 8191
 HEAP32[28210] = $1140; //@line 8192
 HEAP8[651929 + ($584 + 275) >> 0] = 0; //@line 8194
 $1142 = HEAP32[30548] | 0; //@line 8195
 if (($1142 | 0) == ($2 | 0)) {
  $1637 = $1140; //@line 8198
 } else {
  $1144 = $0 + 8 | 0; //@line 8200
  $$sink159 = $1142; //@line 8201
  $1151 = $1140; //@line 8201
  while (1) {
   $1145 = HEAP32[$$sink159 >> 2] | 0; //@line 8203
   $1147 = HEAP32[$1145 + 20 >> 2] | 0; //@line 8205
   HEAP8[651929 + $1151 >> 0] = $1147 >>> 24; //@line 8210
   HEAP8[651929 + ($1151 + 1) >> 0] = $1147 >>> 16; //@line 8215
   HEAP8[651929 + ($1151 + 2) >> 0] = $1147 >>> 8; //@line 8220
   $1162 = $1151 + 4 | 0; //@line 8222
   HEAP8[651929 + ($1151 + 3) >> 0] = $1147; //@line 8224
   HEAP8[651929 + $1162 >> 0] = 0; //@line 8227
   HEAP8[651929 + ($1151 + 5) >> 0] = 0; //@line 8230
   HEAP8[651929 + ($1151 + 6) >> 0] = 0; //@line 8233
   HEAP32[28210] = $1151 + 8; //@line 8235
   HEAP8[651929 + ($1151 + 7) >> 0] = 0; //@line 8237
   $1172 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 0) | 0; //@line 8238
   $1173 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 1) | 0; //@line 8239
   $1174 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 2) | 0; //@line 8240
   $1175 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 3) | 0; //@line 8241
   $1176 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 4) | 0; //@line 8242
   $1177 = __ZL10VModeParmsRK12monitor_desc11video_depth($1145, 5) | 0; //@line 8243
   $1178 = HEAP32[28210] | 0; //@line 8244
   $1179 = $1172 - $1178 | 0; //@line 8245
   HEAP8[651929 + $1178 >> 0] = 1; //@line 8248
   HEAP8[651929 + ($1178 + 1) >> 0] = $1179 >>> 16; //@line 8253
   HEAP8[651929 + ($1178 + 2) >> 0] = $1179 >>> 8; //@line 8258
   HEAP8[651929 + ($1178 + 3) >> 0] = $1179; //@line 8262
   HEAP8[651929 + ($1178 + 4) >> 0] = 3; //@line 8265
   HEAP8[651929 + ($1178 + 5) >> 0] = 0; //@line 8268
   HEAP8[651929 + ($1178 + 6) >> 0] = 0; //@line 8271
   HEAP8[651929 + ($1178 + 7) >> 0] = 1; //@line 8274
   HEAP8[651929 + ($1178 + 8) >> 0] = 4; //@line 8277
   HEAP8[651929 + ($1178 + 9) >> 0] = 0; //@line 8280
   HEAP8[651929 + ($1178 + 10) >> 0] = 0; //@line 8283
   HEAP8[651929 + ($1178 + 11) >> 0] = 0; //@line 8286
   HEAP8[651929 + ($1178 + 12) >> 0] = -1; //@line 8289
   HEAP8[651929 + ($1178 + 13) >> 0] = 0; //@line 8292
   HEAP8[651929 + ($1178 + 14) >> 0] = 0; //@line 8295
   $1215 = $1178 + 16 | 0; //@line 8296
   HEAP8[651929 + ($1178 + 15) >> 0] = 0; //@line 8298
   $1217 = $1173 - $1215 | 0; //@line 8299
   HEAP8[651929 + $1215 >> 0] = 1; //@line 8302
   HEAP8[651929 + ($1178 + 17) >> 0] = $1217 >>> 16; //@line 8307
   HEAP8[651929 + ($1178 + 18) >> 0] = $1217 >>> 8; //@line 8312
   HEAP8[651929 + ($1178 + 19) >> 0] = $1217; //@line 8316
   HEAP8[651929 + ($1178 + 20) >> 0] = 3; //@line 8319
   HEAP8[651929 + ($1178 + 21) >> 0] = 0; //@line 8322
   HEAP8[651929 + ($1178 + 22) >> 0] = 0; //@line 8325
   HEAP8[651929 + ($1178 + 23) >> 0] = 1; //@line 8328
   HEAP8[651929 + ($1178 + 24) >> 0] = 4; //@line 8331
   HEAP8[651929 + ($1178 + 25) >> 0] = 0; //@line 8334
   HEAP8[651929 + ($1178 + 26) >> 0] = 0; //@line 8337
   HEAP8[651929 + ($1178 + 27) >> 0] = 0; //@line 8340
   HEAP8[651929 + ($1178 + 28) >> 0] = -1; //@line 8343
   HEAP8[651929 + ($1178 + 29) >> 0] = 0; //@line 8346
   HEAP8[651929 + ($1178 + 30) >> 0] = 0; //@line 8349
   $1253 = $1178 + 32 | 0; //@line 8350
   HEAP8[651929 + ($1178 + 31) >> 0] = 0; //@line 8352
   $1255 = $1174 - $1253 | 0; //@line 8353
   HEAP8[651929 + $1253 >> 0] = 1; //@line 8356
   HEAP8[651929 + ($1178 + 33) >> 0] = $1255 >>> 16; //@line 8361
   HEAP8[651929 + ($1178 + 34) >> 0] = $1255 >>> 8; //@line 8366
   HEAP8[651929 + ($1178 + 35) >> 0] = $1255; //@line 8370
   HEAP8[651929 + ($1178 + 36) >> 0] = 3; //@line 8373
   HEAP8[651929 + ($1178 + 37) >> 0] = 0; //@line 8376
   HEAP8[651929 + ($1178 + 38) >> 0] = 0; //@line 8379
   HEAP8[651929 + ($1178 + 39) >> 0] = 1; //@line 8382
   HEAP8[651929 + ($1178 + 40) >> 0] = 4; //@line 8385
   HEAP8[651929 + ($1178 + 41) >> 0] = 0; //@line 8388
   HEAP8[651929 + ($1178 + 42) >> 0] = 0; //@line 8391
   HEAP8[651929 + ($1178 + 43) >> 0] = 0; //@line 8394
   HEAP8[651929 + ($1178 + 44) >> 0] = -1; //@line 8397
   HEAP8[651929 + ($1178 + 45) >> 0] = 0; //@line 8400
   HEAP8[651929 + ($1178 + 46) >> 0] = 0; //@line 8403
   $1291 = $1178 + 48 | 0; //@line 8404
   HEAP8[651929 + ($1178 + 47) >> 0] = 0; //@line 8406
   $1293 = $1175 - $1291 | 0; //@line 8407
   HEAP8[651929 + $1291 >> 0] = 1; //@line 8410
   HEAP8[651929 + ($1178 + 49) >> 0] = $1293 >>> 16; //@line 8415
   HEAP8[651929 + ($1178 + 50) >> 0] = $1293 >>> 8; //@line 8420
   HEAP8[651929 + ($1178 + 51) >> 0] = $1293; //@line 8424
   HEAP8[651929 + ($1178 + 52) >> 0] = 3; //@line 8427
   HEAP8[651929 + ($1178 + 53) >> 0] = 0; //@line 8430
   HEAP8[651929 + ($1178 + 54) >> 0] = 0; //@line 8433
   HEAP8[651929 + ($1178 + 55) >> 0] = 1; //@line 8436
   HEAP8[651929 + ($1178 + 56) >> 0] = 4; //@line 8439
   HEAP8[651929 + ($1178 + 57) >> 0] = 0; //@line 8442
   HEAP8[651929 + ($1178 + 58) >> 0] = 0; //@line 8445
   HEAP8[651929 + ($1178 + 59) >> 0] = 0; //@line 8448
   HEAP8[651929 + ($1178 + 60) >> 0] = -1; //@line 8451
   HEAP8[651929 + ($1178 + 61) >> 0] = 0; //@line 8454
   HEAP8[651929 + ($1178 + 62) >> 0] = 0; //@line 8457
   $1329 = $1178 + 64 | 0; //@line 8458
   HEAP8[651929 + ($1178 + 63) >> 0] = 0; //@line 8460
   $1331 = $1176 - $1329 | 0; //@line 8461
   HEAP8[651929 + $1329 >> 0] = 1; //@line 8464
   HEAP8[651929 + ($1178 + 65) >> 0] = $1331 >>> 16; //@line 8469
   HEAP8[651929 + ($1178 + 66) >> 0] = $1331 >>> 8; //@line 8474
   HEAP8[651929 + ($1178 + 67) >> 0] = $1331; //@line 8478
   HEAP8[651929 + ($1178 + 68) >> 0] = 3; //@line 8481
   HEAP8[651929 + ($1178 + 69) >> 0] = 0; //@line 8484
   HEAP8[651929 + ($1178 + 70) >> 0] = 0; //@line 8487
   HEAP8[651929 + ($1178 + 71) >> 0] = 1; //@line 8490
   HEAP8[651929 + ($1178 + 72) >> 0] = 4; //@line 8493
   HEAP8[651929 + ($1178 + 73) >> 0] = 0; //@line 8496
   HEAP8[651929 + ($1178 + 74) >> 0] = 0; //@line 8499
   HEAP8[651929 + ($1178 + 75) >> 0] = 2; //@line 8502
   HEAP8[651929 + ($1178 + 76) >> 0] = -1; //@line 8505
   HEAP8[651929 + ($1178 + 77) >> 0] = 0; //@line 8508
   HEAP8[651929 + ($1178 + 78) >> 0] = 0; //@line 8511
   $1367 = $1178 + 80 | 0; //@line 8512
   HEAP8[651929 + ($1178 + 79) >> 0] = 0; //@line 8514
   $1369 = $1177 - $1367 | 0; //@line 8515
   HEAP8[651929 + $1367 >> 0] = 1; //@line 8518
   HEAP8[651929 + ($1178 + 81) >> 0] = $1369 >>> 16; //@line 8523
   HEAP8[651929 + ($1178 + 82) >> 0] = $1369 >>> 8; //@line 8528
   HEAP8[651929 + ($1178 + 83) >> 0] = $1369; //@line 8532
   HEAP8[651929 + ($1178 + 84) >> 0] = 3; //@line 8535
   HEAP8[651929 + ($1178 + 85) >> 0] = 0; //@line 8538
   HEAP8[651929 + ($1178 + 86) >> 0] = 0; //@line 8541
   HEAP8[651929 + ($1178 + 87) >> 0] = 1; //@line 8544
   HEAP8[651929 + ($1178 + 88) >> 0] = 4; //@line 8547
   HEAP8[651929 + ($1178 + 89) >> 0] = 0; //@line 8550
   HEAP8[651929 + ($1178 + 90) >> 0] = 0; //@line 8553
   HEAP8[651929 + ($1178 + 91) >> 0] = 2; //@line 8556
   HEAP8[651929 + ($1178 + 92) >> 0] = -1; //@line 8559
   HEAP8[651929 + ($1178 + 93) >> 0] = 0; //@line 8562
   HEAP8[651929 + ($1178 + 94) >> 0] = 0; //@line 8565
   $1405 = $1178 + 96 | 0; //@line 8566
   HEAP8[651929 + ($1178 + 95) >> 0] = 0; //@line 8568
   $1407 = $186 - $1405 | 0; //@line 8569
   HEAP8[651929 + $1405 >> 0] = 1; //@line 8572
   HEAP8[651929 + ($1178 + 97) >> 0] = $1407 >>> 16; //@line 8577
   HEAP8[651929 + ($1178 + 98) >> 0] = $1407 >>> 8; //@line 8582
   $1419 = $1178 + 100 | 0; //@line 8584
   HEAP8[651929 + ($1178 + 99) >> 0] = $1407; //@line 8586
   $1421 = $202 - $1419 | 0; //@line 8587
   HEAP8[651929 + $1419 >> 0] = 2; //@line 8590
   HEAP8[651929 + ($1178 + 101) >> 0] = $1421 >>> 16; //@line 8595
   HEAP8[651929 + ($1178 + 102) >> 0] = $1421 >>> 8; //@line 8600
   $1433 = $1178 + 104 | 0; //@line 8602
   HEAP8[651929 + ($1178 + 103) >> 0] = $1421; //@line 8604
   $1435 = $503 - $1433 | 0; //@line 8605
   HEAP8[651929 + $1433 >> 0] = 4; //@line 8608
   HEAP8[651929 + ($1178 + 105) >> 0] = $1435 >>> 16; //@line 8613
   HEAP8[651929 + ($1178 + 106) >> 0] = $1435 >>> 8; //@line 8618
   HEAP8[651929 + ($1178 + 107) >> 0] = $1435; //@line 8622
   HEAP8[651929 + ($1178 + 108) >> 0] = 8; //@line 8625
   HEAP8[651929 + ($1178 + 109) >> 0] = 0; //@line 8628
   HEAP8[651929 + ($1178 + 110) >> 0] = 66; //@line 8631
   $1455 = $1178 + 112 | 0; //@line 8632
   HEAP8[651929 + ($1178 + 111) >> 0] = 50; //@line 8634
   $1457 = $1151 - $1455 | 0; //@line 8635
   HEAP8[651929 + $1455 >> 0] = 10; //@line 8638
   HEAP8[651929 + ($1178 + 113) >> 0] = $1457 >>> 16; //@line 8643
   HEAP8[651929 + ($1178 + 114) >> 0] = $1457 >>> 8; //@line 8648
   $1469 = $1178 + 116 | 0; //@line 8650
   HEAP8[651929 + ($1178 + 115) >> 0] = $1457; //@line 8652
   $1471 = $1162 - $1469 | 0; //@line 8653
   HEAP8[651929 + $1469 >> 0] = 11; //@line 8656
   HEAP8[651929 + ($1178 + 117) >> 0] = $1471 >>> 16; //@line 8661
   HEAP8[651929 + ($1178 + 118) >> 0] = $1471 >>> 8; //@line 8666
   $1483 = $1178 + 120 | 0; //@line 8668
   HEAP8[651929 + ($1178 + 119) >> 0] = $1471; //@line 8670
   $1485 = $1118 - $1483 | 0; //@line 8671
   HEAP8[651929 + $1483 >> 0] = 64; //@line 8674
   HEAP8[651929 + ($1178 + 121) >> 0] = $1485 >>> 16; //@line 8679
   HEAP8[651929 + ($1178 + 122) >> 0] = $1485 >>> 8; //@line 8684
   HEAP8[651929 + ($1178 + 123) >> 0] = $1485; //@line 8688
   HEAP8[651929 + ($1178 + 124) >> 0] = 125; //@line 8691
   HEAP8[651929 + ($1178 + 125) >> 0] = 0; //@line 8694
   HEAP8[651929 + ($1178 + 126) >> 0] = 0; //@line 8697
   HEAP32[28210] = $1178 + 128; //@line 8699
   HEAP8[651929 + ($1178 + 127) >> 0] = 6; //@line 8701
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 0) | 0) {
    $1511 = HEAP32[28210] | 0; //@line 8707
    $1512 = $1178 - $1511 | 0; //@line 8708
    HEAP8[651929 + $1511 >> 0] = HEAP16[$1145 + 824 >> 1]; //@line 8711
    HEAP8[651929 + ($1511 + 1) >> 0] = $1512 >>> 16; //@line 8716
    HEAP8[651929 + ($1511 + 2) >> 0] = $1512 >>> 8; //@line 8721
    HEAP32[28210] = $1511 + 4; //@line 8724
    HEAP8[651929 + ($1511 + 3) >> 0] = $1512; //@line 8726
   }
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 1) | 0) {
    $1530 = HEAP32[28210] | 0; //@line 8733
    $1531 = $1215 - $1530 | 0; //@line 8734
    HEAP8[651929 + $1530 >> 0] = HEAP16[$1145 + 826 >> 1]; //@line 8737
    HEAP8[651929 + ($1530 + 1) >> 0] = $1531 >>> 16; //@line 8742
    HEAP8[651929 + ($1530 + 2) >> 0] = $1531 >>> 8; //@line 8747
    HEAP32[28210] = $1530 + 4; //@line 8750
    HEAP8[651929 + ($1530 + 3) >> 0] = $1531; //@line 8752
   }
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 2) | 0) {
    $1549 = HEAP32[28210] | 0; //@line 8759
    $1550 = $1253 - $1549 | 0; //@line 8760
    HEAP8[651929 + $1549 >> 0] = HEAP16[$1145 + 828 >> 1]; //@line 8763
    HEAP8[651929 + ($1549 + 1) >> 0] = $1550 >>> 16; //@line 8768
    HEAP8[651929 + ($1549 + 2) >> 0] = $1550 >>> 8; //@line 8773
    HEAP32[28210] = $1549 + 4; //@line 8776
    HEAP8[651929 + ($1549 + 3) >> 0] = $1550; //@line 8778
   }
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 3) | 0) {
    $1568 = HEAP32[28210] | 0; //@line 8785
    $1569 = $1291 - $1568 | 0; //@line 8786
    HEAP8[651929 + $1568 >> 0] = HEAP16[$1145 + 830 >> 1]; //@line 8789
    HEAP8[651929 + ($1568 + 1) >> 0] = $1569 >>> 16; //@line 8794
    HEAP8[651929 + ($1568 + 2) >> 0] = $1569 >>> 8; //@line 8799
    HEAP32[28210] = $1568 + 4; //@line 8802
    HEAP8[651929 + ($1568 + 3) >> 0] = $1569; //@line 8804
   }
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 4) | 0) {
    $1587 = HEAP32[28210] | 0; //@line 8811
    $1588 = $1329 - $1587 | 0; //@line 8812
    HEAP8[651929 + $1587 >> 0] = HEAP16[$1145 + 832 >> 1]; //@line 8815
    HEAP8[651929 + ($1587 + 1) >> 0] = $1588 >>> 16; //@line 8820
    HEAP8[651929 + ($1587 + 2) >> 0] = $1588 >>> 8; //@line 8825
    HEAP32[28210] = $1587 + 4; //@line 8828
    HEAP8[651929 + ($1587 + 3) >> 0] = $1588; //@line 8830
   }
   if (__ZNK12monitor_desc9has_depthE11video_depth($1145, 5) | 0) {
    $1606 = HEAP32[28210] | 0; //@line 8837
    $1607 = $1367 - $1606 | 0; //@line 8838
    HEAP8[651929 + $1606 >> 0] = HEAP16[$1145 + 834 >> 1]; //@line 8841
    HEAP8[651929 + ($1606 + 1) >> 0] = $1607 >>> 16; //@line 8846
    HEAP8[651929 + ($1606 + 2) >> 0] = $1607 >>> 8; //@line 8851
    $1619 = $1606 + 4 | 0; //@line 8853
    HEAP32[28210] = $1619; //@line 8854
    HEAP8[651929 + ($1606 + 3) >> 0] = $1607; //@line 8856
    $1622 = $1619; //@line 8857
   } else {
    $1622 = HEAP32[28210] | 0; //@line 8860
   }
   HEAP8[651929 + $1622 >> 0] = -1; //@line 8864
   HEAP8[651929 + ($1622 + 1) >> 0] = 0; //@line 8867
   HEAP8[651929 + ($1622 + 2) >> 0] = 0; //@line 8870
   HEAP32[28210] = $1622 + 4; //@line 8872
   HEAP8[651929 + ($1622 + 3) >> 0] = 0; //@line 8874
   HEAP32[$vararg_buffer >> 2] = $1405; //@line 8875
   $1630 = HEAP32[$3 >> 2] | 0; //@line 8876
   if (($1630 | 0) == (HEAP32[$1144 >> 2] | 0)) {
    __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($0, $vararg_buffer); //@line 8880
   } else {
    HEAP32[$1630 >> 2] = $1405; //@line 8882
    HEAP32[$3 >> 2] = $1630 + 4; //@line 8884
   }
   $$sink159 = $$sink159 + 4 | 0; //@line 8886
   $$pre218 = HEAP32[28210] | 0; //@line 8888
   if (($$sink159 | 0) == ($2 | 0)) {
    $1637 = $$pre218; //@line 8890
    break;
   } else {
    $1151 = $$pre218; //@line 8893
   }
  }
 }
 HEAP8[651929 + $1637 >> 0] = 0; //@line 8899
 HEAP8[651929 + ($1637 + 1) >> 0] = 10; //@line 8902
 HEAP8[651929 + ($1637 + 2) >> 0] = 0; //@line 8905
 HEAP8[651929 + ($1637 + 3) >> 0] = 3; //@line 8908
 HEAP8[651929 + ($1637 + 4) >> 0] = 0; //@line 8911
 HEAP8[651929 + ($1637 + 5) >> 0] = 0; //@line 8914
 HEAP8[651929 + ($1637 + 6) >> 0] = 0; //@line 8917
 $1651 = $1637 + 8 | 0; //@line 8918
 HEAP8[651929 + ($1637 + 7) >> 0] = 24; //@line 8920
 HEAP8[651929 + $1651 >> 0] = 67; //@line 8923
 HEAP8[651929 + ($1637 + 9) >> 0] = 80; //@line 8926
 HEAP8[651929 + ($1637 + 10) >> 0] = 85; //@line 8929
 HEAP8[651929 + ($1637 + 11) >> 0] = 95; //@line 8932
 HEAP8[651929 + ($1637 + 12) >> 0] = 54; //@line 8935
 HEAP8[651929 + ($1637 + 13) >> 0] = 56; //@line 8938
 HEAP8[651929 + ($1637 + 14) >> 0] = 48; //@line 8941
 HEAP8[651929 + ($1637 + 15) >> 0] = 50; //@line 8944
 HEAP8[651929 + ($1637 + 16) >> 0] = 48; //@line 8947
 HEAP8[651929 + ($1637 + 17) >> 0] = 0; //@line 8949
 $1672 = $1637 + 18 | 0; //@line 8950
 HEAP32[28210] = $1672; //@line 8951
 if (!($1672 & 1)) {
  $1678 = $1672; //@line 8955
 } else {
  $1675 = $1637 + 19 | 0; //@line 8957
  HEAP32[28210] = $1675; //@line 8959
  HEAP8[651929 + $1672 >> 0] = 0; //@line 8960
  $1678 = $1675; //@line 8961
 }
 HEAP8[651929 + $1678 >> 0] = 0; //@line 8965
 HEAP8[651929 + ($1678 + 1) >> 0] = 0; //@line 8968
 HEAP8[651929 + ($1678 + 2) >> 0] = 0; //@line 8971
 HEAP8[651929 + ($1678 + 3) >> 0] = 0; //@line 8974
 HEAP8[651929 + ($1678 + 4) >> 0] = 127; //@line 8977
 HEAP8[651929 + ($1678 + 5) >> 0] = -1; //@line 8980
 HEAP8[651929 + ($1678 + 6) >> 0] = -1; //@line 8983
 HEAP8[651929 + ($1678 + 7) >> 0] = -1; //@line 8986
 HEAP8[651929 + ($1678 + 8) >> 0] = -16; //@line 8989
 HEAP8[651929 + ($1678 + 9) >> 0] = -128; //@line 8992
 HEAP8[651929 + ($1678 + 10) >> 0] = 0; //@line 8995
 HEAP8[651929 + ($1678 + 11) >> 0] = 0; //@line 8998
 HEAP8[651929 + ($1678 + 12) >> 0] = -16; //@line 9001
 HEAP8[651929 + ($1678 + 13) >> 0] = -1; //@line 9004
 HEAP8[651929 + ($1678 + 14) >> 0] = -1; //@line 9007
 $1708 = $1678 + 16 | 0; //@line 9008
 HEAP8[651929 + ($1678 + 15) >> 0] = -1; //@line 9010
 $1710 = $1637 - $1708 | 0; //@line 9011
 HEAP8[651929 + $1708 >> 0] = 1; //@line 9014
 HEAP8[651929 + ($1678 + 17) >> 0] = $1710 >>> 16; //@line 9019
 HEAP8[651929 + ($1678 + 18) >> 0] = $1710 >>> 8; //@line 9024
 $1722 = $1678 + 20 | 0; //@line 9026
 HEAP8[651929 + ($1678 + 19) >> 0] = $1710; //@line 9028
 $1724 = $1651 - $1722 | 0; //@line 9029
 HEAP8[651929 + $1722 >> 0] = 2; //@line 9032
 HEAP8[651929 + ($1678 + 21) >> 0] = $1724 >>> 16; //@line 9037
 HEAP8[651929 + ($1678 + 22) >> 0] = $1724 >>> 8; //@line 9042
 HEAP8[651929 + ($1678 + 23) >> 0] = $1724; //@line 9046
 HEAP8[651929 + ($1678 + 24) >> 0] = -127; //@line 9049
 HEAP8[651929 + ($1678 + 25) >> 0] = -1; //@line 9052
 HEAP8[651929 + ($1678 + 26) >> 0] = -1; //@line 9055
 HEAP8[651929 + ($1678 + 27) >> 0] = -24; //@line 9058
 HEAP8[651929 + ($1678 + 28) >> 0] = -126; //@line 9061
 HEAP8[651929 + ($1678 + 29) >> 0] = -1; //@line 9064
 HEAP8[651929 + ($1678 + 30) >> 0] = -1; //@line 9067
 HEAP8[651929 + ($1678 + 31) >> 0] = -20; //@line 9070
 HEAP8[651929 + ($1678 + 32) >> 0] = -1; //@line 9073
 HEAP8[651929 + ($1678 + 33) >> 0] = 0; //@line 9076
 HEAP8[651929 + ($1678 + 34) >> 0] = 0; //@line 9079
 $1760 = $1678 + 36 | 0; //@line 9080
 HEAP8[651929 + ($1678 + 35) >> 0] = 0; //@line 9082
 HEAP8[651929 + $1760 >> 0] = 0; //@line 9085
 HEAP8[651929 + ($1678 + 37) >> 0] = 4; //@line 9088
 HEAP8[651929 + ($1678 + 38) >> 0] = 0; //@line 9091
 HEAP8[651929 + ($1678 + 39) >> 0] = 1; //@line 9094
 HEAP8[651929 + ($1678 + 40) >> 0] = 0; //@line 9097
 HEAP8[651929 + ($1678 + 41) >> 0] = 1; //@line 9100
 HEAP8[651929 + ($1678 + 42) >> 0] = 66; //@line 9103
 $1776 = $1678 + 44 | 0; //@line 9104
 HEAP32[28210] = $1776; //@line 9105
 HEAP8[651929 + ($1678 + 43) >> 0] = 50; //@line 9107
 HEAP8[651929 + $1776 >> 0] = 78; //@line 9110
 HEAP8[651929 + ($1678 + 45) >> 0] = 101; //@line 9113
 HEAP8[651929 + ($1678 + 46) >> 0] = 116; //@line 9116
 HEAP8[651929 + ($1678 + 47) >> 0] = 119; //@line 9119
 HEAP8[651929 + ($1678 + 48) >> 0] = 111; //@line 9122
 HEAP8[651929 + ($1678 + 49) >> 0] = 114; //@line 9125
 HEAP8[651929 + ($1678 + 50) >> 0] = 107; //@line 9128
 HEAP8[651929 + ($1678 + 51) >> 0] = 95; //@line 9131
 HEAP8[651929 + ($1678 + 52) >> 0] = 69; //@line 9134
 HEAP8[651929 + ($1678 + 53) >> 0] = 116; //@line 9137
 HEAP8[651929 + ($1678 + 54) >> 0] = 104; //@line 9140
 HEAP8[651929 + ($1678 + 55) >> 0] = 101; //@line 9143
 HEAP8[651929 + ($1678 + 56) >> 0] = 114; //@line 9146
 HEAP8[651929 + ($1678 + 57) >> 0] = 110; //@line 9149
 HEAP8[651929 + ($1678 + 58) >> 0] = 101; //@line 9152
 HEAP8[651929 + ($1678 + 59) >> 0] = 116; //@line 9155
 HEAP8[651929 + ($1678 + 60) >> 0] = 95; //@line 9158
 HEAP8[651929 + ($1678 + 61) >> 0] = 65; //@line 9161
 HEAP8[651929 + ($1678 + 62) >> 0] = 112; //@line 9164
 HEAP8[651929 + ($1678 + 63) >> 0] = 112; //@line 9167
 HEAP8[651929 + ($1678 + 64) >> 0] = 108; //@line 9170
 HEAP8[651929 + ($1678 + 65) >> 0] = 101; //@line 9173
 HEAP8[651929 + ($1678 + 66) >> 0] = 95; //@line 9176
 HEAP8[651929 + ($1678 + 67) >> 0] = 66; //@line 9179
 HEAP8[651929 + ($1678 + 68) >> 0] = 97; //@line 9182
 HEAP8[651929 + ($1678 + 69) >> 0] = 115; //@line 9185
 HEAP8[651929 + ($1678 + 70) >> 0] = 105; //@line 9188
 HEAP8[651929 + ($1678 + 71) >> 0] = 108; //@line 9191
 HEAP8[651929 + ($1678 + 72) >> 0] = 105; //@line 9194
 HEAP8[651929 + ($1678 + 73) >> 0] = 115; //@line 9197
 HEAP8[651929 + ($1678 + 74) >> 0] = 107; //@line 9200
 HEAP8[651929 + ($1678 + 75) >> 0] = 73; //@line 9203
 HEAP8[651929 + ($1678 + 76) >> 0] = 73; //@line 9206
 HEAP8[651929 + ($1678 + 77) >> 0] = 0; //@line 9208
 $1845 = $1678 + 78 | 0; //@line 9209
 HEAP32[28210] = $1845; //@line 9210
 if (!($1845 & 1)) {
  $1851 = $1845; //@line 9214
 } else {
  $1848 = $1678 + 79 | 0; //@line 9216
  HEAP32[28210] = $1848; //@line 9218
  HEAP8[651929 + $1845 >> 0] = 0; //@line 9219
  $1851 = $1848; //@line 9220
 }
 HEAP8[651929 + $1851 >> 0] = 0; //@line 9224
 HEAP8[651929 + ($1851 + 1) >> 0] = 0; //@line 9227
 HEAP8[651929 + ($1851 + 2) >> 0] = 0; //@line 9230
 HEAP8[651929 + ($1851 + 3) >> 0] = -120; //@line 9233
 HEAP8[651929 + ($1851 + 4) >> 0] = 68; //@line 9236
 HEAP8[651929 + ($1851 + 5) >> 0] = 0; //@line 9239
 HEAP8[651929 + ($1851 + 6) >> 0] = 0; //@line 9242
 HEAP8[651929 + ($1851 + 7) >> 0] = 0; //@line 9245
 HEAP8[651929 + ($1851 + 8) >> 0] = 0; //@line 9248
 HEAP8[651929 + ($1851 + 9) >> 0] = 0; //@line 9251
 HEAP8[651929 + ($1851 + 10) >> 0] = 0; //@line 9254
 HEAP8[651929 + ($1851 + 11) >> 0] = 0; //@line 9257
 HEAP8[651929 + ($1851 + 12) >> 0] = 0; //@line 9260
 HEAP8[651929 + ($1851 + 13) >> 0] = 74; //@line 9263
 HEAP8[651929 + ($1851 + 14) >> 0] = 0; //@line 9266
 HEAP8[651929 + ($1851 + 15) >> 0] = 78; //@line 9269
 HEAP8[651929 + ($1851 + 16) >> 0] = 0; //@line 9272
 HEAP8[651929 + ($1851 + 17) >> 0] = 82; //@line 9275
 HEAP8[651929 + ($1851 + 18) >> 0] = 0; //@line 9278
 HEAP8[651929 + ($1851 + 19) >> 0] = 78; //@line 9281
 HEAP8[651929 + ($1851 + 20) >> 0] = 0; //@line 9284
 HEAP8[651929 + ($1851 + 21) >> 0] = -126; //@line 9287
 HEAP8[651929 + ($1851 + 22) >> 0] = 5; //@line 9290
 $1897 = $1851 + 29 | 0; //@line 9291
 HEAP8[651929 + ($1851 + 23) >> 0] = 46; //@line 9294
 HEAP8[651929 + ($1851 + 24) >> 0] = 69; //@line 9297
 HEAP8[651929 + ($1851 + 25) >> 0] = 78; //@line 9300
 HEAP8[651929 + ($1851 + 26) >> 0] = 69; //@line 9303
 HEAP8[651929 + ($1851 + 27) >> 0] = 84; //@line 9306
 HEAP8[651929 + ($1851 + 28) >> 0] = 0; //@line 9308
 $1909 = $1851 + 28 | 0; //@line 9309
 HEAP32[28210] = $1909; //@line 9310
 if (!($1909 & 1)) {
  $1913 = $1909; //@line 9314
 } else {
  HEAP32[28210] = $1897; //@line 9317
  HEAP8[651929 + $1909 >> 0] = 0; //@line 9318
  $1913 = $1897; //@line 9319
 }
 HEAP8[651929 + $1913 >> 0] = 1; //@line 9323
 HEAP8[651929 + ($1913 + 1) >> 0] = 17; //@line 9326
 HEAP8[651929 + ($1913 + 2) >> 0] = -128; //@line 9329
 HEAP8[651929 + ($1913 + 3) >> 0] = 0; //@line 9332
 HEAP8[651929 + ($1913 + 4) >> 0] = 0; //@line 9335
 HEAP8[651929 + ($1913 + 5) >> 0] = 0; //@line 9338
 HEAP8[651929 + ($1913 + 6) >> 0] = 7; //@line 9341
 $1927 = $1913 + 15 | 0; //@line 9342
 HEAP8[651929 + ($1913 + 7) >> 0] = 49; //@line 9345
 HEAP8[651929 + ($1913 + 8) >> 0] = 46; //@line 9348
 HEAP8[651929 + ($1913 + 9) >> 0] = 49; //@line 9351
 HEAP8[651929 + ($1913 + 10) >> 0] = 46; //@line 9354
 HEAP8[651929 + ($1913 + 11) >> 0] = 49; //@line 9357
 HEAP8[651929 + ($1913 + 12) >> 0] = 32; //@line 9360
 HEAP8[651929 + ($1913 + 13) >> 0] = 32; //@line 9363
 HEAP8[651929 + ($1913 + 14) >> 0] = 0; //@line 9365
 $1943 = $1913 + 14 | 0; //@line 9366
 HEAP32[28210] = $1943; //@line 9367
 if (!($1943 & 1)) {
  $1947 = $1943; //@line 9371
 } else {
  HEAP32[28210] = $1927; //@line 9374
  HEAP8[651929 + $1943 >> 0] = 0; //@line 9375
  $1947 = $1927; //@line 9376
 }
 $1946 = $1947 + 1 | 0; //@line 9378
 HEAP32[28210] = $1946; //@line 9379
 HEAP8[651929 + $1947 >> 0] = 35; //@line 9381
 $1949 = $1947 + 37 | 0; //@line 9382
 HEAP8[651929 + $1946 >> 0] = 66; //@line 9385
 HEAP8[651929 + ($1947 + 2) >> 0] = 97; //@line 9388
 HEAP8[651929 + ($1947 + 3) >> 0] = 115; //@line 9391
 HEAP8[651929 + ($1947 + 4) >> 0] = 105; //@line 9394
 HEAP8[651929 + ($1947 + 5) >> 0] = 108; //@line 9397
 HEAP8[651929 + ($1947 + 6) >> 0] = 105; //@line 9400
 HEAP8[651929 + ($1947 + 7) >> 0] = 115; //@line 9403
 HEAP8[651929 + ($1947 + 8) >> 0] = 107; //@line 9406
 HEAP8[651929 + ($1947 + 9) >> 0] = 32; //@line 9409
 HEAP8[651929 + ($1947 + 10) >> 0] = 73; //@line 9412
 HEAP8[651929 + ($1947 + 11) >> 0] = 73; //@line 9415
 HEAP8[651929 + ($1947 + 12) >> 0] = 32; //@line 9418
 HEAP8[651929 + ($1947 + 13) >> 0] = 69; //@line 9421
 HEAP8[651929 + ($1947 + 14) >> 0] = 116; //@line 9424
 HEAP8[651929 + ($1947 + 15) >> 0] = 104; //@line 9427
 HEAP8[651929 + ($1947 + 16) >> 0] = 101; //@line 9430
 HEAP8[651929 + ($1947 + 17) >> 0] = 114; //@line 9433
 HEAP8[651929 + ($1947 + 18) >> 0] = 110; //@line 9436
 HEAP8[651929 + ($1947 + 19) >> 0] = 101; //@line 9439
 HEAP8[651929 + ($1947 + 20) >> 0] = 116; //@line 9442
 HEAP8[651929 + ($1947 + 21) >> 0] = 32; //@line 9445
 HEAP8[651929 + ($1947 + 22) >> 0] = 78; //@line 9448
 HEAP8[651929 + ($1947 + 23) >> 0] = 101; //@line 9451
 HEAP8[651929 + ($1947 + 24) >> 0] = 116; //@line 9454
 HEAP8[651929 + ($1947 + 25) >> 0] = 119; //@line 9457
 HEAP8[651929 + ($1947 + 26) >> 0] = 111; //@line 9460
 HEAP8[651929 + ($1947 + 27) >> 0] = 114; //@line 9463
 HEAP8[651929 + ($1947 + 28) >> 0] = 107; //@line 9466
 HEAP8[651929 + ($1947 + 29) >> 0] = 32; //@line 9469
 HEAP8[651929 + ($1947 + 30) >> 0] = 68; //@line 9472
 HEAP8[651929 + ($1947 + 31) >> 0] = 114; //@line 9475
 HEAP8[651929 + ($1947 + 32) >> 0] = 105; //@line 9478
 HEAP8[651929 + ($1947 + 33) >> 0] = 118; //@line 9481
 HEAP8[651929 + ($1947 + 34) >> 0] = 101; //@line 9484
 HEAP8[651929 + ($1947 + 35) >> 0] = 114; //@line 9487
 HEAP8[651929 + ($1947 + 36) >> 0] = 0; //@line 9489
 $2021 = $1947 + 36 | 0; //@line 9490
 HEAP32[28210] = $2021; //@line 9491
 if (!($2021 & 1)) {
  $2025 = $2021; //@line 9495
 } else {
  HEAP32[28210] = $1949; //@line 9498
  HEAP8[651929 + $2021 >> 0] = 0; //@line 9499
  $2025 = $1949; //@line 9500
 }
 HEAP8[651929 + $2025 >> 0] = 113; //@line 9504
 HEAP8[651929 + ($2025 + 1) >> 0] = 32; //@line 9507
 HEAP8[651929 + ($2025 + 2) >> 0] = 78; //@line 9510
 HEAP8[651929 + ($2025 + 3) >> 0] = 117; //@line 9513
 HEAP8[651929 + ($2025 + 4) >> 0] = 112; //@line 9516
 HEAP8[651929 + ($2025 + 5) >> 0] = -17; //@line 9519
 HEAP8[651929 + ($2025 + 6) >> 0] = 96; //@line 9522
 HEAP8[651929 + ($2025 + 7) >> 0] = 12; //@line 9525
 HEAP8[651929 + ($2025 + 8) >> 0] = 113; //@line 9528
 HEAP8[651929 + ($2025 + 9) >> 0] = 33; //@line 9531
 HEAP8[651929 + ($2025 + 10) >> 0] = 12; //@line 9534
 HEAP8[651929 + ($2025 + 11) >> 0] = 104; //@line 9537
 HEAP8[651929 + ($2025 + 12) >> 0] = 0; //@line 9540
 HEAP8[651929 + ($2025 + 13) >> 0] = 1; //@line 9543
 HEAP8[651929 + ($2025 + 14) >> 0] = 0; //@line 9546
 HEAP8[651929 + ($2025 + 15) >> 0] = 26; //@line 9549
 HEAP8[651929 + ($2025 + 16) >> 0] = 102; //@line 9552
 HEAP8[651929 + ($2025 + 17) >> 0] = 2; //@line 9555
 HEAP8[651929 + ($2025 + 18) >> 0] = 78; //@line 9558
 HEAP8[651929 + ($2025 + 19) >> 0] = 117; //@line 9561
 HEAP8[651929 + ($2025 + 20) >> 0] = 50; //@line 9564
 HEAP8[651929 + ($2025 + 21) >> 0] = 40; //@line 9567
 HEAP8[651929 + ($2025 + 22) >> 0] = 0; //@line 9570
 HEAP8[651929 + ($2025 + 23) >> 0] = 6; //@line 9573
 HEAP8[651929 + ($2025 + 24) >> 0] = 8; //@line 9576
 HEAP8[651929 + ($2025 + 25) >> 0] = 1; //@line 9579
 HEAP8[651929 + ($2025 + 26) >> 0] = 0; //@line 9582
 HEAP8[651929 + ($2025 + 27) >> 0] = 9; //@line 9585
 HEAP8[651929 + ($2025 + 28) >> 0] = 103; //@line 9588
 HEAP8[651929 + ($2025 + 29) >> 0] = 12; //@line 9591
 HEAP8[651929 + ($2025 + 30) >> 0] = 74; //@line 9594
 HEAP8[651929 + ($2025 + 31) >> 0] = 64; //@line 9597
 HEAP8[651929 + ($2025 + 32) >> 0] = 111; //@line 9600
 HEAP8[651929 + ($2025 + 33) >> 0] = 2; //@line 9603
 HEAP8[651929 + ($2025 + 34) >> 0] = 66; //@line 9606
 HEAP8[651929 + ($2025 + 35) >> 0] = 64; //@line 9609
 HEAP8[651929 + ($2025 + 36) >> 0] = 49; //@line 9612
 HEAP8[651929 + ($2025 + 37) >> 0] = 64; //@line 9615
 HEAP8[651929 + ($2025 + 38) >> 0] = 0; //@line 9618
 HEAP8[651929 + ($2025 + 39) >> 0] = 16; //@line 9621
 HEAP8[651929 + ($2025 + 40) >> 0] = 78; //@line 9624
 HEAP8[651929 + ($2025 + 41) >> 0] = 117; //@line 9627
 HEAP8[651929 + ($2025 + 42) >> 0] = 74; //@line 9630
 HEAP8[651929 + ($2025 + 43) >> 0] = 64; //@line 9633
 HEAP8[651929 + ($2025 + 44) >> 0] = 111; //@line 9636
 HEAP8[651929 + ($2025 + 45) >> 0] = 4; //@line 9639
 HEAP8[651929 + ($2025 + 46) >> 0] = 66; //@line 9642
 HEAP8[651929 + ($2025 + 47) >> 0] = 64; //@line 9645
 HEAP8[651929 + ($2025 + 48) >> 0] = 78; //@line 9648
 HEAP8[651929 + ($2025 + 49) >> 0] = 117; //@line 9651
 HEAP8[651929 + ($2025 + 50) >> 0] = 47; //@line 9654
 HEAP8[651929 + ($2025 + 51) >> 0] = 56; //@line 9657
 HEAP8[651929 + ($2025 + 52) >> 0] = 8; //@line 9660
 HEAP8[651929 + ($2025 + 53) >> 0] = -4; //@line 9663
 HEAP8[651929 + ($2025 + 54) >> 0] = 78; //@line 9666
 HEAP8[651929 + ($2025 + 55) >> 0] = 117; //@line 9669
 HEAP8[651929 + ($2025 + 56) >> 0] = 112; //@line 9672
 HEAP8[651929 + ($2025 + 57) >> 0] = -24; //@line 9675
 HEAP8[651929 + ($2025 + 58) >> 0] = 78; //@line 9678
 $2143 = $2025 + 60 | 0; //@line 9679
 HEAP8[651929 + ($2025 + 59) >> 0] = 117; //@line 9681
 $2145 = $1851 - $2143 | 0; //@line 9682
 HEAP8[651929 + $2143 >> 0] = 2; //@line 9685
 HEAP8[651929 + ($2025 + 61) >> 0] = $2145 >>> 16; //@line 9690
 HEAP8[651929 + ($2025 + 62) >> 0] = $2145 >>> 8; //@line 9695
 HEAP8[651929 + ($2025 + 63) >> 0] = $2145; //@line 9699
 HEAP8[651929 + ($2025 + 64) >> 0] = -1; //@line 9702
 HEAP8[651929 + ($2025 + 65) >> 0] = 0; //@line 9705
 HEAP8[651929 + ($2025 + 66) >> 0] = 0; //@line 9708
 $2165 = $2025 + 68 | 0; //@line 9709
 HEAP8[651929 + ($2025 + 67) >> 0] = 0; //@line 9711
 $2167 = $1760 - $2165 | 0; //@line 9712
 HEAP8[651929 + $2165 >> 0] = 1; //@line 9715
 HEAP8[651929 + ($2025 + 69) >> 0] = $2167 >>> 16; //@line 9720
 HEAP8[651929 + ($2025 + 70) >> 0] = $2167 >>> 8; //@line 9725
 $2179 = $2025 + 72 | 0; //@line 9727
 HEAP8[651929 + ($2025 + 71) >> 0] = $2167; //@line 9729
 $2181 = $1776 - $2179 | 0; //@line 9730
 HEAP8[651929 + $2179 >> 0] = 2; //@line 9733
 HEAP8[651929 + ($2025 + 73) >> 0] = $2181 >>> 16; //@line 9738
 HEAP8[651929 + ($2025 + 74) >> 0] = $2181 >>> 8; //@line 9743
 HEAP8[651929 + ($2025 + 75) >> 0] = $2181; //@line 9747
 HEAP8[651929 + ($2025 + 76) >> 0] = 4; //@line 9750
 HEAP8[651929 + ($2025 + 77) >> 0] = -1; //@line 9753
 HEAP8[651929 + ($2025 + 78) >> 0] = -1; //@line 9756
 HEAP8[651929 + ($2025 + 79) >> 0] = -16; //@line 9759
 HEAP8[651929 + ($2025 + 80) >> 0] = 7; //@line 9762
 HEAP8[651929 + ($2025 + 81) >> 0] = 0; //@line 9765
 HEAP8[651929 + ($2025 + 82) >> 0] = 0; //@line 9768
 HEAP8[651929 + ($2025 + 83) >> 0] = 2; //@line 9771
 HEAP8[651929 + ($2025 + 84) >> 0] = 8; //@line 9774
 HEAP8[651929 + ($2025 + 85) >> 0] = 0; //@line 9777
 HEAP8[651929 + ($2025 + 86) >> 0] = 66; //@line 9780
 HEAP8[651929 + ($2025 + 87) >> 0] = 50; //@line 9783
 HEAP8[651929 + ($2025 + 88) >> 0] = -1; //@line 9786
 HEAP8[651929 + ($2025 + 89) >> 0] = 0; //@line 9789
 HEAP8[651929 + ($2025 + 90) >> 0] = 0; //@line 9792
 $2225 = $2025 + 92 | 0; //@line 9793
 HEAP8[651929 + ($2025 + 91) >> 0] = 0; //@line 9795
 $2227 = $134 - $2225 | 0; //@line 9796
 HEAP8[651929 + $2225 >> 0] = 1; //@line 9799
 HEAP8[651929 + ($2025 + 93) >> 0] = $2227 >>> 16; //@line 9804
 HEAP8[651929 + ($2025 + 94) >> 0] = $2227 >>> 8; //@line 9809
 $2239 = $2025 + 96 | 0; //@line 9811
 HEAP32[28210] = $2239; //@line 9812
 HEAP8[651929 + ($2025 + 95) >> 0] = $2227; //@line 9814
 $2241 = HEAP32[30548] | 0; //@line 9815
 if (($2241 | 0) == ($2 | 0)) {
  $2268 = $2239; //@line 9818
 } else {
  $$pre219 = HEAP32[$0 >> 2] | 0; //@line 9820
  $$0158 = 0; //@line 9821
  $2244 = $2241; //@line 9821
  $2250 = $2239; //@line 9821
  while (1) {
   $2249 = (HEAP32[$$pre219 + ($$0158 << 2) >> 2] | 0) - $2250 | 0; //@line 9828
   HEAP8[651929 + $2250 >> 0] = HEAP8[(HEAP32[$2244 >> 2] | 0) + 24 >> 0] | 0; //@line 9831
   HEAP8[651929 + ($2250 + 1) >> 0] = $2249 >>> 16; //@line 9836
   HEAP8[651929 + ($2250 + 2) >> 0] = $2249 >>> 8; //@line 9841
   $2262 = $2250 + 4 | 0; //@line 9843
   HEAP32[28210] = $2262; //@line 9844
   HEAP8[651929 + ($2250 + 3) >> 0] = $2249; //@line 9846
   $2244 = $2244 + 4 | 0; //@line 9847
   if (($2244 | 0) == ($2 | 0)) {
    $2268 = $2262; //@line 9851
    break;
   } else {
    $$0158 = $$0158 + 1 | 0; //@line 9854
    $2250 = $2262; //@line 9854
   }
  }
 }
 $2267 = $1708 - $2268 | 0; //@line 9858
 HEAP8[651929 + $2268 >> 0] = -16; //@line 9861
 HEAP8[651929 + ($2268 + 1) >> 0] = $2267 >>> 16; //@line 9866
 HEAP8[651929 + ($2268 + 2) >> 0] = $2267 >>> 8; //@line 9871
 $2280 = $2268 + 4 | 0; //@line 9873
 HEAP8[651929 + ($2268 + 3) >> 0] = $2267; //@line 9875
 $2282 = $2165 - $2280 | 0; //@line 9876
 HEAP8[651929 + $2280 >> 0] = -15; //@line 9879
 HEAP8[651929 + ($2268 + 5) >> 0] = $2282 >>> 16; //@line 9884
 HEAP8[651929 + ($2268 + 6) >> 0] = $2282 >>> 8; //@line 9889
 HEAP8[651929 + ($2268 + 7) >> 0] = $2282; //@line 9893
 HEAP8[651929 + ($2268 + 8) >> 0] = -1; //@line 9896
 HEAP8[651929 + ($2268 + 9) >> 0] = 0; //@line 9899
 HEAP8[651929 + ($2268 + 10) >> 0] = 0; //@line 9902
 $2302 = $2268 + 12 | 0; //@line 9903
 HEAP8[651929 + ($2268 + 11) >> 0] = 0; //@line 9905
 $2304 = $2225 - $2302 | 0; //@line 9906
 HEAP8[651929 + $2302 >> 0] = 0; //@line 9909
 HEAP8[651929 + ($2268 + 13) >> 0] = $2304 >>> 16; //@line 9914
 HEAP8[651929 + ($2268 + 14) >> 0] = $2304 >>> 8; //@line 9919
 HEAP8[651929 + ($2268 + 15) >> 0] = $2304; //@line 9923
 $2318 = $2268 + 32 | 0; //@line 9924
 HEAP8[651929 + ($2268 + 16) >> 0] = $2318 >>> 24; //@line 9929
 HEAP8[651929 + ($2268 + 17) >> 0] = $2318 >>> 16; //@line 9934
 HEAP8[651929 + ($2268 + 18) >> 0] = $2318 >>> 8; //@line 9939
 HEAP8[651929 + ($2268 + 19) >> 0] = $2318; //@line 9943
 HEAP8[651929 + ($2268 + 20) >> 0] = 0; //@line 9946
 HEAP8[651929 + ($2268 + 21) >> 0] = 0; //@line 9949
 HEAP8[651929 + ($2268 + 22) >> 0] = 0; //@line 9952
 HEAP8[651929 + ($2268 + 23) >> 0] = 0; //@line 9955
 HEAP8[651929 + ($2268 + 24) >> 0] = 1; //@line 9958
 HEAP8[651929 + ($2268 + 25) >> 0] = 1; //@line 9961
 HEAP8[651929 + ($2268 + 26) >> 0] = 90; //@line 9964
 HEAP8[651929 + ($2268 + 27) >> 0] = -109; //@line 9967
 HEAP8[651929 + ($2268 + 28) >> 0] = 43; //@line 9970
 HEAP8[651929 + ($2268 + 29) >> 0] = -57; //@line 9973
 HEAP8[651929 + ($2268 + 30) >> 0] = 0; //@line 9976
 HEAP32[28210] = $2318; //@line 9977
 HEAP8[651929 + ($2268 + 31) >> 0] = 15; //@line 9979
 HEAP32[28211] = $2318; //@line 9980
 _memcpy((HEAP32[30897] | 0) + (HEAP32[30898] | 0) + (-32 - $2268) | 0, 651929, $2318 | 0) | 0; //@line 9986
 $2366 = (HEAP32[30897] | 0) + (HEAP32[30898] | 0) + (-32 - $2268) | 0; //@line 9991
 $2368 = $2366 + ($2268 + 20) | 0; //@line 9993
 HEAP8[$2368 >> 0] = 0; //@line 9994
 $2370 = $2366 + ($2268 + 21) | 0; //@line 9996
 HEAP8[$2370 >> 0] = 0; //@line 9997
 $2372 = $2366 + ($2268 + 22) | 0; //@line 9999
 HEAP8[$2372 >> 0] = 0; //@line 10000
 $2374 = $2366 + ($2268 + 23) | 0; //@line 10002
 HEAP8[$2374 >> 0] = 0; //@line 10003
 if (($2318 | 0) > 0) {
  $$02324$i = 0; //@line 10006
  $$025$i = 0; //@line 10006
  while (1) {
   $2382 = (HEAPU8[$2366 + $$025$i >> 0] | 0) + ($$02324$i << 1 | $$02324$i >>> 31) | 0; //@line 10014
   $$025$i = $$025$i + 1 | 0; //@line 10015
   if (($$025$i | 0) == ($2318 | 0)) {
    $$023$lcssa$i = $2382; //@line 10018
    break;
   } else {
    $$02324$i = $2382; //@line 10021
   }
  }
 } else {
  $$023$lcssa$i = 0; //@line 10025
 }
 HEAP8[$2368 >> 0] = $$023$lcssa$i >>> 24; //@line 10029
 HEAP8[$2370 >> 0] = $$023$lcssa$i >>> 16; //@line 10032
 HEAP8[$2372 >> 0] = $$023$lcssa$i >>> 8; //@line 10035
 HEAP8[$2374 >> 0] = $$023$lcssa$i; //@line 10037
 $2391 = HEAP32[$0 >> 2] | 0; //@line 10038
 if (!$2391) {
  STACKTOP = sp; //@line 10041
  return 1; //@line 10041
 }
 $2393 = HEAP32[$3 >> 2] | 0; //@line 10043
 if (($2393 | 0) != ($2391 | 0)) {
  HEAP32[$3 >> 2] = $2393 + (~(($2393 + -4 - $2391 | 0) >>> 2) << 2); //@line 10053
 }
 __ZdlPv($2391); //@line 10055
 STACKTOP = sp; //@line 10056
 return 1; //@line 10056
}
function _malloc($0) {
 $0 = $0 | 0;
 var $$$0192$i = 0, $$$0193$i = 0, $$$4351$i = 0, $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i18$i = 0, $$01$i$i = 0, $$0189$i = 0, $$0192$lcssa$i = 0, $$01928$i = 0, $$0193$lcssa$i = 0, $$01937$i = 0, $$0197 = 0, $$0199 = 0, $$0206$i$i = 0, $$0207$i$i = 0, $$0211$i$i = 0, $$0212$i$i = 0, $$024371$i = 0, $$0287$i$i = 0, $$0288$i$i = 0, $$0289$i$i = 0, $$0295$i$i = 0, $$0296$i$i = 0, $$0342$i = 0, $$0344$i = 0, $$0345$i = 0, $$0347$i = 0, $$0353$i = 0, $$0358$i = 0, $$0359$i = 0, $$0361$i = 0, $$0362$i = 0, $$0368$i = 0, $$1196$i = 0, $$1198$i = 0, $$124470$i = 0, $$1291$i$i = 0, $$1293$i$i = 0, $$1343$i = 0, $$1348$i = 0, $$1363$i = 0, $$1370$i = 0, $$1374$i = 0, $$2234253237$i = 0, $$2247$ph$i = 0, $$2253$ph$i = 0, $$2355$i = 0, $$3$i = 0, $$3$i$i = 0, $$3$i201 = 0, $$3350$i = 0, $$3372$i = 0, $$4$lcssa$i = 0, $$4$ph$i = 0, $$415$i = 0, $$4236$i = 0, $$4351$lcssa$i = 0, $$435114$i = 0, $$4357$$4$i = 0, $$4357$ph$i = 0, $$435713$i = 0, $$723948$i = 0, $$749$i = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i20$iZ2D = 0, $$pre$phi$i211Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi11$i$iZ2D = 0, $$pre$phiZ2D = 0, $1 = 0, $1001 = 0, $1007 = 0, $101 = 0, $1010 = 0, $1011 = 0, $102 = 0, $1029 = 0, $1031 = 0, $1038 = 0, $1039 = 0, $1040 = 0, $1048 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $108 = 0, $112 = 0, $114 = 0, $115 = 0, $117 = 0, $119 = 0, $121 = 0, $123 = 0, $125 = 0, $127 = 0, $129 = 0, $134 = 0, $138 = 0, $14 = 0, $142 = 0, $145 = 0, $148 = 0, $149 = 0, $155 = 0, $157 = 0, $16 = 0, $160 = 0, $162 = 0, $165 = 0, $167 = 0, $17 = 0, $170 = 0, $173 = 0, $174 = 0, $176 = 0, $177 = 0, $179 = 0, $18 = 0, $180 = 0, $182 = 0, $183 = 0, $188 = 0, $189 = 0, $19 = 0, $20 = 0, $201 = 0, $205 = 0, $211 = 0, $218 = 0, $222 = 0, $231 = 0, $232 = 0, $234 = 0, $235 = 0, $239 = 0, $240 = 0, $248 = 0, $249 = 0, $250 = 0, $252 = 0, $253 = 0, $258 = 0, $259 = 0, $262 = 0, $264 = 0, $267 = 0, $27 = 0, $272 = 0, $279 = 0, $289 = 0, $293 = 0, $299 = 0, $30 = 0, $303 = 0, $306 = 0, $310 = 0, $312 = 0, $313 = 0, $315 = 0, $317 = 0, $319 = 0, $321 = 0, $323 = 0, $325 = 0, $327 = 0, $337 = 0, $338 = 0, $34 = 0, $348 = 0, $350 = 0, $353 = 0, $355 = 0, $358 = 0, $360 = 0, $363 = 0, $366 = 0, $367 = 0, $369 = 0, $37 = 0, $370 = 0, $372 = 0, $373 = 0, $375 = 0, $376 = 0, $381 = 0, $382 = 0, $387 = 0, $394 = 0, $398 = 0, $404 = 0, $41 = 0, $411 = 0, $415 = 0, $423 = 0, $426 = 0, $427 = 0, $428 = 0, $432 = 0, $433 = 0, $439 = 0, $44 = 0, $444 = 0, $445 = 0, $448 = 0, $450 = 0, $453 = 0, $458 = 0, $464 = 0, $466 = 0, $468 = 0, $47 = 0, $470 = 0, $487 = 0, $489 = 0, $49 = 0, $496 = 0, $497 = 0, $498 = 0, $50 = 0, $506 = 0, $508 = 0, $509 = 0, $511 = 0, $52 = 0, $520 = 0, $524 = 0, $526 = 0, $527 = 0, $528 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $546 = 0, $548 = 0, $549 = 0, $555 = 0, $557 = 0, $559 = 0, $56 = 0, $564 = 0, $566 = 0, $568 = 0, $569 = 0, $570 = 0, $578 = 0, $579 = 0, $58 = 0, $582 = 0, $586 = 0, $589 = 0, $591 = 0, $597 = 0, $6 = 0, $60 = 0, $601 = 0, $605 = 0, $614 = 0, $615 = 0, $62 = 0, $621 = 0, $623 = 0, $627 = 0, $630 = 0, $632 = 0, $637 = 0, $64 = 0, $643 = 0, $648 = 0, $649 = 0, $650 = 0, $656 = 0, $657 = 0, $658 = 0, $662 = 0, $67 = 0, $673 = 0, $678 = 0, $679 = 0, $681 = 0, $687 = 0, $689 = 0, $69 = 0, $693 = 0, $699 = 0, $7 = 0, $70 = 0, $703 = 0, $709 = 0, $71 = 0, $711 = 0, $717 = 0, $72 = 0, $721 = 0, $722 = 0, $727 = 0, $73 = 0, $733 = 0, $738 = 0, $741 = 0, $742 = 0, $745 = 0, $747 = 0, $749 = 0, $752 = 0, $763 = 0, $768 = 0, $77 = 0, $770 = 0, $773 = 0, $775 = 0, $778 = 0, $781 = 0, $782 = 0, $783 = 0, $785 = 0, $787 = 0, $788 = 0, $790 = 0, $791 = 0, $796 = 0, $797 = 0, $8 = 0, $80 = 0, $810 = 0, $813 = 0, $814 = 0, $820 = 0, $828 = 0, $834 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $843 = 0, $844 = 0, $850 = 0, $855 = 0, $856 = 0, $859 = 0, $861 = 0, $864 = 0, $869 = 0, $87 = 0, $875 = 0, $877 = 0, $879 = 0, $880 = 0, $898 = 0, $9 = 0, $900 = 0, $907 = 0, $908 = 0, $909 = 0, $916 = 0, $92 = 0, $920 = 0, $924 = 0, $926 = 0, $93 = 0, $932 = 0, $933 = 0, $935 = 0, $936 = 0, $937 = 0, $940 = 0, $945 = 0, $946 = 0, $947 = 0, $95 = 0, $953 = 0, $955 = 0, $96 = 0, $961 = 0, $966 = 0, $969 = 0, $970 = 0, $971 = 0, $975 = 0, $976 = 0, $98 = 0, $982 = 0, $987 = 0, $988 = 0, $991 = 0, $993 = 0, $996 = 0, label = 0, sp = 0, $955$looptemp = 0;
 sp = STACKTOP; //@line 50262
 STACKTOP = STACKTOP + 16 | 0; //@line 50263
 $1 = sp; //@line 50264
 do {
  if ($0 >>> 0 < 245) {
   $6 = $0 >>> 0 < 11 ? 16 : $0 + 11 & -8; //@line 50271
   $7 = $6 >>> 3; //@line 50272
   $8 = HEAP32[162835] | 0; //@line 50273
   $9 = $8 >>> $7; //@line 50274
   if ($9 & 3 | 0) {
    $14 = ($9 & 1 ^ 1) + $7 | 0; //@line 50280
    $16 = 651380 + ($14 << 1 << 2) | 0; //@line 50282
    $17 = $16 + 8 | 0; //@line 50283
    $18 = HEAP32[$17 >> 2] | 0; //@line 50284
    $19 = $18 + 8 | 0; //@line 50285
    $20 = HEAP32[$19 >> 2] | 0; //@line 50286
    do {
     if (($16 | 0) == ($20 | 0)) {
      HEAP32[162835] = $8 & ~(1 << $14); //@line 50293
     } else {
      if ($20 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 50298
      }
      $27 = $20 + 12 | 0; //@line 50301
      if ((HEAP32[$27 >> 2] | 0) == ($18 | 0)) {
       HEAP32[$27 >> 2] = $16; //@line 50305
       HEAP32[$17 >> 2] = $20; //@line 50306
       break;
      } else {
       _abort(); //@line 50309
      }
     }
    } while (0);
    $30 = $14 << 3; //@line 50314
    HEAP32[$18 + 4 >> 2] = $30 | 3; //@line 50317
    $34 = $18 + $30 + 4 | 0; //@line 50319
    HEAP32[$34 >> 2] = HEAP32[$34 >> 2] | 1; //@line 50322
    $$0 = $19; //@line 50323
    STACKTOP = sp; //@line 50324
    return $$0 | 0; //@line 50324
   }
   $37 = HEAP32[162837] | 0; //@line 50326
   if ($6 >>> 0 > $37 >>> 0) {
    if ($9 | 0) {
     $41 = 2 << $7; //@line 50332
     $44 = $9 << $7 & ($41 | 0 - $41); //@line 50335
     $47 = ($44 & 0 - $44) + -1 | 0; //@line 50338
     $49 = $47 >>> 12 & 16; //@line 50340
     $50 = $47 >>> $49; //@line 50341
     $52 = $50 >>> 5 & 8; //@line 50343
     $54 = $50 >>> $52; //@line 50345
     $56 = $54 >>> 2 & 4; //@line 50347
     $58 = $54 >>> $56; //@line 50349
     $60 = $58 >>> 1 & 2; //@line 50351
     $62 = $58 >>> $60; //@line 50353
     $64 = $62 >>> 1 & 1; //@line 50355
     $67 = ($52 | $49 | $56 | $60 | $64) + ($62 >>> $64) | 0; //@line 50358
     $69 = 651380 + ($67 << 1 << 2) | 0; //@line 50360
     $70 = $69 + 8 | 0; //@line 50361
     $71 = HEAP32[$70 >> 2] | 0; //@line 50362
     $72 = $71 + 8 | 0; //@line 50363
     $73 = HEAP32[$72 >> 2] | 0; //@line 50364
     do {
      if (($69 | 0) == ($73 | 0)) {
       $77 = $8 & ~(1 << $67); //@line 50370
       HEAP32[162835] = $77; //@line 50371
       $98 = $77; //@line 50372
      } else {
       if ($73 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
        _abort(); //@line 50377
       }
       $80 = $73 + 12 | 0; //@line 50380
       if ((HEAP32[$80 >> 2] | 0) == ($71 | 0)) {
        HEAP32[$80 >> 2] = $69; //@line 50384
        HEAP32[$70 >> 2] = $73; //@line 50385
        $98 = $8; //@line 50386
        break;
       } else {
        _abort(); //@line 50389
       }
      }
     } while (0);
     $84 = ($67 << 3) - $6 | 0; //@line 50395
     HEAP32[$71 + 4 >> 2] = $6 | 3; //@line 50398
     $87 = $71 + $6 | 0; //@line 50399
     HEAP32[$87 + 4 >> 2] = $84 | 1; //@line 50402
     HEAP32[$87 + $84 >> 2] = $84; //@line 50404
     if ($37 | 0) {
      $92 = HEAP32[162840] | 0; //@line 50407
      $93 = $37 >>> 3; //@line 50408
      $95 = 651380 + ($93 << 1 << 2) | 0; //@line 50410
      $96 = 1 << $93; //@line 50411
      if (!($98 & $96)) {
       HEAP32[162835] = $98 | $96; //@line 50416
       $$0199 = $95; //@line 50418
       $$pre$phiZ2D = $95 + 8 | 0; //@line 50418
      } else {
       $101 = $95 + 8 | 0; //@line 50420
       $102 = HEAP32[$101 >> 2] | 0; //@line 50421
       if ($102 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
        _abort(); //@line 50425
       } else {
        $$0199 = $102; //@line 50428
        $$pre$phiZ2D = $101; //@line 50428
       }
      }
      HEAP32[$$pre$phiZ2D >> 2] = $92; //@line 50431
      HEAP32[$$0199 + 12 >> 2] = $92; //@line 50433
      HEAP32[$92 + 8 >> 2] = $$0199; //@line 50435
      HEAP32[$92 + 12 >> 2] = $95; //@line 50437
     }
     HEAP32[162837] = $84; //@line 50439
     HEAP32[162840] = $87; //@line 50440
     $$0 = $72; //@line 50441
     STACKTOP = sp; //@line 50442
     return $$0 | 0; //@line 50442
    }
    $108 = HEAP32[162836] | 0; //@line 50444
    if (!$108) {
     $$0197 = $6; //@line 50447
    } else {
     $112 = ($108 & 0 - $108) + -1 | 0; //@line 50451
     $114 = $112 >>> 12 & 16; //@line 50453
     $115 = $112 >>> $114; //@line 50454
     $117 = $115 >>> 5 & 8; //@line 50456
     $119 = $115 >>> $117; //@line 50458
     $121 = $119 >>> 2 & 4; //@line 50460
     $123 = $119 >>> $121; //@line 50462
     $125 = $123 >>> 1 & 2; //@line 50464
     $127 = $123 >>> $125; //@line 50466
     $129 = $127 >>> 1 & 1; //@line 50468
     $134 = HEAP32[651644 + (($117 | $114 | $121 | $125 | $129) + ($127 >>> $129) << 2) >> 2] | 0; //@line 50473
     $138 = (HEAP32[$134 + 4 >> 2] & -8) - $6 | 0; //@line 50477
     $142 = HEAP32[$134 + 16 + (((HEAP32[$134 + 16 >> 2] | 0) == 0 & 1) << 2) >> 2] | 0; //@line 50483
     if (!$142) {
      $$0192$lcssa$i = $134; //@line 50486
      $$0193$lcssa$i = $138; //@line 50486
     } else {
      $$01928$i = $134; //@line 50488
      $$01937$i = $138; //@line 50488
      $145 = $142; //@line 50488
      while (1) {
       $148 = (HEAP32[$145 + 4 >> 2] & -8) - $6 | 0; //@line 50493
       $149 = $148 >>> 0 < $$01937$i >>> 0; //@line 50494
       $$$0193$i = $149 ? $148 : $$01937$i; //@line 50495
       $$$0192$i = $149 ? $145 : $$01928$i; //@line 50496
       $145 = HEAP32[$145 + 16 + (((HEAP32[$145 + 16 >> 2] | 0) == 0 & 1) << 2) >> 2] | 0; //@line 50502
       if (!$145) {
        $$0192$lcssa$i = $$$0192$i; //@line 50505
        $$0193$lcssa$i = $$$0193$i; //@line 50505
        break;
       } else {
        $$01928$i = $$$0192$i; //@line 50508
        $$01937$i = $$$0193$i; //@line 50508
       }
      }
     }
     $155 = HEAP32[162839] | 0; //@line 50512
     if ($$0192$lcssa$i >>> 0 < $155 >>> 0) {
      _abort(); //@line 50515
     }
     $157 = $$0192$lcssa$i + $6 | 0; //@line 50518
     if ($$0192$lcssa$i >>> 0 >= $157 >>> 0) {
      _abort(); //@line 50521
     }
     $160 = HEAP32[$$0192$lcssa$i + 24 >> 2] | 0; //@line 50525
     $162 = HEAP32[$$0192$lcssa$i + 12 >> 2] | 0; //@line 50527
     do {
      if (($162 | 0) == ($$0192$lcssa$i | 0)) {
       $173 = $$0192$lcssa$i + 20 | 0; //@line 50531
       $174 = HEAP32[$173 >> 2] | 0; //@line 50532
       if (!$174) {
        $176 = $$0192$lcssa$i + 16 | 0; //@line 50535
        $177 = HEAP32[$176 >> 2] | 0; //@line 50536
        if (!$177) {
         $$3$i = 0; //@line 50539
         break;
        } else {
         $$1196$i = $177; //@line 50542
         $$1198$i = $176; //@line 50542
        }
       } else {
        $$1196$i = $174; //@line 50545
        $$1198$i = $173; //@line 50545
       }
       while (1) {
        $179 = $$1196$i + 20 | 0; //@line 50548
        $180 = HEAP32[$179 >> 2] | 0; //@line 50549
        if ($180 | 0) {
         $$1196$i = $180; //@line 50552
         $$1198$i = $179; //@line 50552
         continue;
        }
        $182 = $$1196$i + 16 | 0; //@line 50555
        $183 = HEAP32[$182 >> 2] | 0; //@line 50556
        if (!$183) {
         break;
        } else {
         $$1196$i = $183; //@line 50561
         $$1198$i = $182; //@line 50561
        }
       }
       if ($$1198$i >>> 0 < $155 >>> 0) {
        _abort(); //@line 50566
       } else {
        HEAP32[$$1198$i >> 2] = 0; //@line 50569
        $$3$i = $$1196$i; //@line 50570
        break;
       }
      } else {
       $165 = HEAP32[$$0192$lcssa$i + 8 >> 2] | 0; //@line 50575
       if ($165 >>> 0 < $155 >>> 0) {
        _abort(); //@line 50578
       }
       $167 = $165 + 12 | 0; //@line 50581
       if ((HEAP32[$167 >> 2] | 0) != ($$0192$lcssa$i | 0)) {
        _abort(); //@line 50585
       }
       $170 = $162 + 8 | 0; //@line 50588
       if ((HEAP32[$170 >> 2] | 0) == ($$0192$lcssa$i | 0)) {
        HEAP32[$167 >> 2] = $162; //@line 50592
        HEAP32[$170 >> 2] = $165; //@line 50593
        $$3$i = $162; //@line 50594
        break;
       } else {
        _abort(); //@line 50597
       }
      }
     } while (0);
     L73 : do {
      if ($160 | 0) {
       $188 = HEAP32[$$0192$lcssa$i + 28 >> 2] | 0; //@line 50606
       $189 = 651644 + ($188 << 2) | 0; //@line 50607
       do {
        if (($$0192$lcssa$i | 0) == (HEAP32[$189 >> 2] | 0)) {
         HEAP32[$189 >> 2] = $$3$i; //@line 50612
         if (!$$3$i) {
          HEAP32[162836] = $108 & ~(1 << $188); //@line 50618
          break L73;
         }
        } else {
         if ($160 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
          _abort(); //@line 50625
         } else {
          HEAP32[$160 + 16 + (((HEAP32[$160 + 16 >> 2] | 0) != ($$0192$lcssa$i | 0) & 1) << 2) >> 2] = $$3$i; //@line 50633
          if (!$$3$i) {
           break L73;
          } else {
           break;
          }
         }
        }
       } while (0);
       $201 = HEAP32[162839] | 0; //@line 50643
       if ($$3$i >>> 0 < $201 >>> 0) {
        _abort(); //@line 50646
       }
       HEAP32[$$3$i + 24 >> 2] = $160; //@line 50650
       $205 = HEAP32[$$0192$lcssa$i + 16 >> 2] | 0; //@line 50652
       do {
        if ($205 | 0) {
         if ($205 >>> 0 < $201 >>> 0) {
          _abort(); //@line 50658
         } else {
          HEAP32[$$3$i + 16 >> 2] = $205; //@line 50662
          HEAP32[$205 + 24 >> 2] = $$3$i; //@line 50664
          break;
         }
        }
       } while (0);
       $211 = HEAP32[$$0192$lcssa$i + 20 >> 2] | 0; //@line 50670
       if ($211 | 0) {
        if ($211 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
         _abort(); //@line 50676
        } else {
         HEAP32[$$3$i + 20 >> 2] = $211; //@line 50680
         HEAP32[$211 + 24 >> 2] = $$3$i; //@line 50682
         break;
        }
       }
      }
     } while (0);
     if ($$0193$lcssa$i >>> 0 < 16) {
      $218 = $$0193$lcssa$i + $6 | 0; //@line 50690
      HEAP32[$$0192$lcssa$i + 4 >> 2] = $218 | 3; //@line 50693
      $222 = $$0192$lcssa$i + $218 + 4 | 0; //@line 50695
      HEAP32[$222 >> 2] = HEAP32[$222 >> 2] | 1; //@line 50698
     } else {
      HEAP32[$$0192$lcssa$i + 4 >> 2] = $6 | 3; //@line 50702
      HEAP32[$157 + 4 >> 2] = $$0193$lcssa$i | 1; //@line 50705
      HEAP32[$157 + $$0193$lcssa$i >> 2] = $$0193$lcssa$i; //@line 50707
      if ($37 | 0) {
       $231 = HEAP32[162840] | 0; //@line 50710
       $232 = $37 >>> 3; //@line 50711
       $234 = 651380 + ($232 << 1 << 2) | 0; //@line 50713
       $235 = 1 << $232; //@line 50714
       if (!($8 & $235)) {
        HEAP32[162835] = $8 | $235; //@line 50719
        $$0189$i = $234; //@line 50721
        $$pre$phi$iZ2D = $234 + 8 | 0; //@line 50721
       } else {
        $239 = $234 + 8 | 0; //@line 50723
        $240 = HEAP32[$239 >> 2] | 0; //@line 50724
        if ($240 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
         _abort(); //@line 50728
        } else {
         $$0189$i = $240; //@line 50731
         $$pre$phi$iZ2D = $239; //@line 50731
        }
       }
       HEAP32[$$pre$phi$iZ2D >> 2] = $231; //@line 50734
       HEAP32[$$0189$i + 12 >> 2] = $231; //@line 50736
       HEAP32[$231 + 8 >> 2] = $$0189$i; //@line 50738
       HEAP32[$231 + 12 >> 2] = $234; //@line 50740
      }
      HEAP32[162837] = $$0193$lcssa$i; //@line 50742
      HEAP32[162840] = $157; //@line 50743
     }
     $$0 = $$0192$lcssa$i + 8 | 0; //@line 50746
     STACKTOP = sp; //@line 50747
     return $$0 | 0; //@line 50747
    }
   } else {
    $$0197 = $6; //@line 50750
   }
  } else {
   if ($0 >>> 0 > 4294967231) {
    $$0197 = -1; //@line 50755
   } else {
    $248 = $0 + 11 | 0; //@line 50757
    $249 = $248 & -8; //@line 50758
    $250 = HEAP32[162836] | 0; //@line 50759
    if (!$250) {
     $$0197 = $249; //@line 50762
    } else {
     $252 = 0 - $249 | 0; //@line 50764
     $253 = $248 >>> 8; //@line 50765
     if (!$253) {
      $$0358$i = 0; //@line 50768
     } else {
      if ($249 >>> 0 > 16777215) {
       $$0358$i = 31; //@line 50772
      } else {
       $258 = ($253 + 1048320 | 0) >>> 16 & 8; //@line 50776
       $259 = $253 << $258; //@line 50777
       $262 = ($259 + 520192 | 0) >>> 16 & 4; //@line 50780
       $264 = $259 << $262; //@line 50782
       $267 = ($264 + 245760 | 0) >>> 16 & 2; //@line 50785
       $272 = 14 - ($262 | $258 | $267) + ($264 << $267 >>> 15) | 0; //@line 50790
       $$0358$i = $249 >>> ($272 + 7 | 0) & 1 | $272 << 1; //@line 50796
      }
     }
     $279 = HEAP32[651644 + ($$0358$i << 2) >> 2] | 0; //@line 50800
     L117 : do {
      if (!$279) {
       $$2355$i = 0; //@line 50804
       $$3$i201 = 0; //@line 50804
       $$3350$i = $252; //@line 50804
       label = 81; //@line 50805
      } else {
       $$0342$i = 0; //@line 50812
       $$0347$i = $252; //@line 50812
       $$0353$i = $279; //@line 50812
       $$0359$i = $249 << (($$0358$i | 0) == 31 ? 0 : 25 - ($$0358$i >>> 1) | 0); //@line 50812
       $$0362$i = 0; //@line 50812
       while (1) {
        $289 = (HEAP32[$$0353$i + 4 >> 2] & -8) - $249 | 0; //@line 50817
        if ($289 >>> 0 < $$0347$i >>> 0) {
         if (!$289) {
          $$415$i = $$0353$i; //@line 50822
          $$435114$i = 0; //@line 50822
          $$435713$i = $$0353$i; //@line 50822
          label = 85; //@line 50823
          break L117;
         } else {
          $$1343$i = $$0353$i; //@line 50826
          $$1348$i = $289; //@line 50826
         }
        } else {
         $$1343$i = $$0342$i; //@line 50829
         $$1348$i = $$0347$i; //@line 50829
        }
        $293 = HEAP32[$$0353$i + 20 >> 2] | 0; //@line 50832
        $$0353$i = HEAP32[$$0353$i + 16 + ($$0359$i >>> 31 << 2) >> 2] | 0; //@line 50835
        $$1363$i = ($293 | 0) == 0 | ($293 | 0) == ($$0353$i | 0) ? $$0362$i : $293; //@line 50839
        $299 = ($$0353$i | 0) == 0; //@line 50840
        if ($299) {
         $$2355$i = $$1363$i; //@line 50845
         $$3$i201 = $$1343$i; //@line 50845
         $$3350$i = $$1348$i; //@line 50845
         label = 81; //@line 50846
         break;
        } else {
         $$0342$i = $$1343$i; //@line 50849
         $$0347$i = $$1348$i; //@line 50849
         $$0359$i = $$0359$i << (($299 ^ 1) & 1); //@line 50849
         $$0362$i = $$1363$i; //@line 50849
        }
       }
      }
     } while (0);
     if ((label | 0) == 81) {
      if (($$2355$i | 0) == 0 & ($$3$i201 | 0) == 0) {
       $303 = 2 << $$0358$i; //@line 50859
       $306 = $250 & ($303 | 0 - $303); //@line 50862
       if (!$306) {
        $$0197 = $249; //@line 50865
        break;
       }
       $310 = ($306 & 0 - $306) + -1 | 0; //@line 50870
       $312 = $310 >>> 12 & 16; //@line 50872
       $313 = $310 >>> $312; //@line 50873
       $315 = $313 >>> 5 & 8; //@line 50875
       $317 = $313 >>> $315; //@line 50877
       $319 = $317 >>> 2 & 4; //@line 50879
       $321 = $317 >>> $319; //@line 50881
       $323 = $321 >>> 1 & 2; //@line 50883
       $325 = $321 >>> $323; //@line 50885
       $327 = $325 >>> 1 & 1; //@line 50887
       $$4$ph$i = 0; //@line 50893
       $$4357$ph$i = HEAP32[651644 + (($315 | $312 | $319 | $323 | $327) + ($325 >>> $327) << 2) >> 2] | 0; //@line 50893
      } else {
       $$4$ph$i = $$3$i201; //@line 50895
       $$4357$ph$i = $$2355$i; //@line 50895
      }
      if (!$$4357$ph$i) {
       $$4$lcssa$i = $$4$ph$i; //@line 50899
       $$4351$lcssa$i = $$3350$i; //@line 50899
      } else {
       $$415$i = $$4$ph$i; //@line 50901
       $$435114$i = $$3350$i; //@line 50901
       $$435713$i = $$4357$ph$i; //@line 50901
       label = 85; //@line 50902
      }
     }
     if ((label | 0) == 85) {
      while (1) {
       label = 0; //@line 50907
       $337 = (HEAP32[$$435713$i + 4 >> 2] & -8) - $249 | 0; //@line 50911
       $338 = $337 >>> 0 < $$435114$i >>> 0; //@line 50912
       $$$4351$i = $338 ? $337 : $$435114$i; //@line 50913
       $$4357$$4$i = $338 ? $$435713$i : $$415$i; //@line 50914
       $$435713$i = HEAP32[$$435713$i + 16 + (((HEAP32[$$435713$i + 16 >> 2] | 0) == 0 & 1) << 2) >> 2] | 0; //@line 50920
       if (!$$435713$i) {
        $$4$lcssa$i = $$4357$$4$i; //@line 50923
        $$4351$lcssa$i = $$$4351$i; //@line 50923
        break;
       } else {
        $$415$i = $$4357$$4$i; //@line 50926
        $$435114$i = $$$4351$i; //@line 50926
        label = 85; //@line 50927
       }
      }
     }
     if (!$$4$lcssa$i) {
      $$0197 = $249; //@line 50933
     } else {
      if ($$4351$lcssa$i >>> 0 < ((HEAP32[162837] | 0) - $249 | 0) >>> 0) {
       $348 = HEAP32[162839] | 0; //@line 50939
       if ($$4$lcssa$i >>> 0 < $348 >>> 0) {
        _abort(); //@line 50942
       }
       $350 = $$4$lcssa$i + $249 | 0; //@line 50945
       if ($$4$lcssa$i >>> 0 >= $350 >>> 0) {
        _abort(); //@line 50948
       }
       $353 = HEAP32[$$4$lcssa$i + 24 >> 2] | 0; //@line 50952
       $355 = HEAP32[$$4$lcssa$i + 12 >> 2] | 0; //@line 50954
       do {
        if (($355 | 0) == ($$4$lcssa$i | 0)) {
         $366 = $$4$lcssa$i + 20 | 0; //@line 50958
         $367 = HEAP32[$366 >> 2] | 0; //@line 50959
         if (!$367) {
          $369 = $$4$lcssa$i + 16 | 0; //@line 50962
          $370 = HEAP32[$369 >> 2] | 0; //@line 50963
          if (!$370) {
           $$3372$i = 0; //@line 50966
           break;
          } else {
           $$1370$i = $370; //@line 50969
           $$1374$i = $369; //@line 50969
          }
         } else {
          $$1370$i = $367; //@line 50972
          $$1374$i = $366; //@line 50972
         }
         while (1) {
          $372 = $$1370$i + 20 | 0; //@line 50975
          $373 = HEAP32[$372 >> 2] | 0; //@line 50976
          if ($373 | 0) {
           $$1370$i = $373; //@line 50979
           $$1374$i = $372; //@line 50979
           continue;
          }
          $375 = $$1370$i + 16 | 0; //@line 50982
          $376 = HEAP32[$375 >> 2] | 0; //@line 50983
          if (!$376) {
           break;
          } else {
           $$1370$i = $376; //@line 50988
           $$1374$i = $375; //@line 50988
          }
         }
         if ($$1374$i >>> 0 < $348 >>> 0) {
          _abort(); //@line 50993
         } else {
          HEAP32[$$1374$i >> 2] = 0; //@line 50996
          $$3372$i = $$1370$i; //@line 50997
          break;
         }
        } else {
         $358 = HEAP32[$$4$lcssa$i + 8 >> 2] | 0; //@line 51002
         if ($358 >>> 0 < $348 >>> 0) {
          _abort(); //@line 51005
         }
         $360 = $358 + 12 | 0; //@line 51008
         if ((HEAP32[$360 >> 2] | 0) != ($$4$lcssa$i | 0)) {
          _abort(); //@line 51012
         }
         $363 = $355 + 8 | 0; //@line 51015
         if ((HEAP32[$363 >> 2] | 0) == ($$4$lcssa$i | 0)) {
          HEAP32[$360 >> 2] = $355; //@line 51019
          HEAP32[$363 >> 2] = $358; //@line 51020
          $$3372$i = $355; //@line 51021
          break;
         } else {
          _abort(); //@line 51024
         }
        }
       } while (0);
       L164 : do {
        if (!$353) {
         $470 = $250; //@line 51032
        } else {
         $381 = HEAP32[$$4$lcssa$i + 28 >> 2] | 0; //@line 51035
         $382 = 651644 + ($381 << 2) | 0; //@line 51036
         do {
          if (($$4$lcssa$i | 0) == (HEAP32[$382 >> 2] | 0)) {
           HEAP32[$382 >> 2] = $$3372$i; //@line 51041
           if (!$$3372$i) {
            $387 = $250 & ~(1 << $381); //@line 51046
            HEAP32[162836] = $387; //@line 51047
            $470 = $387; //@line 51048
            break L164;
           }
          } else {
           if ($353 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
            _abort(); //@line 51055
           } else {
            HEAP32[$353 + 16 + (((HEAP32[$353 + 16 >> 2] | 0) != ($$4$lcssa$i | 0) & 1) << 2) >> 2] = $$3372$i; //@line 51063
            if (!$$3372$i) {
             $470 = $250; //@line 51066
             break L164;
            } else {
             break;
            }
           }
          }
         } while (0);
         $394 = HEAP32[162839] | 0; //@line 51074
         if ($$3372$i >>> 0 < $394 >>> 0) {
          _abort(); //@line 51077
         }
         HEAP32[$$3372$i + 24 >> 2] = $353; //@line 51081
         $398 = HEAP32[$$4$lcssa$i + 16 >> 2] | 0; //@line 51083
         do {
          if ($398 | 0) {
           if ($398 >>> 0 < $394 >>> 0) {
            _abort(); //@line 51089
           } else {
            HEAP32[$$3372$i + 16 >> 2] = $398; //@line 51093
            HEAP32[$398 + 24 >> 2] = $$3372$i; //@line 51095
            break;
           }
          }
         } while (0);
         $404 = HEAP32[$$4$lcssa$i + 20 >> 2] | 0; //@line 51101
         if (!$404) {
          $470 = $250; //@line 51104
         } else {
          if ($404 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
           _abort(); //@line 51109
          } else {
           HEAP32[$$3372$i + 20 >> 2] = $404; //@line 51113
           HEAP32[$404 + 24 >> 2] = $$3372$i; //@line 51115
           $470 = $250; //@line 51116
           break;
          }
         }
        }
       } while (0);
       do {
        if ($$4351$lcssa$i >>> 0 < 16) {
         $411 = $$4351$lcssa$i + $249 | 0; //@line 51125
         HEAP32[$$4$lcssa$i + 4 >> 2] = $411 | 3; //@line 51128
         $415 = $$4$lcssa$i + $411 + 4 | 0; //@line 51130
         HEAP32[$415 >> 2] = HEAP32[$415 >> 2] | 1; //@line 51133
        } else {
         HEAP32[$$4$lcssa$i + 4 >> 2] = $249 | 3; //@line 51137
         HEAP32[$350 + 4 >> 2] = $$4351$lcssa$i | 1; //@line 51140
         HEAP32[$350 + $$4351$lcssa$i >> 2] = $$4351$lcssa$i; //@line 51142
         $423 = $$4351$lcssa$i >>> 3; //@line 51143
         if ($$4351$lcssa$i >>> 0 < 256) {
          $426 = 651380 + ($423 << 1 << 2) | 0; //@line 51147
          $427 = HEAP32[162835] | 0; //@line 51148
          $428 = 1 << $423; //@line 51149
          if (!($427 & $428)) {
           HEAP32[162835] = $427 | $428; //@line 51154
           $$0368$i = $426; //@line 51156
           $$pre$phi$i211Z2D = $426 + 8 | 0; //@line 51156
          } else {
           $432 = $426 + 8 | 0; //@line 51158
           $433 = HEAP32[$432 >> 2] | 0; //@line 51159
           if ($433 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
            _abort(); //@line 51163
           } else {
            $$0368$i = $433; //@line 51166
            $$pre$phi$i211Z2D = $432; //@line 51166
           }
          }
          HEAP32[$$pre$phi$i211Z2D >> 2] = $350; //@line 51169
          HEAP32[$$0368$i + 12 >> 2] = $350; //@line 51171
          HEAP32[$350 + 8 >> 2] = $$0368$i; //@line 51173
          HEAP32[$350 + 12 >> 2] = $426; //@line 51175
          break;
         }
         $439 = $$4351$lcssa$i >>> 8; //@line 51178
         if (!$439) {
          $$0361$i = 0; //@line 51181
         } else {
          if ($$4351$lcssa$i >>> 0 > 16777215) {
           $$0361$i = 31; //@line 51185
          } else {
           $444 = ($439 + 1048320 | 0) >>> 16 & 8; //@line 51189
           $445 = $439 << $444; //@line 51190
           $448 = ($445 + 520192 | 0) >>> 16 & 4; //@line 51193
           $450 = $445 << $448; //@line 51195
           $453 = ($450 + 245760 | 0) >>> 16 & 2; //@line 51198
           $458 = 14 - ($448 | $444 | $453) + ($450 << $453 >>> 15) | 0; //@line 51203
           $$0361$i = $$4351$lcssa$i >>> ($458 + 7 | 0) & 1 | $458 << 1; //@line 51209
          }
         }
         $464 = 651644 + ($$0361$i << 2) | 0; //@line 51212
         HEAP32[$350 + 28 >> 2] = $$0361$i; //@line 51214
         $466 = $350 + 16 | 0; //@line 51215
         HEAP32[$466 + 4 >> 2] = 0; //@line 51217
         HEAP32[$466 >> 2] = 0; //@line 51218
         $468 = 1 << $$0361$i; //@line 51219
         if (!($470 & $468)) {
          HEAP32[162836] = $470 | $468; //@line 51224
          HEAP32[$464 >> 2] = $350; //@line 51225
          HEAP32[$350 + 24 >> 2] = $464; //@line 51227
          HEAP32[$350 + 12 >> 2] = $350; //@line 51229
          HEAP32[$350 + 8 >> 2] = $350; //@line 51231
          break;
         }
         $$0344$i = $$4351$lcssa$i << (($$0361$i | 0) == 31 ? 0 : 25 - ($$0361$i >>> 1) | 0); //@line 51240
         $$0345$i = HEAP32[$464 >> 2] | 0; //@line 51240
         while (1) {
          if ((HEAP32[$$0345$i + 4 >> 2] & -8 | 0) == ($$4351$lcssa$i | 0)) {
           label = 139; //@line 51247
           break;
          }
          $487 = $$0345$i + 16 + ($$0344$i >>> 31 << 2) | 0; //@line 51251
          $489 = HEAP32[$487 >> 2] | 0; //@line 51253
          if (!$489) {
           label = 136; //@line 51256
           break;
          } else {
           $$0344$i = $$0344$i << 1; //@line 51259
           $$0345$i = $489; //@line 51259
          }
         }
         if ((label | 0) == 136) {
          if ($487 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
           _abort(); //@line 51266
          } else {
           HEAP32[$487 >> 2] = $350; //@line 51269
           HEAP32[$350 + 24 >> 2] = $$0345$i; //@line 51271
           HEAP32[$350 + 12 >> 2] = $350; //@line 51273
           HEAP32[$350 + 8 >> 2] = $350; //@line 51275
           break;
          }
         } else if ((label | 0) == 139) {
          $496 = $$0345$i + 8 | 0; //@line 51280
          $497 = HEAP32[$496 >> 2] | 0; //@line 51281
          $498 = HEAP32[162839] | 0; //@line 51282
          if ($497 >>> 0 >= $498 >>> 0 & $$0345$i >>> 0 >= $498 >>> 0) {
           HEAP32[$497 + 12 >> 2] = $350; //@line 51288
           HEAP32[$496 >> 2] = $350; //@line 51289
           HEAP32[$350 + 8 >> 2] = $497; //@line 51291
           HEAP32[$350 + 12 >> 2] = $$0345$i; //@line 51293
           HEAP32[$350 + 24 >> 2] = 0; //@line 51295
           break;
          } else {
           _abort(); //@line 51298
          }
         }
        }
       } while (0);
       $$0 = $$4$lcssa$i + 8 | 0; //@line 51305
       STACKTOP = sp; //@line 51306
       return $$0 | 0; //@line 51306
      } else {
       $$0197 = $249; //@line 51308
      }
     }
    }
   }
  }
 } while (0);
 $506 = HEAP32[162837] | 0; //@line 51315
 if ($506 >>> 0 >= $$0197 >>> 0) {
  $508 = $506 - $$0197 | 0; //@line 51318
  $509 = HEAP32[162840] | 0; //@line 51319
  if ($508 >>> 0 > 15) {
   $511 = $509 + $$0197 | 0; //@line 51322
   HEAP32[162840] = $511; //@line 51323
   HEAP32[162837] = $508; //@line 51324
   HEAP32[$511 + 4 >> 2] = $508 | 1; //@line 51327
   HEAP32[$511 + $508 >> 2] = $508; //@line 51329
   HEAP32[$509 + 4 >> 2] = $$0197 | 3; //@line 51332
  } else {
   HEAP32[162837] = 0; //@line 51334
   HEAP32[162840] = 0; //@line 51335
   HEAP32[$509 + 4 >> 2] = $506 | 3; //@line 51338
   $520 = $509 + $506 + 4 | 0; //@line 51340
   HEAP32[$520 >> 2] = HEAP32[$520 >> 2] | 1; //@line 51343
  }
  $$0 = $509 + 8 | 0; //@line 51346
  STACKTOP = sp; //@line 51347
  return $$0 | 0; //@line 51347
 }
 $524 = HEAP32[162838] | 0; //@line 51349
 if ($524 >>> 0 > $$0197 >>> 0) {
  $526 = $524 - $$0197 | 0; //@line 51352
  HEAP32[162838] = $526; //@line 51353
  $527 = HEAP32[162841] | 0; //@line 51354
  $528 = $527 + $$0197 | 0; //@line 51355
  HEAP32[162841] = $528; //@line 51356
  HEAP32[$528 + 4 >> 2] = $526 | 1; //@line 51359
  HEAP32[$527 + 4 >> 2] = $$0197 | 3; //@line 51362
  $$0 = $527 + 8 | 0; //@line 51364
  STACKTOP = sp; //@line 51365
  return $$0 | 0; //@line 51365
 }
 if (!(HEAP32[162953] | 0)) {
  HEAP32[162955] = 4096; //@line 51370
  HEAP32[162954] = 4096; //@line 51371
  HEAP32[162956] = -1; //@line 51372
  HEAP32[162957] = -1; //@line 51373
  HEAP32[162958] = 0; //@line 51374
  HEAP32[162946] = 0; //@line 51375
  $538 = $1 & -16 ^ 1431655768; //@line 51378
  HEAP32[$1 >> 2] = $538; //@line 51379
  HEAP32[162953] = $538; //@line 51380
  $542 = 4096; //@line 51381
 } else {
  $542 = HEAP32[162955] | 0; //@line 51384
 }
 $539 = $$0197 + 48 | 0; //@line 51386
 $540 = $$0197 + 47 | 0; //@line 51387
 $541 = $542 + $540 | 0; //@line 51388
 $543 = 0 - $542 | 0; //@line 51389
 $544 = $541 & $543; //@line 51390
 if ($544 >>> 0 <= $$0197 >>> 0) {
  $$0 = 0; //@line 51393
  STACKTOP = sp; //@line 51394
  return $$0 | 0; //@line 51394
 }
 $546 = HEAP32[162945] | 0; //@line 51396
 if ($546 | 0) {
  $548 = HEAP32[162943] | 0; //@line 51399
  $549 = $548 + $544 | 0; //@line 51400
  if ($549 >>> 0 <= $548 >>> 0 | $549 >>> 0 > $546 >>> 0) {
   $$0 = 0; //@line 51405
   STACKTOP = sp; //@line 51406
   return $$0 | 0; //@line 51406
  }
 }
 L244 : do {
  if (!(HEAP32[162946] & 4)) {
   $555 = HEAP32[162841] | 0; //@line 51414
   L246 : do {
    if (!$555) {
     label = 163; //@line 51418
    } else {
     $$0$i$i = 651788; //@line 51420
     while (1) {
      $557 = HEAP32[$$0$i$i >> 2] | 0; //@line 51422
      if ($557 >>> 0 <= $555 >>> 0) {
       $559 = $$0$i$i + 4 | 0; //@line 51425
       if (($557 + (HEAP32[$559 >> 2] | 0) | 0) >>> 0 > $555 >>> 0) {
        break;
       }
      }
      $564 = HEAP32[$$0$i$i + 8 >> 2] | 0; //@line 51434
      if (!$564) {
       label = 163; //@line 51437
       break L246;
      } else {
       $$0$i$i = $564; //@line 51440
      }
     }
     $589 = $541 - $524 & $543; //@line 51444
     if ($589 >>> 0 < 2147483647) {
      $591 = _sbrk($589 | 0) | 0; //@line 51447
      if (($591 | 0) == ((HEAP32[$$0$i$i >> 2] | 0) + (HEAP32[$559 >> 2] | 0) | 0)) {
       if (($591 | 0) == (-1 | 0)) {
        $$2234253237$i = $589; //@line 51455
       } else {
        $$723948$i = $589; //@line 51457
        $$749$i = $591; //@line 51457
        label = 180; //@line 51458
        break L244;
       }
      } else {
       $$2247$ph$i = $591; //@line 51462
       $$2253$ph$i = $589; //@line 51462
       label = 171; //@line 51463
      }
     } else {
      $$2234253237$i = 0; //@line 51466
     }
    }
   } while (0);
   do {
    if ((label | 0) == 163) {
     $566 = _sbrk(0) | 0; //@line 51472
     if (($566 | 0) == (-1 | 0)) {
      $$2234253237$i = 0; //@line 51475
     } else {
      $568 = $566; //@line 51477
      $569 = HEAP32[162954] | 0; //@line 51478
      $570 = $569 + -1 | 0; //@line 51479
      $$$i = (($570 & $568 | 0) == 0 ? 0 : ($570 + $568 & 0 - $569) - $568 | 0) + $544 | 0; //@line 51487
      $578 = HEAP32[162943] | 0; //@line 51488
      $579 = $$$i + $578 | 0; //@line 51489
      if ($$$i >>> 0 > $$0197 >>> 0 & $$$i >>> 0 < 2147483647) {
       $582 = HEAP32[162945] | 0; //@line 51494
       if ($582 | 0) {
        if ($579 >>> 0 <= $578 >>> 0 | $579 >>> 0 > $582 >>> 0) {
         $$2234253237$i = 0; //@line 51501
         break;
        }
       }
       $586 = _sbrk($$$i | 0) | 0; //@line 51505
       if (($586 | 0) == ($566 | 0)) {
        $$723948$i = $$$i; //@line 51508
        $$749$i = $566; //@line 51508
        label = 180; //@line 51509
        break L244;
       } else {
        $$2247$ph$i = $586; //@line 51512
        $$2253$ph$i = $$$i; //@line 51512
        label = 171; //@line 51513
       }
      } else {
       $$2234253237$i = 0; //@line 51516
      }
     }
    }
   } while (0);
   do {
    if ((label | 0) == 171) {
     $597 = 0 - $$2253$ph$i | 0; //@line 51523
     if (!($539 >>> 0 > $$2253$ph$i >>> 0 & ($$2253$ph$i >>> 0 < 2147483647 & ($$2247$ph$i | 0) != (-1 | 0)))) {
      if (($$2247$ph$i | 0) == (-1 | 0)) {
       $$2234253237$i = 0; //@line 51532
       break;
      } else {
       $$723948$i = $$2253$ph$i; //@line 51535
       $$749$i = $$2247$ph$i; //@line 51535
       label = 180; //@line 51536
       break L244;
      }
     }
     $601 = HEAP32[162955] | 0; //@line 51540
     $605 = $540 - $$2253$ph$i + $601 & 0 - $601; //@line 51544
     if ($605 >>> 0 >= 2147483647) {
      $$723948$i = $$2253$ph$i; //@line 51547
      $$749$i = $$2247$ph$i; //@line 51547
      label = 180; //@line 51548
      break L244;
     }
     if ((_sbrk($605 | 0) | 0) == (-1 | 0)) {
      _sbrk($597 | 0) | 0; //@line 51554
      $$2234253237$i = 0; //@line 51555
      break;
     } else {
      $$723948$i = $605 + $$2253$ph$i | 0; //@line 51559
      $$749$i = $$2247$ph$i; //@line 51559
      label = 180; //@line 51560
      break L244;
     }
    }
   } while (0);
   HEAP32[162946] = HEAP32[162946] | 4; //@line 51567
   $$4236$i = $$2234253237$i; //@line 51568
   label = 178; //@line 51569
  } else {
   $$4236$i = 0; //@line 51571
   label = 178; //@line 51572
  }
 } while (0);
 if ((label | 0) == 178) {
  if ($544 >>> 0 < 2147483647) {
   $614 = _sbrk($544 | 0) | 0; //@line 51578
   $615 = _sbrk(0) | 0; //@line 51579
   $621 = $615 - $614 | 0; //@line 51587
   $623 = $621 >>> 0 > ($$0197 + 40 | 0) >>> 0; //@line 51589
   if (!(($614 | 0) == (-1 | 0) | $623 ^ 1 | $614 >>> 0 < $615 >>> 0 & (($614 | 0) != (-1 | 0) & ($615 | 0) != (-1 | 0)) ^ 1)) {
    $$723948$i = $623 ? $621 : $$4236$i; //@line 51597
    $$749$i = $614; //@line 51597
    label = 180; //@line 51598
   }
  }
 }
 if ((label | 0) == 180) {
  $627 = (HEAP32[162943] | 0) + $$723948$i | 0; //@line 51604
  HEAP32[162943] = $627; //@line 51605
  if ($627 >>> 0 > (HEAP32[162944] | 0) >>> 0) {
   HEAP32[162944] = $627; //@line 51609
  }
  $630 = HEAP32[162841] | 0; //@line 51611
  do {
   if (!$630) {
    $632 = HEAP32[162839] | 0; //@line 51615
    if (($632 | 0) == 0 | $$749$i >>> 0 < $632 >>> 0) {
     HEAP32[162839] = $$749$i; //@line 51620
    }
    HEAP32[162947] = $$749$i; //@line 51622
    HEAP32[162948] = $$723948$i; //@line 51623
    HEAP32[162950] = 0; //@line 51624
    HEAP32[162844] = HEAP32[162953]; //@line 51626
    HEAP32[162843] = -1; //@line 51627
    $$01$i$i = 0; //@line 51628
    do {
     $637 = 651380 + ($$01$i$i << 1 << 2) | 0; //@line 51631
     HEAP32[$637 + 12 >> 2] = $637; //@line 51633
     HEAP32[$637 + 8 >> 2] = $637; //@line 51635
     $$01$i$i = $$01$i$i + 1 | 0; //@line 51636
    } while (($$01$i$i | 0) != 32);
    $643 = $$749$i + 8 | 0; //@line 51646
    $648 = ($643 & 7 | 0) == 0 ? 0 : 0 - $643 & 7; //@line 51651
    $649 = $$749$i + $648 | 0; //@line 51652
    $650 = $$723948$i + -40 - $648 | 0; //@line 51653
    HEAP32[162841] = $649; //@line 51654
    HEAP32[162838] = $650; //@line 51655
    HEAP32[$649 + 4 >> 2] = $650 | 1; //@line 51658
    HEAP32[$649 + $650 + 4 >> 2] = 40; //@line 51661
    HEAP32[162842] = HEAP32[162957]; //@line 51663
   } else {
    $$024371$i = 651788; //@line 51665
    while (1) {
     $656 = HEAP32[$$024371$i >> 2] | 0; //@line 51667
     $657 = $$024371$i + 4 | 0; //@line 51668
     $658 = HEAP32[$657 >> 2] | 0; //@line 51669
     if (($$749$i | 0) == ($656 + $658 | 0)) {
      label = 190; //@line 51673
      break;
     }
     $662 = HEAP32[$$024371$i + 8 >> 2] | 0; //@line 51677
     if (!$662) {
      break;
     } else {
      $$024371$i = $662; //@line 51682
     }
    }
    if ((label | 0) == 190) {
     if (!(HEAP32[$$024371$i + 12 >> 2] & 8)) {
      if ($630 >>> 0 < $$749$i >>> 0 & $630 >>> 0 >= $656 >>> 0) {
       HEAP32[$657 >> 2] = $658 + $$723948$i; //@line 51696
       $673 = $630 + 8 | 0; //@line 51699
       $678 = ($673 & 7 | 0) == 0 ? 0 : 0 - $673 & 7; //@line 51704
       $679 = $630 + $678 | 0; //@line 51705
       $681 = (HEAP32[162838] | 0) + ($$723948$i - $678) | 0; //@line 51707
       HEAP32[162841] = $679; //@line 51708
       HEAP32[162838] = $681; //@line 51709
       HEAP32[$679 + 4 >> 2] = $681 | 1; //@line 51712
       HEAP32[$679 + $681 + 4 >> 2] = 40; //@line 51715
       HEAP32[162842] = HEAP32[162957]; //@line 51717
       break;
      }
     }
    }
    $687 = HEAP32[162839] | 0; //@line 51722
    if ($$749$i >>> 0 < $687 >>> 0) {
     HEAP32[162839] = $$749$i; //@line 51725
     $752 = $$749$i; //@line 51726
    } else {
     $752 = $687; //@line 51728
    }
    $689 = $$749$i + $$723948$i | 0; //@line 51730
    $$124470$i = 651788; //@line 51731
    while (1) {
     if ((HEAP32[$$124470$i >> 2] | 0) == ($689 | 0)) {
      label = 198; //@line 51736
      break;
     }
     $693 = HEAP32[$$124470$i + 8 >> 2] | 0; //@line 51740
     if (!$693) {
      break;
     } else {
      $$124470$i = $693; //@line 51745
     }
    }
    if ((label | 0) == 198) {
     if (!(HEAP32[$$124470$i + 12 >> 2] & 8)) {
      HEAP32[$$124470$i >> 2] = $$749$i; //@line 51754
      $699 = $$124470$i + 4 | 0; //@line 51755
      HEAP32[$699 >> 2] = (HEAP32[$699 >> 2] | 0) + $$723948$i; //@line 51758
      $703 = $$749$i + 8 | 0; //@line 51760
      $709 = $$749$i + (($703 & 7 | 0) == 0 ? 0 : 0 - $703 & 7) | 0; //@line 51766
      $711 = $689 + 8 | 0; //@line 51768
      $717 = $689 + (($711 & 7 | 0) == 0 ? 0 : 0 - $711 & 7) | 0; //@line 51774
      $721 = $709 + $$0197 | 0; //@line 51778
      $722 = $717 - $709 - $$0197 | 0; //@line 51779
      HEAP32[$709 + 4 >> 2] = $$0197 | 3; //@line 51782
      do {
       if (($717 | 0) == ($630 | 0)) {
        $727 = (HEAP32[162838] | 0) + $722 | 0; //@line 51787
        HEAP32[162838] = $727; //@line 51788
        HEAP32[162841] = $721; //@line 51789
        HEAP32[$721 + 4 >> 2] = $727 | 1; //@line 51792
       } else {
        if (($717 | 0) == (HEAP32[162840] | 0)) {
         $733 = (HEAP32[162837] | 0) + $722 | 0; //@line 51798
         HEAP32[162837] = $733; //@line 51799
         HEAP32[162840] = $721; //@line 51800
         HEAP32[$721 + 4 >> 2] = $733 | 1; //@line 51803
         HEAP32[$721 + $733 >> 2] = $733; //@line 51805
         break;
        }
        $738 = HEAP32[$717 + 4 >> 2] | 0; //@line 51809
        if (($738 & 3 | 0) == 1) {
         $741 = $738 & -8; //@line 51813
         $742 = $738 >>> 3; //@line 51814
         L314 : do {
          if ($738 >>> 0 < 256) {
           $745 = HEAP32[$717 + 8 >> 2] | 0; //@line 51819
           $747 = HEAP32[$717 + 12 >> 2] | 0; //@line 51821
           $749 = 651380 + ($742 << 1 << 2) | 0; //@line 51823
           do {
            if (($745 | 0) != ($749 | 0)) {
             if ($745 >>> 0 < $752 >>> 0) {
              _abort(); //@line 51829
             }
             if ((HEAP32[$745 + 12 >> 2] | 0) == ($717 | 0)) {
              break;
             }
             _abort(); //@line 51838
            }
           } while (0);
           if (($747 | 0) == ($745 | 0)) {
            HEAP32[162835] = HEAP32[162835] & ~(1 << $742); //@line 51848
            break;
           }
           do {
            if (($747 | 0) == ($749 | 0)) {
             $$pre$phi11$i$iZ2D = $747 + 8 | 0; //@line 51855
            } else {
             if ($747 >>> 0 < $752 >>> 0) {
              _abort(); //@line 51859
             }
             $763 = $747 + 8 | 0; //@line 51862
             if ((HEAP32[$763 >> 2] | 0) == ($717 | 0)) {
              $$pre$phi11$i$iZ2D = $763; //@line 51866
              break;
             }
             _abort(); //@line 51869
            }
           } while (0);
           HEAP32[$745 + 12 >> 2] = $747; //@line 51874
           HEAP32[$$pre$phi11$i$iZ2D >> 2] = $745; //@line 51875
          } else {
           $768 = HEAP32[$717 + 24 >> 2] | 0; //@line 51878
           $770 = HEAP32[$717 + 12 >> 2] | 0; //@line 51880
           do {
            if (($770 | 0) == ($717 | 0)) {
             $781 = $717 + 16 | 0; //@line 51884
             $782 = $781 + 4 | 0; //@line 51885
             $783 = HEAP32[$782 >> 2] | 0; //@line 51886
             if (!$783) {
              $785 = HEAP32[$781 >> 2] | 0; //@line 51889
              if (!$785) {
               $$3$i$i = 0; //@line 51892
               break;
              } else {
               $$1291$i$i = $785; //@line 51895
               $$1293$i$i = $781; //@line 51895
              }
             } else {
              $$1291$i$i = $783; //@line 51898
              $$1293$i$i = $782; //@line 51898
             }
             while (1) {
              $787 = $$1291$i$i + 20 | 0; //@line 51901
              $788 = HEAP32[$787 >> 2] | 0; //@line 51902
              if ($788 | 0) {
               $$1291$i$i = $788; //@line 51905
               $$1293$i$i = $787; //@line 51905
               continue;
              }
              $790 = $$1291$i$i + 16 | 0; //@line 51908
              $791 = HEAP32[$790 >> 2] | 0; //@line 51909
              if (!$791) {
               break;
              } else {
               $$1291$i$i = $791; //@line 51914
               $$1293$i$i = $790; //@line 51914
              }
             }
             if ($$1293$i$i >>> 0 < $752 >>> 0) {
              _abort(); //@line 51919
             } else {
              HEAP32[$$1293$i$i >> 2] = 0; //@line 51922
              $$3$i$i = $$1291$i$i; //@line 51923
              break;
             }
            } else {
             $773 = HEAP32[$717 + 8 >> 2] | 0; //@line 51928
             if ($773 >>> 0 < $752 >>> 0) {
              _abort(); //@line 51931
             }
             $775 = $773 + 12 | 0; //@line 51934
             if ((HEAP32[$775 >> 2] | 0) != ($717 | 0)) {
              _abort(); //@line 51938
             }
             $778 = $770 + 8 | 0; //@line 51941
             if ((HEAP32[$778 >> 2] | 0) == ($717 | 0)) {
              HEAP32[$775 >> 2] = $770; //@line 51945
              HEAP32[$778 >> 2] = $773; //@line 51946
              $$3$i$i = $770; //@line 51947
              break;
             } else {
              _abort(); //@line 51950
             }
            }
           } while (0);
           if (!$768) {
            break;
           }
           $796 = HEAP32[$717 + 28 >> 2] | 0; //@line 51960
           $797 = 651644 + ($796 << 2) | 0; //@line 51961
           do {
            if (($717 | 0) == (HEAP32[$797 >> 2] | 0)) {
             HEAP32[$797 >> 2] = $$3$i$i; //@line 51966
             if ($$3$i$i | 0) {
              break;
             }
             HEAP32[162836] = HEAP32[162836] & ~(1 << $796); //@line 51975
             break L314;
            } else {
             if ($768 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
              _abort(); //@line 51981
             } else {
              HEAP32[$768 + 16 + (((HEAP32[$768 + 16 >> 2] | 0) != ($717 | 0) & 1) << 2) >> 2] = $$3$i$i; //@line 51989
              if (!$$3$i$i) {
               break L314;
              } else {
               break;
              }
             }
            }
           } while (0);
           $810 = HEAP32[162839] | 0; //@line 51999
           if ($$3$i$i >>> 0 < $810 >>> 0) {
            _abort(); //@line 52002
           }
           HEAP32[$$3$i$i + 24 >> 2] = $768; //@line 52006
           $813 = $717 + 16 | 0; //@line 52007
           $814 = HEAP32[$813 >> 2] | 0; //@line 52008
           do {
            if ($814 | 0) {
             if ($814 >>> 0 < $810 >>> 0) {
              _abort(); //@line 52014
             } else {
              HEAP32[$$3$i$i + 16 >> 2] = $814; //@line 52018
              HEAP32[$814 + 24 >> 2] = $$3$i$i; //@line 52020
              break;
             }
            }
           } while (0);
           $820 = HEAP32[$813 + 4 >> 2] | 0; //@line 52026
           if (!$820) {
            break;
           }
           if ($820 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
            _abort(); //@line 52034
           } else {
            HEAP32[$$3$i$i + 20 >> 2] = $820; //@line 52038
            HEAP32[$820 + 24 >> 2] = $$3$i$i; //@line 52040
            break;
           }
          }
         } while (0);
         $$0$i18$i = $717 + $741 | 0; //@line 52047
         $$0287$i$i = $741 + $722 | 0; //@line 52047
        } else {
         $$0$i18$i = $717; //@line 52049
         $$0287$i$i = $722; //@line 52049
        }
        $828 = $$0$i18$i + 4 | 0; //@line 52051
        HEAP32[$828 >> 2] = HEAP32[$828 >> 2] & -2; //@line 52054
        HEAP32[$721 + 4 >> 2] = $$0287$i$i | 1; //@line 52057
        HEAP32[$721 + $$0287$i$i >> 2] = $$0287$i$i; //@line 52059
        $834 = $$0287$i$i >>> 3; //@line 52060
        if ($$0287$i$i >>> 0 < 256) {
         $837 = 651380 + ($834 << 1 << 2) | 0; //@line 52064
         $838 = HEAP32[162835] | 0; //@line 52065
         $839 = 1 << $834; //@line 52066
         do {
          if (!($838 & $839)) {
           HEAP32[162835] = $838 | $839; //@line 52072
           $$0295$i$i = $837; //@line 52074
           $$pre$phi$i20$iZ2D = $837 + 8 | 0; //@line 52074
          } else {
           $843 = $837 + 8 | 0; //@line 52076
           $844 = HEAP32[$843 >> 2] | 0; //@line 52077
           if ($844 >>> 0 >= (HEAP32[162839] | 0) >>> 0) {
            $$0295$i$i = $844; //@line 52081
            $$pre$phi$i20$iZ2D = $843; //@line 52081
            break;
           }
           _abort(); //@line 52084
          }
         } while (0);
         HEAP32[$$pre$phi$i20$iZ2D >> 2] = $721; //@line 52088
         HEAP32[$$0295$i$i + 12 >> 2] = $721; //@line 52090
         HEAP32[$721 + 8 >> 2] = $$0295$i$i; //@line 52092
         HEAP32[$721 + 12 >> 2] = $837; //@line 52094
         break;
        }
        $850 = $$0287$i$i >>> 8; //@line 52097
        do {
         if (!$850) {
          $$0296$i$i = 0; //@line 52101
         } else {
          if ($$0287$i$i >>> 0 > 16777215) {
           $$0296$i$i = 31; //@line 52105
           break;
          }
          $855 = ($850 + 1048320 | 0) >>> 16 & 8; //@line 52110
          $856 = $850 << $855; //@line 52111
          $859 = ($856 + 520192 | 0) >>> 16 & 4; //@line 52114
          $861 = $856 << $859; //@line 52116
          $864 = ($861 + 245760 | 0) >>> 16 & 2; //@line 52119
          $869 = 14 - ($859 | $855 | $864) + ($861 << $864 >>> 15) | 0; //@line 52124
          $$0296$i$i = $$0287$i$i >>> ($869 + 7 | 0) & 1 | $869 << 1; //@line 52130
         }
        } while (0);
        $875 = 651644 + ($$0296$i$i << 2) | 0; //@line 52133
        HEAP32[$721 + 28 >> 2] = $$0296$i$i; //@line 52135
        $877 = $721 + 16 | 0; //@line 52136
        HEAP32[$877 + 4 >> 2] = 0; //@line 52138
        HEAP32[$877 >> 2] = 0; //@line 52139
        $879 = HEAP32[162836] | 0; //@line 52140
        $880 = 1 << $$0296$i$i; //@line 52141
        if (!($879 & $880)) {
         HEAP32[162836] = $879 | $880; //@line 52146
         HEAP32[$875 >> 2] = $721; //@line 52147
         HEAP32[$721 + 24 >> 2] = $875; //@line 52149
         HEAP32[$721 + 12 >> 2] = $721; //@line 52151
         HEAP32[$721 + 8 >> 2] = $721; //@line 52153
         break;
        }
        $$0288$i$i = $$0287$i$i << (($$0296$i$i | 0) == 31 ? 0 : 25 - ($$0296$i$i >>> 1) | 0); //@line 52162
        $$0289$i$i = HEAP32[$875 >> 2] | 0; //@line 52162
        while (1) {
         if ((HEAP32[$$0289$i$i + 4 >> 2] & -8 | 0) == ($$0287$i$i | 0)) {
          label = 265; //@line 52169
          break;
         }
         $898 = $$0289$i$i + 16 + ($$0288$i$i >>> 31 << 2) | 0; //@line 52173
         $900 = HEAP32[$898 >> 2] | 0; //@line 52175
         if (!$900) {
          label = 262; //@line 52178
          break;
         } else {
          $$0288$i$i = $$0288$i$i << 1; //@line 52181
          $$0289$i$i = $900; //@line 52181
         }
        }
        if ((label | 0) == 262) {
         if ($898 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
          _abort(); //@line 52188
         } else {
          HEAP32[$898 >> 2] = $721; //@line 52191
          HEAP32[$721 + 24 >> 2] = $$0289$i$i; //@line 52193
          HEAP32[$721 + 12 >> 2] = $721; //@line 52195
          HEAP32[$721 + 8 >> 2] = $721; //@line 52197
          break;
         }
        } else if ((label | 0) == 265) {
         $907 = $$0289$i$i + 8 | 0; //@line 52202
         $908 = HEAP32[$907 >> 2] | 0; //@line 52203
         $909 = HEAP32[162839] | 0; //@line 52204
         if ($908 >>> 0 >= $909 >>> 0 & $$0289$i$i >>> 0 >= $909 >>> 0) {
          HEAP32[$908 + 12 >> 2] = $721; //@line 52210
          HEAP32[$907 >> 2] = $721; //@line 52211
          HEAP32[$721 + 8 >> 2] = $908; //@line 52213
          HEAP32[$721 + 12 >> 2] = $$0289$i$i; //@line 52215
          HEAP32[$721 + 24 >> 2] = 0; //@line 52217
          break;
         } else {
          _abort(); //@line 52220
         }
        }
       }
      } while (0);
      $$0 = $709 + 8 | 0; //@line 52227
      STACKTOP = sp; //@line 52228
      return $$0 | 0; //@line 52228
     }
    }
    $$0$i$i$i = 651788; //@line 52231
    while (1) {
     $916 = HEAP32[$$0$i$i$i >> 2] | 0; //@line 52233
     if ($916 >>> 0 <= $630 >>> 0) {
      $920 = $916 + (HEAP32[$$0$i$i$i + 4 >> 2] | 0) | 0; //@line 52238
      if ($920 >>> 0 > $630 >>> 0) {
       break;
      }
     }
     $$0$i$i$i = HEAP32[$$0$i$i$i + 8 >> 2] | 0; //@line 52246
    }
    $924 = $920 + -47 | 0; //@line 52248
    $926 = $924 + 8 | 0; //@line 52250
    $932 = $924 + (($926 & 7 | 0) == 0 ? 0 : 0 - $926 & 7) | 0; //@line 52256
    $933 = $630 + 16 | 0; //@line 52257
    $935 = $932 >>> 0 < $933 >>> 0 ? $630 : $932; //@line 52259
    $936 = $935 + 8 | 0; //@line 52260
    $937 = $935 + 24 | 0; //@line 52261
    $940 = $$749$i + 8 | 0; //@line 52264
    $945 = ($940 & 7 | 0) == 0 ? 0 : 0 - $940 & 7; //@line 52269
    $946 = $$749$i + $945 | 0; //@line 52270
    $947 = $$723948$i + -40 - $945 | 0; //@line 52271
    HEAP32[162841] = $946; //@line 52272
    HEAP32[162838] = $947; //@line 52273
    HEAP32[$946 + 4 >> 2] = $947 | 1; //@line 52276
    HEAP32[$946 + $947 + 4 >> 2] = 40; //@line 52279
    HEAP32[162842] = HEAP32[162957]; //@line 52281
    $953 = $935 + 4 | 0; //@line 52282
    HEAP32[$953 >> 2] = 27; //@line 52283
    HEAP32[$936 >> 2] = HEAP32[162947]; //@line 52284
    HEAP32[$936 + 4 >> 2] = HEAP32[162948]; //@line 52284
    HEAP32[$936 + 8 >> 2] = HEAP32[162949]; //@line 52284
    HEAP32[$936 + 12 >> 2] = HEAP32[162950]; //@line 52284
    HEAP32[162947] = $$749$i; //@line 52285
    HEAP32[162948] = $$723948$i; //@line 52286
    HEAP32[162950] = 0; //@line 52287
    HEAP32[162949] = $936; //@line 52288
    $955 = $937; //@line 52289
    do {
     $955$looptemp = $955;
     $955 = $955 + 4 | 0; //@line 52291
     HEAP32[$955 >> 2] = 7; //@line 52292
    } while (($955$looptemp + 8 | 0) >>> 0 < $920 >>> 0);
    if (($935 | 0) != ($630 | 0)) {
     $961 = $935 - $630 | 0; //@line 52305
     HEAP32[$953 >> 2] = HEAP32[$953 >> 2] & -2; //@line 52308
     HEAP32[$630 + 4 >> 2] = $961 | 1; //@line 52311
     HEAP32[$935 >> 2] = $961; //@line 52312
     $966 = $961 >>> 3; //@line 52313
     if ($961 >>> 0 < 256) {
      $969 = 651380 + ($966 << 1 << 2) | 0; //@line 52317
      $970 = HEAP32[162835] | 0; //@line 52318
      $971 = 1 << $966; //@line 52319
      if (!($970 & $971)) {
       HEAP32[162835] = $970 | $971; //@line 52324
       $$0211$i$i = $969; //@line 52326
       $$pre$phi$i$iZ2D = $969 + 8 | 0; //@line 52326
      } else {
       $975 = $969 + 8 | 0; //@line 52328
       $976 = HEAP32[$975 >> 2] | 0; //@line 52329
       if ($976 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
        _abort(); //@line 52333
       } else {
        $$0211$i$i = $976; //@line 52336
        $$pre$phi$i$iZ2D = $975; //@line 52336
       }
      }
      HEAP32[$$pre$phi$i$iZ2D >> 2] = $630; //@line 52339
      HEAP32[$$0211$i$i + 12 >> 2] = $630; //@line 52341
      HEAP32[$630 + 8 >> 2] = $$0211$i$i; //@line 52343
      HEAP32[$630 + 12 >> 2] = $969; //@line 52345
      break;
     }
     $982 = $961 >>> 8; //@line 52348
     if (!$982) {
      $$0212$i$i = 0; //@line 52351
     } else {
      if ($961 >>> 0 > 16777215) {
       $$0212$i$i = 31; //@line 52355
      } else {
       $987 = ($982 + 1048320 | 0) >>> 16 & 8; //@line 52359
       $988 = $982 << $987; //@line 52360
       $991 = ($988 + 520192 | 0) >>> 16 & 4; //@line 52363
       $993 = $988 << $991; //@line 52365
       $996 = ($993 + 245760 | 0) >>> 16 & 2; //@line 52368
       $1001 = 14 - ($991 | $987 | $996) + ($993 << $996 >>> 15) | 0; //@line 52373
       $$0212$i$i = $961 >>> ($1001 + 7 | 0) & 1 | $1001 << 1; //@line 52379
      }
     }
     $1007 = 651644 + ($$0212$i$i << 2) | 0; //@line 52382
     HEAP32[$630 + 28 >> 2] = $$0212$i$i; //@line 52384
     HEAP32[$630 + 20 >> 2] = 0; //@line 52386
     HEAP32[$933 >> 2] = 0; //@line 52387
     $1010 = HEAP32[162836] | 0; //@line 52388
     $1011 = 1 << $$0212$i$i; //@line 52389
     if (!($1010 & $1011)) {
      HEAP32[162836] = $1010 | $1011; //@line 52394
      HEAP32[$1007 >> 2] = $630; //@line 52395
      HEAP32[$630 + 24 >> 2] = $1007; //@line 52397
      HEAP32[$630 + 12 >> 2] = $630; //@line 52399
      HEAP32[$630 + 8 >> 2] = $630; //@line 52401
      break;
     }
     $$0206$i$i = $961 << (($$0212$i$i | 0) == 31 ? 0 : 25 - ($$0212$i$i >>> 1) | 0); //@line 52410
     $$0207$i$i = HEAP32[$1007 >> 2] | 0; //@line 52410
     while (1) {
      if ((HEAP32[$$0207$i$i + 4 >> 2] & -8 | 0) == ($961 | 0)) {
       label = 292; //@line 52417
       break;
      }
      $1029 = $$0207$i$i + 16 + ($$0206$i$i >>> 31 << 2) | 0; //@line 52421
      $1031 = HEAP32[$1029 >> 2] | 0; //@line 52423
      if (!$1031) {
       label = 289; //@line 52426
       break;
      } else {
       $$0206$i$i = $$0206$i$i << 1; //@line 52429
       $$0207$i$i = $1031; //@line 52429
      }
     }
     if ((label | 0) == 289) {
      if ($1029 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 52436
      } else {
       HEAP32[$1029 >> 2] = $630; //@line 52439
       HEAP32[$630 + 24 >> 2] = $$0207$i$i; //@line 52441
       HEAP32[$630 + 12 >> 2] = $630; //@line 52443
       HEAP32[$630 + 8 >> 2] = $630; //@line 52445
       break;
      }
     } else if ((label | 0) == 292) {
      $1038 = $$0207$i$i + 8 | 0; //@line 52450
      $1039 = HEAP32[$1038 >> 2] | 0; //@line 52451
      $1040 = HEAP32[162839] | 0; //@line 52452
      if ($1039 >>> 0 >= $1040 >>> 0 & $$0207$i$i >>> 0 >= $1040 >>> 0) {
       HEAP32[$1039 + 12 >> 2] = $630; //@line 52458
       HEAP32[$1038 >> 2] = $630; //@line 52459
       HEAP32[$630 + 8 >> 2] = $1039; //@line 52461
       HEAP32[$630 + 12 >> 2] = $$0207$i$i; //@line 52463
       HEAP32[$630 + 24 >> 2] = 0; //@line 52465
       break;
      } else {
       _abort(); //@line 52468
      }
     }
    }
   }
  } while (0);
  $1048 = HEAP32[162838] | 0; //@line 52475
  if ($1048 >>> 0 > $$0197 >>> 0) {
   $1050 = $1048 - $$0197 | 0; //@line 52478
   HEAP32[162838] = $1050; //@line 52479
   $1051 = HEAP32[162841] | 0; //@line 52480
   $1052 = $1051 + $$0197 | 0; //@line 52481
   HEAP32[162841] = $1052; //@line 52482
   HEAP32[$1052 + 4 >> 2] = $1050 | 1; //@line 52485
   HEAP32[$1051 + 4 >> 2] = $$0197 | 3; //@line 52488
   $$0 = $1051 + 8 | 0; //@line 52490
   STACKTOP = sp; //@line 52491
   return $$0 | 0; //@line 52491
  }
 }
 HEAP32[(___errno_location() | 0) >> 2] = 12; //@line 52495
 $$0 = 0; //@line 52496
 STACKTOP = sp; //@line 52497
 return $$0 | 0; //@line 52497
}
function __Z12CDROMControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$$i = 0, $$$i169 = 0, $$0$ph = 0, $$0142283 = 0, $$0142291 = 0, $$0146289 = 0, $$0258$ph = 0, $$0259$ph = 0, $$0260$ph = 0, $$0261$ph = 0, $$0262$ph = 0, $$0263$ph = 0, $$0264$ph = 0, $$0265$ph = 0, $$03439$i = 0, $$03439$i161 = 0, $$03439$i165 = 0, $$03439$i170 = 0, $$03439$i174 = 0, $$1143290 = 0, $$3 = 0, $$6 = 0, $$9 = 0, $$not = 0, $$sink = 0, $$sink275 = 0, $$sroa$0187$0 = 0, $$sroa$03$012$i = 0, $$sroa$03$07$i = 0, $10 = 0, $1001 = 0, $1013 = 0, $1014 = 0, $102 = 0, $1022 = 0, $1023 = 0, $1029 = 0, $1037 = 0, $1045 = 0, $1053 = 0, $1059 = 0, $109 = 0, $11 = 0, $115 = 0, $12 = 0, $121 = 0, $126 = 0, $13 = 0, $136 = 0, $142 = 0, $147 = 0, $15 = 0, $155 = 0, $165 = 0, $173 = 0, $175 = 0, $18 = 0, $189 = 0, $2 = 0, $201 = 0, $216 = 0, $228 = 0, $240 = 0, $246 = 0, $251 = 0, $252 = 0, $258 = 0, $259 = 0, $26 = 0, $267 = 0, $275 = 0, $287 = 0, $3 = 0, $30 = 0, $300 = 0, $313 = 0, $332 = 0, $339 = 0, $345 = 0, $357 = 0, $36 = 0, $367 = 0, $379 = 0, $38 = 0, $391 = 0, $4 = 0, $405 = 0, $413 = 0, $423 = 0, $43 = 0, $433 = 0, $445 = 0, $457 = 0, $469 = 0, $47 = 0, $48 = 0, $481 = 0, $493 = 0, $505 = 0, $517 = 0, $529 = 0, $537 = 0, $54 = 0, $545 = 0, $552 = 0, $553 = 0, $558 = 0, $579 = 0, $582 = 0, $585 = 0, $596 = 0, $60 = 0, $615 = 0, $625 = 0, $633 = 0, $634 = 0, $641 = 0, $648 = 0, $649 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $66 = 0, $67 = 0, $68 = 0, $681 = 0, $684 = 0, $69 = 0, $715 = 0, $718 = 0, $72 = 0, $721 = 0, $732 = 0, $753 = 0, $76 = 0, $761 = 0, $775 = 0, $783 = 0, $785 = 0, $791 = 0, $793 = 0, $811 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $83 = 0, $84 = 0, $841 = 0, $844 = 0, $857 = 0, $86 = 0, $868 = 0, $896 = 0, $905 = 0, $915 = 0, $927 = 0, $939 = 0, $95 = 0, $953 = 0, $961 = 0, $968 = 0, $969 = 0, $974 = 0, $995 = 0, $998 = 0, $trunc = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 20400
 STACKTOP = STACKTOP + 80 | 0; //@line 20401
 $vararg_buffer = sp; //@line 20402
 $2 = sp + 4 | 0; //@line 20403
 $3 = sp + 72 | 0; //@line 20404
 $4 = $0 + 26 | 0; //@line 20405
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 20411
 $11 = $10 & 65535; //@line 20412
 $trunc = $10 & 65535; //@line 20413
 switch ($trunc << 16 >> 16) {
 case 65:
  {
   $12 = HEAP32[28494] | 0; //@line 20416
   $13 = HEAP32[28493] | 0; //@line 20417
   if (($13 | 0) != ($12 | 0)) {
    $15 = $2 + 32 | 0; //@line 20420
    $$sroa$03$012$i = $13; //@line 20421
    do {
     $18 = (HEAP32[$$sroa$03$012$i + 836 >> 2] | 0) + 3 | 0; //@line 20425
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0)) {
      $26 = $$sroa$03$012$i + 4 | 0; //@line 20434
      if (__Z17SysIsDiskInsertedPv(HEAP32[$26 >> 2] | 0) | 0) {
       __Z16CDROMMountVolumePv(HEAP32[$26 >> 2] | 0) | 0; //@line 20439
      }
     }
     $30 = $$sroa$03$012$i + 20 | 0; //@line 20442
     if (HEAP8[$30 >> 0] | 0) {
      HEAP32[$2 >> 2] = HEAP32[$$sroa$03$012$i >> 2]; //@line 20447
      HEAP32[$15 >> 2] = 7; //@line 20448
      _Execute68kTrap(-24529, $2); //@line 20449
      HEAP8[$30 >> 0] = 0; //@line 20450
     }
     $$sroa$03$012$i = $$sroa$03$012$i + 840 | 0; //@line 20452
    } while (($$sroa$03$012$i | 0) != ($12 | 0));
   }
   $36 = $1 + 4 | 0; //@line 20461
   $38 = 123608 + ($36 >>> 16 << 2) | 0; //@line 20463
   $43 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$38 >> 2] | 0) + 4 >> 2] & 127]($36) | 0) & -8193; //@line 20468
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$38 >> 2] | 0) + 16 >> 2] & 31]($36, $43); //@line 20472
   HEAP8[657354] = 1; //@line 20473
   $$9 = 0; //@line 20474
   STACKTOP = sp; //@line 20475
   return $$9 | 0; //@line 20475
  }
 case 81:
  {
   $47 = $1 + 34 | 0; //@line 20479
   $48 = $0 + 28 | 0; //@line 20480
   $54 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($48) | 0; //@line 20486
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($47 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($47, $54); //@line 20492
   $$9 = 0; //@line 20493
   STACKTOP = sp; //@line 20494
   return $$9 | 0; //@line 20494
  }
 case 1:
  {
   $$9 = 0; //@line 20498
   STACKTOP = sp; //@line 20499
   return $$9 | 0; //@line 20499
  }
 default:
  {
   $60 = $0 + 22 | 0; //@line 20503
   $66 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($60 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($60) | 0; //@line 20509
   $67 = HEAP32[28494] | 0; //@line 20510
   $68 = HEAP32[28493] | 0; //@line 20511
   $69 = ($68 | 0) == ($67 | 0); //@line 20512
   if ($69) {
    $$9 = -56; //@line 20514
    STACKTOP = sp; //@line 20515
    return $$9 | 0; //@line 20515
   } else {
    $$sroa$03$07$i = $68; //@line 20517
   }
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($66 | 0)) {
     label = 15; //@line 20523
     break;
    }
    $72 = $$sroa$03$07$i + 840 | 0; //@line 20526
    if (($72 | 0) == ($67 | 0)) {
     label = 16; //@line 20529
     break;
    } else {
     $$sroa$03$07$i = $72; //@line 20532
    }
   }
   if ((label | 0) == 15) {
    $$not = ($$sroa$03$07$i | 0) != ($67 | 0); //@line 20536
    if ($$not | $69 ^ 1) {
     $$sroa$0187$0 = $$not ? $$sroa$03$07$i : $68; //@line 20541
    } else {
     $$9 = -56; //@line 20543
     STACKTOP = sp; //@line 20544
     return $$9 | 0; //@line 20544
    }
   } else if ((label | 0) == 16) {
    if ($69) {
     $$9 = -56; //@line 20549
     STACKTOP = sp; //@line 20550
     return $$9 | 0; //@line 20550
    } else {
     $$sroa$0187$0 = $68; //@line 20552
    }
   }
   do {
    switch ($trunc << 16 >> 16) {
    case 5:
     {
      $76 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 20560
      $83 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($76 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($76) | 0) == 0; //@line 20567
      $$9 = $83 ? -65 : 0; //@line 20569
      STACKTOP = sp; //@line 20570
      return $$9 | 0; //@line 20570
     }
    case 7:
     {
      $84 = $$sroa$0187$0 + 836 | 0; //@line 20574
      $86 = (HEAP32[$84 >> 2] | 0) + 3 | 0; //@line 20576
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($86 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($86) | 0)) {
       $$9 = 0; //@line 20585
       STACKTOP = sp; //@line 20586
       return $$9 | 0; //@line 20586
      }
      $95 = (HEAP32[$84 >> 2] | 0) + 3 | 0; //@line 20589
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($95 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($95, 0); //@line 20595
      HEAP32[$$sroa$0187$0 + 12 >> 2] = -1; //@line 20597
      $$9 = 0; //@line 20598
      STACKTOP = sp; //@line 20599
      return $$9 | 0; //@line 20599
     }
    case 22:
    case 21:
     {
      $102 = $0 + 28 | 0; //@line 20603
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($102 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($102, HEAP32[28492] | 0); //@line 20610
      $$9 = 0; //@line 20611
      STACKTOP = sp; //@line 20612
      return $$9 | 0; //@line 20612
     }
    case 23:
     {
      $109 = $0 + 28 | 0; //@line 20616
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($109 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($109, 2817); //@line 20622
      $$9 = 0; //@line 20623
      STACKTOP = sp; //@line 20624
      return $$9 | 0; //@line 20624
     }
    case 70:
     {
      $115 = $0 + 28 | 0; //@line 20628
      $121 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($115 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($115) | 0; //@line 20634
      if (($121 & 252) >>> 0 > 3) {
       $$9 = -50; //@line 20638
       STACKTOP = sp; //@line 20639
       return $$9 | 0; //@line 20639
      }
      HEAP8[$$sroa$0187$0 + 833 >> 0] = $121; //@line 20643
      $$9 = 0; //@line 20644
      STACKTOP = sp; //@line 20645
      return $$9 | 0; //@line 20645
     }
    case 76:
     {
      $126 = $0 + 28 | 0; //@line 20649
      HEAP8[$$sroa$0187$0 + 21 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($126 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($126) | 0) != 0 & 1; //@line 20659
      $$9 = 0; //@line 20660
      STACKTOP = sp; //@line 20661
      return $$9 | 0; //@line 20661
     }
    case 79:
     {
      $136 = $0 + 28 | 0; //@line 20665
      $142 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($136 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($136) | 0; //@line 20671
      switch (($142 & 65535) << 16 >> 16) {
      case 2048:
      case 512:
       {
        break;
       }
      default:
       {
        $$9 = -50; //@line 20678
        STACKTOP = sp; //@line 20679
        return $$9 | 0; //@line 20679
       }
      }
      HEAP32[$$sroa$0187$0 + 8 >> 2] = $142 & 65535; //@line 20684
      $$9 = 0; //@line 20685
      STACKTOP = sp; //@line 20686
      return $$9 | 0; //@line 20686
     }
    case 80:
     {
      $147 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 20692
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($147 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($147) | 0)) {
       $$9 = -65; //@line 20701
       STACKTOP = sp; //@line 20702
       return $$9 | 0; //@line 20702
      }
      $155 = $0 + 28 | 0; //@line 20704
      if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($155 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($155) | 0) == 1) {
       $$9 = 0; //@line 20713
       STACKTOP = sp; //@line 20714
       return $$9 | 0; //@line 20714
      } else {
       $$9 = 0; //@line 20716
       STACKTOP = sp; //@line 20717
       return $$9 | 0; //@line 20717
      }
      break;
     }
    case 100:
     {
      $165 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 20724
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($165 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($165) | 0)) {
       $$9 = -65; //@line 20733
       STACKTOP = sp; //@line 20734
       return $$9 | 0; //@line 20734
      }
      $173 = $0 + 28 | 0; //@line 20736
      $175 = 123608 + ($173 >>> 16 << 2) | 0; //@line 20738
      switch (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$175 >> 2] | 0) + 4 >> 2] & 127]($173) | 0) {
      case 1:
       {
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[$175 >> 2] | 0) + 20 >> 2] & 31]($173, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 24 >> 0] | 0) >> 0] | 0); //@line 20754
        $189 = $0 + 29 | 0; //@line 20755
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($189 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($189, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 25 >> 0] | 0) >> 0] | 0); //@line 20767
        $201 = $0 + 30 | 0; //@line 20768
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($201 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($201, 0); //@line 20774
        $$9 = 0; //@line 20775
        STACKTOP = sp; //@line 20776
        return $$9 | 0; //@line 20776
       }
      case 2:
       {
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[$175 >> 2] | 0) + 20 >> 2] & 31]($173, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 826 >> 0] | 0) >> 0] | 0); //@line 20789
        $216 = $0 + 29 | 0; //@line 20790
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($216 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($216, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 827 >> 0] | 0) >> 0] | 0); //@line 20802
        $228 = $0 + 30 | 0; //@line 20803
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($228 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($228, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 828 >> 0] | 0) >> 0] | 0); //@line 20815
        $240 = $0 + 31 | 0; //@line 20816
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($240 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($240, 0); //@line 20822
        $$9 = 0; //@line 20823
        STACKTOP = sp; //@line 20824
        return $$9 | 0; //@line 20824
       }
      case 3:
       {
        $246 = $0 + 30 | 0; //@line 20828
        $251 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($246 >>> 16 << 2) >> 2] >> 2] & 127]($246) | 0; //@line 20833
        $252 = $0 + 34 | 0; //@line 20834
        $258 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($252 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($252) | 0; //@line 20840
        $259 = $0 + 36 | 0; //@line 20841
        $267 = HEAP8[95413 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($259 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($259) | 0) >> 0] | 0; //@line 20849
        $$0142291 = 4; //@line 20850
        while (1) {
         if ((HEAP8[($$0142291 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0) == $267 << 24 >> 24) {
          $$0142283 = $$0142291; //@line 20857
          break;
         }
         $$0142291 = $$0142291 + 8 | 0; //@line 20860
         if (($$0142291 | 0) >= 804) {
          label = 39; //@line 20865
          break;
         }
        }
        if ((label | 0) == 39) {
         if (($$0142291 | 0) == 804) {
          $$9 = 0; //@line 20872
          STACKTOP = sp; //@line 20873
          return $$9 | 0; //@line 20873
         } else {
          $$0142283 = $$0142291; //@line 20875
         }
        }
        $275 = $258 & 65535; //@line 20878
        if (!$275) {
         $$9 = 0; //@line 20881
         STACKTOP = sp; //@line 20882
         return $$9 | 0; //@line 20882
        } else {
         $$0146289 = $251; //@line 20884
         $$1143290 = $$0142283; //@line 20884
         $332 = $275; //@line 20884
        }
        while (1) {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$0146289 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($$0146289, HEAP8[($$1143290 | 1) + ($$sroa$0187$0 + 22) >> 0] & 15); //@line 20897
         $287 = $$0146289 + 1 | 0; //@line 20898
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($287 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($287, HEAPU8[95157 + (HEAPU8[$$1143290 + 5 + ($$sroa$0187$0 + 22) >> 0] | 0) >> 0] | 0); //@line 20911
         $300 = $$0146289 + 2 | 0; //@line 20912
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($300 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($300, HEAPU8[95157 + (HEAPU8[$$1143290 + 6 + ($$sroa$0187$0 + 22) >> 0] | 0) >> 0] | 0); //@line 20925
         $313 = $$0146289 + 3 | 0; //@line 20926
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($313 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($313, HEAPU8[95157 + (HEAPU8[$$1143290 + 7 + ($$sroa$0187$0 + 22) >> 0] | 0) >> 0] | 0); //@line 20939
         if ((HEAP8[($$1143290 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0) == -86) {
          $$9 = 0; //@line 20945
          label = 132; //@line 20946
          break;
         }
         $332 = $332 + 65532 & 65535; //@line 20952
         if (!$332) {
          $$9 = 0; //@line 20955
          label = 132; //@line 20956
          break;
         } else {
          $$0146289 = $$0146289 + 4 | 0; //@line 20959
          $$1143290 = $$1143290 + 8 | 0; //@line 20959
         }
        }
        if ((label | 0) == 132) {
         STACKTOP = sp; //@line 20963
         return $$9 | 0; //@line 20963
        }
        break;
       }
      case 5:
       {
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[$175 >> 2] | 0) + 16 >> 2] & 31]($173, 1); //@line 20971
        $339 = $0 + 30 | 0; //@line 20972
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($339 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($339, 1); //@line 20978
        $345 = $0 + 32 | 0; //@line 20979
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($345 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($345, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 24 >> 0] | 0) >> 0] | 0); //@line 20991
        $357 = $0 + 34 | 0; //@line 20992
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($357 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($357, HEAP8[$$sroa$0187$0 + 27 >> 0] & 15); //@line 21002
        $367 = $0 + 35 | 0; //@line 21003
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($367 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($367, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 31 >> 0] | 0) >> 0] | 0); //@line 21015
        $379 = $0 + 36 | 0; //@line 21016
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($379 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($379, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 32 >> 0] | 0) >> 0] | 0); //@line 21028
        $391 = $0 + 37 | 0; //@line 21029
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($391 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($391, HEAPU8[95157 + (HEAPU8[$$sroa$0187$0 + 33 >> 0] | 0) >> 0] | 0); //@line 21041
        $$9 = 0; //@line 21042
        STACKTOP = sp; //@line 21043
        return $$9 | 0; //@line 21043
       }
      default:
       {
        _puts(95669) | 0; //@line 21047
        $$9 = -50; //@line 21048
        STACKTOP = sp; //@line 21049
        return $$9 | 0; //@line 21049
       }
      }
      break;
     }
    case 101:
     {
      $405 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21057
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($405 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($405) | 0)) {
       $413 = $0 + 28 | 0; //@line 21066
       dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($413 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($413) | 0; //@line 21073
       stop = dest + 10 | 0; //@line 21073
       do {
        HEAP8[dest >> 0] = 0; //@line 21073
        dest = dest + 1 | 0; //@line 21073
       } while ((dest | 0) < (stop | 0));
       $$9 = -65; //@line 21074
       STACKTOP = sp; //@line 21075
       return $$9 | 0; //@line 21075
      }
      if (__Z16SysCDGetPositionPvPh(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, $2) | 0) {
       $423 = $0 + 28 | 0; //@line 21081
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($423 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($423, HEAP8[$2 + 5 >> 0] & 15); //@line 21091
       $433 = $0 + 29 | 0; //@line 21092
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($433 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($433, HEAPU8[95157 + (HEAPU8[$2 + 6 >> 0] | 0) >> 0] | 0); //@line 21104
       $445 = $0 + 30 | 0; //@line 21105
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($445 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($445, HEAPU8[95157 + (HEAPU8[$2 + 7 >> 0] | 0) >> 0] | 0); //@line 21117
       $457 = $0 + 31 | 0; //@line 21118
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($457 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($457, HEAPU8[95157 + (HEAPU8[$2 + 13 >> 0] | 0) >> 0] | 0); //@line 21130
       $469 = $0 + 32 | 0; //@line 21131
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($469 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($469, HEAPU8[95157 + (HEAPU8[$2 + 14 >> 0] | 0) >> 0] | 0); //@line 21143
       $481 = $0 + 33 | 0; //@line 21144
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($481 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($481, HEAPU8[95157 + (HEAPU8[$2 + 15 >> 0] | 0) >> 0] | 0); //@line 21156
       $493 = $0 + 34 | 0; //@line 21157
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($493 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($493, HEAPU8[95157 + (HEAPU8[$2 + 9 >> 0] | 0) >> 0] | 0); //@line 21169
       $505 = $0 + 35 | 0; //@line 21170
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($505 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($505, HEAPU8[95157 + (HEAPU8[$2 + 10 >> 0] | 0) >> 0] | 0); //@line 21182
       $517 = $0 + 36 | 0; //@line 21183
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($517 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($517, HEAPU8[95157 + (HEAPU8[$2 + 11 >> 0] | 0) >> 0] | 0); //@line 21195
       $529 = $0 + 37 | 0; //@line 21196
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($529 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($529, 0); //@line 21202
       $$3 = 0; //@line 21203
      } else {
       $$3 = -36; //@line 21205
      }
      $$9 = $$3; //@line 21207
      STACKTOP = sp; //@line 21208
      return $$9 | 0; //@line 21208
     }
    case 102:
     {
      _puts(95722) | 0; //@line 21212
      $$9 = -17; //@line 21213
      STACKTOP = sp; //@line 21214
      return $$9 | 0; //@line 21214
     }
    case 103:
     {
      $537 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21220
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($537 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($537) | 0)) {
       $$9 = -65; //@line 21229
       STACKTOP = sp; //@line 21230
       return $$9 | 0; //@line 21230
      }
      $545 = $0 + 28 | 0; //@line 21232
      $552 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($545 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($545) | 0) & 65535; //@line 21239
      $553 = $0 + 30 | 0; //@line 21240
      $558 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($553 >>> 16 << 2) >> 2] >> 2] & 127]($553) | 0; //@line 21245
      L93 : do {
       switch ($552 << 16 >> 16) {
       case 0:
        {
         $$0263$ph = (($558 >>> 0) % 75 | 0) & 255; //@line 21256
         $$0264$ph = (((($558 >>> 0) / 75 | 0) >>> 0) % 60 | 0) & 255; //@line 21256
         $$0265$ph = (($558 >>> 0) / 4500 | 0) & 255; //@line 21256
         break;
        }
       case 1:
        {
         $$0263$ph = HEAP8[95413 + ($558 & 255) >> 0] | 0; //@line 21271
         $$0264$ph = HEAP8[95413 + ($558 >>> 8 & 255) >> 0] | 0; //@line 21271
         $$0265$ph = HEAP8[95413 + ($558 >>> 16 & 255) >> 0] | 0; //@line 21271
         break;
        }
       case 2:
        {
         $579 = HEAP8[95413 + ($558 & 255) >> 0] | 0; //@line 21277
         $$03439$i174 = 4; //@line 21278
         while (1) {
          $582 = HEAP8[($$03439$i174 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21282
          if ($582 << 24 >> 24 == -86 ? 1 : $582 << 24 >> 24 == $579 << 24 >> 24) {
           label = 58; //@line 21287
           break;
          }
          $585 = $$03439$i174 + 8 | 0; //@line 21290
          if (($585 | 0) < 804) {
           $$03439$i174 = $585; //@line 21293
          } else {
           $$9 = -50; //@line 21295
           label = 132; //@line 21296
           break;
          }
         }
         if ((label | 0) == 58) {
          $$0263$ph = HEAP8[$$03439$i174 + 7 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21310
          $$0264$ph = HEAP8[$$03439$i174 + 6 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21310
          $$0265$ph = HEAP8[$$03439$i174 + 5 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21310
          break L93;
         } else if ((label | 0) == 132) {
          STACKTOP = sp; //@line 21314
          return $$9 | 0; //@line 21314
         }
         break;
        }
       default:
        {
         $$9 = -50; //@line 21319
         STACKTOP = sp; //@line 21320
         return $$9 | 0; //@line 21320
        }
       }
      } while (0);
      $596 = $0 + 37 | 0; //@line 21324
      HEAP8[$$sroa$0187$0 + 832 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($596 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($596) | 0) & 15; //@line 21334
      if (!(__Z9SysCDPlayPvhhhhhh(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, $$0265$ph, $$0264$ph, $$0263$ph, HEAP8[$$sroa$0187$0 + 829 >> 0] | 0, HEAP8[$$sroa$0187$0 + 830 >> 0] | 0, HEAP8[$$sroa$0187$0 + 831 >> 0] | 0) | 0)) {
       $$9 = -50; //@line 21345
       STACKTOP = sp; //@line 21346
       return $$9 | 0; //@line 21346
      }
      $615 = $0 + 34 | 0; //@line 21348
      if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($615 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($615) | 0) {
       $$9 = 0; //@line 21357
       STACKTOP = sp; //@line 21358
       return $$9 | 0; //@line 21358
      }
      $$9 = 0; //@line 21360
      STACKTOP = sp; //@line 21361
      return $$9 | 0; //@line 21361
     }
    case 104:
     {
      $625 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21367
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($625 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($625) | 0)) {
       $$9 = -65; //@line 21376
       STACKTOP = sp; //@line 21377
       return $$9 | 0; //@line 21377
      }
      $633 = $0 + 28 | 0; //@line 21379
      $634 = $0 + 34 | 0; //@line 21380
      $641 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($634 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($634) | 0) == 0; //@line 21387
      $648 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($633) | 0) & 65535; //@line 21394
      $649 = $0 + 30 | 0; //@line 21395
      $654 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($649 >>> 16 << 2) >> 2] >> 2] & 127]($649) | 0; //@line 21400
      if ($641) {
       L118 : do {
        switch ($648 << 16 >> 16) {
        case 0:
         {
          $$0260$ph = (($654 >>> 0) % 75 | 0) & 255; //@line 21412
          $$0261$ph = (((($654 >>> 0) / 75 | 0) >>> 0) % 60 | 0) & 255; //@line 21412
          $$0262$ph = (($654 >>> 0) / 4500 | 0) & 255; //@line 21412
          break;
         }
        case 1:
         {
          $$0260$ph = HEAP8[95413 + ($654 & 255) >> 0] | 0; //@line 21427
          $$0261$ph = HEAP8[95413 + ($654 >>> 8 & 255) >> 0] | 0; //@line 21427
          $$0262$ph = HEAP8[95413 + ($654 >>> 16 & 255) >> 0] | 0; //@line 21427
          break;
         }
        case 2:
         {
          $715 = HEAP8[95413 + ($654 & 255) >> 0] | 0; //@line 21433
          $$03439$i165 = 4; //@line 21434
          while (1) {
           $718 = HEAP8[($$03439$i165 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21438
           if ($718 << 24 >> 24 == -86 ? 1 : $718 << 24 >> 24 == $715 << 24 >> 24) {
            label = 77; //@line 21443
            break;
           }
           $721 = $$03439$i165 + 8 | 0; //@line 21446
           if (($721 | 0) < 804) {
            $$03439$i165 = $721; //@line 21449
           } else {
            $$9 = -50; //@line 21451
            label = 132; //@line 21452
            break;
           }
          }
          if ((label | 0) == 77) {
           $$0260$ph = HEAP8[$$03439$i165 + 7 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21466
           $$0261$ph = HEAP8[$$03439$i165 + 6 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21466
           $$0262$ph = HEAP8[$$03439$i165 + 5 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21466
           break L118;
          } else if ((label | 0) == 132) {
           STACKTOP = sp; //@line 21470
           return $$9 | 0; //@line 21470
          }
          break;
         }
        default:
         {
          $$9 = -50; //@line 21475
          STACKTOP = sp; //@line 21476
          return $$9 | 0; //@line 21476
         }
        }
       } while (0);
       $732 = $0 + 37 | 0; //@line 21480
       HEAP8[$$sroa$0187$0 + 832 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($732 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($732) | 0) & 15; //@line 21490
       if (!(__Z9SysCDPlayPvhhhhhh(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, $$0262$ph, $$0261$ph, $$0260$ph, HEAP8[$$sroa$0187$0 + 829 >> 0] | 0, HEAP8[$$sroa$0187$0 + 830 >> 0] | 0, HEAP8[$$sroa$0187$0 + 831 >> 0] | 0) | 0)) {
        $$9 = -50; //@line 21501
        STACKTOP = sp; //@line 21502
        return $$9 | 0; //@line 21502
       }
      } else {
       $655 = $$sroa$0187$0 + 829 | 0; //@line 21505
       $656 = $$sroa$0187$0 + 830 | 0; //@line 21506
       $657 = $$sroa$0187$0 + 831 | 0; //@line 21507
       L132 : do {
        switch ($648 << 16 >> 16) {
        case 0:
         {
          HEAP8[$655 >> 0] = ($654 >>> 0) / 4500 | 0; //@line 21513
          HEAP8[$656 >> 0] = ((($654 >>> 0) / 75 | 0) >>> 0) % 60 | 0; //@line 21517
          $$sink = (($654 >>> 0) % 75 | 0) & 255; //@line 21520
          break;
         }
        case 1:
         {
          HEAP8[$655 >> 0] = HEAP8[95413 + ($654 >>> 16 & 255) >> 0] | 0; //@line 21528
          HEAP8[$656 >> 0] = HEAP8[95413 + ($654 >>> 8 & 255) >> 0] | 0; //@line 21533
          $$sink = HEAP8[95413 + ($654 & 255) >> 0] | 0; //@line 21537
          break;
         }
        case 2:
         {
          $$$i169 = (HEAP8[95413 + ($654 & 255) >> 0] | 0) + 1 << 24 >> 24; //@line 21544
          $$03439$i170 = 4; //@line 21545
          while (1) {
           $681 = HEAP8[($$03439$i170 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21549
           if ($681 << 24 >> 24 == -86 ? 1 : $681 << 24 >> 24 == $$$i169 << 24 >> 24) {
            label = 70; //@line 21554
            break;
           }
           $684 = $$03439$i170 + 8 | 0; //@line 21557
           if (($684 | 0) < 804) {
            $$03439$i170 = $684; //@line 21560
           } else {
            $$9 = -50; //@line 21562
            label = 132; //@line 21563
            break;
           }
          }
          if ((label | 0) == 70) {
           HEAP8[$655 >> 0] = HEAP8[$$03439$i170 + 5 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21571
           HEAP8[$656 >> 0] = HEAP8[$$03439$i170 + 6 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21575
           $$sink = HEAP8[$$03439$i170 + 7 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21579
           break L132;
          } else if ((label | 0) == 132) {
           STACKTOP = sp; //@line 21583
           return $$9 | 0; //@line 21583
          }
          break;
         }
        default:
         {
          $$9 = -50; //@line 21588
          STACKTOP = sp; //@line 21589
          return $$9 | 0; //@line 21589
         }
        }
       } while (0);
       HEAP8[$657 >> 0] = $$sink; //@line 21593
      }
      $$9 = 0; //@line 21595
      STACKTOP = sp; //@line 21596
      return $$9 | 0; //@line 21596
     }
    case 105:
     {
      $753 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21602
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($753 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($753) | 0)) {
       $$9 = -65; //@line 21611
       STACKTOP = sp; //@line 21612
       return $$9 | 0; //@line 21612
      }
      $761 = $0 + 28 | 0; //@line 21614
      switch (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($761 >>> 16 << 2) >> 2] >> 2] & 127]($761) | 0) {
      case 0:
       {
        if (!(__Z11SysCDResumePv(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0) | 0)) {
         $$9 = -50; //@line 21626
         STACKTOP = sp; //@line 21627
         return $$9 | 0; //@line 21627
        }
        break;
       }
      case 1:
       {
        if (!(__Z10SysCDPausePv(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0) | 0)) {
         $$9 = -50; //@line 21636
         STACKTOP = sp; //@line 21637
         return $$9 | 0; //@line 21637
        }
        break;
       }
      default:
       {
        $$9 = -50; //@line 21642
        STACKTOP = sp; //@line 21643
        return $$9 | 0; //@line 21643
       }
      }
      $$9 = 0; //@line 21646
      STACKTOP = sp; //@line 21647
      return $$9 | 0; //@line 21647
     }
    case 106:
     {
      $775 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21653
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($775 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($775) | 0)) {
       $$9 = -65; //@line 21662
       STACKTOP = sp; //@line 21663
       return $$9 | 0; //@line 21663
      }
      $783 = $0 + 28 | 0; //@line 21665
      $785 = 123608 + ($783 >>> 16 << 2) | 0; //@line 21667
      $791 = $0 + 30 | 0; //@line 21673
      $793 = 123608 + ($791 >>> 16 << 2) | 0; //@line 21675
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$785 >> 2] | 0) + 4 >> 2] & 127]($783) | 0)) {
       if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[$793 >> 2] >> 2] & 127]($791) | 0)) {
        if (!(__Z9SysCDStopPvhhh(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, HEAP8[$$sroa$0187$0 + 826 >> 0] | 0, HEAP8[$$sroa$0187$0 + 827 >> 0] | 0, HEAP8[$$sroa$0187$0 + 828 >> 0] | 0) | 0)) {
         $$9 = -50; //@line 21692
         STACKTOP = sp; //@line 21693
         return $$9 | 0; //@line 21693
        }
       } else {
        label = 90; //@line 21696
       }
      } else {
       label = 90; //@line 21699
      }
      if ((label | 0) == 90) {
       $811 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$785 >> 2] | 0) + 4 >> 2] & 127]($783) | 0) & 65535; //@line 21706
       $814 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$793 >> 2] >> 2] & 127]($791) | 0; //@line 21709
       $815 = $$sroa$0187$0 + 829 | 0; //@line 21710
       $816 = $$sroa$0187$0 + 830 | 0; //@line 21711
       $817 = $$sroa$0187$0 + 831 | 0; //@line 21712
       L168 : do {
        switch ($811 << 16 >> 16) {
        case 0:
         {
          HEAP8[$815 >> 0] = ($814 >>> 0) / 4500 | 0; //@line 21718
          HEAP8[$816 >> 0] = ((($814 >>> 0) / 75 | 0) >>> 0) % 60 | 0; //@line 21722
          $$sink275 = (($814 >>> 0) % 75 | 0) & 255; //@line 21725
          break;
         }
        case 1:
         {
          HEAP8[$815 >> 0] = HEAP8[95413 + ($814 >>> 16 & 255) >> 0] | 0; //@line 21733
          HEAP8[$816 >> 0] = HEAP8[95413 + ($814 >>> 8 & 255) >> 0] | 0; //@line 21738
          $$sink275 = HEAP8[95413 + ($814 & 255) >> 0] | 0; //@line 21742
          break;
         }
        case 2:
         {
          $$$i = (HEAP8[95413 + ($814 & 255) >> 0] | 0) + 1 << 24 >> 24; //@line 21749
          $$03439$i161 = 4; //@line 21750
          while (1) {
           $841 = HEAP8[($$03439$i161 | 2) + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21754
           if ($841 << 24 >> 24 == -86 ? 1 : $841 << 24 >> 24 == $$$i << 24 >> 24) {
            label = 96; //@line 21759
            break;
           }
           $844 = $$03439$i161 + 8 | 0; //@line 21762
           if (($844 | 0) < 804) {
            $$03439$i161 = $844; //@line 21765
           } else {
            $$9 = -50; //@line 21767
            label = 132; //@line 21768
            break;
           }
          }
          if ((label | 0) == 96) {
           HEAP8[$815 >> 0] = HEAP8[$$03439$i161 + 5 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21776
           HEAP8[$816 >> 0] = HEAP8[$$03439$i161 + 6 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21780
           $$sink275 = HEAP8[$$03439$i161 + 7 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 21784
           break L168;
          } else if ((label | 0) == 132) {
           STACKTOP = sp; //@line 21788
           return $$9 | 0; //@line 21788
          }
          break;
         }
        default:
         {
          $$9 = -50; //@line 21793
          STACKTOP = sp; //@line 21794
          return $$9 | 0; //@line 21794
         }
        }
       } while (0);
       HEAP8[$817 >> 0] = $$sink275; //@line 21798
      }
      $$9 = 0; //@line 21800
      STACKTOP = sp; //@line 21801
      return $$9 | 0; //@line 21801
     }
    case 107:
     {
      $857 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21807
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($857 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($857) | 0)) {
       $$9 = -65; //@line 21816
       STACKTOP = sp; //@line 21817
       return $$9 | 0; //@line 21817
      }
      if (__Z16SysCDGetPositionPvPh(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, $2) | 0) {
       $868 = $0 + 28 | 0; //@line 21823
       switch (HEAP8[$2 + 1 >> 0] | 0) {
       case 17:
        {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($868, 0); //@line 21833
         break;
        }
       case 18:
        {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($868, 1); //@line 21842
         break;
        }
       case 19:
        {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($868, 3); //@line 21851
         break;
        }
       case 20:
        {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($868, 4); //@line 21860
         break;
        }
       default:
        {
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($868, 5); //@line 21869
        }
       }
       $896 = $0 + 29 | 0; //@line 21872
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($896 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($896, HEAPU8[$$sroa$0187$0 + 832 >> 0] | 0); //@line 21881
       $905 = $0 + 30 | 0; //@line 21882
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($905 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($905, HEAP8[$2 + 5 >> 0] & 15); //@line 21892
       $915 = $0 + 31 | 0; //@line 21893
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($915 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($915, HEAPU8[95157 + (HEAPU8[$2 + 9 >> 0] | 0) >> 0] | 0); //@line 21905
       $927 = $0 + 32 | 0; //@line 21906
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($927 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($927, HEAPU8[95157 + (HEAPU8[$2 + 10 >> 0] | 0) >> 0] | 0); //@line 21918
       $939 = $0 + 33 | 0; //@line 21919
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($939 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($939, HEAPU8[95157 + (HEAPU8[$2 + 11 >> 0] | 0) >> 0] | 0); //@line 21931
       $$6 = 0; //@line 21932
      } else {
       $$6 = -50; //@line 21934
      }
      $$9 = $$6; //@line 21936
      STACKTOP = sp; //@line 21937
      return $$9 | 0; //@line 21937
     }
    case 108:
     {
      $953 = (HEAP32[$$sroa$0187$0 + 836 >> 2] | 0) + 3 | 0; //@line 21943
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($953 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($953) | 0)) {
       $$9 = -65; //@line 21952
       STACKTOP = sp; //@line 21953
       return $$9 | 0; //@line 21953
      }
      $961 = $0 + 28 | 0; //@line 21955
      $968 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($961 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($961) | 0) & 65535; //@line 21962
      $969 = $0 + 30 | 0; //@line 21963
      $974 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($969 >>> 16 << 2) >> 2] >> 2] & 127]($969) | 0; //@line 21968
      L201 : do {
       switch ($968 << 16 >> 16) {
       case 0:
        {
         $$0$ph = (($974 >>> 0) % 75 | 0) & 255; //@line 21979
         $$0258$ph = (((($974 >>> 0) / 75 | 0) >>> 0) % 60 | 0) & 255; //@line 21979
         $$0259$ph = (($974 >>> 0) / 4500 | 0) & 255; //@line 21979
         break;
        }
       case 1:
        {
         $$0$ph = HEAP8[95413 + ($974 & 255) >> 0] | 0; //@line 21994
         $$0258$ph = HEAP8[95413 + ($974 >>> 8 & 255) >> 0] | 0; //@line 21994
         $$0259$ph = HEAP8[95413 + ($974 >>> 16 & 255) >> 0] | 0; //@line 21994
         break;
        }
       case 2:
        {
         $995 = HEAP8[95413 + ($974 & 255) >> 0] | 0; //@line 22000
         $$03439$i = 4; //@line 22001
         while (1) {
          $998 = HEAP8[($$03439$i | 2) + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 22005
          if ($998 << 24 >> 24 == -86 ? 1 : $998 << 24 >> 24 == $995 << 24 >> 24) {
           label = 116; //@line 22010
           break;
          }
          $1001 = $$03439$i + 8 | 0; //@line 22013
          if (($1001 | 0) < 804) {
           $$03439$i = $1001; //@line 22016
          } else {
           $$9 = -50; //@line 22018
           label = 132; //@line 22019
           break;
          }
         }
         if ((label | 0) == 116) {
          $$0$ph = HEAP8[$$03439$i + 7 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 22033
          $$0258$ph = HEAP8[$$03439$i + 6 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 22033
          $$0259$ph = HEAP8[$$03439$i + 5 + ($$sroa$0187$0 + 22) >> 0] | 0; //@line 22033
          break L201;
         } else if ((label | 0) == 132) {
          STACKTOP = sp; //@line 22037
          return $$9 | 0; //@line 22037
         }
         break;
        }
       default:
        {
         $$9 = -50; //@line 22042
         STACKTOP = sp; //@line 22043
         return $$9 | 0; //@line 22043
        }
       }
      } while (0);
      $1013 = HEAP32[$$sroa$0187$0 + 4 >> 2] | 0; //@line 22048
      $1014 = $0 + 34 | 0; //@line 22049
      $1022 = __Z9SysCDScanPvhhhb($1013, $$0259$ph, $$0258$ph, $$0$ph, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1014 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1014) | 0) != 0) | 0; //@line 22057
      $$9 = $1022 ? 0 : -50; //@line 22059
      STACKTOP = sp; //@line 22060
      return $$9 | 0; //@line 22060
     }
    case 109:
     {
      $1023 = $0 + 28 | 0; //@line 22064
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1023 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($1023) | 0; //@line 22070
      $1029 = $0 + 29 | 0; //@line 22071
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1029 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($1029) | 0; //@line 22077
      $$9 = 0; //@line 22078
      STACKTOP = sp; //@line 22079
      return $$9 | 0; //@line 22079
     }
    case 110:
     {
      _puts(95771) | 0; //@line 22083
      $$9 = -17; //@line 22084
      STACKTOP = sp; //@line 22085
      return $$9 | 0; //@line 22085
     }
    case 111:
     {
      _puts(95820) | 0; //@line 22089
      $$9 = -17; //@line 22090
      STACKTOP = sp; //@line 22091
      return $$9 | 0; //@line 22091
     }
    case 112:
     {
      HEAP8[$2 >> 0] = 0; //@line 22095
      HEAP8[$3 >> 0] = 0; //@line 22096
      __Z14SysCDGetVolumePvRhS0_(HEAP32[$$sroa$0187$0 + 4 >> 2] | 0, $2, $3); //@line 22099
      $1037 = $0 + 28 | 0; //@line 22100
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1037 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($1037, HEAPU8[$2 >> 0] | 0); //@line 22108
      $1045 = $0 + 29 | 0; //@line 22109
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1045 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($1045, HEAPU8[$3 >> 0] | 0); //@line 22117
      $$9 = 0; //@line 22118
      STACKTOP = sp; //@line 22119
      return $$9 | 0; //@line 22119
     }
    case 113:
     {
      $1053 = $0 + 28 | 0; //@line 22123
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1053 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1053, 255); //@line 22129
      $$9 = 0; //@line 22130
      STACKTOP = sp; //@line 22131
      return $$9 | 0; //@line 22131
     }
    case 114:
     {
      $$9 = 0; //@line 22135
      STACKTOP = sp; //@line 22136
      return $$9 | 0; //@line 22136
     }
    case 115:
     {
      _puts(95869) | 0; //@line 22140
      $$9 = -17; //@line 22141
      STACKTOP = sp; //@line 22142
      return $$9 | 0; //@line 22142
     }
    case 116:
     {
      _puts(95918) | 0; //@line 22146
      $$9 = -17; //@line 22147
      STACKTOP = sp; //@line 22148
      return $$9 | 0; //@line 22148
     }
    case 122:
     {
      _puts(95967) | 0; //@line 22152
      $$9 = -17; //@line 22153
      STACKTOP = sp; //@line 22154
      return $$9 | 0; //@line 22154
     }
    case 123:
     {
      _puts(96016) | 0; //@line 22158
      $$9 = -17; //@line 22159
      STACKTOP = sp; //@line 22160
      return $$9 | 0; //@line 22160
     }
    case 124:
     {
      _puts(96065) | 0; //@line 22164
      $$9 = -17; //@line 22165
      STACKTOP = sp; //@line 22166
      return $$9 | 0; //@line 22166
     }
    case 125:
     {
      _puts(96114) | 0; //@line 22170
      $$9 = -17; //@line 22171
      STACKTOP = sp; //@line 22172
      return $$9 | 0; //@line 22172
     }
    case 126:
     {
      $1059 = $0 + 28 | 0; //@line 22176
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1059 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1059, 0); //@line 22182
      $$9 = 0; //@line 22183
      STACKTOP = sp; //@line 22184
      return $$9 | 0; //@line 22184
     }
    case 6:
     {
      $$9 = -20; //@line 22188
      STACKTOP = sp; //@line 22189
      return $$9 | 0; //@line 22189
     }
    default:
     {
      HEAP32[$vararg_buffer >> 2] = $11; //@line 22193
      _printf(96163, $vararg_buffer) | 0; //@line 22194
      $$9 = -17; //@line 22195
      STACKTOP = sp; //@line 22196
      return $$9 | 0; //@line 22196
     }
    }
   } while (0);
  }
 }
 return 0; //@line 22202
}
function __Z13AudioDispatchjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0187 = 0, $$03450$i = 0, $$03549$i = 0, $$052$i = 0, $$07885$i = 0, $$07984$i = 0, $$087$i = 0, $$3$i = 0, $$3$i190 = 0, $$in$i = 0, $$in91$i = 0, $$in92$i = 0, $1004 = 0, $1011 = 0, $105 = 0, $111 = 0, $117 = 0, $123 = 0, $132 = 0, $138 = 0, $144 = 0, $150 = 0, $156 = 0, $162 = 0, $168 = 0, $17 = 0, $174 = 0, $183 = 0, $189 = 0, $195 = 0, $2 = 0, $201 = 0, $207 = 0, $213 = 0, $219 = 0, $225 = 0, $231 = 0, $237 = 0, $24 = 0, $243 = 0, $252 = 0, $258 = 0, $264 = 0, $270 = 0, $276 = 0, $282 = 0, $288 = 0, $294 = 0, $3 = 0, $30 = 0, $300 = 0, $306 = 0, $312 = 0, $321 = 0, $327 = 0, $333 = 0, $339 = 0, $345 = 0, $351 = 0, $357 = 0, $36 = 0, $363 = 0, $369 = 0, $375 = 0, $381 = 0, $390 = 0, $396 = 0, $4 = 0, $402 = 0, $408 = 0, $414 = 0, $42 = 0, $420 = 0, $426 = 0, $432 = 0, $438 = 0, $447 = 0, $453 = 0, $459 = 0, $465 = 0, $471 = 0, $477 = 0, $48 = 0, $483 = 0, $489 = 0, $495 = 0, $5 = 0, $505 = 0, $508 = 0, $510 = 0, $512 = 0, $514 = 0, $516 = 0, $531 = 0, $538 = 0, $54 = 0, $548 = 0, $556 = 0, $564 = 0, $572 = 0, $580 = 0, $587 = 0, $594 = 0, $6 = 0, $60 = 0, $600 = 0, $607 = 0, $618 = 0, $633 = 0, $634 = 0, $639 = 0, $640 = 0, $645 = 0, $656 = 0, $667 = 0, $677 = 0, $679 = 0, $683 = 0, $69 = 0, $708 = 0, $719 = 0, $729 = 0, $731 = 0, $735 = 0, $75 = 0, $760 = 0, $771 = 0, $781 = 0, $783 = 0, $787 = 0, $802 = 0, $808 = 0, $81 = 0, $815 = 0, $821 = 0, $845 = 0, $854 = 0, $861 = 0, $868 = 0, $87 = 0, $875 = 0, $882 = 0, $888 = 0, $894 = 0, $906 = 0, $907 = 0, $912 = 0, $913 = 0, $918 = 0, $923 = 0, $924 = 0, $926 = 0, $928 = 0, $93 = 0, $933 = 0, $935 = 0, $940 = 0, $941 = 0, $943 = 0, $945 = 0, $949 = 0, $951 = 0, $956 = 0, $957 = 0, $959 = 0, $961 = 0, $966 = 0, $968 = 0, $969 = 0, $977 = 0, $99 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 26693
 STACKTOP = STACKTOP + 208 | 0; //@line 26694
 $2 = sp + 136 | 0; //@line 26695
 $3 = sp + 68 | 0; //@line 26696
 $4 = sp; //@line 26697
 $5 = $0 + 4 | 0; //@line 26698
 $6 = $0 + 2 | 0; //@line 26699
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0) << 16; //@line 26706
 do {
  switch ($sext >> 16 | 0) {
  case -1:
   {
    if (!(HEAP32[30824] | 0)) {
     HEAP32[$4 >> 2] = 204; //@line 26714
     _Execute68kTrap(-24512, $4); //@line 26715
     HEAP32[$4 >> 2] = 204; //@line 26716
     _Execute68kTrap(-23778, $4); //@line 26717
     $17 = HEAP32[$4 + 32 >> 2] | 0; //@line 26719
     if (!$17) {
      $$0187 = -108; //@line 26722
      STACKTOP = sp; //@line 26723
      return $$0187 | 0; //@line 26723
     }
     HEAP32[30824] = $17; //@line 26725
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($17, 22927); //@line 26731
     $24 = $17 + 2 | 0; //@line 26732
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, 12041); //@line 26738
     $30 = $17 + 4 | 0; //@line 26739
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, 12040); //@line 26745
     $36 = $17 + 6 | 0; //@line 26746
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($36, 28708); //@line 26752
     $42 = $17 + 8 | 0; //@line 26753
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($42 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($42, 43050); //@line 26759
     $48 = $17 + 10 | 0; //@line 26760
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($48, 8223); //@line 26766
     $54 = $17 + 12 | 0; //@line 26767
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($54 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($54, 20085); //@line 26773
     $60 = $17 + 14 | 0; //@line 26774
     if (($60 - (HEAP32[30824] | 0) | 0) != 14) {
      _puts(96528) | 0; //@line 26779
      __Z12QuitEmulatorv(); //@line 26780
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($60 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($60, 21903); //@line 26788
     $69 = $17 + 16 | 0; //@line 26789
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($69 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($69, 12041); //@line 26795
     $75 = $17 + 18 | 0; //@line 26796
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($75 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($75, 12032); //@line 26802
     $81 = $17 + 20 | 0; //@line 26803
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($81 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($81, 12040); //@line 26809
     $87 = $17 + 22 | 0; //@line 26810
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($87 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($87, 8252); //@line 26816
     $93 = $17 + 24 | 0; //@line 26817
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($93 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($93, 101974040); //@line 26823
     $99 = $17 + 28 | 0; //@line 26824
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($99 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($99, 43008); //@line 26830
     $105 = $17 + 30 | 0; //@line 26831
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($105 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($105, 12319); //@line 26837
     $111 = $17 + 32 | 0; //@line 26838
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($111 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($111, 18624); //@line 26844
     $117 = $17 + 34 | 0; //@line 26845
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($117 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($117, 20085); //@line 26851
     $123 = $17 + 36 | 0; //@line 26852
     if (($123 - (HEAP32[30824] | 0) | 0) != 36) {
      _puts(96528) | 0; //@line 26857
      __Z12QuitEmulatorv(); //@line 26858
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($123 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($123, 21903); //@line 26866
     $132 = $17 + 38 | 0; //@line 26867
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($132 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($132, 12040); //@line 26873
     $138 = $17 + 40 | 0; //@line 26874
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($138 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($138, 8252); //@line 26880
     $144 = $17 + 42 | 0; //@line 26881
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($144 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($144, 35127320); //@line 26887
     $150 = $17 + 46 | 0; //@line 26888
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($150 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($150, 43008); //@line 26894
     $156 = $17 + 48 | 0; //@line 26895
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($156 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($156, 12319); //@line 26901
     $162 = $17 + 50 | 0; //@line 26902
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($162 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($162, 18624); //@line 26908
     $168 = $17 + 52 | 0; //@line 26909
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($168 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($168, 20085); //@line 26915
     $174 = $17 + 54 | 0; //@line 26916
     if (($174 - (HEAP32[30824] | 0) | 0) != 54) {
      _puts(96528) | 0; //@line 26921
      __Z12QuitEmulatorv(); //@line 26922
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($174 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($174, 22927); //@line 26930
     $183 = $17 + 56 | 0; //@line 26931
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($183 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($183, 12042); //@line 26937
     $189 = $17 + 58 | 0; //@line 26938
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($189 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($189, 12041); //@line 26944
     $195 = $17 + 60 | 0; //@line 26945
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($195 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($195, 12032); //@line 26951
     $201 = $17 + 62 | 0; //@line 26952
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($201 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($201, 12040); //@line 26958
     $207 = $17 + 64 | 0; //@line 26959
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($207 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($207, 12092); //@line 26965
     $213 = $17 + 66 | 0; //@line 26966
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($213 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($213, 786691); //@line 26972
     $219 = $17 + 70 | 0; //@line 26973
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($219 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($219, 28672); //@line 26979
     $225 = $17 + 72 | 0; //@line 26980
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($225 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($225, 43050); //@line 26986
     $231 = $17 + 74 | 0; //@line 26987
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($231 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($231, 8223); //@line 26993
     $237 = $17 + 76 | 0; //@line 26994
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($237 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($237, 20085); //@line 27000
     $243 = $17 + 78 | 0; //@line 27001
     if (($243 - (HEAP32[30824] | 0) | 0) != 78) {
      _puts(96528) | 0; //@line 27006
      __Z12QuitEmulatorv(); //@line 27007
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($243 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($243, 22927); //@line 27015
     $252 = $17 + 80 | 0; //@line 27016
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($252 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($252, 12042); //@line 27022
     $258 = $17 + 82 | 0; //@line 27023
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($258 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($258, 12041); //@line 27029
     $264 = $17 + 84 | 0; //@line 27030
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($264 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($264, 12032); //@line 27036
     $270 = $17 + 86 | 0; //@line 27037
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($270 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($270, 12040); //@line 27043
     $276 = $17 + 88 | 0; //@line 27044
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($276 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($276, 12092); //@line 27050
     $282 = $17 + 90 | 0; //@line 27051
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($282 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($282, 786692); //@line 27057
     $288 = $17 + 94 | 0; //@line 27058
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($288 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($288, 28672); //@line 27064
     $294 = $17 + 96 | 0; //@line 27065
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($294 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($294, 43050); //@line 27071
     $300 = $17 + 98 | 0; //@line 27072
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($300 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($300, 8223); //@line 27078
     $306 = $17 + 100 | 0; //@line 27079
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($306 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($306, 20085); //@line 27085
     $312 = $17 + 102 | 0; //@line 27086
     if (($312 - (HEAP32[30824] | 0) | 0) != 102) {
      _puts(96528) | 0; //@line 27091
      __Z12QuitEmulatorv(); //@line 27092
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($312 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($312, 22927); //@line 27100
     $321 = $17 + 104 | 0; //@line 27101
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($321 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($321, 12042); //@line 27107
     $327 = $17 + 106 | 0; //@line 27108
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($327 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($327, 12041); //@line 27114
     $333 = $17 + 108 | 0; //@line 27115
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($333 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($333, 12040); //@line 27121
     $339 = $17 + 110 | 0; //@line 27122
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($339 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($339, 12032); //@line 27128
     $345 = $17 + 112 | 0; //@line 27129
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($345 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($345, 12092); //@line 27135
     $351 = $17 + 114 | 0; //@line 27136
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($351 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($351, 786696); //@line 27142
     $357 = $17 + 118 | 0; //@line 27143
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($357 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($357, 28672); //@line 27149
     $363 = $17 + 120 | 0; //@line 27150
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($363 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($363, 43050); //@line 27156
     $369 = $17 + 122 | 0; //@line 27157
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($369 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($369, 8223); //@line 27163
     $375 = $17 + 124 | 0; //@line 27164
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($375 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($375, 20085); //@line 27170
     $381 = $17 + 126 | 0; //@line 27171
     if (($381 - (HEAP32[30824] | 0) | 0) != 126) {
      _puts(96528) | 0; //@line 27176
      __Z12QuitEmulatorv(); //@line 27177
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($381 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($381, 22927); //@line 27185
     $390 = $17 + 128 | 0; //@line 27186
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($390 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($390, 12041); //@line 27192
     $396 = $17 + 130 | 0; //@line 27193
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($396 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($396, 12040); //@line 27199
     $402 = $17 + 132 | 0; //@line 27200
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($402 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($402, 12092); //@line 27206
     $408 = $17 + 134 | 0; //@line 27207
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($408 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($408, 262148); //@line 27213
     $414 = $17 + 138 | 0; //@line 27214
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($414 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($414, 28672); //@line 27220
     $420 = $17 + 140 | 0; //@line 27221
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($420 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($420, 43050); //@line 27227
     $426 = $17 + 142 | 0; //@line 27228
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($426 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($426, 8223); //@line 27234
     $432 = $17 + 144 | 0; //@line 27235
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($432 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($432, 20085); //@line 27241
     $438 = $17 + 146 | 0; //@line 27242
     if (($438 - (HEAP32[30824] | 0) | 0) != 146) {
      _puts(96528) | 0; //@line 27247
      __Z12QuitEmulatorv(); //@line 27248
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($438 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($438, 22927); //@line 27256
     $447 = $17 + 148 | 0; //@line 27257
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($447 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($447, 12041); //@line 27263
     $453 = $17 + 150 | 0; //@line 27264
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($453 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($453, 16128); //@line 27270
     $459 = $17 + 152 | 0; //@line 27271
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($459 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($459, 12040); //@line 27277
     $465 = $17 + 154 | 0; //@line 27278
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($465 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($465, 12092); //@line 27284
     $471 = $17 + 156 | 0; //@line 27285
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($471 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($471, 393477); //@line 27291
     $477 = $17 + 160 | 0; //@line 27292
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($477 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($477, 28672); //@line 27298
     $483 = $17 + 162 | 0; //@line 27299
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($483 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($483, 43050); //@line 27305
     $489 = $17 + 164 | 0; //@line 27306
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($489 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($489, 8223); //@line 27312
     $495 = $17 + 166 | 0; //@line 27313
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($495 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($495, 20085); //@line 27319
     if (($17 + 168 - (HEAP32[30824] | 0) | 0) != 168) {
      _puts(96528) | 0; //@line 27325
      __Z12QuitEmulatorv(); //@line 27326
     }
    }
    HEAP8[657357] = 1; //@line 27330
    $505 = HEAP32[30825] | 0; //@line 27331
    if (!$505) {
     $508 = HEAP32[30825] | 0; //@line 27335
    } else {
     $508 = $505; //@line 27337
    }
    HEAP32[30825] = $508 + 1; //@line 27340
    $$0187 = 0; //@line 27341
    STACKTOP = sp; //@line 27342
    return $$0187 | 0; //@line 27342
   }
  case -2:
   {
    $510 = (HEAP32[30825] | 0) + -1 | 0; //@line 27347
    HEAP32[30825] = $510; //@line 27348
    if ($510 | 0) {
     $$0187 = 0; //@line 27351
     STACKTOP = sp; //@line 27352
     return $$0187 | 0; //@line 27352
    }
    $512 = HEAP32[30824] | 0; //@line 27354
    do {
     if ($512 | 0) {
      $514 = HEAP32[30820] | 0; //@line 27358
      $516 = $4 + 32 | 0; //@line 27360
      if (!$514) {
       HEAP32[$516 >> 2] = $512; //@line 27362
       _Execute68kTrap(-24545, $4); //@line 27363
       HEAP32[30824] = 0; //@line 27364
       break;
      }
      HEAP32[$516 >> 2] = $514; //@line 27367
      _Execute68k($512 + 36 | 0, $4); //@line 27369
      HEAP32[30820] = 0; //@line 27370
      $$0187 = HEAP32[$4 >> 2] | 0; //@line 27372
      STACKTOP = sp; //@line 27373
      return $$0187 | 0; //@line 27373
     }
    } while (0);
    HEAP32[30821] = 0; //@line 27376
    $$0187 = 0; //@line 27377
    STACKTOP = sp; //@line 27378
    return $$0187 | 0; //@line 27378
   }
  case -3:
   {
    switch ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0) << 16 >> 16 | 0) {
    case 261:
    case 260:
    case 259:
    case 3:
    case 1:
    case -5:
    case -4:
    case -3:
    case -2:
    case -1:
     {
      $$0187 = 1; //@line 27392
      STACKTOP = sp; //@line 27393
      return $$0187 | 0; //@line 27393
     }
    default:
     {}
    }
    $$0187 = 0; //@line 27399
    STACKTOP = sp; //@line 27400
    return $$0187 | 0; //@line 27400
   }
  case -5:
   {
    $$0187 = 0; //@line 27404
    STACKTOP = sp; //@line 27405
    return $$0187 | 0; //@line 27405
   }
  case 1:
   {
    if (!(HEAP8[657356] | 0)) {
     $$0187 = -200; //@line 27412
     STACKTOP = sp; //@line 27413
     return $$0187 | 0; //@line 27413
    }
    if (HEAP32[30820] | 0) {
     $$0187 = 0; //@line 27418
     STACKTOP = sp; //@line 27419
     return $$0187 | 0; //@line 27419
    }
    $531 = (HEAP32[30824] | 0) + 168 | 0; //@line 27422
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($531 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($531, 0); //@line 27428
    $538 = (HEAP32[30824] | 0) + 172 | 0; //@line 27430
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($538 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($538, (HEAP32[30818] | 0) == 16 ? 1953984371 : 1918990112); //@line 27439
    $548 = (HEAP32[30824] | 0) + 176 | 0; //@line 27441
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($548 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($548, HEAP32[30819] | 0); //@line 27448
    $556 = (HEAP32[30824] | 0) + 178 | 0; //@line 27450
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($556 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($556, HEAP32[30818] | 0); //@line 27457
    $564 = (HEAP32[30824] | 0) + 180 | 0; //@line 27459
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($564 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($564, HEAP32[30817] | 0); //@line 27466
    $572 = (HEAP32[30824] | 0) + 184 | 0; //@line 27468
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($572 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($572, HEAP32[30822] | 0); //@line 27475
    $580 = (HEAP32[30824] | 0) + 188 | 0; //@line 27477
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($580 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($580, 0); //@line 27483
    $587 = (HEAP32[30824] | 0) + 192 | 0; //@line 27485
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($587 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($587, 0); //@line 27491
    $594 = (HEAP32[30824] | 0) + 200 | 0; //@line 27493
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($594 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($594, 0); //@line 27499
    $600 = HEAP32[30824] | 0; //@line 27500
    HEAP32[$4 + 32 >> 2] = $600 + 196; //@line 27503
    HEAP32[$4 >> 2] = 0; //@line 27504
    HEAP32[$4 + 36 >> 2] = $600 + 168; //@line 27507
    _Execute68k($600 + 14 | 0, $4); //@line 27509
    $607 = (HEAP32[30824] | 0) + 196 | 0; //@line 27511
    HEAP32[30820] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($607 >>> 16 << 2) >> 2] >> 2] & 127]($607) | 0; //@line 27517
    $$0187 = HEAP32[$4 >> 2] | 0; //@line 27519
    STACKTOP = sp; //@line 27520
    return $$0187 | 0; //@line 27520
   }
  case 3:
   {
    $618 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27528
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($618 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($618, HEAP32[30820] | 0); //@line 27535
    $$0187 = 0; //@line 27536
    STACKTOP = sp; //@line 27537
    return $$0187 | 0; //@line 27537
   }
  case 257:
   {
    HEAP32[30821] = (HEAP32[30821] | 0) + 1; //@line 27543
    break;
   }
  case 258:
   {
    HEAP32[30821] = (HEAP32[30821] | 0) + -1; //@line 27549
    break;
   }
  case 259:
   {
    $633 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27557
    $634 = $0 + 8 | 0; //@line 27558
    $639 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($634 >>> 16 << 2) >> 2] >> 2] & 127]($634) | 0; //@line 27563
    $640 = $0 + 12 | 0; //@line 27564
    $645 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($640 >>> 16 << 2) >> 2] >> 2] & 127]($640) | 0; //@line 27569
    L69 : do {
     if (($639 | 0) < 1752655469) {
      if (($639 | 0) >= 1752396912) {
       if (($639 | 0) < 1752592236) {
        switch ($639 | 0) {
        case 1752396912:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27582
          break L69;
         }
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, 7); //@line 27591
        $$3$i = 0; //@line 27592
        break;
       }
       if (($639 | 0) < 1752654451) {
        switch ($639 | 0) {
        case 1752592236:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27602
          break L69;
         }
        }
        $821 = __Z21audio_get_main_volumev() | 0; //@line 27606
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($633, $821); //@line 27612
        $$3$i = 0; //@line 27613
        break;
       } else {
        switch ($639 | 0) {
        case 1752654451:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27621
          break L69;
         }
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, (HEAP32[30821] | 0) != 0 & 1); //@line 27633
        $$3$i = 0; //@line 27634
        break;
       }
      }
      if (($639 | 0) < 1667785078) {
       switch ($639 | 0) {
       case 1667785070:
        {
         break;
        }
       default:
        {
         label = 51; //@line 27645
         break L69;
        }
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, HEAP32[30819] | 0); //@line 27655
       $$3$i = 0; //@line 27656
       break;
      }
      if (($639 | 0) >= 1752003956) {
       switch ($639 | 0) {
       case 1752003956:
        {
         break;
        }
       default:
        {
         label = 51; //@line 27666
         break L69;
        }
       }
       $815 = (__Z19audio_get_main_mutev() | 0) & 1; //@line 27671
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, $815); //@line 27677
       $$3$i = 0; //@line 27678
       break;
      }
      switch ($639 | 0) {
      case 1667785078:
       {
        break;
       }
      default:
       {
        label = 51; //@line 27686
        break L69;
       }
      }
      HEAP32[$2 >> 2] = (HEAP32[30815] | 0) - (HEAP32[30814] | 0); //@line 27693
      _Execute68kTrap(-24286, $2); //@line 27694
      $708 = HEAP32[$2 + 32 >> 2] | 0; //@line 27696
      if (!$708) {
       $$3$i = -108; //@line 27699
      } else {
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, (HEAP32[30815] | 0) - (HEAP32[30814] | 0) >> 1); //@line 27710
       $719 = $633 + 2 | 0; //@line 27711
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($719 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($719, $708); //@line 27717
       $729 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($708 >>> 16 << 2) >> 2] >> 2] & 127]($708) | 0; //@line 27722
       $731 = HEAP32[30814] | 0; //@line 27724
       if ((HEAP32[30815] | 0) == ($731 | 0)) {
        $$3$i = 0; //@line 27727
       } else {
        $$07885$i = 0; //@line 27729
        $$in91$i = $731; //@line 27729
        do {
         $735 = ($$07885$i << 1) + $729 | 0; //@line 27733
         FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($735 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($735, HEAPU16[$$in91$i + ($$07885$i << 1) >> 1] | 0); //@line 27742
         $$07885$i = $$07885$i + 1 | 0; //@line 27743
         $$in91$i = HEAP32[30814] | 0; //@line 27745
        } while ($$07885$i >>> 0 < (HEAP32[30815] | 0) - $$in91$i >> 1 >>> 0);
        $$3$i = 0; //@line 27752
       }
      }
     } else {
      if (($639 | 0) < 1936875894) {
       if (($639 | 0) < 1936553332) {
        switch ($639 | 0) {
        case 1752655469:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27768
          break L69;
         }
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($633, 0); //@line 27777
        $845 = $633 + 4 | 0; //@line 27778
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($845 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($845, (HEAP32[30818] | 0) == 16 ? 1953984371 : 1918990112); //@line 27787
        $854 = $633 + 8 | 0; //@line 27788
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($854 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($854, HEAP32[30819] | 0); //@line 27795
        $861 = $633 + 10 | 0; //@line 27796
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($861 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($861, HEAP32[30818] | 0); //@line 27803
        $868 = $633 + 12 | 0; //@line 27804
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($868 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($868, HEAP32[30817] | 0); //@line 27811
        $875 = $633 + 16 | 0; //@line 27812
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($875 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($875, HEAP32[30822] | 0); //@line 27819
        $882 = $633 + 20 | 0; //@line 27820
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($882 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($882, 0); //@line 27826
        $888 = $633 + 24 | 0; //@line 27827
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($888 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($888, 0); //@line 27833
        $$3$i = 0; //@line 27834
        break;
       }
       if (($639 | 0) < 1936875892) {
        switch ($639 | 0) {
        case 1936553332:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27844
          break L69;
         }
        }
        $802 = (__Z22audio_get_speaker_mutev() | 0) & 1; //@line 27849
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, $802); //@line 27855
        $$3$i = 0; //@line 27856
        break;
       } else {
        switch ($639 | 0) {
        case 1936875892:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27864
          break L69;
         }
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($633, HEAP32[30817] | 0); //@line 27874
        $$3$i = 0; //@line 27875
        break;
       }
      }
      if (($639 | 0) >= 1936943482) {
       if (($639 | 0) < 1937141612) {
        switch ($639 | 0) {
        case 1936943482:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27888
          break L69;
         }
        }
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, HEAP32[30818] | 0); //@line 27898
        $$3$i = 0; //@line 27899
        break;
       } else {
        switch ($639 | 0) {
        case 1937141612:
         {
          break;
         }
        default:
         {
          label = 51; //@line 27907
          break L69;
         }
        }
        $808 = __Z24audio_get_speaker_volumev() | 0; //@line 27911
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($633, $808); //@line 27917
        $$3$i = 0; //@line 27918
        break;
       }
      }
      if (($639 | 0) < 1936941430) {
       switch ($639 | 0) {
       case 1936875894:
        {
         break;
        }
       default:
        {
         label = 51; //@line 27929
         break L69;
        }
       }
       HEAP32[$2 >> 2] = (HEAP32[30809] | 0) - (HEAP32[30808] | 0); //@line 27936
       _Execute68kTrap(-24286, $2); //@line 27937
       $760 = HEAP32[$2 + 32 >> 2] | 0; //@line 27939
       if (!$760) {
        $$3$i = -108; //@line 27942
        break;
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, (HEAP32[30809] | 0) - (HEAP32[30808] | 0) >> 2); //@line 27954
       $771 = $633 + 2 | 0; //@line 27955
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($771 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($771, $760); //@line 27961
       $781 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($760 >>> 16 << 2) >> 2] >> 2] & 127]($760) | 0; //@line 27966
       $783 = HEAP32[30808] | 0; //@line 27968
       if ((HEAP32[30809] | 0) == ($783 | 0)) {
        $$3$i = 0; //@line 27971
        break;
       } else {
        $$087$i = 0; //@line 27974
        $$in$i = $783; //@line 27974
       }
       do {
        $787 = ($$087$i << 2) + $781 | 0; //@line 27979
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($787 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($787, HEAP32[$$in$i + ($$087$i << 2) >> 2] | 0); //@line 27987
        $$087$i = $$087$i + 1 | 0; //@line 27988
        $$in$i = HEAP32[30808] | 0; //@line 27990
       } while ($$087$i >>> 0 < (HEAP32[30809] | 0) - $$in$i >> 2 >>> 0);
       $$3$i = 0; //@line 27997
      } else {
       switch ($639 | 0) {
       case 1936941430:
        {
         break;
        }
       default:
        {
         label = 51; //@line 28007
         break L69;
        }
       }
       HEAP32[$2 >> 2] = (HEAP32[30812] | 0) - (HEAP32[30811] | 0); //@line 28014
       _Execute68kTrap(-24286, $2); //@line 28015
       $656 = HEAP32[$2 + 32 >> 2] | 0; //@line 28017
       if (!$656) {
        $$3$i = -108; //@line 28020
        break;
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($633 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($633, (HEAP32[30812] | 0) - (HEAP32[30811] | 0) >> 1); //@line 28032
       $667 = $633 + 2 | 0; //@line 28033
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($667 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($667, $656); //@line 28039
       $677 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($656 >>> 16 << 2) >> 2] >> 2] & 127]($656) | 0; //@line 28044
       $679 = HEAP32[30811] | 0; //@line 28046
       if ((HEAP32[30812] | 0) == ($679 | 0)) {
        $$3$i = 0; //@line 28049
        break;
       } else {
        $$07984$i = 0; //@line 28052
        $$in92$i = $679; //@line 28052
       }
       do {
        $683 = ($$07984$i << 1) + $677 | 0; //@line 28057
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($683 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($683, HEAPU16[$$in92$i + ($$07984$i << 1) >> 1] | 0); //@line 28066
        $$07984$i = $$07984$i + 1 | 0; //@line 28067
        $$in92$i = HEAP32[30811] | 0; //@line 28069
       } while ($$07984$i >>> 0 < (HEAP32[30812] | 0) - $$in92$i >> 1 >>> 0);
       $$3$i = 0; //@line 28076
      }
     }
    } while (0);
    if ((label | 0) == 51) {
     $894 = HEAP32[30820] | 0; //@line 28084
     if (!$894) {
      $$3$i = -2147450878; //@line 28087
     } else {
      HEAP32[$3 + 32 >> 2] = $633; //@line 28090
      HEAP32[$3 >> 2] = $639; //@line 28091
      HEAP32[$3 + 36 >> 2] = $645; //@line 28093
      HEAP32[$3 + 40 >> 2] = $894; //@line 28095
      _Execute68k((HEAP32[30824] | 0) + 54 | 0, $3); //@line 28098
      $$3$i = HEAP32[$3 >> 2] | 0; //@line 28100
     }
    }
    $$0187 = $$3$i; //@line 28103
    STACKTOP = sp; //@line 28104
    return $$0187 | 0; //@line 28104
   }
  case 260:
   {
    $906 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28112
    $907 = $0 + 8 | 0; //@line 28113
    $912 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($907 >>> 16 << 2) >> 2] >> 2] & 127]($907) | 0; //@line 28118
    $913 = $0 + 12 | 0; //@line 28119
    $918 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($913 >>> 16 << 2) >> 2] >> 2] & 127]($913) | 0; //@line 28124
    L133 : do {
     if (($912 | 0) < 1936553332) {
      if (($912 | 0) >= 1752003956) {
       if (($912 | 0) < 1752592236) {
        switch ($912 | 0) {
        case 1752003956:
         {
          break;
         }
        default:
         {
          label = 80; //@line 28137
          break L133;
         }
        }
        $$3$i190 = 0; //@line 28141
        break;
       } else {
        switch ($912 | 0) {
        case 1752592236:
         {
          break;
         }
        default:
         {
          label = 80; //@line 28149
          break L133;
         }
        }
        $$3$i190 = 0; //@line 28153
        break;
       }
      }
      switch ($912 | 0) {
      case 1667785070:
       {
        break;
       }
      default:
       {
        label = 80; //@line 28162
        break L133;
       }
      }
      if (!(HEAP32[30821] | 0)) {
       if ((HEAP32[30819] | 0) == ($906 | 0)) {
        $$3$i190 = 0; //@line 28172
       } else {
        $956 = HEAP32[30815] | 0; //@line 28174
        $957 = HEAP32[30814] | 0; //@line 28175
        $959 = $957; //@line 28177
        if (($956 | 0) == ($957 | 0)) {
         $$3$i190 = -205; //@line 28179
        } else {
         $961 = $956 - $957 >> 1; //@line 28182
         $$052$i = 0; //@line 28183
         while (1) {
          if ((HEAPU16[$959 + ($$052$i << 1) >> 1] | 0) == ($906 | 0)) {
           break;
          }
          $966 = $$052$i + 1 | 0; //@line 28192
          if ($966 >>> 0 < $961 >>> 0) {
           $$052$i = $966; //@line 28195
          } else {
           $$3$i190 = -205; //@line 28197
           break L133;
          }
         }
         $968 = __Z18audio_set_channelsi($$052$i) | 0; //@line 28201
         $$3$i190 = $968 ? 0 : -205; //@line 28203
        }
       }
      } else {
       $$3$i190 = -227; //@line 28207
      }
     } else {
      if (($912 | 0) < 1936943482) {
       if (($912 | 0) < 1936875892) {
        switch ($912 | 0) {
        case 1936553332:
         {
          break;
         }
        default:
         {
          label = 80; //@line 28219
          break L133;
         }
        }
        $$3$i190 = 0; //@line 28223
        break;
       }
       switch ($912 | 0) {
       case 1936875892:
        {
         break;
        }
       default:
        {
         label = 80; //@line 28231
         break L133;
        }
       }
       if (HEAP32[30821] | 0) {
        $$3$i190 = -227; //@line 28238
        break;
       }
       if ((HEAP32[30817] | 0) == ($906 | 0)) {
        $$3$i190 = 0; //@line 28244
        break;
       }
       $940 = HEAP32[30809] | 0; //@line 28247
       $941 = HEAP32[30808] | 0; //@line 28248
       $943 = $941; //@line 28250
       if (($940 | 0) == ($941 | 0)) {
        $$3$i190 = -225; //@line 28252
        break;
       }
       $945 = $940 - $941 >> 2; //@line 28256
       $$03450$i = 0; //@line 28257
       while (1) {
        if ((HEAP32[$943 + ($$03450$i << 2) >> 2] | 0) == ($906 | 0)) {
         break;
        }
        $949 = $$03450$i + 1 | 0; //@line 28265
        if ($949 >>> 0 < $945 >>> 0) {
         $$03450$i = $949; //@line 28268
        } else {
         $$3$i190 = -225; //@line 28270
         break L133;
        }
       }
       $951 = __Z21audio_set_sample_ratei($$03450$i) | 0; //@line 28274
       $$3$i190 = $951 ? 0 : -225; //@line 28276
       break;
      } else {
       if (($912 | 0) >= 1937141612) {
        switch ($912 | 0) {
        case 1937141612:
         {
          break;
         }
        default:
         {
          label = 80; //@line 28286
          break L133;
         }
        }
        $$3$i190 = 0; //@line 28290
        break;
       }
       switch ($912 | 0) {
       case 1936943482:
        {
         break;
        }
       default:
        {
         label = 80; //@line 28298
         break L133;
        }
       }
       if (HEAP32[30821] | 0) {
        $$3$i190 = -227; //@line 28305
        break;
       }
       if ((HEAP32[30818] | 0) == ($906 | 0)) {
        $$3$i190 = 0; //@line 28311
        break;
       }
       $923 = HEAP32[30812] | 0; //@line 28314
       $924 = HEAP32[30811] | 0; //@line 28315
       $926 = $924; //@line 28317
       if (($923 | 0) == ($924 | 0)) {
        $$3$i190 = -226; //@line 28319
        break;
       }
       $928 = $923 - $924 >> 1; //@line 28323
       $$03549$i = 0; //@line 28324
       while (1) {
        if ((HEAPU16[$926 + ($$03549$i << 1) >> 1] | 0) == ($906 | 0)) {
         break;
        }
        $933 = $$03549$i + 1 | 0; //@line 28333
        if ($933 >>> 0 < $928 >>> 0) {
         $$03549$i = $933; //@line 28336
        } else {
         $$3$i190 = -226; //@line 28338
         break L133;
        }
       }
       $935 = __Z21audio_set_sample_sizei($$03549$i) | 0; //@line 28342
       $$3$i190 = $935 ? 0 : -226; //@line 28344
       break;
      }
     }
    } while (0);
    if ((label | 0) == 80) {
     $969 = HEAP32[30820] | 0; //@line 28350
     if (!$969) {
      $$3$i190 = -2147450878; //@line 28353
     } else {
      HEAP32[$2 + 32 >> 2] = $906; //@line 28356
      HEAP32[$2 >> 2] = $912; //@line 28357
      HEAP32[$2 + 36 >> 2] = $918; //@line 28359
      HEAP32[$2 + 40 >> 2] = $969; //@line 28361
      _Execute68k((HEAP32[30824] | 0) + 78 | 0, $2); //@line 28364
      $$3$i190 = HEAP32[$2 >> 2] | 0; //@line 28366
     }
    }
    $$0187 = $$3$i190; //@line 28369
    STACKTOP = sp; //@line 28370
    return $$0187 | 0; //@line 28370
   }
  case 261:
   {
    $977 = $0 + 8 | 0; //@line 28374
    HEAP32[$4 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($977 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($977) | 0; //@line 28381
    HEAP32[$4 + 32 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28388
    HEAP32[$4 + 36 >> 2] = HEAP32[30820]; //@line 28391
    _Execute68k((HEAP32[30824] | 0) + 146 | 0, $4); //@line 28394
    $$0187 = 0; //@line 28395
    STACKTOP = sp; //@line 28396
    return $$0187 | 0; //@line 28396
   }
  case 263:
  case 262:
   {
    break;
   }
  case 264:
   {
    HEAP32[$4 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28408
    $1004 = $0 + 8 | 0; //@line 28409
    HEAP32[$4 + 32 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1004 >>> 16 << 2) >> 2] >> 2] & 127]($1004) | 0; //@line 28416
    $1011 = $0 + 12 | 0; //@line 28417
    HEAP32[$4 + 36 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1011 >>> 16 << 2) >> 2] >> 2] & 127]($1011) | 0; //@line 28424
    HEAP32[$4 + 40 >> 2] = HEAP32[30820]; //@line 28427
    _Execute68k((HEAP32[30824] | 0) + 102 | 0, $4); //@line 28430
    $$0187 = HEAP32[$4 >> 2] | 0; //@line 28432
    STACKTOP = sp; //@line 28433
    return $$0187 | 0; //@line 28433
   }
  case -4:
   {
    $$0187 = 65539; //@line 28437
    STACKTOP = sp; //@line 28438
    return $$0187 | 0; //@line 28438
   }
  default:
   {
    if (($sext | 0) <= 16711680) {
     $$0187 = -2147450878; //@line 28444
     STACKTOP = sp; //@line 28445
     return $$0187 | 0; //@line 28445
    }
   }
  }
 } while (0);
 HEAP32[$4 + 32 >> 2] = HEAP32[30820]; //@line 28452
 HEAP32[$4 + 36 >> 2] = $0; //@line 28454
 _Execute68k(HEAP32[30824] | 0, $4); //@line 28456
 $$0187 = HEAP32[$4 >> 2] | 0; //@line 28458
 STACKTOP = sp; //@line 28459
 return $$0187 | 0; //@line 28459
}
function __Z6EmulOptP13M68kRegisters($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$in = 0, $$0313 = 0, $$pre$phi326Z2D = 0, $102 = 0, $11 = 0, $110 = 0, $126 = 0, $127 = 0, $129 = 0, $13 = 0, $135 = 0, $138 = 0, $139 = 0, $143 = 0, $15 = 0, $151 = 0, $152 = 0, $153 = 0, $155 = 0, $157 = 0, $158 = 0, $165 = 0, $166 = 0, $17 = 0, $170 = 0, $175 = 0, $177 = 0, $188 = 0, $19 = 0, $190 = 0, $2 = 0, $200 = 0, $207 = 0, $209 = 0, $21 = 0, $214 = 0, $23 = 0, $230 = 0, $233 = 0, $245 = 0, $247 = 0, $25 = 0, $252 = 0, $27 = 0, $278 = 0, $281 = 0, $287 = 0, $288 = 0, $29 = 0, $31 = 0, $33 = 0, $36 = 0, $40 = 0, $468 = 0, $469 = 0, $47 = 0, $474 = 0, $476 = 0, $482 = 0, $483 = 0, $484 = 0, $486 = 0, $49 = 0, $493 = 0, $499 = 0, $5 = 0, $50 = 0, $508 = 0, $514 = 0, $520 = 0, $522 = 0, $527 = 0, $535 = 0, $541 = 0, $546 = 0, $548 = 0, $553 = 0, $555 = 0, $56 = 0, $562 = 0, $568 = 0, $575 = 0, $581 = 0, $588 = 0, $595 = 0, $601 = 0, $607 = 0, $614 = 0, $63 = 0, $631 = 0, $648 = 0, $652 = 0, $655 = 0, $658 = 0, $671 = 0, $673 = 0, $678 = 0, $685 = 0, $69 = 0, $691 = 0, $696 = 0, $698 = 0, $7 = 0, $703 = 0, $710 = 0, $716 = 0, $722 = 0, $724 = 0, $731 = 0, $733 = 0, $739 = 0, $747 = 0, $759 = 0, $760 = 0, $761 = 0, $762 = 0, $769 = 0, $771 = 0, $776 = 0, $778 = 0, $78 = 0, $785 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $799 = 0, $801 = 0, $808 = 0, $810 = 0, $815 = 0, $817 = 0, $822 = 0, $824 = 0, $833 = 0, $840 = 0, $859 = 0, $861 = 0, $863 = 0, $865 = 0, $867 = 0, $869 = 0, $87 = 0, $871 = 0, $873 = 0, $875 = 0, $877 = 0, $879 = 0, $881 = 0, $883 = 0, $885 = 0, $887 = 0, $890 = 0, $9 = 0, $97 = 0, $vararg_buffer = 0, $vararg_buffer17 = 0, $vararg_buffer20 = 0, $vararg_buffer23 = 0, sp = 0;
 sp = STACKTOP; //@line 11179
 STACKTOP = STACKTOP + 224 | 0; //@line 11180
 $vararg_buffer23 = sp + 88 | 0; //@line 11181
 $vararg_buffer20 = sp + 80 | 0; //@line 11182
 $vararg_buffer17 = sp + 72 | 0; //@line 11183
 $vararg_buffer = sp; //@line 11184
 $2 = sp + 156 | 0; //@line 11185
 do {
  switch ($0 << 16 >> 16) {
  case 28929:
   {
    _puts(92920) | 0; //@line 11189
    $5 = HEAP32[$1 + 4 >> 2] | 0; //@line 11192
    $7 = HEAP32[$1 + 8 >> 2] | 0; //@line 11194
    $9 = HEAP32[$1 + 12 >> 2] | 0; //@line 11196
    $11 = HEAP32[$1 + 16 >> 2] | 0; //@line 11198
    $13 = HEAP32[$1 + 20 >> 2] | 0; //@line 11200
    $15 = HEAP32[$1 + 24 >> 2] | 0; //@line 11202
    $17 = HEAP32[$1 + 28 >> 2] | 0; //@line 11204
    $19 = HEAP32[$1 + 32 >> 2] | 0; //@line 11206
    $21 = HEAP32[$1 + 36 >> 2] | 0; //@line 11208
    $23 = HEAP32[$1 + 40 >> 2] | 0; //@line 11210
    $25 = HEAP32[$1 + 44 >> 2] | 0; //@line 11212
    $27 = HEAP32[$1 + 48 >> 2] | 0; //@line 11214
    $29 = HEAP32[$1 + 52 >> 2] | 0; //@line 11216
    $31 = HEAP32[$1 + 56 >> 2] | 0; //@line 11218
    $33 = HEAP32[$1 + 60 >> 2] | 0; //@line 11220
    $36 = HEAPU16[$1 + 64 >> 1] | 0; //@line 11223
    HEAP32[$vararg_buffer >> 2] = HEAP32[$1 >> 2]; //@line 11224
    HEAP32[$vararg_buffer + 4 >> 2] = $5; //@line 11226
    HEAP32[$vararg_buffer + 8 >> 2] = $7; //@line 11228
    HEAP32[$vararg_buffer + 12 >> 2] = $9; //@line 11230
    HEAP32[$vararg_buffer + 16 >> 2] = $11; //@line 11232
    HEAP32[$vararg_buffer + 20 >> 2] = $13; //@line 11234
    HEAP32[$vararg_buffer + 24 >> 2] = $15; //@line 11236
    HEAP32[$vararg_buffer + 28 >> 2] = $17; //@line 11238
    HEAP32[$vararg_buffer + 32 >> 2] = $19; //@line 11240
    HEAP32[$vararg_buffer + 36 >> 2] = $21; //@line 11242
    HEAP32[$vararg_buffer + 40 >> 2] = $23; //@line 11244
    HEAP32[$vararg_buffer + 44 >> 2] = $25; //@line 11246
    HEAP32[$vararg_buffer + 48 >> 2] = $27; //@line 11248
    HEAP32[$vararg_buffer + 52 >> 2] = $29; //@line 11250
    HEAP32[$vararg_buffer + 56 >> 2] = $31; //@line 11252
    HEAP32[$vararg_buffer + 60 >> 2] = $33; //@line 11254
    HEAP32[$vararg_buffer + 64 >> 2] = $36; //@line 11256
    _printf(92935, $vararg_buffer) | 0; //@line 11257
    __Z19VideoQuitFullScreenv(); //@line 11258
    __Z12QuitEmulatorv(); //@line 11259
    break;
   }
  case 28930:
   {
    __Z12QuitEmulatorv(); //@line 11264
    break;
   }
  case 28931:
   {
    __Z10TimerResetv(); //@line 11269
    __Z10EtherResetv(); //@line 11270
    __Z10AudioResetv(); //@line 11271
    $40 = (HEAP32[30893] | 0) + -4096 + (HEAP32[30895] | 0) | 0; //@line 11275
    _memset(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($40) | 0, 0, 4096) | 0; //@line 11282
    $47 = HEAP32[30893] | 0; //@line 11283
    $49 = (HEAP32[30895] | 0) + $47 | 0; //@line 11285
    $50 = $49 + -28 | 0; //@line 11286
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($50, $47); //@line 11292
    $56 = $49 + -24 | 0; //@line 11293
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($56 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($56, HEAP32[30895] | 0); //@line 11300
    $63 = $49 + -20 | 0; //@line 11301
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($63 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($63, -1); //@line 11307
    $69 = $49 + -16 | 0; //@line 11308
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($69 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($69, 0); //@line 11314
    $78 = (HEAP32[30896] | 0) + 24 + (HEAP32[28201] | 0) | 0; //@line 11318
    HEAP32[$1 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($78 >>> 16 << 2) >> 2] >> 2] & 127]($78) | 0; //@line 11324
    $87 = (HEAP32[30896] | 0) + 28 + (HEAP32[28201] | 0) | 0; //@line 11328
    HEAP32[$1 + 4 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($87 >>> 16 << 2) >> 2] >> 2] & 127]($87) | 0; //@line 11335
    $97 = (HEAP32[30896] | 0) + 16 + (HEAP32[28201] | 0) | 0; //@line 11339
    $102 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($97 >>> 16 << 2) >> 2] >> 2] & 127]($97) | 0; //@line 11344
    HEAP32[$1 + 8 >> 2] = HEAP32[30881] | 0 ? $102 | 268435456 : $102 & -268435457; //@line 11351
    $110 = (HEAP32[28201] | 0) + (HEAP32[30896] | 0) | 0; //@line 11354
    HEAP32[$1 + 32 >> 2] = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($110 >>> 16 << 2) >> 2] >> 2] & 127]($110) | 0) + $110; //@line 11362
    HEAP32[$1 + 36 >> 2] = (HEAP32[28201] | 0) + (HEAP32[30896] | 0); //@line 11367
    HEAP32[$1 + 56 >> 2] = $50; //@line 11369
    HEAP32[$1 + 60 >> 2] = (HEAP32[30893] | 0) + 65536; //@line 11373
    STACKTOP = sp; //@line 11374
    return;
   }
  case 28932:
   {
    $126 = $1 + 4 | 0; //@line 11378
    $127 = HEAP32[$126 >> 2] | 0; //@line 11379
    $129 = ($127 & 128 | 0) != 0; //@line 11381
    L8 : do {
     if (($127 & 120 | 0) == 56) {
      $135 = $127 << 5 & 224 | $127 >>> 10 & 31; //@line 11390
      if (!$129) {
       $151 = $1 + 8 | 0; //@line 11396
       $152 = HEAP32[$151 >> 2] | 0; //@line 11397
       if (($135 | 0) == 138 & (HEAP8[659480] | 0) == 0) {
        $153 = $152 | 5; //@line 11399
        HEAP32[$151 >> 2] = $153; //@line 11400
        $155 = $153; //@line 11401
       } else {
        $155 = $152; //@line 11403
       }
       HEAP8[656025 + $135 >> 0] = $155; //@line 11407
       $$pre$phi326Z2D = $151; //@line 11408
       break;
      }
      $138 = HEAPU8[656025 + $135 >> 0] | 0; //@line 11413
      $139 = $1 + 8 | 0; //@line 11414
      HEAP32[$139 >> 2] = $138; //@line 11415
      $143 = (HEAP8[656250] | HEAP8[656249]) << 24 >> 24 == 0; //@line 11419
      switch (($135 & 255) << 24 >> 24) {
      case 8:
       {
        if ((HEAP16[325960] | 0) == 1660) {
         $$pre$phi326Z2D = $139; //@line 11426
         break L8;
        }
        HEAP32[$139 >> 2] = $138 & 248; //@line 11430
        $$pre$phi326Z2D = $139; //@line 11431
        break L8;
        break;
       }
      case -118:
       {
        HEAP32[$139 >> 2] = $138 | 5; //@line 11437
        $$pre$phi326Z2D = $139; //@line 11438
        break L8;
        break;
       }
      case -32:
       {
        if (!$143) {
         $$pre$phi326Z2D = $139; //@line 11444
         break L8;
        }
        HEAP32[$139 >> 2] = 0; //@line 11447
        $$pre$phi326Z2D = $139; //@line 11448
        break L8;
        break;
       }
      case -31:
       {
        if (!$143) {
         $$pre$phi326Z2D = $139; //@line 11454
         break L8;
        }
        HEAP32[$139 >> 2] = 241; //@line 11457
        $$pre$phi326Z2D = $139; //@line 11458
        break L8;
        break;
       }
      case -30:
       {
        if (!$143) {
         $$pre$phi326Z2D = $139; //@line 11464
         break L8;
        }
        HEAP32[$139 >> 2] = 0; //@line 11467
        $$pre$phi326Z2D = $139; //@line 11468
        break L8;
        break;
       }
      case -29:
       {
        if (!$143) {
         $$pre$phi326Z2D = $139; //@line 11474
         break L8;
        }
        HEAP32[$139 >> 2] = 10; //@line 11477
        $$pre$phi326Z2D = $139; //@line 11478
        break L8;
        break;
       }
      default:
       {
        $$pre$phi326Z2D = $139; //@line 11483
        break L8;
       }
      }
     } else {
      $157 = $127 >>> 2; //@line 11488
      $158 = $157 & 31; //@line 11489
      if ($158 >>> 0 > 15 | ($157 & 28 | 0) == 8) {
       if ($129) {
        $165 = $1 + 8 | 0; //@line 11499
        HEAP32[$165 >> 2] = HEAPU8[656025 + $158 >> 0]; //@line 11500
        $$pre$phi326Z2D = $165; //@line 11501
        break;
       } else {
        $166 = $1 + 8 | 0; //@line 11504
        HEAP8[656025 + $158 >> 0] = HEAP32[$166 >> 2]; //@line 11508
        $$pre$phi326Z2D = $166; //@line 11509
        break;
       }
      }
      if ($158 >>> 0 > 7 | $129 ^ 1) {
       $$pre$phi326Z2D = $1 + 8 | 0; //@line 11518
       break;
      }
      $170 = __Z13TimerDateTimev() | 0; //@line 11521
      switch ($157 & 3) {
      case 1:
       {
        $$0$in = $170 >>> 8; //@line 11527
        break;
       }
      case 2:
       {
        $$0$in = $170 >>> 16; //@line 11532
        break;
       }
      case 3:
       {
        $$0$in = $170 >>> 24; //@line 11537
        break;
       }
      default:
       {
        $$0$in = $170; //@line 11541
       }
      }
      $175 = $1 + 8 | 0; //@line 11545
      HEAP32[$175 >> 2] = $$0$in & 255; //@line 11546
      $$pre$phi326Z2D = $175; //@line 11547
     }
    } while (0);
    HEAP32[$1 >> 2] = 0; //@line 11550
    HEAP32[$126 >> 2] = HEAP32[$$pre$phi326Z2D >> 2]; //@line 11552
    STACKTOP = sp; //@line 11553
    return;
   }
  case 28933:
   {
    $177 = $1 + 4 | 0; //@line 11557
    HEAP32[$177 >> 2] = HEAPU8[656025 + (HEAP32[$177 >> 2] & 255) >> 0]; //@line 11563
    STACKTOP = sp; //@line 11564
    return;
   }
  case 28934:
   {
    HEAP32[$1 >> 2] = HEAPU8[656025 + (HEAP32[$1 >> 2] & 255) >> 0]; //@line 11573
    STACKTOP = sp; //@line 11574
    return;
   }
  case 28935:
   {
    $188 = $1 + 48 | 0; //@line 11578
    $190 = (HEAP32[$188 >> 2] | 0) + -20 | 0; //@line 11580
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($190 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($190, (HEAP32[30895] | 0) + (HEAP32[30893] | 0) | 0); //@line 11589
    $200 = (HEAP32[$188 >> 2] | 0) + -26 | 0; //@line 11591
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($200 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($200, 0); //@line 11597
    $207 = (HEAP32[$188 >> 2] | 0) + -25 | 0; //@line 11599
    $209 = 123608 + ($207 >>> 16 << 2) | 0; //@line 11601
    $214 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$209 >> 2] | 0) + 8 >> 2] & 127]($207) | 0 | 1; //@line 11606
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$209 >> 2] | 0) + 20 >> 2] & 31]($207, $214); //@line 11610
    HEAP32[$1 + 56 >> 2] = (HEAP32[30895] | 0) + (HEAP32[30893] | 0); //@line 11615
    STACKTOP = sp; //@line 11616
    return;
   }
  case 28936:
   {
    HEAP32[$1 + 36 >> 2] = (((HEAP32[30895] | 0) * 3 | 0) >>> 2) + (HEAP32[30893] | 0); //@line 11626
    STACKTOP = sp; //@line 11627
    return;
   }
  case 28937:
   {
    $230 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](7928) | 0; //@line 11633
    $233 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](7924) | 0; //@line 11636
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](7928, HEAP32[30895] | 0); //@line 11641
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](7924, $233 - $230 + (HEAP32[30895] | 0) | 0); //@line 11648
    STACKTOP = sp; //@line 11649
    return;
   }
  case 28963:
   {
    $245 = HEAP32[$1 >> 2] & 255; //@line 11654
    $247 = HEAP32[$1 + 32 >> 2] | 0; //@line 11656
    $252 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($247 >>> 16 << 2) >> 2] >> 2] & 127]($247) | 0; //@line 11661
    __Z5ADBOphPh($245, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($252 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($252) | 0); //@line 11668
    STACKTOP = sp; //@line 11669
    return;
   }
  case 28964:
   {
    HEAP32[$1 >> 2] = (__Z7InsTimejt(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 4 >> 2] & 65535) | 0) << 16 >> 16; //@line 11680
    STACKTOP = sp; //@line 11681
    return;
   }
  case 28965:
   {
    HEAP32[$1 >> 2] = (__Z7RmvTimej(HEAP32[$1 + 32 >> 2] | 0) | 0) << 16 >> 16; //@line 11689
    STACKTOP = sp; //@line 11690
    return;
   }
  case 28966:
   {
    HEAP32[$1 >> 2] = (__Z9PrimeTimeji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11699
    STACKTOP = sp; //@line 11700
    return;
   }
  case 28967:
   {
    __Z12MicrosecondsRjS_($1 + 32 | 0, $1); //@line 11705
    STACKTOP = sp; //@line 11706
    return;
   }
  case 28938:
   {
    __Z14InstallDriversj(HEAP32[$1 + 32 >> 2] | 0); //@line 11712
    $278 = HEAP32[28202] | 0; //@line 11713
    if ($278 | 0) {
     HEAP32[$2 >> 2] = 43518; //@line 11716
     HEAP32[$2 + 32 >> 2] = $278; //@line 11718
     _Execute68kTrap(-22969, $2); //@line 11719
    }
    $281 = HEAP32[28203] | 0; //@line 11721
    if ($281 | 0) {
     HEAP32[$2 >> 2] = 43517; //@line 11724
     HEAP32[$2 + 32 >> 2] = $281; //@line 11726
     _Execute68kTrap(-22969, $2); //@line 11727
    }
    if ((HEAP16[325960] | 0) == 1660) {
     HEAP32[$2 >> 2] = 4096; //@line 11732
     _Execute68kTrap(-22754, $2); //@line 11733
     $287 = HEAP32[$2 + 32 >> 2] | 0; //@line 11735
     $288 = $287 + 2048 | 0; //@line 11736
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($288 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($288, 15); //@line 11742
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](3264, $287); //@line 11746
    }
    STACKTOP = sp; //@line 11748
    return;
   }
  case 28939:
   {
    __Z11InstallSERDv(); //@line 11752
    STACKTOP = sp; //@line 11753
    return;
   }
  case 28940:
   {
    HEAP32[$1 >> 2] = (__Z8SonyOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11763
    STACKTOP = sp; //@line 11764
    return;
   }
  case 28941:
   {
    HEAP32[$1 >> 2] = (__Z9SonyPrimejj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11774
    STACKTOP = sp; //@line 11775
    return;
   }
  case 28942:
   {
    HEAP32[$1 >> 2] = (__Z11SonyControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11785
    STACKTOP = sp; //@line 11786
    return;
   }
  case 28943:
   {
    HEAP32[$1 >> 2] = (__Z10SonyStatusjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11796
    STACKTOP = sp; //@line 11797
    return;
   }
  case 28944:
   {
    HEAP32[$1 >> 2] = (__Z8DiskOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11807
    STACKTOP = sp; //@line 11808
    return;
   }
  case 28945:
   {
    HEAP32[$1 >> 2] = (__Z9DiskPrimejj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11818
    STACKTOP = sp; //@line 11819
    return;
   }
  case 28946:
   {
    HEAP32[$1 >> 2] = (__Z11DiskControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11829
    STACKTOP = sp; //@line 11830
    return;
   }
  case 28947:
   {
    HEAP32[$1 >> 2] = (__Z10DiskStatusjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11840
    STACKTOP = sp; //@line 11841
    return;
   }
  case 28948:
   {
    HEAP32[$1 >> 2] = (__Z9CDROMOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11851
    STACKTOP = sp; //@line 11852
    return;
   }
  case 28949:
   {
    HEAP32[$1 >> 2] = (__Z10CDROMPrimejj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11862
    STACKTOP = sp; //@line 11863
    return;
   }
  case 28950:
   {
    HEAP32[$1 >> 2] = (__Z12CDROMControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11873
    STACKTOP = sp; //@line 11874
    return;
   }
  case 28951:
   {
    HEAP32[$1 >> 2] = (__Z11CDROMStatusjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11884
    STACKTOP = sp; //@line 11885
    return;
   }
  case 28952:
   {
    HEAP32[$1 >> 2] = (__Z15VideoDriverOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11895
    STACKTOP = sp; //@line 11896
    return;
   }
  case 28953:
   {
    HEAP32[$1 >> 2] = (__Z18VideoDriverControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11906
    STACKTOP = sp; //@line 11907
    return;
   }
  case 28954:
   {
    HEAP32[$1 >> 2] = (__Z17VideoDriverStatusjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11917
    STACKTOP = sp; //@line 11918
    return;
   }
  case 28955:
   {
    HEAP32[$1 >> 2] = (__Z10SerialOpenjji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11929
    STACKTOP = sp; //@line 11930
    return;
   }
  case 28956:
   {
    HEAP32[$1 >> 2] = (__Z11SerialPrimejji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11941
    STACKTOP = sp; //@line 11942
    return;
   }
  case 28957:
   {
    HEAP32[$1 >> 2] = (__Z13SerialControljji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11953
    STACKTOP = sp; //@line 11954
    return;
   }
  case 28958:
   {
    HEAP32[$1 >> 2] = (__Z12SerialStatusjji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11965
    STACKTOP = sp; //@line 11966
    return;
   }
  case 28959:
   {
    HEAP32[$1 >> 2] = (__Z11SerialClosejji(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) << 16 >> 16; //@line 11977
    STACKTOP = sp; //@line 11978
    return;
   }
  case 28960:
   {
    HEAP32[$1 >> 2] = (__Z9EtherOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11988
    STACKTOP = sp; //@line 11989
    return;
   }
  case 28961:
   {
    HEAP32[$1 >> 2] = (__Z12EtherControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 11999
    STACKTOP = sp; //@line 12000
    return;
   }
  case 28962:
   {
    __Z15EtherReadPacketRjS_S_S_($1 + 32 | 0, $1 + 44 | 0, $1 + 12 | 0, $1 + 4 | 0); //@line 12008
    STACKTOP = sp; //@line 12009
    return;
   }
  case 28977:
   {
    HEAP32[$1 >> 2] = (__Z11SoundInOpenjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 12019
    STACKTOP = sp; //@line 12020
    return;
   }
  case 28978:
   {
    HEAP32[$1 >> 2] = (__Z12SoundInPrimejj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 12030
    STACKTOP = sp; //@line 12031
    return;
   }
  case 28979:
   {
    HEAP32[$1 >> 2] = (__Z14SoundInControljj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 12041
    STACKTOP = sp; //@line 12042
    return;
   }
  case 28980:
   {
    HEAP32[$1 >> 2] = (__Z13SoundInStatusjj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 12052
    STACKTOP = sp; //@line 12053
    return;
   }
  case 28981:
   {
    HEAP32[$1 >> 2] = (__Z12SoundInClosejj(HEAP32[$1 + 32 >> 2] | 0, HEAP32[$1 + 36 >> 2] | 0) | 0) << 16 >> 16; //@line 12063
    STACKTOP = sp; //@line 12064
    return;
   }
  case 28968:
   {
    $468 = $1 + 60 | 0; //@line 12068
    $469 = HEAP32[$468 >> 2] | 0; //@line 12069
    $474 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($469 >>> 16 << 2) >> 2] >> 2] & 127]($469) | 0; //@line 12074
    $476 = (HEAP32[$468 >> 2] | 0) + 4 | 0; //@line 12076
    $482 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($476 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($476) | 0; //@line 12082
    $483 = HEAP32[$468 >> 2] | 0; //@line 12083
    $484 = $483 + 6 | 0; //@line 12084
    HEAP32[$468 >> 2] = $484; //@line 12085
    do {
     switch (($482 & 65535) << 16 >> 16) {
     case 0:
      {
       $486 = (__Z9SCSIResetv() | 0) << 16 >> 16; //@line 12091
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($484, $486); //@line 12097
       $$0313 = 0; //@line 12098
       break;
      }
     case 1:
      {
       $493 = (__Z7SCSIGetv() | 0) << 16 >> 16; //@line 12103
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($484, $493); //@line 12109
       $$0313 = 0; //@line 12110
       break;
      }
     case 11:
     case 2:
      {
       $499 = $483 + 8 | 0; //@line 12114
       $508 = (__Z10SCSISelecti((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($484) | 0) & 255) | 0) << 16 >> 16; //@line 12123
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($499 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($499, $508); //@line 12129
       $$0313 = 2; //@line 12130
       break;
      }
     case 3:
      {
       $514 = $483 + 12 | 0; //@line 12134
       $520 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($484) | 0; //@line 12140
       $522 = (HEAP32[$468 >> 2] | 0) + 2 | 0; //@line 12142
       $527 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($522 >>> 16 << 2) >> 2] >> 2] & 127]($522) | 0; //@line 12147
       $535 = (__Z7SCSICmdiPh($520, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($527 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($527) | 0) | 0) << 16 >> 16; //@line 12155
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($514 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($514, $535); //@line 12161
       $$0313 = 6; //@line 12162
       break;
      }
     case 4:
      {
       $541 = $483 + 18 | 0; //@line 12166
       $546 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($484 >>> 16 << 2) >> 2] >> 2] & 127]($484) | 0; //@line 12171
       $548 = (HEAP32[$468 >> 2] | 0) + 4 | 0; //@line 12173
       $553 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($548 >>> 16 << 2) >> 2] >> 2] & 127]($548) | 0; //@line 12178
       $555 = (HEAP32[$468 >> 2] | 0) + 8 | 0; //@line 12180
       $562 = (__Z12SCSICompletejjj($546, $553, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($555 >>> 16 << 2) >> 2] >> 2] & 127]($555) | 0) | 0) << 16 >> 16; //@line 12187
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($541 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($541, $562); //@line 12193
       $$0313 = 12; //@line 12194
       break;
      }
     case 8:
     case 5:
      {
       $568 = $483 + 10 | 0; //@line 12198
       $575 = (__Z8SCSIReadj(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($484 >>> 16 << 2) >> 2] >> 2] & 127]($484) | 0) | 0) << 16 >> 16; //@line 12205
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($568 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($568, $575); //@line 12211
       $$0313 = 4; //@line 12212
       break;
      }
     case 9:
     case 6:
      {
       $581 = $483 + 10 | 0; //@line 12216
       $588 = (__Z9SCSIWritej(FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($484 >>> 16 << 2) >> 2] >> 2] & 127]($484) | 0) | 0) << 16 >> 16; //@line 12223
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($581 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($581, $588); //@line 12229
       $$0313 = 4; //@line 12230
       break;
      }
     case 10:
      {
       $595 = (__Z8SCSIStatv() | 0) & 65535; //@line 12235
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($484, $595); //@line 12241
       $$0313 = 0; //@line 12242
       break;
      }
     case 12:
      {
       $601 = $483 + 10 | 0; //@line 12246
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($601 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($601, 0); //@line 12252
       $$0313 = 4; //@line 12253
       break;
      }
     case 13:
      {
       $607 = $483 + 8 | 0; //@line 12257
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($607 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($607, 0); //@line 12263
       $$0313 = 2; //@line 12264
       break;
      }
     case 14:
      {
       $614 = (__Z11SCSIMgrBusyv() | 0) << 16 >> 16; //@line 12269
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($484 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($484, $614); //@line 12275
       $$0313 = 0; //@line 12276
       break;
      }
     default:
      {
       HEAP32[$vararg_buffer17 >> 2] = $482 & 65535; //@line 12281
       _printf(93072, $vararg_buffer17) | 0; //@line 12282
       __Z12QuitEmulatorv(); //@line 12283
      }
     }
    } while (0);
    HEAP32[$1 + 32 >> 2] = $474; //@line 12289
    HEAP32[$1 + 36 >> 2] = (HEAP32[$468 >> 2] | 0) + $$0313; //@line 12293
    STACKTOP = sp; //@line 12294
    return;
   }
  case 28969:
   {
    HEAP32[$1 >> 2] = 0; //@line 12298
    if (HEAP32[30882] & 1 | 0) {
     __Z18ClearInterruptFlagj(1); //@line 12303
     $631 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](362) | 0) + 1 | 0; //@line 12307
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](362, $631); //@line 12311
     if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3324) | 0) == 1464619843) {
      __Z14TimerInterruptv(); //@line 12317
      __Z14VideoInterruptv(); //@line 12318
      if ((HEAP16[325960] | 0) == 1660) {
       HEAP32[$2 >> 2] = 0; //@line 12322
       _Execute68kTrap(-24462, $2); //@line 12323
      }
      HEAP32[$1 >> 2] = 1; //@line 12325
     }
    }
    if (HEAP32[30882] & 2 | 0) {
     __Z18ClearInterruptFlagj(2); //@line 12332
     if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3324) | 0) == 1464619843) {
      __Z13SonyInterruptv(); //@line 12338
      __Z13DiskInterruptv(); //@line 12339
      __Z14CDROMInterruptv(); //@line 12340
     }
    }
    $648 = HEAP32[30882] | 0; //@line 12343
    if (!($648 & 4)) {
     $652 = $648; //@line 12347
    } else {
     __Z18ClearInterruptFlagj(4); //@line 12349
     __Z15SerialInterruptv(); //@line 12350
     $652 = HEAP32[30882] | 0; //@line 12352
    }
    if (!($652 & 8)) {
     $655 = $652; //@line 12357
    } else {
     __Z18ClearInterruptFlagj(8); //@line 12359
     __Z14EtherInterruptv(); //@line 12360
     $655 = HEAP32[30882] | 0; //@line 12362
    }
    if (!($655 & 16)) {
     $658 = $655; //@line 12367
    } else {
     __Z18ClearInterruptFlagj(16); //@line 12369
     __Z14AudioInterruptv(); //@line 12370
     $658 = HEAP32[30882] | 0; //@line 12372
    }
    if ($658 & 64 | 0) {
     __Z18ClearInterruptFlagj(64); //@line 12377
     if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3324) | 0) == 1464619843) {
      __Z12ADBInterruptv(); //@line 12383
     }
    }
    if (!(HEAP32[30882] & 128)) {
     STACKTOP = sp; //@line 12390
     return;
    }
    __Z18ClearInterruptFlagj(128); //@line 12392
    if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3324) | 0) != 1464619843) {
     STACKTOP = sp; //@line 12398
     return;
    }
    STACKTOP = sp; //@line 12400
    return;
   }
  case 28970:
   {
    $671 = $1 + 60 | 0; //@line 12404
    $673 = (HEAP32[$671 >> 2] | 0) + 4 | 0; //@line 12406
    $678 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($673 >>> 16 << 2) >> 2] >> 2] & 127]($673) | 0; //@line 12411
    FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($678 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($678) | 0; //@line 12417
    $685 = (HEAP32[$671 >> 2] | 0) + 8 | 0; //@line 12419
    FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($685 >>> 16 << 2) >> 2] >> 2] & 127]($685) | 0; //@line 12424
    $691 = (HEAP32[$671 >> 2] | 0) + 12 | 0; //@line 12426
    FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($691 >>> 16 << 2) >> 2] >> 2] & 127]($691) | 0; //@line 12431
    STACKTOP = sp; //@line 12432
    return;
   }
  case 28971:
   {
    $696 = $1 + 60 | 0; //@line 12436
    $698 = (HEAP32[$696 >> 2] | 0) + 4 | 0; //@line 12438
    $703 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($698 >>> 16 << 2) >> 2] >> 2] & 127]($698) | 0; //@line 12443
    FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($703 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($703) | 0; //@line 12449
    $710 = (HEAP32[$696 >> 2] | 0) + 8 | 0; //@line 12451
    FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($710 >>> 16 << 2) >> 2] >> 2] & 127]($710) | 0; //@line 12456
    $716 = (HEAP32[$696 >> 2] | 0) + 12 | 0; //@line 12458
    FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($716 >>> 16 << 2) >> 2] >> 2] & 127]($716) | 0; //@line 12463
    STACKTOP = sp; //@line 12464
    return;
   }
  case 28972:
   {
    $722 = HEAP32[$1 + 4 >> 2] | 0; //@line 12469
    $724 = HEAP32[$1 + 40 >> 2] | 0; //@line 12471
    $731 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($724 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($724) | 0) & 65535; //@line 12478
    $733 = HEAP32[$1 + 32 >> 2] | 0; //@line 12480
    if (!$733) {
     STACKTOP = sp; //@line 12483
     return;
    }
    $739 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($733 >>> 16 << 2) >> 2] >> 2] & 127]($733) | 0; //@line 12489
    if (!$739) {
     STACKTOP = sp; //@line 12492
     return;
    }
    $747 = $739 + -8 | 0; //@line 12500
    __Z9CheckLoadjsPhj($722, $731, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($739 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($739) | 0, (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($747 >>> 16 << 2) >> 2] >> 2] & 127]($747) | 0) & 16777215); //@line 12507
    STACKTOP = sp; //@line 12508
    return;
   }
  case 28973:
   {
    HEAP32[$1 >> 2] = __Z13AudioDispatchjj(HEAP32[$1 + 44 >> 2] | 0, HEAP32[$1 + 48 >> 2] | 0) | 0; //@line 12517
    STACKTOP = sp; //@line 12518
    return;
   }
  case 28974:
   {
    $759 = $1 + 60 | 0; //@line 12522
    $760 = HEAP32[$759 >> 2] | 0; //@line 12523
    $761 = $760 + 14 | 0; //@line 12524
    $762 = $760 + 12 | 0; //@line 12525
    $769 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($762 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($762) | 0) & 65535; //@line 12532
    $771 = (HEAP32[$759 >> 2] | 0) + 8 | 0; //@line 12534
    $776 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($771 >>> 16 << 2) >> 2] >> 2] & 127]($771) | 0; //@line 12539
    $778 = (HEAP32[$759 >> 2] | 0) + 4 | 0; //@line 12541
    $785 = (__Z9ExtFSCommtjj($769, $776, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($778 >>> 16 << 2) >> 2] >> 2] & 127]($778) | 0) | 0) << 16 >> 16; //@line 12548
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($761 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($761, $785); //@line 12554
    STACKTOP = sp; //@line 12555
    return;
   }
  case 28975:
   {
    $791 = $1 + 60 | 0; //@line 12559
    $792 = HEAP32[$791 >> 2] | 0; //@line 12560
    $793 = $792 + 20 | 0; //@line 12561
    $794 = $792 + 16 | 0; //@line 12562
    $799 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($794 >>> 16 << 2) >> 2] >> 2] & 127]($794) | 0; //@line 12567
    $801 = (HEAP32[$791 >> 2] | 0) + 14 | 0; //@line 12569
    $808 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($801 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($801) | 0) & 65535; //@line 12576
    $810 = (HEAP32[$791 >> 2] | 0) + 10 | 0; //@line 12578
    $815 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($810 >>> 16 << 2) >> 2] >> 2] & 127]($810) | 0; //@line 12583
    $817 = (HEAP32[$791 >> 2] | 0) + 6 | 0; //@line 12585
    $822 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($817 >>> 16 << 2) >> 2] >> 2] & 127]($817) | 0; //@line 12590
    $824 = (HEAP32[$791 >> 2] | 0) + 4 | 0; //@line 12592
    $833 = (__Z8ExtFSHFSjtjjs($799, $808, $815, $822, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($824 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($824) | 0) & 65535) | 0) << 16 >> 16; //@line 12601
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($793 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($793, $833); //@line 12607
    STACKTOP = sp; //@line 12608
    return;
   }
  case 28976:
   {
    $840 = HEAP32[$1 + 32 >> 2] | 0; //@line 12613
    FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($840 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($840) | 0; //@line 12619
    STACKTOP = sp; //@line 12620
    return;
   }
  case 28982:
   {
    HEAP32[$1 >> 2] = __Z9DebugUtilj(HEAP32[$1 >> 2] | 0) | 0; //@line 12626
    STACKTOP = sp; //@line 12627
    return;
   }
  case 28983:
   {
    if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](332) | 0)) {
     __Z9idle_waitv(); //@line 12636
    }
    HEAP32[$1 + 32 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](694) | 0; //@line 12642
    STACKTOP = sp; //@line 12643
    return;
   }
  default:
   {
    HEAP32[$vararg_buffer20 >> 2] = $0 & 65535; //@line 12648
    _printf(93115, $vararg_buffer20) | 0; //@line 12649
    $859 = HEAP32[$1 + 4 >> 2] | 0; //@line 12652
    $861 = HEAP32[$1 + 8 >> 2] | 0; //@line 12654
    $863 = HEAP32[$1 + 12 >> 2] | 0; //@line 12656
    $865 = HEAP32[$1 + 16 >> 2] | 0; //@line 12658
    $867 = HEAP32[$1 + 20 >> 2] | 0; //@line 12660
    $869 = HEAP32[$1 + 24 >> 2] | 0; //@line 12662
    $871 = HEAP32[$1 + 28 >> 2] | 0; //@line 12664
    $873 = HEAP32[$1 + 32 >> 2] | 0; //@line 12666
    $875 = HEAP32[$1 + 36 >> 2] | 0; //@line 12668
    $877 = HEAP32[$1 + 40 >> 2] | 0; //@line 12670
    $879 = HEAP32[$1 + 44 >> 2] | 0; //@line 12672
    $881 = HEAP32[$1 + 48 >> 2] | 0; //@line 12674
    $883 = HEAP32[$1 + 52 >> 2] | 0; //@line 12676
    $885 = HEAP32[$1 + 56 >> 2] | 0; //@line 12678
    $887 = HEAP32[$1 + 60 >> 2] | 0; //@line 12680
    $890 = HEAPU16[$1 + 64 >> 1] | 0; //@line 12683
    HEAP32[$vararg_buffer23 >> 2] = HEAP32[$1 >> 2]; //@line 12684
    HEAP32[$vararg_buffer23 + 4 >> 2] = $859; //@line 12686
    HEAP32[$vararg_buffer23 + 8 >> 2] = $861; //@line 12688
    HEAP32[$vararg_buffer23 + 12 >> 2] = $863; //@line 12690
    HEAP32[$vararg_buffer23 + 16 >> 2] = $865; //@line 12692
    HEAP32[$vararg_buffer23 + 20 >> 2] = $867; //@line 12694
    HEAP32[$vararg_buffer23 + 24 >> 2] = $869; //@line 12696
    HEAP32[$vararg_buffer23 + 28 >> 2] = $871; //@line 12698
    HEAP32[$vararg_buffer23 + 32 >> 2] = $873; //@line 12700
    HEAP32[$vararg_buffer23 + 36 >> 2] = $875; //@line 12702
    HEAP32[$vararg_buffer23 + 40 >> 2] = $877; //@line 12704
    HEAP32[$vararg_buffer23 + 44 >> 2] = $879; //@line 12706
    HEAP32[$vararg_buffer23 + 48 >> 2] = $881; //@line 12708
    HEAP32[$vararg_buffer23 + 52 >> 2] = $883; //@line 12710
    HEAP32[$vararg_buffer23 + 56 >> 2] = $885; //@line 12712
    HEAP32[$vararg_buffer23 + 60 >> 2] = $887; //@line 12714
    HEAP32[$vararg_buffer23 + 64 >> 2] = $890; //@line 12716
    _printf(92935, $vararg_buffer23) | 0; //@line 12717
    __Z12QuitEmulatorv(); //@line 12718
   }
  }
 } while (0);
}
function _vfscanf($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$ = 0, $$$0268 = 0, $$$0305 = 0, $$$3 = 0, $$0266$lcssa = 0, $$0266417 = 0, $$0268 = 0, $$0272 = 0, $$0273429 = 0, $$0276$ph = 0, $$0278$ph = 0, $$0278$ph$phi = 0, $$0278$ph336 = 0, $$0283428 = 0, $$0286420 = 0, $$0288425 = 0, $$0292 = 0, $$0293 = 0, $$0305423 = 0, $$10 = 0, $$11 = 0, $$1267 = 0, $$1271 = 0, $$1274 = 0, $$1277$ph = 0, $$1279 = 0, $$1284 = 0, $$1289 = 0, $$2 = 0, $$2275 = 0, $$2280 = 0, $$2280$ph = 0, $$2280$ph$phi = 0, $$2285 = 0, $$2290 = 0, $$2307$ph = 0, $$3$lcssa = 0, $$327 = 0, $$328$le441 = 0, $$3281 = 0, $$3291 = 0, $$3416 = 0, $$4282 = 0, $$4309 = 0, $$5 = 0, $$5299 = 0, $$5310 = 0, $$6 = 0, $$6311 = 0, $$7 = 0, $$7$ph = 0, $$7312 = 0, $$8 = 0, $$8313 = 0, $$9 = 0, $$9314 = 0, $$9314$ph = 0, $$lcssa355 = 0, $$ph = 0, $$ph353 = 0, $$pre$phi516Z2D = 0, $$sink443 = 0, $$sroa$2$0$$sroa_idx13 = 0, $100 = 0, $102 = 0, $103 = 0, $106 = 0, $109 = 0, $11 = 0, $112 = 0, $114 = 0, $119 = 0, $126 = 0, $13 = 0, $132 = 0, $138 = 0, $14 = 0, $140 = 0, $141 = 0, $147 = 0, $15 = 0, $150 = 0, $154 = 0, $156 = 0, $16 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $167 = 0, $17 = 0, $172 = 0, $176 = 0, $18 = 0, $181 = 0, $182 = 0, $184 = 0, $186 = 0, $187 = 0, $19 = 0, $195 = 0, $20 = 0, $205 = 0, $207 = 0, $21 = 0, $211 = 0, $213 = 0, $22 = 0, $221 = 0, $229 = 0, $230 = 0, $233 = 0, $235 = 0, $24 = 0, $241 = 0, $248 = 0, $250 = 0, $256 = 0, $263 = 0, $268 = 0, $269 = 0, $27 = 0, $276 = 0, $285 = 0.0, $3 = 0, $304 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $39 = 0, $4 = 0, $45 = 0, $5 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $58 = 0, $6 = 0, $68 = 0, $88 = 0, $89 = 0, $90 = 0, $91 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $99 = 0, $isdigittmp = 0, $narrow = 0, $narrow469 = 0, $trunc = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 639
 STACKTOP = STACKTOP + 288 | 0; //@line 640
 $3 = sp + 8 | 0; //@line 641
 $4 = sp + 17 | 0; //@line 642
 $5 = sp; //@line 643
 $6 = sp + 16 | 0; //@line 644
 if ((HEAP32[$0 + 76 >> 2] | 0) > -1) {
  $306 = ___lockfile($0) | 0; //@line 650
 } else {
  $306 = 0; //@line 652
 }
 $11 = HEAP8[$1 >> 0] | 0; //@line 654
 L4 : do {
  if (!($11 << 24 >> 24)) {
   $$3291 = 0; //@line 658
  } else {
   $13 = $0 + 4 | 0; //@line 660
   $14 = $0 + 100 | 0; //@line 661
   $15 = $0 + 108 | 0; //@line 662
   $16 = $0 + 8 | 0; //@line 663
   $17 = $4 + 10 | 0; //@line 664
   $18 = $4 + 33 | 0; //@line 665
   $$sroa$2$0$$sroa_idx13 = $3 + 4 | 0; //@line 666
   $19 = $4 + 46 | 0; //@line 667
   $20 = $4 + 94 | 0; //@line 668
   $21 = $4 + 1 | 0; //@line 669
   $22 = $4 + 1 | 0; //@line 670
   $$0273429 = $1; //@line 671
   $$0283428 = 0; //@line 671
   $$0288425 = 0; //@line 671
   $$0305423 = 0; //@line 671
   $102 = 0; //@line 671
   $24 = $11; //@line 671
   L6 : while (1) {
    L8 : do {
     if (!(_isspace($24 & 255) | 0)) {
      $53 = $24 << 24 >> 24 == 37; //@line 678
      L10 : do {
       if ($53) {
        $54 = $$0273429 + 1 | 0; //@line 681
        $55 = HEAP8[$54 >> 0] | 0; //@line 682
        L12 : do {
         switch ($55 << 24 >> 24) {
         case 37:
          {
           break L10;
           break;
          }
         case 42:
          {
           $$0293 = 0; //@line 691
           $$2275 = $$0273429 + 2 | 0; //@line 691
           break;
          }
         default:
          {
           $isdigittmp = ($55 & 255) + -48 | 0; //@line 696
           if ($isdigittmp >>> 0 < 10) {
            if ((HEAP8[$$0273429 + 2 >> 0] | 0) == 36) {
             $$0293 = _arg_n($2, $isdigittmp) | 0; //@line 705
             $$2275 = $$0273429 + 3 | 0; //@line 705
             break L12;
            }
           }
           $88 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 720
           $89 = HEAP32[$88 >> 2] | 0; //@line 721
           HEAP32[$2 >> 2] = $88 + 4; //@line 723
           $$0293 = $89; //@line 724
           $$2275 = $54; //@line 724
          }
         }
        } while (0);
        $90 = HEAP8[$$2275 >> 0] | 0; //@line 728
        $91 = $90 & 255; //@line 729
        if (($91 + -48 | 0) >>> 0 < 10) {
         $$0266417 = 0; //@line 733
         $$3416 = $$2275; //@line 733
         $95 = $91; //@line 733
         while (1) {
          $94 = ($$0266417 * 10 | 0) + -48 + $95 | 0; //@line 737
          $96 = $$3416 + 1 | 0; //@line 738
          $97 = HEAP8[$96 >> 0] | 0; //@line 739
          $95 = $97 & 255; //@line 740
          if (($95 + -48 | 0) >>> 0 >= 10) {
           $$0266$lcssa = $94; //@line 746
           $$3$lcssa = $96; //@line 746
           $$lcssa355 = $97; //@line 746
           break;
          } else {
           $$0266417 = $94; //@line 744
           $$3416 = $96; //@line 744
          }
         }
        } else {
         $$0266$lcssa = 0; //@line 751
         $$3$lcssa = $$2275; //@line 751
         $$lcssa355 = $90; //@line 751
        }
        $99 = $$lcssa355 << 24 >> 24 == 109; //@line 753
        $100 = ($$0293 | 0) != 0; //@line 754
        $$$0305 = $99 ? 0 : $$0305423; //@line 756
        $$327 = $99 ? 0 : $102; //@line 757
        $$$3 = $99 ? $$3$lcssa + 1 | 0 : $$3$lcssa; //@line 758
        $narrow = $100 & $99; //@line 759
        $103 = $$$3 + 1 | 0; //@line 760
        switch (HEAP8[$$$3 >> 0] | 0) {
        case 104:
         {
          $106 = (HEAP8[$103 >> 0] | 0) == 104; //@line 765
          $$0268 = $106 ? -2 : -1; //@line 769
          $$5 = $106 ? $$$3 + 2 | 0 : $103; //@line 769
          break;
         }
        case 108:
         {
          $109 = (HEAP8[$103 >> 0] | 0) == 108; //@line 774
          $$0268 = $109 ? 3 : 1; //@line 778
          $$5 = $109 ? $$$3 + 2 | 0 : $103; //@line 778
          break;
         }
        case 106:
         {
          $$0268 = 3; //@line 782
          $$5 = $103; //@line 782
          break;
         }
        case 116:
        case 122:
         {
          $$0268 = 1; //@line 786
          $$5 = $103; //@line 786
          break;
         }
        case 76:
         {
          $$0268 = 2; //@line 790
          $$5 = $103; //@line 790
          break;
         }
        case 110:
        case 112:
        case 67:
        case 83:
        case 91:
        case 99:
        case 115:
        case 88:
        case 71:
        case 70:
        case 69:
        case 65:
        case 103:
        case 102:
        case 101:
        case 97:
        case 120:
        case 117:
        case 111:
        case 105:
        case 100:
         {
          $$0268 = 0; //@line 794
          $$5 = $$$3; //@line 794
          break;
         }
        default:
         {
          $$7312 = $$$0305; //@line 798
          $309 = $$327; //@line 798
          $narrow469 = $narrow; //@line 798
          label = 137; //@line 799
          break L6;
         }
        }
        $112 = HEAPU8[$$5 >> 0] | 0; //@line 804
        $114 = ($112 & 47 | 0) == 3; //@line 806
        $$ = $114 ? $112 | 32 : $112; //@line 808
        $$$0268 = $114 ? 1 : $$0268; //@line 809
        $trunc = $$ & 255; //@line 810
        switch ($trunc << 24 >> 24) {
        case 99:
         {
          $$1267 = ($$0266$lcssa | 0) > 1 ? $$0266$lcssa : 1; //@line 815
          $$1284 = $$0283428; //@line 815
          break;
         }
        case 91:
         {
          $$1267 = $$0266$lcssa; //@line 819
          $$1284 = $$0283428; //@line 819
          break;
         }
        case 110:
         {
          _store_int($$0293, $$$0268, $$0283428, (($$0283428 | 0) < 0) << 31 >> 31); //@line 825
          $$11 = $$5; //@line 826
          $$1289 = $$0288425; //@line 826
          $$2285 = $$0283428; //@line 826
          $$6311 = $$$0305; //@line 826
          $307 = $$327; //@line 826
          break L8;
          break;
         }
        default:
         {
          ___shlim($0, 0); //@line 831
          do {
           $119 = HEAP32[$13 >> 2] | 0; //@line 833
           if ($119 >>> 0 < (HEAP32[$14 >> 2] | 0) >>> 0) {
            HEAP32[$13 >> 2] = $119 + 1; //@line 838
            $126 = HEAPU8[$119 >> 0] | 0; //@line 841
           } else {
            $126 = ___shgetc($0) | 0; //@line 844
           }
          } while ((_isspace($126) | 0) != 0);
          if (!(HEAP32[$14 >> 2] | 0)) {
           $138 = HEAP32[$13 >> 2] | 0; //@line 856
          } else {
           $132 = (HEAP32[$13 >> 2] | 0) + -1 | 0; //@line 859
           HEAP32[$13 >> 2] = $132; //@line 860
           $138 = $132; //@line 862
          }
          $$1267 = $$0266$lcssa; //@line 869
          $$1284 = (HEAP32[$15 >> 2] | 0) + $$0283428 + $138 - (HEAP32[$16 >> 2] | 0) | 0; //@line 869
         }
        }
        ___shlim($0, $$1267); //@line 872
        $140 = HEAP32[$13 >> 2] | 0; //@line 873
        $141 = HEAP32[$14 >> 2] | 0; //@line 874
        if ($140 >>> 0 < $141 >>> 0) {
         HEAP32[$13 >> 2] = $140 + 1; //@line 878
         $147 = $141; //@line 879
        } else {
         if ((___shgetc($0) | 0) < 0) {
          $$7312 = $$$0305; //@line 884
          $309 = $$327; //@line 884
          $narrow469 = $narrow; //@line 884
          label = 137; //@line 885
          break L6;
         }
         $147 = HEAP32[$14 >> 2] | 0; //@line 889
        }
        if ($147 | 0) {
         HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + -1; //@line 895
        }
        L55 : do {
         switch ($trunc << 24 >> 24) {
         case 91:
         case 99:
         case 115:
          {
           $150 = ($$ | 0) == 99; //@line 900
           L57 : do {
            if (($$ | 16 | 0) == 115) {
             _memset($21 | 0, -1, 256) | 0; //@line 906
             HEAP8[$4 >> 0] = 0; //@line 907
             if (($$ | 0) == 115) {
              HEAP8[$18 >> 0] = 0; //@line 909
              HEAP8[$17 >> 0] = 0; //@line 910
              HEAP8[$17 + 1 >> 0] = 0; //@line 910
              HEAP8[$17 + 2 >> 0] = 0; //@line 910
              HEAP8[$17 + 3 >> 0] = 0; //@line 910
              HEAP8[$17 + 4 >> 0] = 0; //@line 910
              $$9 = $$5; //@line 911
             } else {
              $$9 = $$5; //@line 913
             }
            } else {
             $154 = $$5 + 1 | 0; //@line 916
             $156 = (HEAP8[$154 >> 0] | 0) == 94; //@line 918
             $$0292 = $156 & 1; //@line 920
             $$6 = $156 ? $$5 + 2 | 0 : $154; //@line 921
             _memset($22 | 0, $156 & 1 | 0, 256) | 0; //@line 923
             HEAP8[$4 >> 0] = 0; //@line 924
             switch (HEAP8[$$6 >> 0] | 0) {
             case 45:
              {
               $$sink443 = $19; //@line 928
               label = 64; //@line 929
               break;
              }
             case 93:
              {
               $$sink443 = $20; //@line 933
               label = 64; //@line 934
               break;
              }
             default:
              {
               $$7$ph = $$6; //@line 940
               $$pre$phi516Z2D = ($$0292 ^ 1) & 255; //@line 940
              }
             }
             if ((label | 0) == 64) {
              label = 0; //@line 944
              $162 = ($$0292 ^ 1) & 255; //@line 947
              HEAP8[$$sink443 >> 0] = $162; //@line 948
              $$7$ph = $$6 + 1 | 0; //@line 949
              $$pre$phi516Z2D = $162; //@line 949
             }
             $$7 = $$7$ph; //@line 951
             while (1) {
              $163 = HEAP8[$$7 >> 0] | 0; //@line 953
              L69 : do {
               switch ($163 << 24 >> 24) {
               case 0:
                {
                 $$7312 = $$$0305; //@line 957
                 $309 = $$327; //@line 957
                 $narrow469 = $narrow; //@line 957
                 label = 137; //@line 958
                 break L6;
                 break;
                }
               case 93:
                {
                 $$9 = $$7; //@line 963
                 break L57;
                 break;
                }
               case 45:
                {
                 $164 = $$7 + 1 | 0; //@line 968
                 $165 = HEAP8[$164 >> 0] | 0; //@line 969
                 switch ($165 << 24 >> 24) {
                 case 93:
                 case 0:
                  {
                   $$8 = $$7; //@line 972
                   $176 = 45; //@line 972
                   break L69;
                   break;
                  }
                 default:
                  {}
                 }
                 $167 = HEAP8[$$7 + -1 >> 0] | 0; //@line 980
                 if (($167 & 255) < ($165 & 255)) {
                  $$0286420 = $167 & 255; //@line 984
                  do {
                   $$0286420 = $$0286420 + 1 | 0; //@line 986
                   HEAP8[$4 + $$0286420 >> 0] = $$pre$phi516Z2D; //@line 988
                   $172 = HEAP8[$164 >> 0] | 0; //@line 989
                  } while (($$0286420 | 0) < ($172 & 255 | 0));
                  $$8 = $164; //@line 995
                  $176 = $172; //@line 995
                 } else {
                  $$8 = $164; //@line 1000
                  $176 = $165; //@line 1000
                 }
                 break;
                }
               default:
                {
                 $$8 = $$7; //@line 1005
                 $176 = $163; //@line 1005
                }
               }
              } while (0);
              HEAP8[$4 + (($176 & 255) + 1) >> 0] = $$pre$phi516Z2D; //@line 1012
              $$7 = $$8 + 1 | 0; //@line 1014
             }
            }
           } while (0);
           $181 = $150 ? $$1267 + 1 | 0 : 31; //@line 1019
           $182 = ($$$0268 | 0) == 1; //@line 1020
           L77 : do {
            if ($182) {
             if ($narrow) {
              $184 = _malloc($181 << 2) | 0; //@line 1025
              if (!$184) {
               $$7312 = 0; //@line 1028
               $309 = 0; //@line 1028
               $narrow469 = 1; //@line 1028
               label = 137; //@line 1029
               break L6;
              } else {
               $311 = $184; //@line 1032
              }
             } else {
              $311 = $$0293; //@line 1035
             }
             HEAP32[$3 >> 2] = 0; //@line 1037
             HEAP32[$$sroa$2$0$$sroa_idx13 >> 2] = 0; //@line 1038
             $$0276$ph = $181; //@line 1039
             $$0278$ph = 0; //@line 1039
             $$ph = $311; //@line 1039
             L82 : while (1) {
              $186 = ($$ph | 0) == 0; //@line 1041
              $$0278$ph336 = $$0278$ph; //@line 1042
              while (1) {
               L86 : while (1) {
                $187 = HEAP32[$13 >> 2] | 0; //@line 1045
                if ($187 >>> 0 < (HEAP32[$14 >> 2] | 0) >>> 0) {
                 HEAP32[$13 >> 2] = $187 + 1; //@line 1050
                 $195 = HEAPU8[$187 >> 0] | 0; //@line 1053
                } else {
                 $195 = ___shgetc($0) | 0; //@line 1056
                }
                if (!(HEAP8[$4 + ($195 + 1) >> 0] | 0)) {
                 break L82;
                }
                HEAP8[$6 >> 0] = $195; //@line 1066
                switch (_mbrtowc($5, $6, 1, $3) | 0) {
                case -1:
                 {
                  $$7312 = 0; //@line 1070
                  $309 = $$ph; //@line 1070
                  $narrow469 = $narrow; //@line 1070
                  label = 137; //@line 1071
                  break L6;
                  break;
                 }
                case -2:
                 {
                  break;
                 }
                default:
                 {
                  break L86;
                 }
                }
               }
               if ($186) {
                $$1279 = $$0278$ph336; //@line 1084
               } else {
                HEAP32[$$ph + ($$0278$ph336 << 2) >> 2] = HEAP32[$5 >> 2]; //@line 1089
                $$1279 = $$0278$ph336 + 1 | 0; //@line 1090
               }
               if ($narrow & ($$1279 | 0) == ($$0276$ph | 0)) {
                break;
               } else {
                $$0278$ph336 = $$1279; //@line 1097
               }
              }
              $205 = $$0276$ph << 1 | 1; //@line 1101
              $207 = _realloc($$ph, $205 << 2) | 0; //@line 1103
              if (!$207) {
               $$7312 = 0; //@line 1106
               $309 = $$ph; //@line 1106
               $narrow469 = 1; //@line 1106
               label = 137; //@line 1107
               break L6;
              } else {
               $$0278$ph$phi = $$0276$ph; //@line 1110
               $$0276$ph = $205; //@line 1110
               $$ph = $207; //@line 1110
               $$0278$ph = $$0278$ph$phi; //@line 1110
              }
             }
             if (!(_mbsinit($3) | 0)) {
              $$7312 = 0; //@line 1116
              $309 = $$ph; //@line 1116
              $narrow469 = $narrow; //@line 1116
              label = 137; //@line 1117
              break L6;
             } else {
              $$4282 = $$0278$ph336; //@line 1120
              $$4309 = 0; //@line 1120
              $$5299 = $$ph; //@line 1120
              $312 = $$ph; //@line 1120
             }
            } else {
             if ($narrow) {
              $211 = _malloc($181) | 0; //@line 1124
              if (!$211) {
               $$7312 = 0; //@line 1127
               $309 = 0; //@line 1127
               $narrow469 = 1; //@line 1127
               label = 137; //@line 1128
               break L6;
              } else {
               $$1277$ph = $181; //@line 1131
               $$2280$ph = 0; //@line 1131
               $$2307$ph = $211; //@line 1131
              }
              while (1) {
               $$2280 = $$2280$ph; //@line 1134
               do {
                $213 = HEAP32[$13 >> 2] | 0; //@line 1136
                if ($213 >>> 0 < (HEAP32[$14 >> 2] | 0) >>> 0) {
                 HEAP32[$13 >> 2] = $213 + 1; //@line 1141
                 $221 = HEAPU8[$213 >> 0] | 0; //@line 1144
                } else {
                 $221 = ___shgetc($0) | 0; //@line 1147
                }
                if (!(HEAP8[$4 + ($221 + 1) >> 0] | 0)) {
                 $$4282 = $$2280; //@line 1154
                 $$4309 = $$2307$ph; //@line 1154
                 $$5299 = 0; //@line 1154
                 $312 = 0; //@line 1154
                 break L77;
                }
                HEAP8[$$2307$ph + $$2280 >> 0] = $221; //@line 1160
                $$2280 = $$2280 + 1 | 0; //@line 1158
               } while (($$2280 | 0) != ($$1277$ph | 0));
               $229 = $$1277$ph << 1 | 1; //@line 1169
               $230 = _realloc($$2307$ph, $229) | 0; //@line 1170
               if (!$230) {
                $$7312 = $$2307$ph; //@line 1173
                $309 = 0; //@line 1173
                $narrow469 = 1; //@line 1173
                label = 137; //@line 1174
                break L6;
               } else {
                $$2280$ph$phi = $$1277$ph; //@line 1177
                $$1277$ph = $229; //@line 1177
                $$2307$ph = $230; //@line 1177
                $$2280$ph = $$2280$ph$phi; //@line 1177
               }
              }
             }
             if (!$$0293) {
              $250 = $147; //@line 1183
              while (1) {
               $248 = HEAP32[$13 >> 2] | 0; //@line 1185
               if ($248 >>> 0 < $250 >>> 0) {
                HEAP32[$13 >> 2] = $248 + 1; //@line 1189
                $256 = HEAPU8[$248 >> 0] | 0; //@line 1192
               } else {
                $256 = ___shgetc($0) | 0; //@line 1195
               }
               if (!(HEAP8[$4 + ($256 + 1) >> 0] | 0)) {
                $$4282 = 0; //@line 1202
                $$4309 = 0; //@line 1202
                $$5299 = 0; //@line 1202
                $312 = 0; //@line 1202
                break L77;
               }
               $250 = HEAP32[$14 >> 2] | 0; //@line 1206
              }
             } else {
              $$3281 = 0; //@line 1209
              $235 = $147; //@line 1209
              while (1) {
               $233 = HEAP32[$13 >> 2] | 0; //@line 1211
               if ($233 >>> 0 < $235 >>> 0) {
                HEAP32[$13 >> 2] = $233 + 1; //@line 1215
                $241 = HEAPU8[$233 >> 0] | 0; //@line 1218
               } else {
                $241 = ___shgetc($0) | 0; //@line 1221
               }
               if (!(HEAP8[$4 + ($241 + 1) >> 0] | 0)) {
                $$4282 = $$3281; //@line 1228
                $$4309 = $$0293; //@line 1228
                $$5299 = 0; //@line 1228
                $312 = 0; //@line 1228
                break L77;
               }
               HEAP8[$$0293 + $$3281 >> 0] = $241; //@line 1234
               $$3281 = $$3281 + 1 | 0; //@line 1236
               $235 = HEAP32[$14 >> 2] | 0; //@line 1236
              }
             }
            }
           } while (0);
           if (!(HEAP32[$14 >> 2] | 0)) {
            $268 = HEAP32[$13 >> 2] | 0; //@line 1245
           } else {
            $263 = (HEAP32[$13 >> 2] | 0) + -1 | 0; //@line 1248
            HEAP32[$13 >> 2] = $263; //@line 1249
            $268 = $263; //@line 1251
           }
           $269 = $268 - (HEAP32[$16 >> 2] | 0) + (HEAP32[$15 >> 2] | 0) | 0; //@line 1256
           if (!$269) {
            $$9314$ph = $$4309; //@line 1259
            $$ph353 = $312; //@line 1259
            label = 139; //@line 1260
            break L6;
           }
           if (!(($269 | 0) == ($$1267 | 0) | $150 ^ 1)) {
            $$9314$ph = $$4309; //@line 1267
            $$ph353 = $312; //@line 1267
            label = 139; //@line 1268
            break L6;
           }
           do {
            if ($narrow) {
             if ($182) {
              HEAP32[$$0293 >> 2] = $$5299; //@line 1274
              break;
             } else {
              HEAP32[$$0293 >> 2] = $$4309; //@line 1277
              break;
             }
            }
           } while (0);
           if ($150) {
            $$10 = $$9; //@line 1283
            $$5310 = $$4309; //@line 1283
            $310 = $312; //@line 1283
           } else {
            if ($$5299 | 0) {
             HEAP32[$$5299 + ($$4282 << 2) >> 2] = 0; //@line 1288
            }
            if (!$$4309) {
             $$10 = $$9; //@line 1292
             $$5310 = 0; //@line 1292
             $310 = $312; //@line 1292
             break L55;
            }
            HEAP8[$$4309 + $$4282 >> 0] = 0; //@line 1296
            $$10 = $$9; //@line 1297
            $$5310 = $$4309; //@line 1297
            $310 = $312; //@line 1297
           }
           break;
          }
         case 120:
         case 88:
         case 112:
          {
           $$0272 = 16; //@line 1302
           label = 125; //@line 1303
           break;
          }
         case 111:
          {
           $$0272 = 8; //@line 1307
           label = 125; //@line 1308
           break;
          }
         case 117:
         case 100:
          {
           $$0272 = 10; //@line 1312
           label = 125; //@line 1313
           break;
          }
         case 105:
          {
           $$0272 = 0; //@line 1317
           label = 125; //@line 1318
           break;
          }
         case 71:
         case 103:
         case 70:
         case 102:
         case 69:
         case 101:
         case 65:
         case 97:
          {
           $285 = +___floatscan($0, $$$0268, 0); //@line 1322
           if ((HEAP32[$15 >> 2] | 0) == ((HEAP32[$16 >> 2] | 0) - (HEAP32[$13 >> 2] | 0) | 0)) {
            $$9314$ph = $$$0305; //@line 1329
            $$ph353 = $$327; //@line 1329
            label = 139; //@line 1330
            break L6;
           }
           if (!$$0293) {
            $$10 = $$5; //@line 1335
            $$5310 = $$$0305; //@line 1335
            $310 = $$327; //@line 1335
           } else {
            switch ($$$0268 | 0) {
            case 0:
             {
              HEAPF32[$$0293 >> 2] = $285; //@line 1340
              $$10 = $$5; //@line 1341
              $$5310 = $$$0305; //@line 1341
              $310 = $$327; //@line 1341
              break L55;
              break;
             }
            case 1:
             {
              HEAPF64[$$0293 >> 3] = $285; //@line 1346
              $$10 = $$5; //@line 1347
              $$5310 = $$$0305; //@line 1347
              $310 = $$327; //@line 1347
              break L55;
              break;
             }
            case 2:
             {
              HEAPF64[$$0293 >> 3] = $285; //@line 1352
              $$10 = $$5; //@line 1353
              $$5310 = $$$0305; //@line 1353
              $310 = $$327; //@line 1353
              break L55;
              break;
             }
            default:
             {
              $$10 = $$5; //@line 1358
              $$5310 = $$$0305; //@line 1358
              $310 = $$327; //@line 1358
              break L55;
             }
            }
           }
           break;
          }
         default:
          {
           $$10 = $$5; //@line 1366
           $$5310 = $$$0305; //@line 1366
           $310 = $$327; //@line 1366
          }
         }
        } while (0);
        do {
         if ((label | 0) == 125) {
          label = 0; //@line 1372
          $276 = ___intscan($0, $$0272, 0, -1, -1) | 0; //@line 1373
          if ((HEAP32[$15 >> 2] | 0) == ((HEAP32[$16 >> 2] | 0) - (HEAP32[$13 >> 2] | 0) | 0)) {
           $$9314$ph = $$$0305; //@line 1381
           $$ph353 = $$327; //@line 1381
           label = 139; //@line 1382
           break L6;
          }
          if ($100 & ($$ | 0) == 112) {
           HEAP32[$$0293 >> 2] = $276; //@line 1389
           $$10 = $$5; //@line 1390
           $$5310 = $$$0305; //@line 1390
           $310 = $$327; //@line 1390
           break;
          } else {
           _store_int($$0293, $$$0268, $276, tempRet0); //@line 1393
           $$10 = $$5; //@line 1394
           $$5310 = $$$0305; //@line 1394
           $310 = $$327; //@line 1394
           break;
          }
         }
        } while (0);
        $$11 = $$10; //@line 1407
        $$1289 = ($100 & 1) + $$0288425 | 0; //@line 1407
        $$2285 = (HEAP32[$15 >> 2] | 0) + $$1284 + (HEAP32[$13 >> 2] | 0) - (HEAP32[$16 >> 2] | 0) | 0; //@line 1407
        $$6311 = $$5310; //@line 1407
        $307 = $310; //@line 1407
        break L8;
       }
      } while (0);
      $57 = $$0273429 + ($53 & 1) | 0; //@line 1412
      ___shlim($0, 0); //@line 1413
      $58 = HEAP32[$13 >> 2] | 0; //@line 1414
      if ($58 >>> 0 < (HEAP32[$14 >> 2] | 0) >>> 0) {
       HEAP32[$13 >> 2] = $58 + 1; //@line 1419
       $68 = HEAPU8[$58 >> 0] | 0; //@line 1422
      } else {
       $68 = ___shgetc($0) | 0; //@line 1425
      }
      if (($68 | 0) != (HEAPU8[$57 >> 0] | 0)) {
       label = 22; //@line 1431
       break L6;
      }
      $$11 = $57; //@line 1435
      $$1289 = $$0288425; //@line 1435
      $$2285 = $$0283428 + 1 | 0; //@line 1435
      $$6311 = $$0305423; //@line 1435
      $307 = $102; //@line 1435
     } else {
      $$1274 = $$0273429; //@line 1437
      while (1) {
       $27 = $$1274 + 1 | 0; //@line 1439
       if (!(_isspace(HEAPU8[$27 >> 0] | 0) | 0)) {
        break;
       } else {
        $$1274 = $27; //@line 1447
       }
      }
      ___shlim($0, 0); //@line 1450
      do {
       $32 = HEAP32[$13 >> 2] | 0; //@line 1452
       if ($32 >>> 0 < (HEAP32[$14 >> 2] | 0) >>> 0) {
        HEAP32[$13 >> 2] = $32 + 1; //@line 1457
        $39 = HEAPU8[$32 >> 0] | 0; //@line 1460
       } else {
        $39 = ___shgetc($0) | 0; //@line 1463
       }
      } while ((_isspace($39) | 0) != 0);
      if (!(HEAP32[$14 >> 2] | 0)) {
       $51 = HEAP32[$13 >> 2] | 0; //@line 1475
      } else {
       $45 = (HEAP32[$13 >> 2] | 0) + -1 | 0; //@line 1478
       HEAP32[$13 >> 2] = $45; //@line 1479
       $51 = $45; //@line 1481
      }
      $$11 = $$1274; //@line 1488
      $$1289 = $$0288425; //@line 1488
      $$2285 = (HEAP32[$15 >> 2] | 0) + $$0283428 + $51 - (HEAP32[$16 >> 2] | 0) | 0; //@line 1488
      $$6311 = $$0305423; //@line 1488
      $307 = $102; //@line 1488
     }
    } while (0);
    $$0273429 = $$11 + 1 | 0; //@line 1491
    $24 = HEAP8[$$0273429 >> 0] | 0; //@line 1492
    if (!($24 << 24 >> 24)) {
     $$3291 = $$1289; //@line 1495
     break L4;
    } else {
     $$0283428 = $$2285; //@line 1498
     $$0288425 = $$1289; //@line 1498
     $$0305423 = $$6311; //@line 1498
     $102 = $307; //@line 1498
    }
   }
   if ((label | 0) == 22) {
    if (HEAP32[$14 >> 2] | 0) {
     HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + -1; //@line 1507
    }
    if (($$0288425 | 0) != 0 | ($68 | 0) > -1) {
     $$3291 = $$0288425; //@line 1513
     break;
    } else {
     $$1271 = 0; //@line 1516
     $$8313 = $$0305423; //@line 1516
     $308 = $102; //@line 1516
     label = 138; //@line 1517
    }
   } else if ((label | 0) == 137) {
    $$328$le441 = $narrow469 & 1; //@line 1521
    if (!$$0288425) {
     $$1271 = $$328$le441; //@line 1524
     $$8313 = $$7312; //@line 1524
     $308 = $309; //@line 1524
     label = 138; //@line 1525
    } else {
     $$2 = $$328$le441; //@line 1527
     $$2290 = $$0288425; //@line 1527
     $$9314 = $$7312; //@line 1527
     $304 = $309; //@line 1527
    }
   } else if ((label | 0) == 139) {
    $$2 = $narrow & 1; //@line 1532
    $$2290 = $$0288425; //@line 1532
    $$9314 = $$9314$ph; //@line 1532
    $304 = $$ph353; //@line 1532
   }
   if ((label | 0) == 138) {
    $$2 = $$1271; //@line 1535
    $$2290 = -1; //@line 1535
    $$9314 = $$8313; //@line 1535
    $304 = $308; //@line 1535
   }
   if (!$$2) {
    $$3291 = $$2290; //@line 1539
   } else {
    _free($$9314); //@line 1541
    _free($304); //@line 1542
    $$3291 = $$2290; //@line 1543
   }
  }
 } while (0);
 if ($306 | 0) {
  ___unlockfile($0); //@line 1549
 }
 STACKTOP = sp; //@line 1551
 return $$3291 | 0; //@line 1551
}
function __Z12InstallExtFSv() {
 var $0 = 0, $100 = 0, $106 = 0, $115 = 0, $121 = 0, $127 = 0, $133 = 0, $139 = 0, $145 = 0, $15 = 0, $151 = 0, $157 = 0, $166 = 0, $17 = 0, $172 = 0, $178 = 0, $184 = 0, $190 = 0, $196 = 0, $202 = 0, $208 = 0, $214 = 0, $220 = 0, $229 = 0, $235 = 0, $24 = 0, $241 = 0, $247 = 0, $253 = 0, $259 = 0, $265 = 0, $271 = 0, $277 = 0, $286 = 0, $292 = 0, $298 = 0, $30 = 0, $304 = 0, $310 = 0, $316 = 0, $325 = 0, $331 = 0, $337 = 0, $343 = 0, $349 = 0, $355 = 0, $36 = 0, $364 = 0, $370 = 0, $376 = 0, $382 = 0, $388 = 0, $394 = 0, $400 = 0, $409 = 0, $415 = 0, $421 = 0, $427 = 0, $433 = 0, $439 = 0, $448 = 0, $45 = 0, $454 = 0, $460 = 0, $466 = 0, $472 = 0, $478 = 0, $487 = 0, $493 = 0, $499 = 0, $505 = 0, $51 = 0, $511 = 0, $517 = 0, $523 = 0, $529 = 0, $538 = 0, $544 = 0, $550 = 0, $556 = 0, $562 = 0, $568 = 0, $57 = 0, $574 = 0, $58 = 0, $583 = 0, $589 = 0, $595 = 0, $6 = 0, $601 = 0, $607 = 0, $613 = 0, $622 = 0, $628 = 0, $634 = 0, $64 = 0, $640 = 0, $646 = 0, $652 = 0, $658 = 0, $664 = 0, $673 = 0, $679 = 0, $685 = 0, $691 = 0, $697 = 0, $70 = 0, $703 = 0, $709 = 0, $718 = 0, $724 = 0, $730 = 0, $736 = 0, $742 = 0, $748 = 0, $757 = 0, $76 = 0, $763 = 0, $769 = 0, $775 = 0, $781 = 0, $787 = 0, $796 = 0, $802 = 0, $808 = 0, $814 = 0, $82 = 0, $820 = 0, $827 = 0, $830 = 0, $837 = 0, $844 = 0, $851 = 0, $858 = 0, $865 = 0, $871 = 0, $877 = 0, $88 = 0, $884 = 0, $891 = 0, $898 = 0, $905 = 0, $906 = 0, $912 = 0, $913 = 0, $921 = 0, $929 = 0, $936 = 0, $94 = 0, $945 = 0, $947 = 0, $951 = 0, $959 = 0, $960 = 0, $968 = 0, $975 = 0, dest = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 28738
 STACKTOP = STACKTOP + 80 | 0; //@line 28739
 $0 = sp; //@line 28740
 if (!(HEAP8[657422] | 0)) {
  STACKTOP = sp; //@line 28744
  return;
 }
 HEAP32[$0 >> 2] = 1718820896; //@line 28746
 _Execute68kTrap(-24147, $0); //@line 28747
 if (!(HEAP32[$0 >> 2] & 65535)) {
  $6 = $0 + 32 | 0; //@line 28752
  if (HEAP32[$6 >> 2] & 4 | 0) {
   HEAP32[$0 >> 2] = 1718840608; //@line 28757
   _Execute68kTrap(-24147, $0); //@line 28758
   if ((HEAP32[$0 >> 2] & 65535 | 0) != 0 | (HEAP32[$6 >> 2] | 0) >>> 0 < 288) {
    _puts(96624) | 0; //@line 28766
    STACKTOP = sp; //@line 28767
    return;
   }
   HEAP32[$0 >> 2] = 65536; //@line 28769
   _Execute68kTrap(-22754, $0); //@line 28770
   $15 = HEAP32[$6 >> 2] | 0; //@line 28771
   if (!$15) {
    STACKTOP = sp; //@line 28774
    return;
   }
   HEAP32[$0 >> 2] = 802; //@line 28776
   _Execute68kTrap(-22754, $0); //@line 28777
   $17 = HEAP32[$6 >> 2] | 0; //@line 28778
   if (!$17) {
    STACKTOP = sp; //@line 28781
    return;
   }
   HEAP32[30848] = $17; //@line 28783
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($17, 28974); //@line 28789
   $24 = $17 + 2 | 0; //@line 28790
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, 20084); //@line 28796
   $30 = $17 + 4 | 0; //@line 28797
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, 10); //@line 28803
   $36 = $17 + 6 | 0; //@line 28804
   if (($36 - (HEAP32[30848] | 0) | 0) != 6) {
    _puts(96665) | 0; //@line 28809
    __Z12QuitEmulatorv(); //@line 28810
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($36, 28975); //@line 28818
   $45 = $17 + 8 | 0; //@line 28819
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($45 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($45, 20084); //@line 28825
   $51 = $17 + 10 | 0; //@line 28826
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($51, 16); //@line 28832
   $57 = HEAP32[30848] | 0; //@line 28833
   $58 = $57 + 562 | 0; //@line 28834
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($58 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($58, 16999); //@line 28840
   $64 = $57 + 564 | 0; //@line 28841
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($64 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($64, 12040); //@line 28847
   $70 = $57 + 566 | 0; //@line 28848
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($70 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($70, 12041); //@line 28854
   $76 = $57 + 568 | 0; //@line 28855
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($76 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($76, 16999); //@line 28861
   $82 = $57 + 570 | 0; //@line 28862
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($82, 28678); //@line 28868
   $88 = $57 + 572 | 0; //@line 28869
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($88 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($88, 43044); //@line 28875
   $94 = $57 + 574 | 0; //@line 28876
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($94 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($94, 12319); //@line 28882
   $100 = $57 + 576 | 0; //@line 28883
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($100 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($100, 20085); //@line 28889
   $106 = $57 + 578 | 0; //@line 28890
   if (($106 - (HEAP32[30848] | 0) | 0) != 578) {
    _puts(96665) | 0; //@line 28895
    __Z12QuitEmulatorv(); //@line 28896
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($106 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($106, 16999); //@line 28904
   $115 = $57 + 580 | 0; //@line 28905
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($115 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($115, 16128); //@line 28911
   $121 = $57 + 582 | 0; //@line 28912
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($121 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($121, 12040); //@line 28918
   $127 = $57 + 584 | 0; //@line 28919
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($127 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($127, 12041); //@line 28925
   $133 = $57 + 586 | 0; //@line 28926
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($133 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($133, 28679); //@line 28932
   $139 = $57 + 588 | 0; //@line 28933
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($139 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($139, 43044); //@line 28939
   $145 = $57 + 590 | 0; //@line 28940
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($145 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($145, 12319); //@line 28946
   $151 = $57 + 592 | 0; //@line 28947
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($151 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($151, 20085); //@line 28953
   $157 = $57 + 594 | 0; //@line 28954
   if (($157 - (HEAP32[30848] | 0) | 0) != 594) {
    _puts(96665) | 0; //@line 28959
    __Z12QuitEmulatorv(); //@line 28960
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($157 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($157, 16999); //@line 28968
   $166 = $57 + 596 | 0; //@line 28969
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($166 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($166, 12040); //@line 28975
   $172 = $57 + 598 | 0; //@line 28976
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($172 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($172, 12041); //@line 28982
   $178 = $57 + 600 | 0; //@line 28983
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($178 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($178, 12042); //@line 28989
   $184 = $57 + 602 | 0; //@line 28990
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($184 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($184, 12043); //@line 28996
   $190 = $57 + 604 | 0; //@line 28997
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($190 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($190, 12044); //@line 29003
   $196 = $57 + 606 | 0; //@line 29004
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($196 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($196, 28701); //@line 29010
   $202 = $57 + 608 | 0; //@line 29011
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($202 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($202, 43044); //@line 29017
   $208 = $57 + 610 | 0; //@line 29018
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($208 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($208, 12319); //@line 29024
   $214 = $57 + 612 | 0; //@line 29025
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($214 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($214, 20085); //@line 29031
   $220 = $57 + 614 | 0; //@line 29032
   if (($220 - (HEAP32[30848] | 0) | 0) != 614) {
    _puts(96665) | 0; //@line 29037
    __Z12QuitEmulatorv(); //@line 29038
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($220 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($220, 16999); //@line 29046
   $229 = $57 + 616 | 0; //@line 29047
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($229 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($229, 12032); //@line 29053
   $235 = $57 + 618 | 0; //@line 29054
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($235 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($235, 16129); //@line 29060
   $241 = $57 + 620 | 0; //@line 29061
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($241 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($241, 16130); //@line 29067
   $247 = $57 + 622 | 0; //@line 29068
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($247 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($247, 12040); //@line 29074
   $253 = $57 + 624 | 0; //@line 29075
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($253 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($253, 28686); //@line 29081
   $259 = $57 + 626 | 0; //@line 29082
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($259 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($259, 43044); //@line 29088
   $265 = $57 + 628 | 0; //@line 29089
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($265 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($265, 12319); //@line 29095
   $271 = $57 + 630 | 0; //@line 29096
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($271 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($271, 20085); //@line 29102
   $277 = $57 + 632 | 0; //@line 29103
   if (($277 - (HEAP32[30848] | 0) | 0) != 632) {
    _puts(96665) | 0; //@line 29108
    __Z12QuitEmulatorv(); //@line 29109
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($277 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($277, 16999); //@line 29117
   $286 = $57 + 634 | 0; //@line 29118
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($286 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($286, 12040); //@line 29124
   $292 = $57 + 636 | 0; //@line 29125
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($292 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($292, 28690); //@line 29131
   $298 = $57 + 638 | 0; //@line 29132
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($298 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($298, 43044); //@line 29138
   $304 = $57 + 640 | 0; //@line 29139
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($304 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($304, 12319); //@line 29145
   $310 = $57 + 642 | 0; //@line 29146
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($310 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($310, 20085); //@line 29152
   $316 = $57 + 644 | 0; //@line 29153
   if (($316 - (HEAP32[30848] | 0) | 0) != 644) {
    _puts(96665) | 0; //@line 29158
    __Z12QuitEmulatorv(); //@line 29159
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($316 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($316, 16999); //@line 29167
   $325 = $57 + 646 | 0; //@line 29168
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($325 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($325, 12040); //@line 29174
   $331 = $57 + 648 | 0; //@line 29175
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($331 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($331, 28700); //@line 29181
   $337 = $57 + 650 | 0; //@line 29182
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($337 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($337, 43044); //@line 29188
   $343 = $57 + 652 | 0; //@line 29189
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($343 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($343, 12319); //@line 29195
   $349 = $57 + 654 | 0; //@line 29196
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($349 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($349, 20085); //@line 29202
   $355 = $57 + 656 | 0; //@line 29203
   if (($355 - (HEAP32[30848] | 0) | 0) != 656) {
    _puts(96665) | 0; //@line 29208
    __Z12QuitEmulatorv(); //@line 29209
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($355 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($355, 16999); //@line 29217
   $364 = $57 + 658 | 0; //@line 29218
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($364 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($364, 12040); //@line 29224
   $370 = $57 + 660 | 0; //@line 29225
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($370 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($370, 12041); //@line 29231
   $376 = $57 + 662 | 0; //@line 29232
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($376 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($376, 28699); //@line 29238
   $382 = $57 + 664 | 0; //@line 29239
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($382 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($382, 43044); //@line 29245
   $388 = $57 + 666 | 0; //@line 29246
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($388 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($388, 12319); //@line 29252
   $394 = $57 + 668 | 0; //@line 29253
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($394 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($394, 20085); //@line 29259
   $400 = $57 + 670 | 0; //@line 29260
   if (($400 - (HEAP32[30848] | 0) | 0) != 670) {
    _puts(96665) | 0; //@line 29265
    __Z12QuitEmulatorv(); //@line 29266
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($400 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($400, 16999); //@line 29274
   $409 = $57 + 672 | 0; //@line 29275
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($409 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($409, 12040); //@line 29281
   $415 = $57 + 674 | 0; //@line 29282
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($415 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($415, 28680); //@line 29288
   $421 = $57 + 676 | 0; //@line 29289
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($421 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($421, 43044); //@line 29295
   $427 = $57 + 678 | 0; //@line 29296
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($427 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($427, 12319); //@line 29302
   $433 = $57 + 680 | 0; //@line 29303
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($433 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($433, 20085); //@line 29309
   $439 = $57 + 682 | 0; //@line 29310
   if (($439 - (HEAP32[30848] | 0) | 0) != 682) {
    _puts(96665) | 0; //@line 29315
    __Z12QuitEmulatorv(); //@line 29316
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($439 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($439, 16999); //@line 29324
   $448 = $57 + 684 | 0; //@line 29325
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($448 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($448, 16128); //@line 29331
   $454 = $57 + 686 | 0; //@line 29332
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($454 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($454, 28691); //@line 29338
   $460 = $57 + 688 | 0; //@line 29339
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($460 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($460, 43044); //@line 29345
   $466 = $57 + 690 | 0; //@line 29346
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($466 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($466, 12319); //@line 29352
   $472 = $57 + 692 | 0; //@line 29353
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($472 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($472, 20085); //@line 29359
   $478 = $57 + 694 | 0; //@line 29360
   if (($478 - (HEAP32[30848] | 0) | 0) != 694) {
    _puts(96665) | 0; //@line 29365
    __Z12QuitEmulatorv(); //@line 29366
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($478 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($478, 16999); //@line 29374
   $487 = $57 + 696 | 0; //@line 29375
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($487 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($487, 12032); //@line 29381
   $493 = $57 + 698 | 0; //@line 29382
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($493 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($493, 12033); //@line 29388
   $499 = $57 + 700 | 0; //@line 29389
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($499 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($499, 16130); //@line 29395
   $505 = $57 + 702 | 0; //@line 29396
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($505 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($505, 28689); //@line 29402
   $511 = $57 + 704 | 0; //@line 29403
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($511 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($511, 43044); //@line 29409
   $517 = $57 + 706 | 0; //@line 29410
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($517 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($517, 12319); //@line 29416
   $523 = $57 + 708 | 0; //@line 29417
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($523 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($523, 20085); //@line 29423
   $529 = $57 + 710 | 0; //@line 29424
   if (($529 - (HEAP32[30848] | 0) | 0) != 710) {
    _puts(96665) | 0; //@line 29429
    __Z12QuitEmulatorv(); //@line 29430
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($529 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($529, 16999); //@line 29438
   $538 = $57 + 712 | 0; //@line 29439
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($538 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($538, 12040); //@line 29445
   $544 = $57 + 714 | 0; //@line 29446
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($544 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($544, 12041); //@line 29452
   $550 = $57 + 716 | 0; //@line 29453
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($550 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($550, 28672); //@line 29459
   $556 = $57 + 718 | 0; //@line 29460
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($556 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($556, 43044); //@line 29466
   $562 = $57 + 720 | 0; //@line 29467
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($562 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($562, 12319); //@line 29473
   $568 = $57 + 722 | 0; //@line 29474
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($568 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($568, 20085); //@line 29480
   $574 = $57 + 724 | 0; //@line 29481
   if (($574 - (HEAP32[30848] | 0) | 0) != 724) {
    _puts(96665) | 0; //@line 29486
    __Z12QuitEmulatorv(); //@line 29487
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($574 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($574, 16999); //@line 29495
   $583 = $57 + 726 | 0; //@line 29496
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($583 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($583, 16128); //@line 29502
   $589 = $57 + 728 | 0; //@line 29503
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($589 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($589, 28673); //@line 29509
   $595 = $57 + 730 | 0; //@line 29510
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($595 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($595, 43044); //@line 29516
   $601 = $57 + 732 | 0; //@line 29517
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($601 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($601, 12319); //@line 29523
   $607 = $57 + 734 | 0; //@line 29524
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($607 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($607, 20085); //@line 29530
   $613 = $57 + 736 | 0; //@line 29531
   if (($613 - (HEAP32[30848] | 0) | 0) != 736) {
    _puts(96665) | 0; //@line 29536
    __Z12QuitEmulatorv(); //@line 29537
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($613 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($613, 16999); //@line 29545
   $622 = $57 + 738 | 0; //@line 29546
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($622 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($622, 12040); //@line 29552
   $628 = $57 + 740 | 0; //@line 29553
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($628 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($628, 12041); //@line 29559
   $634 = $57 + 742 | 0; //@line 29560
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($634 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($634, 12042); //@line 29566
   $640 = $57 + 744 | 0; //@line 29567
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($640 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($640, 28676); //@line 29573
   $646 = $57 + 746 | 0; //@line 29574
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($646 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($646, 43044); //@line 29580
   $652 = $57 + 748 | 0; //@line 29581
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($652 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($652, 12319); //@line 29587
   $658 = $57 + 750 | 0; //@line 29588
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($658 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($658, 20085); //@line 29594
   $664 = $57 + 752 | 0; //@line 29595
   if (($664 - (HEAP32[30848] | 0) | 0) != 752) {
    _puts(96665) | 0; //@line 29600
    __Z12QuitEmulatorv(); //@line 29601
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($664 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($664, 16999); //@line 29609
   $673 = $57 + 754 | 0; //@line 29610
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($673 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($673, 16128); //@line 29616
   $679 = $57 + 756 | 0; //@line 29617
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($679 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($679, 12040); //@line 29623
   $685 = $57 + 758 | 0; //@line 29624
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($685 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($685, 28677); //@line 29630
   $691 = $57 + 760 | 0; //@line 29631
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($691 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($691, 43044); //@line 29637
   $697 = $57 + 762 | 0; //@line 29638
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($697 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($697, 12319); //@line 29644
   $703 = $57 + 764 | 0; //@line 29645
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($703 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($703, 20085); //@line 29651
   $709 = $57 + 766 | 0; //@line 29652
   if (($709 - (HEAP32[30848] | 0) | 0) != 766) {
    _puts(96665) | 0; //@line 29657
    __Z12QuitEmulatorv(); //@line 29658
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($709 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($709, 16999); //@line 29666
   $718 = $57 + 768 | 0; //@line 29667
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($718 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($718, 16128); //@line 29673
   $724 = $57 + 770 | 0; //@line 29674
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($724 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($724, 28688); //@line 29680
   $730 = $57 + 772 | 0; //@line 29681
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($730 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($730, 43044); //@line 29687
   $736 = $57 + 774 | 0; //@line 29688
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($736 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($736, 12319); //@line 29694
   $742 = $57 + 776 | 0; //@line 29695
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($742 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($742, 20085); //@line 29701
   $748 = $57 + 778 | 0; //@line 29702
   if (($748 - (HEAP32[30848] | 0) | 0) != 778) {
    _puts(96665) | 0; //@line 29707
    __Z12QuitEmulatorv(); //@line 29708
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($748 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($748, 16999); //@line 29716
   $757 = $57 + 780 | 0; //@line 29717
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($757 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($757, 12040); //@line 29723
   $763 = $57 + 782 | 0; //@line 29724
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($763 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($763, 28684); //@line 29730
   $769 = $57 + 784 | 0; //@line 29731
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($769 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($769, 43044); //@line 29737
   $775 = $57 + 786 | 0; //@line 29738
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($775 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($775, 12319); //@line 29744
   $781 = $57 + 788 | 0; //@line 29745
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($781 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($781, 20085); //@line 29751
   $787 = $57 + 790 | 0; //@line 29752
   if (($787 - (HEAP32[30848] | 0) | 0) != 790) {
    _puts(96665) | 0; //@line 29757
    __Z12QuitEmulatorv(); //@line 29758
   }
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($787 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($787, 16999); //@line 29766
   $796 = $57 + 792 | 0; //@line 29767
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($796 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($796, 16128); //@line 29773
   $802 = $57 + 794 | 0; //@line 29774
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($802 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($802, 28685); //@line 29780
   $808 = $57 + 796 | 0; //@line 29781
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($808 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($808, 43044); //@line 29787
   $814 = $57 + 798 | 0; //@line 29788
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($814 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($814, 12319); //@line 29794
   $820 = $57 + 800 | 0; //@line 29795
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($820 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($820, 20085); //@line 29801
   $827 = HEAP32[30848] | 0; //@line 29803
   if (($57 + 802 - $827 | 0) != 802) {
    _puts(96665) | 0; //@line 29807
    __Z12QuitEmulatorv(); //@line 29808
   }
   $830 = $827 + 15 | 0; //@line 29811
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($830 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($830, 8); //@line 29817
   $837 = (HEAP32[30848] | 0) + 16 | 0; //@line 29819
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($837 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($837, 1); //@line 29825
   $844 = (HEAP32[30848] | 0) + 22 | 0; //@line 29827
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($844 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($844, 1); //@line 29833
   $851 = (HEAP32[30848] | 0) + 30 | 0; //@line 29835
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($851 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($851, 65535); //@line 29841
   $858 = (HEAP32[30848] | 0) + 32 | 0; //@line 29843
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($858 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($858, 0); //@line 29849
   $865 = (HEAP32[30848] | 0) + 28 | 0; //@line 29851
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($865 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($865, 25185); //@line 29857
   $871 = __Z19FindFreeDriveNumberi(1) | 0; //@line 29858
   HEAP32[30849] = $871; //@line 29859
   HEAP32[$0 >> 2] = $871 << 16 | 65473; //@line 29862
   HEAP32[$6 >> 2] = (HEAP32[30848] | 0) + 18; //@line 29865
   _Execute68kTrap(-24498, $0); //@line 29866
   $877 = (HEAP32[30848] | 0) + 46 | 0; //@line 29868
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($877 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($877, 196); //@line 29874
   $884 = (HEAP32[30848] | 0) + 48 | 0; //@line 29876
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($884 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($884, 1); //@line 29882
   $891 = (HEAP32[30848] | 0) + 50 | 0; //@line 29884
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($891 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($891, 25185); //@line 29890
   $898 = (HEAP32[30848] | 0) + 52 | 0; //@line 29892
   dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($898 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($898) | 0; //@line 29899
   src = 657358; //@line 29899
   stop = dest + 32 | 0; //@line 29899
   do {
    HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 29899
    dest = dest + 1 | 0; //@line 29899
    src = src + 1 | 0; //@line 29899
   } while ((dest | 0) < (stop | 0));
   $905 = HEAP32[30848] | 0; //@line 29900
   $906 = $905 + 158 | 0; //@line 29901
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($906 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($906, $905); //@line 29907
   $912 = HEAP32[30848] | 0; //@line 29908
   $913 = $912 + 178 | 0; //@line 29909
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($913 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($913, $912 + 6 | 0); //@line 29916
   $921 = (HEAP32[30848] | 0) + 186 | 0; //@line 29918
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($921 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($921, $15 + 65536 | 0); //@line 29925
   $929 = (HEAP32[30848] | 0) + 190 | 0; //@line 29927
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($929 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($929, 65536); //@line 29933
   $936 = (HEAP32[30848] | 0) + 202 | 0; //@line 29935
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($936 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($936, -1); //@line 29941
   HEAP32[$6 >> 2] = (HEAP32[30848] | 0) + 42; //@line 29944
   HEAP32[$0 >> 2] = 0; //@line 29945
   _Execute68kTrap(-24404, $0); //@line 29946
   $945 = (HEAP32[30848] | 0) + 174 | 0; //@line 29948
   $947 = 123608 + ($945 >>> 16 << 2) | 0; //@line 29950
   $951 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$947 >> 2] >> 2] & 127]($945) | 0 | -2138570752; //@line 29954
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$947 >> 2] | 0) + 12 >> 2] & 31]($945, $951); //@line 29958
   HEAP32[$6 >> 2] = (HEAP32[30848] | 0) + 42; //@line 29961
   HEAP32[$0 + 12 >> 2] = 196; //@line 29963
   HEAP32[$0 + 16 >> 2] = 25185; //@line 29965
   HEAP32[$0 >> 2] = 5; //@line 29966
   _Execute68kTrap(-24404, $0); //@line 29967
   $959 = HEAP32[30848] | 0; //@line 29968
   $960 = $959 + 270 | 0; //@line 29969
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($960 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($960, $959 + 288 | 0); //@line 29976
   $968 = (HEAP32[30848] | 0) + 288 | 0; //@line 29978
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($968 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($968, 8); //@line 29984
   $975 = (HEAP32[30848] | 0) + 290 | 0; //@line 29986
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($975 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($975, 1650553705); //@line 29992
   HEAP32[$6 >> 2] = (HEAP32[30848] | 0) + 238; //@line 29995
   HEAP32[$0 >> 2] = 65; //@line 29996
   _Execute68kTrap(-23968, $0); //@line 29997
   STACKTOP = sp; //@line 29998
   return;
  }
 }
 _puts(96583) | 0; //@line 30001
 STACKTOP = sp; //@line 30002
 return;
}
function _decfloat($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 var $$0329 = 0, $$0332490 = 0, $$0333 = 0, $$0334 = 0, $$0336486 = 0, $$0340496 = 0, $$0341$lcssa = 0, $$0341463 = 0, $$0341464 = 0, $$0341465 = 0, $$0341513 = 0, $$0345$lcssa = 0, $$0345467 = 0, $$0345468 = 0, $$0345469 = 0, $$0345512 = 0, $$0350$lcssa554 = 0, $$0350494 = 0, $$0360 = 0.0, $$0361 = 0.0, $$0365484 = 0.0, $$0372 = 0, $$0380 = 0, $$0380$ph = 0, $$0385$lcssa553 = 0, $$0385493 = 0, $$0393 = 0, $$0396 = 0, $$0401$lcssa = 0, $$0401473 = 0, $$0401474 = 0, $$0401475 = 0, $$0401509 = 0, $$1 = 0.0, $$10 = 0, $$1330$be = 0, $$1330$ph = 0, $$1335 = 0, $$1337 = 0, $$1362 = 0.0, $$1366 = 0.0, $$1373 = 0, $$1373$ph448 = 0, $$1381 = 0, $$1381$ph = 0, $$1381$ph558 = 0, $$1394$lcssa = 0, $$1394511 = 0, $$2 = 0, $$2343 = 0, $$2347 = 0, $$2352$ph449 = 0, $$2367 = 0.0, $$2374 = 0, $$2387$ph447 = 0, $$2395 = 0, $$2398 = 0, $$2403 = 0, $$3$be = 0, $$3$lcssa = 0, $$3344503 = 0, $$3348 = 0, $$3364 = 0.0, $$3368 = 0.0, $$3383 = 0, $$3399$lcssa = 0, $$3399510 = 0, $$3514 = 0, $$425 = 0, $$4349495 = 0, $$4354 = 0, $$4354$ph = 0, $$4354$ph559 = 0, $$4376 = 0, $$4384 = 0, $$4389$ph = 0, $$4389$ph445 = 0, $$4400 = 0, $$4485 = 0, $$5 = 0, $$5$in = 0, $$5355488 = 0, $$5390487 = 0, $$6378$ph = 0, $$6489 = 0, $$9483 = 0, $$pre = 0, $$sink = 0, $$sink421$off0 = 0, $10 = 0, $100 = 0, $105 = 0, $106 = 0, $108 = 0, $109 = 0, $122 = 0, $124 = 0, $134 = 0, $136 = 0, $148 = 0, $150 = 0, $157 = 0, $17 = 0, $170 = 0, $182 = 0, $186 = 0, $189 = 0, $191 = 0, $192 = 0, $193 = 0, $196 = 0, $210 = 0, $211 = 0, $212 = 0, $216 = 0, $218 = 0, $220 = 0, $221 = 0, $227 = 0, $229 = 0, $234 = 0, $241 = 0, $244 = 0, $247 = 0, $25 = 0, $254 = 0, $257 = 0, $259 = 0, $26 = 0, $262 = 0, $265 = 0, $266 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $275 = 0, $28 = 0, $287 = 0, $29 = 0, $292 = 0, $297 = 0, $300 = 0, $309 = 0.0, $310 = 0.0, $311 = 0, $312 = 0, $313 = 0, $318 = 0.0, $321 = 0.0, $325 = 0, $328 = 0, $352 = 0.0, $357 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $39 = 0, $41 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $54 = 0, $55 = 0, $59 = 0, $6 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $or$cond420 = 0, $or$cond426 = 0, $sum = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 60485
 STACKTOP = STACKTOP + 512 | 0; //@line 60486
 $6 = sp; //@line 60487
 $sum = $3 + $2 | 0; //@line 60488
 $7 = 0 - $sum | 0; //@line 60489
 $8 = $0 + 4 | 0; //@line 60490
 $9 = $0 + 100 | 0; //@line 60491
 $$0329 = $1; //@line 60492
 $$0396 = 0; //@line 60492
 L1 : while (1) {
  switch ($$0329 | 0) {
  case 46:
   {
    label = 6; //@line 60496
    break L1;
    break;
   }
  case 48:
   {
    break;
   }
  default:
   {
    $$0393 = 0; //@line 60504
    $$2 = $$0329; //@line 60504
    $$2398 = $$0396; //@line 60504
    $366 = 0; //@line 60504
    $367 = 0; //@line 60504
    break L1;
   }
  }
  $10 = HEAP32[$8 >> 2] | 0; //@line 60508
  if ($10 >>> 0 < (HEAP32[$9 >> 2] | 0) >>> 0) {
   HEAP32[$8 >> 2] = $10 + 1; //@line 60513
   $$0329 = HEAPU8[$10 >> 0] | 0; //@line 60516
   $$0396 = 1; //@line 60516
   continue;
  } else {
   $$0329 = ___shgetc($0) | 0; //@line 60520
   $$0396 = 1; //@line 60520
   continue;
  }
 }
 if ((label | 0) == 6) {
  $17 = HEAP32[$8 >> 2] | 0; //@line 60525
  if ($17 >>> 0 < (HEAP32[$9 >> 2] | 0) >>> 0) {
   HEAP32[$8 >> 2] = $17 + 1; //@line 60530
   $$1330$ph = HEAPU8[$17 >> 0] | 0; //@line 60533
  } else {
   $$1330$ph = ___shgetc($0) | 0; //@line 60536
  }
  if (($$1330$ph | 0) == 48) {
   $25 = 0; //@line 60540
   $26 = 0; //@line 60540
   while (1) {
    $27 = _i64Add($25 | 0, $26 | 0, -1, -1) | 0; //@line 60542
    $28 = tempRet0; //@line 60543
    $29 = HEAP32[$8 >> 2] | 0; //@line 60544
    if ($29 >>> 0 < (HEAP32[$9 >> 2] | 0) >>> 0) {
     HEAP32[$8 >> 2] = $29 + 1; //@line 60549
     $$1330$be = HEAPU8[$29 >> 0] | 0; //@line 60552
    } else {
     $$1330$be = ___shgetc($0) | 0; //@line 60555
    }
    if (($$1330$be | 0) == 48) {
     $25 = $27; //@line 60559
     $26 = $28; //@line 60559
    } else {
     $$0393 = 1; //@line 60561
     $$2 = $$1330$be; //@line 60561
     $$2398 = 1; //@line 60561
     $366 = $27; //@line 60561
     $367 = $28; //@line 60561
     break;
    }
   }
  } else {
   $$0393 = 1; //@line 60566
   $$2 = $$1330$ph; //@line 60566
   $$2398 = $$0396; //@line 60566
   $366 = 0; //@line 60566
   $367 = 0; //@line 60566
  }
 }
 HEAP32[$6 >> 2] = 0; //@line 60569
 $37 = $$2 + -48 | 0; //@line 60570
 $39 = ($$2 | 0) == 46; //@line 60572
 L20 : do {
  if ($39 | $37 >>> 0 < 10) {
   $41 = $6 + 496 | 0; //@line 60576
   $$0341513 = 0; //@line 60577
   $$0345512 = 0; //@line 60577
   $$0401509 = 0; //@line 60577
   $$1394511 = $$0393; //@line 60577
   $$3399510 = $$2398; //@line 60577
   $$3514 = $$2; //@line 60577
   $368 = $39; //@line 60577
   $369 = $37; //@line 60577
   $370 = $366; //@line 60577
   $371 = $367; //@line 60577
   $44 = 0; //@line 60577
   $45 = 0; //@line 60577
   L22 : while (1) {
    do {
     if ($368) {
      if (!$$1394511) {
       $$2343 = $$0341513; //@line 60583
       $$2347 = $$0345512; //@line 60583
       $$2395 = 1; //@line 60583
       $$2403 = $$0401509; //@line 60583
       $$4400 = $$3399510; //@line 60583
       $372 = $44; //@line 60583
       $373 = $45; //@line 60583
       $374 = $44; //@line 60583
       $375 = $45; //@line 60583
      } else {
       break L22;
      }
     } else {
      $46 = _i64Add($44 | 0, $45 | 0, 1, 0) | 0; //@line 60589
      $47 = tempRet0; //@line 60590
      $48 = ($$3514 | 0) != 48; //@line 60591
      if (($$0345512 | 0) >= 125) {
       if (!$48) {
        $$2343 = $$0341513; //@line 60594
        $$2347 = $$0345512; //@line 60594
        $$2395 = $$1394511; //@line 60594
        $$2403 = $$0401509; //@line 60594
        $$4400 = $$3399510; //@line 60594
        $372 = $370; //@line 60594
        $373 = $371; //@line 60594
        $374 = $46; //@line 60594
        $375 = $47; //@line 60594
        break;
       }
       HEAP32[$41 >> 2] = HEAP32[$41 >> 2] | 1; //@line 60599
       $$2343 = $$0341513; //@line 60600
       $$2347 = $$0345512; //@line 60600
       $$2395 = $$1394511; //@line 60600
       $$2403 = $$0401509; //@line 60600
       $$4400 = $$3399510; //@line 60600
       $372 = $370; //@line 60600
       $373 = $371; //@line 60600
       $374 = $46; //@line 60600
       $375 = $47; //@line 60600
       break;
      }
      $$pre = $6 + ($$0345512 << 2) | 0; //@line 60605
      if (!$$0341513) {
       $$sink = $369; //@line 60607
      } else {
       $$sink = $$3514 + -48 + ((HEAP32[$$pre >> 2] | 0) * 10 | 0) | 0; //@line 60613
      }
      HEAP32[$$pre >> 2] = $$sink; //@line 60615
      $54 = $$0341513 + 1 | 0; //@line 60616
      $55 = ($54 | 0) == 9; //@line 60617
      $$2343 = $55 ? 0 : $54; //@line 60621
      $$2347 = ($55 & 1) + $$0345512 | 0; //@line 60621
      $$2395 = $$1394511; //@line 60621
      $$2403 = $48 ? $46 : $$0401509; //@line 60621
      $$4400 = 1; //@line 60621
      $372 = $370; //@line 60621
      $373 = $371; //@line 60621
      $374 = $46; //@line 60621
      $375 = $47; //@line 60621
     }
    } while (0);
    $59 = HEAP32[$8 >> 2] | 0; //@line 60624
    if ($59 >>> 0 < (HEAP32[$9 >> 2] | 0) >>> 0) {
     HEAP32[$8 >> 2] = $59 + 1; //@line 60629
     $$3$be = HEAPU8[$59 >> 0] | 0; //@line 60632
    } else {
     $$3$be = ___shgetc($0) | 0; //@line 60635
    }
    $369 = $$3$be + -48 | 0; //@line 60637
    $368 = ($$3$be | 0) == 46; //@line 60639
    if (!($368 | $369 >>> 0 < 10)) {
     $$0341$lcssa = $$2343; //@line 60644
     $$0345$lcssa = $$2347; //@line 60644
     $$0401$lcssa = $$2403; //@line 60644
     $$1394$lcssa = $$2395; //@line 60644
     $$3$lcssa = $$3$be; //@line 60644
     $$3399$lcssa = $$4400; //@line 60644
     $72 = $374; //@line 60644
     $73 = $372; //@line 60644
     $75 = $375; //@line 60644
     $76 = $373; //@line 60644
     label = 29; //@line 60645
     break L20;
    } else {
     $$0341513 = $$2343; //@line 60642
     $$0345512 = $$2347; //@line 60642
     $$0401509 = $$2403; //@line 60642
     $$1394511 = $$2395; //@line 60642
     $$3399510 = $$4400; //@line 60642
     $$3514 = $$3$be; //@line 60642
     $370 = $372; //@line 60642
     $371 = $373; //@line 60642
     $44 = $374; //@line 60642
     $45 = $375; //@line 60642
    }
   }
   $$0341465 = $$0341513; //@line 60650
   $$0345469 = $$0345512; //@line 60650
   $$0401475 = $$0401509; //@line 60650
   $376 = $44; //@line 60650
   $377 = $45; //@line 60650
   $378 = $370; //@line 60650
   $379 = $371; //@line 60650
   $380 = ($$3399510 | 0) != 0; //@line 60650
   label = 37; //@line 60651
  } else {
   $$0341$lcssa = 0; //@line 60653
   $$0345$lcssa = 0; //@line 60653
   $$0401$lcssa = 0; //@line 60653
   $$1394$lcssa = $$0393; //@line 60653
   $$3$lcssa = $$2; //@line 60653
   $$3399$lcssa = $$2398; //@line 60653
   $72 = 0; //@line 60653
   $73 = $366; //@line 60653
   $75 = 0; //@line 60653
   $76 = $367; //@line 60653
   label = 29; //@line 60654
  }
 } while (0);
 do {
  if ((label | 0) == 29) {
   $70 = ($$1394$lcssa | 0) == 0; //@line 60659
   $71 = $70 ? $72 : $73; //@line 60660
   $74 = $70 ? $75 : $76; //@line 60661
   $77 = ($$3399$lcssa | 0) != 0; //@line 60662
   if (!($77 & ($$3$lcssa | 32 | 0) == 101)) {
    if (($$3$lcssa | 0) > -1) {
     $$0341465 = $$0341$lcssa; //@line 60669
     $$0345469 = $$0345$lcssa; //@line 60669
     $$0401475 = $$0401$lcssa; //@line 60669
     $376 = $72; //@line 60669
     $377 = $75; //@line 60669
     $378 = $71; //@line 60669
     $379 = $74; //@line 60669
     $380 = $77; //@line 60669
     label = 37; //@line 60670
     break;
    } else {
     $$0341464 = $$0341$lcssa; //@line 60673
     $$0345468 = $$0345$lcssa; //@line 60673
     $$0401474 = $$0401$lcssa; //@line 60673
     $381 = $72; //@line 60673
     $382 = $75; //@line 60673
     $383 = $77; //@line 60673
     $384 = $71; //@line 60673
     $385 = $74; //@line 60673
     label = 39; //@line 60674
     break;
    }
   }
   $80 = _scanexp($0, $5) | 0; //@line 60678
   $81 = tempRet0; //@line 60679
   if (($80 | 0) == 0 & ($81 | 0) == -2147483648) {
    if (!$5) {
     ___shlim($0, 0); //@line 60686
     $$1 = 0.0; //@line 60687
     break;
    }
    if (!(HEAP32[$9 >> 2] | 0)) {
     $90 = 0; //@line 60693
     $91 = 0; //@line 60693
    } else {
     HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + -1; //@line 60697
     $90 = 0; //@line 60698
     $91 = 0; //@line 60698
    }
   } else {
    $90 = $80; //@line 60701
    $91 = $81; //@line 60701
   }
   $92 = _i64Add($90 | 0, $91 | 0, $71 | 0, $74 | 0) | 0; //@line 60703
   $$0341463 = $$0341$lcssa; //@line 60705
   $$0345467 = $$0345$lcssa; //@line 60705
   $$0401473 = $$0401$lcssa; //@line 60705
   $105 = $92; //@line 60705
   $106 = $72; //@line 60705
   $108 = tempRet0; //@line 60705
   $109 = $75; //@line 60705
   label = 41; //@line 60706
  }
 } while (0);
 if ((label | 0) == 37) {
  if (!(HEAP32[$9 >> 2] | 0)) {
   $$0341464 = $$0341465; //@line 60713
   $$0345468 = $$0345469; //@line 60713
   $$0401474 = $$0401475; //@line 60713
   $381 = $376; //@line 60713
   $382 = $377; //@line 60713
   $383 = $380; //@line 60713
   $384 = $378; //@line 60713
   $385 = $379; //@line 60713
   label = 39; //@line 60714
  } else {
   HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + -1; //@line 60718
   if ($380) {
    $$0341463 = $$0341465; //@line 60720
    $$0345467 = $$0345469; //@line 60720
    $$0401473 = $$0401475; //@line 60720
    $105 = $378; //@line 60720
    $106 = $376; //@line 60720
    $108 = $379; //@line 60720
    $109 = $377; //@line 60720
    label = 41; //@line 60721
   } else {
    label = 40; //@line 60723
   }
  }
 }
 if ((label | 0) == 39) {
  if ($383) {
   $$0341463 = $$0341464; //@line 60729
   $$0345467 = $$0345468; //@line 60729
   $$0401473 = $$0401474; //@line 60729
   $105 = $384; //@line 60729
   $106 = $381; //@line 60729
   $108 = $385; //@line 60729
   $109 = $382; //@line 60729
   label = 41; //@line 60730
  } else {
   label = 40; //@line 60732
  }
 }
 do {
  if ((label | 0) == 40) {
   HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 60738
   ___shlim($0, 0); //@line 60739
   $$1 = 0.0; //@line 60740
  } else if ((label | 0) == 41) {
   $100 = HEAP32[$6 >> 2] | 0; //@line 60743
   if (!$100) {
    $$1 = +($4 | 0) * 0.0; //@line 60748
    break;
   }
   if ((($109 | 0) < 0 | ($109 | 0) == 0 & $106 >>> 0 < 10) & (($105 | 0) == ($106 | 0) & ($108 | 0) == ($109 | 0))) {
    if (($2 | 0) > 30 | ($100 >>> $2 | 0) == 0) {
     $$1 = +($4 | 0) * +($100 >>> 0); //@line 60769
     break;
    }
   }
   $122 = ($3 | 0) / -2 | 0; //@line 60773
   $124 = (($122 | 0) < 0) << 31 >> 31; //@line 60775
   if (($108 | 0) > ($124 | 0) | ($108 | 0) == ($124 | 0) & $105 >>> 0 > $122 >>> 0) {
    HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 60783
    $$1 = +($4 | 0) * 1.7976931348623157e+308 * 1.7976931348623157e+308; //@line 60787
    break;
   }
   $134 = $3 + -106 | 0; //@line 60790
   $136 = (($134 | 0) < 0) << 31 >> 31; //@line 60792
   if (($108 | 0) < ($136 | 0) | ($108 | 0) == ($136 | 0) & $105 >>> 0 < $134 >>> 0) {
    HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 60800
    $$1 = +($4 | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308; //@line 60804
    break;
   }
   if (!$$0341463) {
    $$3348 = $$0345467; //@line 60809
   } else {
    if (($$0341463 | 0) < 9) {
     $148 = $6 + ($$0345467 << 2) | 0; //@line 60813
     $$3344503 = $$0341463; //@line 60815
     $150 = HEAP32[$148 >> 2] | 0; //@line 60815
     do {
      $150 = $150 * 10 | 0; //@line 60817
      $$3344503 = $$3344503 + 1 | 0; //@line 60818
     } while (($$3344503 | 0) != 9);
     HEAP32[$148 >> 2] = $150; //@line 60826
    }
    $$3348 = $$0345467 + 1 | 0; //@line 60829
   }
   if (($$0401473 | 0) < 9) {
    if (($$0401473 | 0) <= ($105 | 0) & ($105 | 0) < 18) {
     $157 = HEAP32[$6 >> 2] | 0; //@line 60838
     if (($105 | 0) == 9) {
      $$1 = +($4 | 0) * +($157 >>> 0); //@line 60843
      break;
     }
     if (($105 | 0) < 9) {
      $$1 = +($4 | 0) * +($157 >>> 0) / +(HEAP32[88780 + (8 - $105 << 2) >> 2] | 0); //@line 60856
      break;
     }
     $170 = $2 + 27 + (Math_imul($105, -3) | 0) | 0; //@line 60861
     if (($170 | 0) > 30 | ($157 >>> $170 | 0) == 0) {
      $$1 = +($4 | 0) * +($157 >>> 0) * +(HEAP32[88780 + ($105 + -10 << 2) >> 2] | 0); //@line 60875
      break;
     }
    }
   }
   $182 = ($105 | 0) % 9 | 0; //@line 60880
   if (!$182) {
    $$0380$ph = 0; //@line 60883
    $$1373$ph448 = $$3348; //@line 60883
    $$2352$ph449 = 0; //@line 60883
    $$2387$ph447 = $105; //@line 60883
   } else {
    $186 = ($105 | 0) > -1 ? $182 : $182 + 9 | 0; //@line 60887
    $189 = HEAP32[88780 + (8 - $186 << 2) >> 2] | 0; //@line 60890
    if (!$$3348) {
     $$0350$lcssa554 = 0; //@line 60893
     $$0372 = 0; //@line 60893
     $$0385$lcssa553 = $105; //@line 60893
    } else {
     $191 = 1e9 / ($189 | 0) | 0; //@line 60895
     $$0340496 = 0; //@line 60896
     $$0350494 = 0; //@line 60896
     $$0385493 = $105; //@line 60896
     $$4349495 = 0; //@line 60896
     do {
      $192 = $6 + ($$4349495 << 2) | 0; //@line 60898
      $193 = HEAP32[$192 >> 2] | 0; //@line 60899
      $196 = (($193 >>> 0) / ($189 >>> 0) | 0) + $$0340496 | 0; //@line 60902
      HEAP32[$192 >> 2] = $196; //@line 60903
      $$0340496 = Math_imul($191, ($193 >>> 0) % ($189 >>> 0) | 0) | 0; //@line 60904
      $or$cond420 = ($$4349495 | 0) == ($$0350494 | 0) & ($196 | 0) == 0; //@line 60907
      $$0385493 = $or$cond420 ? $$0385493 + -9 | 0 : $$0385493; //@line 60911
      $$0350494 = $or$cond420 ? $$0350494 + 1 & 127 : $$0350494; //@line 60912
      $$4349495 = $$4349495 + 1 | 0; //@line 60913
     } while (($$4349495 | 0) != ($$3348 | 0));
     if (!$$0340496) {
      $$0350$lcssa554 = $$0350494; //@line 60923
      $$0372 = $$3348; //@line 60923
      $$0385$lcssa553 = $$0385493; //@line 60923
     } else {
      HEAP32[$6 + ($$3348 << 2) >> 2] = $$0340496; //@line 60927
      $$0350$lcssa554 = $$0350494; //@line 60928
      $$0372 = $$3348 + 1 | 0; //@line 60928
      $$0385$lcssa553 = $$0385493; //@line 60928
     }
    }
    $$0380$ph = 0; //@line 60933
    $$1373$ph448 = $$0372; //@line 60933
    $$2352$ph449 = $$0350$lcssa554; //@line 60933
    $$2387$ph447 = 9 - $186 + $$0385$lcssa553 | 0; //@line 60933
   }
   L101 : while (1) {
    $210 = ($$2387$ph447 | 0) < 18; //@line 60936
    $211 = ($$2387$ph447 | 0) == 18; //@line 60937
    $212 = $6 + ($$2352$ph449 << 2) | 0; //@line 60938
    $$0380 = $$0380$ph; //@line 60939
    $$1373 = $$1373$ph448; //@line 60939
    while (1) {
     if (!$210) {
      if (!$211) {
       $$1381$ph = $$0380; //@line 60943
       $$4354$ph = $$2352$ph449; //@line 60943
       $$4389$ph445 = $$2387$ph447; //@line 60943
       $$6378$ph = $$1373; //@line 60943
       break L101;
      }
      if ((HEAP32[$212 >> 2] | 0) >>> 0 >= 9007199) {
       $$1381$ph = $$0380; //@line 60949
       $$4354$ph = $$2352$ph449; //@line 60949
       $$4389$ph445 = 18; //@line 60949
       $$6378$ph = $$1373; //@line 60949
       break L101;
      }
     }
     $$0334 = 0; //@line 60954
     $$2374 = $$1373; //@line 60954
     $$5$in = $$1373 + 127 | 0; //@line 60954
     while (1) {
      $$5 = $$5$in & 127; //@line 60956
      $216 = $6 + ($$5 << 2) | 0; //@line 60957
      $218 = _bitshift64Shl(HEAP32[$216 >> 2] | 0, 0, 29) | 0; //@line 60959
      $220 = _i64Add($218 | 0, tempRet0 | 0, $$0334 | 0, 0) | 0; //@line 60961
      $221 = tempRet0; //@line 60962
      if ($221 >>> 0 > 0 | ($221 | 0) == 0 & $220 >>> 0 > 1e9) {
       $227 = ___udivdi3($220 | 0, $221 | 0, 1e9, 0) | 0; //@line 60969
       $229 = ___uremdi3($220 | 0, $221 | 0, 1e9, 0) | 0; //@line 60971
       $$1335 = $227; //@line 60973
       $$sink421$off0 = $229; //@line 60973
      } else {
       $$1335 = 0; //@line 60975
       $$sink421$off0 = $220; //@line 60975
      }
      HEAP32[$216 >> 2] = $$sink421$off0; //@line 60977
      $234 = ($$5 | 0) == ($$2352$ph449 | 0); //@line 60981
      $$2374 = ($$sink421$off0 | 0) == 0 & ((($$5 | 0) != ($$2374 + 127 & 127 | 0) | $234) ^ 1) ? $$5 : $$2374; //@line 60986
      if ($234) {
       break;
      } else {
       $$0334 = $$1335; //@line 60991
       $$5$in = $$5 + -1 | 0; //@line 60991
      }
     }
     $$0380 = $$0380 + -29 | 0; //@line 60994
     if ($$1335 | 0) {
      break;
     } else {
      $$1373 = $$2374; //@line 60997
     }
    }
    $241 = $$2352$ph449 + 127 & 127; //@line 61004
    $244 = $$2374 + 127 & 127; //@line 61007
    $247 = $6 + (($$2374 + 126 & 127) << 2) | 0; //@line 61010
    if (($241 | 0) == ($$2374 | 0)) {
     HEAP32[$247 >> 2] = HEAP32[$247 >> 2] | HEAP32[$6 + ($244 << 2) >> 2]; //@line 61016
     $$4376 = $244; //@line 61017
    } else {
     $$4376 = $$2374; //@line 61019
    }
    HEAP32[$6 + ($241 << 2) >> 2] = $$1335; //@line 61022
    $$0380$ph = $$0380; //@line 61023
    $$1373$ph448 = $$4376; //@line 61023
    $$2352$ph449 = $241; //@line 61023
    $$2387$ph447 = $$2387$ph447 + 9 | 0; //@line 61023
   }
   L119 : while (1) {
    $287 = $$6378$ph + 1 & 127; //@line 61027
    $292 = $6 + (($$6378$ph + 127 & 127) << 2) | 0; //@line 61030
    $$1381$ph558 = $$1381$ph; //@line 61031
    $$4354$ph559 = $$4354$ph; //@line 61031
    $$4389$ph = $$4389$ph445; //@line 61031
    while (1) {
     $265 = ($$4389$ph | 0) == 18; //@line 61033
     $$425 = ($$4389$ph | 0) > 27 ? 9 : 1; //@line 61035
     $$1381 = $$1381$ph558; //@line 61036
     $$4354 = $$4354$ph559; //@line 61036
     while (1) {
      $$0336486 = 0; //@line 61038
      while (1) {
       $254 = $$0336486 + $$4354 & 127; //@line 61041
       if (($254 | 0) == ($$6378$ph | 0)) {
        $$1337 = 2; //@line 61044
        label = 88; //@line 61045
        break;
       }
       $257 = HEAP32[$6 + ($254 << 2) >> 2] | 0; //@line 61049
       $259 = HEAP32[88812 + ($$0336486 << 2) >> 2] | 0; //@line 61051
       if ($257 >>> 0 < $259 >>> 0) {
        $$1337 = 2; //@line 61054
        label = 88; //@line 61055
        break;
       }
       if ($257 >>> 0 > $259 >>> 0) {
        break;
       }
       $262 = $$0336486 + 1 | 0; //@line 61062
       if (($262 | 0) < 2) {
        $$0336486 = $262; //@line 61065
       } else {
        $$1337 = $262; //@line 61067
        label = 88; //@line 61068
        break;
       }
      }
      if ((label | 0) == 88) {
       label = 0; //@line 61073
       if ($265 & ($$1337 | 0) == 2) {
        $$0365484 = 0.0; //@line 61077
        $$4485 = 0; //@line 61077
        $$9483 = $$6378$ph; //@line 61077
        break L119;
       }
      }
      $266 = $$425 + $$1381 | 0; //@line 61081
      if (($$4354 | 0) == ($$6378$ph | 0)) {
       $$1381 = $266; //@line 61084
       $$4354 = $$6378$ph; //@line 61084
      } else {
       break;
      }
     }
     $269 = (1 << $$425) + -1 | 0; //@line 61090
     $270 = 1e9 >>> $$425; //@line 61091
     $$0332490 = 0; //@line 61092
     $$5355488 = $$4354; //@line 61092
     $$5390487 = $$4389$ph; //@line 61092
     $$6489 = $$4354; //@line 61092
     do {
      $271 = $6 + ($$6489 << 2) | 0; //@line 61094
      $272 = HEAP32[$271 >> 2] | 0; //@line 61095
      $275 = ($272 >>> $$425) + $$0332490 | 0; //@line 61098
      HEAP32[$271 >> 2] = $275; //@line 61099
      $$0332490 = Math_imul($272 & $269, $270) | 0; //@line 61100
      $or$cond426 = ($$6489 | 0) == ($$5355488 | 0) & ($275 | 0) == 0; //@line 61103
      $$5390487 = $or$cond426 ? $$5390487 + -9 | 0 : $$5390487; //@line 61107
      $$5355488 = $or$cond426 ? $$5355488 + 1 & 127 : $$5355488; //@line 61108
      $$6489 = $$6489 + 1 & 127; //@line 61110
     } while (($$6489 | 0) != ($$6378$ph | 0));
     if (!$$0332490) {
      $$1381$ph558 = $266; //@line 61120
      $$4354$ph559 = $$5355488; //@line 61120
      $$4389$ph = $$5390487; //@line 61120
      continue;
     }
     if (($287 | 0) != ($$5355488 | 0)) {
      break;
     }
     HEAP32[$292 >> 2] = HEAP32[$292 >> 2] | 1; //@line 61129
     $$1381$ph558 = $266; //@line 61130
     $$4354$ph559 = $$5355488; //@line 61130
     $$4389$ph = $$5390487; //@line 61130
    }
    HEAP32[$6 + ($$6378$ph << 2) >> 2] = $$0332490; //@line 61133
    $$1381$ph = $266; //@line 61134
    $$4354$ph = $$5355488; //@line 61134
    $$4389$ph445 = $$5390487; //@line 61134
    $$6378$ph = $287; //@line 61134
   }
   while (1) {
    $297 = $$4485 + $$4354 & 127; //@line 61138
    $300 = $$9483 + 1 & 127; //@line 61141
    if (($297 | 0) == ($$9483 | 0)) {
     HEAP32[$6 + ($300 + -1 << 2) >> 2] = 0; //@line 61145
     $$10 = $300; //@line 61146
    } else {
     $$10 = $$9483; //@line 61148
    }
    $$0365484 = $$0365484 * 1.0e9 + +((HEAP32[$6 + ($297 << 2) >> 2] | 0) >>> 0); //@line 61154
    $$4485 = $$4485 + 1 | 0; //@line 61155
    if (($$4485 | 0) == 2) {
     break;
    } else {
     $$9483 = $$10; //@line 61160
    }
   }
   $309 = +($4 | 0); //@line 61163
   $310 = $309 * $$0365484; //@line 61164
   $311 = $$1381 + 53 | 0; //@line 61165
   $312 = $311 - $3 | 0; //@line 61166
   $313 = ($312 | 0) < ($2 | 0); //@line 61167
   $$0333 = $313 ? ($312 | 0) > 0 ? $312 : 0 : $2; //@line 61170
   if (($$0333 | 0) < 53) {
    $318 = +_copysignl(+_scalbn(1.0, 105 - $$0333 | 0), $310); //@line 61175
    $321 = +_fmodl($310, +_scalbn(1.0, 53 - $$0333 | 0)); //@line 61178
    $$0360 = $318; //@line 61181
    $$0361 = $321; //@line 61181
    $$1366 = $318 + ($310 - $321); //@line 61181
   } else {
    $$0360 = 0.0; //@line 61183
    $$0361 = 0.0; //@line 61183
    $$1366 = $310; //@line 61183
   }
   $325 = $$4354 + 2 & 127; //@line 61186
   if (($325 | 0) == ($$10 | 0)) {
    $$3364 = $$0361; //@line 61189
   } else {
    $328 = HEAP32[$6 + ($325 << 2) >> 2] | 0; //@line 61192
    do {
     if ($328 >>> 0 < 5e8) {
      if (!$328) {
       if (($$4354 + 3 & 127 | 0) == ($$10 | 0)) {
        $$1362 = $$0361; //@line 61202
        break;
       }
      }
      $$1362 = $309 * .25 + $$0361; //@line 61208
     } else {
      if (($328 | 0) != 5e8) {
       $$1362 = $309 * .75 + $$0361; //@line 61214
       break;
      }
      if (($$4354 + 3 & 127 | 0) == ($$10 | 0)) {
       $$1362 = $309 * .5 + $$0361; //@line 61223
       break;
      } else {
       $$1362 = $309 * .75 + $$0361; //@line 61228
       break;
      }
     }
    } while (0);
    if ((53 - $$0333 | 0) > 1) {
     if (+_fmodl($$1362, 1.0) != 0.0) {
      $$3364 = $$1362; //@line 61239
     } else {
      $$3364 = $$1362 + 1.0; //@line 61242
     }
    } else {
     $$3364 = $$1362; //@line 61245
    }
   }
   $352 = $$1366 + $$3364 - $$0360; //@line 61249
   do {
    if (($311 & 2147483647 | 0) > (-2 - $sum | 0)) {
     $357 = !(+Math_abs(+$352) >= 9007199254740992.0); //@line 61256
     $$3383 = (($357 ^ 1) & 1) + $$1381 | 0; //@line 61260
     $$2367 = $357 ? $352 : $352 * .5; //@line 61261
     if (($$3383 + 50 | 0) <= ($7 | 0)) {
      if (!($$3364 != 0.0 & ($313 & (($$0333 | 0) != ($312 | 0) | $357)))) {
       $$3368 = $$2367; //@line 61271
       $$4384 = $$3383; //@line 61271
       break;
      }
     }
     HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 61276
     $$3368 = $$2367; //@line 61277
     $$4384 = $$3383; //@line 61277
    } else {
     $$3368 = $352; //@line 61279
     $$4384 = $$1381; //@line 61279
    }
   } while (0);
   $$1 = +_scalbnl($$3368, $$4384); //@line 61283
  }
 } while (0);
 STACKTOP = sp; //@line 61286
 return +$$1;
}
function _fmt_fp($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = +$1;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 var $$$3484 = 0, $$$3484692 = 0, $$$4502 = 0, $$$559 = 0.0, $$0 = 0, $$0463$lcssa = 0, $$0463584 = 0, $$0464594 = 0, $$0471 = 0.0, $$0479 = 0, $$0487642 = 0, $$0488653 = 0, $$0488655 = 0, $$0496$$9 = 0, $$0497654 = 0, $$0498 = 0, $$0509582 = 0.0, $$0511 = 0, $$0514637 = 0, $$0520 = 0, $$0521 = 0, $$0521$ = 0, $$0523 = 0, $$0527629 = 0, $$0527631 = 0, $$0530636 = 0, $$1465 = 0, $$1467 = 0.0, $$1469 = 0.0, $$1472 = 0.0, $$1480 = 0, $$1482$lcssa = 0, $$1482661 = 0, $$1489641 = 0, $$1499$lcssa = 0, $$1499660 = 0, $$1508583 = 0, $$1512$lcssa = 0, $$1512607 = 0, $$1515 = 0, $$1524 = 0, $$1528614 = 0, $$1531$lcssa = 0, $$1531630 = 0, $$1598 = 0, $$2 = 0, $$2473 = 0.0, $$2476 = 0, $$2483$ph = 0, $$2500 = 0, $$2513 = 0, $$2516618 = 0, $$2529 = 0, $$2532617 = 0, $$3 = 0.0, $$3477 = 0, $$3484$lcssa = 0, $$3484648 = 0, $$3501$lcssa = 0, $$3501647 = 0, $$3533613 = 0, $$4 = 0.0, $$4478$lcssa = 0, $$4478590 = 0, $$4492 = 0, $$4502 = 0, $$4518 = 0, $$5$lcssa = 0, $$539 = 0, $$539$ = 0, $$542 = 0.0, $$546 = 0, $$548 = 0, $$5486$lcssa = 0, $$5486623 = 0, $$5493597 = 0, $$5519$ph = 0, $$556 = 0, $$5602 = 0, $$6 = 0, $$6494589 = 0, $$7495601 = 0, $$7505 = 0, $$7505$ = 0, $$7505$ph = 0, $$8 = 0, $$9$ph = 0, $$lcssa673 = 0, $$pn = 0, $$pn566 = 0, $$pr = 0, $$pr564 = 0, $$pre$phi690Z2D = 0, $$sink545$lcssa = 0, $$sink545622 = 0, $$sink562 = 0, $10 = 0, $100 = 0, $104 = 0, $11 = 0, $111 = 0, $114 = 0, $122 = 0, $123 = 0, $126 = 0, $128 = 0, $129 = 0, $130 = 0, $136 = 0, $138 = 0, $142 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $152 = 0, $158 = 0, $159 = 0, $160 = 0, $172 = 0, $183 = 0, $187 = 0, $188 = 0, $191 = 0, $196 = 0, $197 = 0, $199 = 0, $207 = 0, $21 = 0, $210 = 0, $213 = 0, $214 = 0, $215 = 0, $218 = 0, $222 = 0, $227 = 0, $230 = 0, $233 = 0, $235 = 0, $237 = 0, $239 = 0, $244 = 0, $245 = 0, $248 = 0, $250 = 0, $253 = 0, $256 = 0, $264 = 0, $267 = 0, $272 = 0, $28 = 0, $281 = 0, $282 = 0, $286 = 0, $289 = 0, $291 = 0, $293 = 0, $297 = 0, $300 = 0, $301 = 0, $305 = 0, $315 = 0, $32 = 0, $320 = 0, $323 = 0, $324 = 0, $325 = 0, $327 = 0, $332 = 0, $344 = 0, $348 = 0, $353 = 0, $36 = 0.0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $366 = 0, $37 = 0, $370 = 0, $372 = 0, $375 = 0, $378 = 0, $40 = 0, $42 = 0, $45 = 0, $47 = 0, $6 = 0, $61 = 0, $64 = 0, $67 = 0, $69 = 0, $7 = 0, $77 = 0, $79 = 0, $8 = 0, $80 = 0, $86 = 0, $9 = 0, $99 = 0, $notrhs = 0, sp = 0;
 sp = STACKTOP; //@line 57867
 STACKTOP = STACKTOP + 560 | 0; //@line 57868
 $6 = sp + 8 | 0; //@line 57869
 $7 = sp; //@line 57870
 $8 = sp + 524 | 0; //@line 57871
 $9 = $8; //@line 57872
 $10 = sp + 512 | 0; //@line 57873
 HEAP32[$7 >> 2] = 0; //@line 57874
 $11 = $10 + 12 | 0; //@line 57875
 ___DOUBLE_BITS_685($1) | 0; //@line 57876
 if ((tempRet0 | 0) < 0) {
  $$0471 = -$1; //@line 57881
  $$0520 = 1; //@line 57881
  $$0521 = 110543; //@line 57881
 } else {
  $$0471 = $1; //@line 57892
  $$0520 = ($4 & 2049 | 0) != 0 & 1; //@line 57892
  $$0521 = ($4 & 2048 | 0) == 0 ? ($4 & 1 | 0) == 0 ? 110544 : 110549 : 110546; //@line 57892
 }
 ___DOUBLE_BITS_685($$0471) | 0; //@line 57894
 $21 = tempRet0 & 2146435072; //@line 57896
 do {
  if ($21 >>> 0 < 2146435072 | ($21 | 0) == 2146435072 & 0 < 0) {
   $36 = +_frexpl($$0471, $7) * 2.0; //@line 57905
   $37 = $36 != 0.0; //@line 57906
   if ($37) {
    HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + -1; //@line 57910
   }
   $40 = $5 | 32; //@line 57912
   if (($40 | 0) == 97) {
    $42 = $5 & 32; //@line 57915
    $$0521$ = ($42 | 0) == 0 ? $$0521 : $$0521 + 9 | 0; //@line 57918
    $45 = $$0520 | 2; //@line 57919
    $47 = 12 - $3 | 0; //@line 57921
    do {
     if ($3 >>> 0 > 11 | ($47 | 0) == 0) {
      $$1472 = $36; //@line 57926
     } else {
      $$0509582 = 8.0; //@line 57928
      $$1508583 = $47; //@line 57928
      do {
       $$1508583 = $$1508583 + -1 | 0; //@line 57930
       $$0509582 = $$0509582 * 16.0; //@line 57931
      } while (($$1508583 | 0) != 0);
      if ((HEAP8[$$0521$ >> 0] | 0) == 45) {
       $$1472 = -($$0509582 + (-$36 - $$0509582)); //@line 57946
       break;
      } else {
       $$1472 = $36 + $$0509582 - $$0509582; //@line 57951
       break;
      }
     }
    } while (0);
    $61 = HEAP32[$7 >> 2] | 0; //@line 57956
    $64 = ($61 | 0) < 0 ? 0 - $61 | 0 : $61; //@line 57959
    $67 = _fmt_u($64, (($64 | 0) < 0) << 31 >> 31, $11) | 0; //@line 57962
    if (($67 | 0) == ($11 | 0)) {
     $69 = $10 + 11 | 0; //@line 57965
     HEAP8[$69 >> 0] = 48; //@line 57966
     $$0511 = $69; //@line 57967
    } else {
     $$0511 = $67; //@line 57969
    }
    HEAP8[$$0511 + -1 >> 0] = ($61 >> 31 & 2) + 43; //@line 57976
    $77 = $$0511 + -2 | 0; //@line 57979
    HEAP8[$77 >> 0] = $5 + 15; //@line 57980
    $notrhs = ($3 | 0) < 1; //@line 57981
    $79 = ($4 & 8 | 0) == 0; //@line 57983
    $$0523 = $8; //@line 57984
    $$2473 = $$1472; //@line 57984
    while (1) {
     $80 = ~~$$2473; //@line 57986
     $86 = $$0523 + 1 | 0; //@line 57992
     HEAP8[$$0523 >> 0] = HEAPU8[110574 + $80 >> 0] | $42; //@line 57993
     $$2473 = ($$2473 - +($80 | 0)) * 16.0; //@line 57996
     if (($86 - $9 | 0) == 1) {
      if ($79 & ($notrhs & $$2473 == 0.0)) {
       $$1524 = $86; //@line 58005
      } else {
       HEAP8[$86 >> 0] = 46; //@line 58008
       $$1524 = $$0523 + 2 | 0; //@line 58009
      }
     } else {
      $$1524 = $86; //@line 58012
     }
     if (!($$2473 != 0.0)) {
      break;
     } else {
      $$0523 = $$1524; //@line 58016
     }
    }
    $99 = $$1524 - $9 | 0; //@line 58025
    $100 = $11 - $77 | 0; //@line 58026
    $$pn = ($3 | 0) != 0 & ($99 + -2 | 0) < ($3 | 0) ? $3 + 2 | 0 : $99; //@line 58031
    $104 = $100 + $45 + $$pn | 0; //@line 58033
    _pad_684($0, 32, $2, $104, $4); //@line 58034
    _out($0, $$0521$, $45); //@line 58035
    _pad_684($0, 48, $2, $104, $4 ^ 65536); //@line 58037
    _out($0, $8, $99); //@line 58038
    _pad_684($0, 48, $$pn - $99 | 0, 0, 0); //@line 58040
    _out($0, $77, $100); //@line 58041
    _pad_684($0, 32, $2, $104, $4 ^ 8192); //@line 58043
    $$sink562 = $104; //@line 58044
    break;
   }
   $$539 = ($3 | 0) < 0 ? 6 : $3; //@line 58048
   if ($37) {
    $111 = (HEAP32[$7 >> 2] | 0) + -28 | 0; //@line 58052
    HEAP32[$7 >> 2] = $111; //@line 58053
    $$3 = $36 * 268435456.0; //@line 58054
    $$pr = $111; //@line 58054
   } else {
    $$3 = $36; //@line 58057
    $$pr = HEAP32[$7 >> 2] | 0; //@line 58057
   }
   $$556 = ($$pr | 0) < 0 ? $6 : $6 + 288 | 0; //@line 58061
   $$0498 = $$556; //@line 58062
   $$4 = $$3; //@line 58062
   do {
    $114 = ~~$$4 >>> 0; //@line 58064
    HEAP32[$$0498 >> 2] = $114; //@line 58065
    $$0498 = $$0498 + 4 | 0; //@line 58066
    $$4 = ($$4 - +($114 >>> 0)) * 1.0e9; //@line 58069
   } while ($$4 != 0.0);
   if (($$pr | 0) > 0) {
    $$1482661 = $$556; //@line 58079
    $$1499660 = $$0498; //@line 58079
    $122 = $$pr; //@line 58079
    while (1) {
     $123 = ($122 | 0) < 29 ? $122 : 29; //@line 58082
     $$0488653 = $$1499660 + -4 | 0; //@line 58083
     if ($$0488653 >>> 0 < $$1482661 >>> 0) {
      $$2483$ph = $$1482661; //@line 58086
     } else {
      $$0488655 = $$0488653; //@line 58088
      $$0497654 = 0; //@line 58088
      do {
       $126 = _bitshift64Shl(HEAP32[$$0488655 >> 2] | 0, 0, $123 | 0) | 0; //@line 58091
       $128 = _i64Add($126 | 0, tempRet0 | 0, $$0497654 | 0, 0) | 0; //@line 58093
       $129 = tempRet0; //@line 58094
       $130 = ___uremdi3($128 | 0, $129 | 0, 1e9, 0) | 0; //@line 58095
       HEAP32[$$0488655 >> 2] = $130; //@line 58097
       $$0497654 = ___udivdi3($128 | 0, $129 | 0, 1e9, 0) | 0; //@line 58098
       $$0488655 = $$0488655 + -4 | 0; //@line 58100
      } while ($$0488655 >>> 0 >= $$1482661 >>> 0);
      if (!$$0497654) {
       $$2483$ph = $$1482661; //@line 58110
      } else {
       $136 = $$1482661 + -4 | 0; //@line 58112
       HEAP32[$136 >> 2] = $$0497654; //@line 58113
       $$2483$ph = $136; //@line 58114
      }
     }
     $$2500 = $$1499660; //@line 58117
     while (1) {
      if ($$2500 >>> 0 <= $$2483$ph >>> 0) {
       break;
      }
      $138 = $$2500 + -4 | 0; //@line 58123
      if (!(HEAP32[$138 >> 2] | 0)) {
       $$2500 = $138; //@line 58127
      } else {
       break;
      }
     }
     $142 = (HEAP32[$7 >> 2] | 0) - $123 | 0; //@line 58133
     HEAP32[$7 >> 2] = $142; //@line 58134
     if (($142 | 0) > 0) {
      $$1482661 = $$2483$ph; //@line 58137
      $$1499660 = $$2500; //@line 58137
      $122 = $142; //@line 58137
     } else {
      $$1482$lcssa = $$2483$ph; //@line 58139
      $$1499$lcssa = $$2500; //@line 58139
      $$pr564 = $142; //@line 58139
      break;
     }
    }
   } else {
    $$1482$lcssa = $$556; //@line 58144
    $$1499$lcssa = $$0498; //@line 58144
    $$pr564 = $$pr; //@line 58144
   }
   if (($$pr564 | 0) < 0) {
    $147 = (($$539 + 25 | 0) / 9 | 0) + 1 | 0; //@line 58150
    $148 = ($40 | 0) == 102; //@line 58151
    $$3484648 = $$1482$lcssa; //@line 58152
    $$3501647 = $$1499$lcssa; //@line 58152
    $150 = $$pr564; //@line 58152
    while (1) {
     $149 = 0 - $150 | 0; //@line 58154
     $152 = ($149 | 0) < 9 ? $149 : 9; //@line 58156
     if ($$3484648 >>> 0 < $$3501647 >>> 0) {
      $158 = (1 << $152) + -1 | 0; //@line 58160
      $159 = 1e9 >>> $152; //@line 58161
      $$0487642 = 0; //@line 58162
      $$1489641 = $$3484648; //@line 58162
      do {
       $160 = HEAP32[$$1489641 >> 2] | 0; //@line 58164
       HEAP32[$$1489641 >> 2] = ($160 >>> $152) + $$0487642; //@line 58168
       $$0487642 = Math_imul($160 & $158, $159) | 0; //@line 58169
       $$1489641 = $$1489641 + 4 | 0; //@line 58170
      } while ($$1489641 >>> 0 < $$3501647 >>> 0);
      $$$3484 = (HEAP32[$$3484648 >> 2] | 0) == 0 ? $$3484648 + 4 | 0 : $$3484648; //@line 58181
      if (!$$0487642) {
       $$$3484692 = $$$3484; //@line 58184
       $$4502 = $$3501647; //@line 58184
      } else {
       HEAP32[$$3501647 >> 2] = $$0487642; //@line 58187
       $$$3484692 = $$$3484; //@line 58188
       $$4502 = $$3501647 + 4 | 0; //@line 58188
      }
     } else {
      $$$3484692 = (HEAP32[$$3484648 >> 2] | 0) == 0 ? $$3484648 + 4 | 0 : $$3484648; //@line 58195
      $$4502 = $$3501647; //@line 58195
     }
     $172 = $148 ? $$556 : $$$3484692; //@line 58197
     $$$4502 = ($$4502 - $172 >> 2 | 0) > ($147 | 0) ? $172 + ($147 << 2) | 0 : $$4502; //@line 58204
     $150 = (HEAP32[$7 >> 2] | 0) + $152 | 0; //@line 58206
     HEAP32[$7 >> 2] = $150; //@line 58207
     if (($150 | 0) >= 0) {
      $$3484$lcssa = $$$3484692; //@line 58212
      $$3501$lcssa = $$$4502; //@line 58212
      break;
     } else {
      $$3484648 = $$$3484692; //@line 58210
      $$3501647 = $$$4502; //@line 58210
     }
    }
   } else {
    $$3484$lcssa = $$1482$lcssa; //@line 58217
    $$3501$lcssa = $$1499$lcssa; //@line 58217
   }
   $183 = $$556; //@line 58220
   if ($$3484$lcssa >>> 0 < $$3501$lcssa >>> 0) {
    $187 = ($183 - $$3484$lcssa >> 2) * 9 | 0; //@line 58225
    $188 = HEAP32[$$3484$lcssa >> 2] | 0; //@line 58226
    if ($188 >>> 0 < 10) {
     $$1515 = $187; //@line 58229
    } else {
     $$0514637 = $187; //@line 58231
     $$0530636 = 10; //@line 58231
     while (1) {
      $$0530636 = $$0530636 * 10 | 0; //@line 58233
      $191 = $$0514637 + 1 | 0; //@line 58234
      if ($188 >>> 0 < $$0530636 >>> 0) {
       $$1515 = $191; //@line 58237
       break;
      } else {
       $$0514637 = $191; //@line 58240
      }
     }
    }
   } else {
    $$1515 = 0; //@line 58245
   }
   $196 = ($40 | 0) == 103; //@line 58250
   $197 = ($$539 | 0) != 0; //@line 58251
   $199 = $$539 - (($40 | 0) != 102 ? $$1515 : 0) + (($197 & $196) << 31 >> 31) | 0; //@line 58254
   if (($199 | 0) < ((($$3501$lcssa - $183 >> 2) * 9 | 0) + -9 | 0)) {
    $207 = $199 + 9216 | 0; //@line 58263
    $210 = $$556 + 4 + ((($207 | 0) / 9 | 0) + -1024 << 2) | 0; //@line 58266
    $$0527629 = (($207 | 0) % 9 | 0) + 1 | 0; //@line 58268
    if (($$0527629 | 0) < 9) {
     $$0527631 = $$0527629; //@line 58271
     $$1531630 = 10; //@line 58271
     while (1) {
      $213 = $$1531630 * 10 | 0; //@line 58273
      $$0527631 = $$0527631 + 1 | 0; //@line 58274
      if (($$0527631 | 0) == 9) {
       $$1531$lcssa = $213; //@line 58277
       break;
      } else {
       $$1531630 = $213; //@line 58280
      }
     }
    } else {
     $$1531$lcssa = 10; //@line 58284
    }
    $214 = HEAP32[$210 >> 2] | 0; //@line 58286
    $215 = ($214 >>> 0) % ($$1531$lcssa >>> 0) | 0; //@line 58287
    $218 = ($210 + 4 | 0) == ($$3501$lcssa | 0); //@line 58290
    if ($218 & ($215 | 0) == 0) {
     $$4492 = $210; //@line 58293
     $$4518 = $$1515; //@line 58293
     $$8 = $$3484$lcssa; //@line 58293
    } else {
     $$542 = ((($214 >>> 0) / ($$1531$lcssa >>> 0) | 0) & 1 | 0) == 0 ? 9007199254740992.0 : 9007199254740994.0; //@line 58298
     $222 = ($$1531$lcssa | 0) / 2 | 0; //@line 58299
     $$$559 = $215 >>> 0 < $222 >>> 0 ? .5 : $218 & ($215 | 0) == ($222 | 0) ? 1.0 : 1.5; //@line 58304
     if (!$$0520) {
      $$1467 = $$$559; //@line 58307
      $$1469 = $$542; //@line 58307
     } else {
      $227 = (HEAP8[$$0521 >> 0] | 0) == 45; //@line 58310
      $$1467 = $227 ? -$$$559 : $$$559; //@line 58315
      $$1469 = $227 ? -$$542 : $$542; //@line 58315
     }
     $230 = $214 - $215 | 0; //@line 58317
     HEAP32[$210 >> 2] = $230; //@line 58318
     if ($$1469 + $$1467 != $$1469) {
      $233 = $230 + $$1531$lcssa | 0; //@line 58322
      HEAP32[$210 >> 2] = $233; //@line 58323
      if ($233 >>> 0 > 999999999) {
       $$5486623 = $$3484$lcssa; //@line 58326
       $$sink545622 = $210; //@line 58326
       while (1) {
        $235 = $$sink545622 + -4 | 0; //@line 58328
        HEAP32[$$sink545622 >> 2] = 0; //@line 58329
        if ($235 >>> 0 < $$5486623 >>> 0) {
         $237 = $$5486623 + -4 | 0; //@line 58332
         HEAP32[$237 >> 2] = 0; //@line 58333
         $$6 = $237; //@line 58334
        } else {
         $$6 = $$5486623; //@line 58336
        }
        $239 = (HEAP32[$235 >> 2] | 0) + 1 | 0; //@line 58339
        HEAP32[$235 >> 2] = $239; //@line 58340
        if ($239 >>> 0 > 999999999) {
         $$5486623 = $$6; //@line 58343
         $$sink545622 = $235; //@line 58343
        } else {
         $$5486$lcssa = $$6; //@line 58345
         $$sink545$lcssa = $235; //@line 58345
         break;
        }
       }
      } else {
       $$5486$lcssa = $$3484$lcssa; //@line 58350
       $$sink545$lcssa = $210; //@line 58350
      }
      $244 = ($183 - $$5486$lcssa >> 2) * 9 | 0; //@line 58355
      $245 = HEAP32[$$5486$lcssa >> 2] | 0; //@line 58356
      if ($245 >>> 0 < 10) {
       $$4492 = $$sink545$lcssa; //@line 58359
       $$4518 = $244; //@line 58359
       $$8 = $$5486$lcssa; //@line 58359
      } else {
       $$2516618 = $244; //@line 58361
       $$2532617 = 10; //@line 58361
       while (1) {
        $$2532617 = $$2532617 * 10 | 0; //@line 58363
        $248 = $$2516618 + 1 | 0; //@line 58364
        if ($245 >>> 0 < $$2532617 >>> 0) {
         $$4492 = $$sink545$lcssa; //@line 58367
         $$4518 = $248; //@line 58367
         $$8 = $$5486$lcssa; //@line 58367
         break;
        } else {
         $$2516618 = $248; //@line 58370
        }
       }
      }
     } else {
      $$4492 = $210; //@line 58375
      $$4518 = $$1515; //@line 58375
      $$8 = $$3484$lcssa; //@line 58375
     }
    }
    $250 = $$4492 + 4 | 0; //@line 58378
    $$5519$ph = $$4518; //@line 58381
    $$7505$ph = $$3501$lcssa >>> 0 > $250 >>> 0 ? $250 : $$3501$lcssa; //@line 58381
    $$9$ph = $$8; //@line 58381
   } else {
    $$5519$ph = $$1515; //@line 58383
    $$7505$ph = $$3501$lcssa; //@line 58383
    $$9$ph = $$3484$lcssa; //@line 58383
   }
   $$7505 = $$7505$ph; //@line 58385
   while (1) {
    if ($$7505 >>> 0 <= $$9$ph >>> 0) {
     $$lcssa673 = 0; //@line 58389
     break;
    }
    $253 = $$7505 + -4 | 0; //@line 58392
    if (!(HEAP32[$253 >> 2] | 0)) {
     $$7505 = $253; //@line 58396
    } else {
     $$lcssa673 = 1; //@line 58398
     break;
    }
   }
   $256 = 0 - $$5519$ph | 0; //@line 58402
   do {
    if ($196) {
     $$539$ = (($197 ^ 1) & 1) + $$539 | 0; //@line 58407
     if (($$539$ | 0) > ($$5519$ph | 0) & ($$5519$ph | 0) > -5) {
      $$0479 = $5 + -1 | 0; //@line 58415
      $$2476 = $$539$ + -1 - $$5519$ph | 0; //@line 58415
     } else {
      $$0479 = $5 + -2 | 0; //@line 58419
      $$2476 = $$539$ + -1 | 0; //@line 58419
     }
     $264 = $4 & 8; //@line 58421
     if (!$264) {
      if ($$lcssa673) {
       $267 = HEAP32[$$7505 + -4 >> 2] | 0; //@line 58426
       if (!$267) {
        $$2529 = 9; //@line 58429
       } else {
        if (!(($267 >>> 0) % 10 | 0)) {
         $$1528614 = 0; //@line 58434
         $$3533613 = 10; //@line 58434
         while (1) {
          $$3533613 = $$3533613 * 10 | 0; //@line 58436
          $272 = $$1528614 + 1 | 0; //@line 58437
          if (($267 >>> 0) % ($$3533613 >>> 0) | 0 | 0) {
           $$2529 = $272; //@line 58443
           break;
          } else {
           $$1528614 = $272; //@line 58441
          }
         }
        } else {
         $$2529 = 0; //@line 58448
        }
       }
      } else {
       $$2529 = 9; //@line 58452
      }
      $281 = (($$7505 - $183 >> 2) * 9 | 0) + -9 | 0; //@line 58460
      if (($$0479 | 32 | 0) == 102) {
       $282 = $281 - $$2529 | 0; //@line 58462
       $$546 = ($282 | 0) > 0 ? $282 : 0; //@line 58464
       $$1480 = $$0479; //@line 58467
       $$3477 = ($$2476 | 0) < ($$546 | 0) ? $$2476 : $$546; //@line 58467
       $$pre$phi690Z2D = 0; //@line 58467
       break;
      } else {
       $286 = $281 + $$5519$ph - $$2529 | 0; //@line 58471
       $$548 = ($286 | 0) > 0 ? $286 : 0; //@line 58473
       $$1480 = $$0479; //@line 58476
       $$3477 = ($$2476 | 0) < ($$548 | 0) ? $$2476 : $$548; //@line 58476
       $$pre$phi690Z2D = 0; //@line 58476
       break;
      }
     } else {
      $$1480 = $$0479; //@line 58480
      $$3477 = $$2476; //@line 58480
      $$pre$phi690Z2D = $264; //@line 58480
     }
    } else {
     $$1480 = $5; //@line 58484
     $$3477 = $$539; //@line 58484
     $$pre$phi690Z2D = $4 & 8; //@line 58484
    }
   } while (0);
   $289 = $$3477 | $$pre$phi690Z2D; //@line 58487
   $291 = ($289 | 0) != 0 & 1; //@line 58489
   $293 = ($$1480 | 32 | 0) == 102; //@line 58491
   if ($293) {
    $$2513 = 0; //@line 58495
    $$pn566 = ($$5519$ph | 0) > 0 ? $$5519$ph : 0; //@line 58495
   } else {
    $297 = ($$5519$ph | 0) < 0 ? $256 : $$5519$ph; //@line 58498
    $300 = _fmt_u($297, (($297 | 0) < 0) << 31 >> 31, $11) | 0; //@line 58501
    $301 = $11; //@line 58502
    if (($301 - $300 | 0) < 2) {
     $$1512607 = $300; //@line 58507
     while (1) {
      $305 = $$1512607 + -1 | 0; //@line 58509
      HEAP8[$305 >> 0] = 48; //@line 58510
      if (($301 - $305 | 0) < 2) {
       $$1512607 = $305; //@line 58515
      } else {
       $$1512$lcssa = $305; //@line 58517
       break;
      }
     }
    } else {
     $$1512$lcssa = $300; //@line 58522
    }
    HEAP8[$$1512$lcssa + -1 >> 0] = ($$5519$ph >> 31 & 2) + 43; //@line 58529
    $315 = $$1512$lcssa + -2 | 0; //@line 58531
    HEAP8[$315 >> 0] = $$1480; //@line 58532
    $$2513 = $315; //@line 58535
    $$pn566 = $301 - $315 | 0; //@line 58535
   }
   $320 = $$0520 + 1 + $$3477 + $291 + $$pn566 | 0; //@line 58540
   _pad_684($0, 32, $2, $320, $4); //@line 58541
   _out($0, $$0521, $$0520); //@line 58542
   _pad_684($0, 48, $2, $320, $4 ^ 65536); //@line 58544
   if ($293) {
    $$0496$$9 = $$9$ph >>> 0 > $$556 >>> 0 ? $$556 : $$9$ph; //@line 58547
    $323 = $8 + 9 | 0; //@line 58548
    $324 = $323; //@line 58549
    $325 = $8 + 8 | 0; //@line 58550
    $$5493597 = $$0496$$9; //@line 58551
    do {
     $327 = _fmt_u(HEAP32[$$5493597 >> 2] | 0, 0, $323) | 0; //@line 58554
     if (($$5493597 | 0) == ($$0496$$9 | 0)) {
      if (($327 | 0) == ($323 | 0)) {
       HEAP8[$325 >> 0] = 48; //@line 58559
       $$1465 = $325; //@line 58560
      } else {
       $$1465 = $327; //@line 58562
      }
     } else {
      if ($327 >>> 0 > $8 >>> 0) {
       _memset($8 | 0, 48, $327 - $9 | 0) | 0; //@line 58569
       $$0464594 = $327; //@line 58570
       while (1) {
        $332 = $$0464594 + -1 | 0; //@line 58572
        if ($332 >>> 0 > $8 >>> 0) {
         $$0464594 = $332; //@line 58575
        } else {
         $$1465 = $332; //@line 58577
         break;
        }
       }
      } else {
       $$1465 = $327; //@line 58582
      }
     }
     _out($0, $$1465, $324 - $$1465 | 0); //@line 58587
     $$5493597 = $$5493597 + 4 | 0; //@line 58588
    } while ($$5493597 >>> 0 <= $$556 >>> 0);
    if ($289 | 0) {
     _out($0, 110590, 1); //@line 58598
    }
    if ($$5493597 >>> 0 < $$7505 >>> 0 & ($$3477 | 0) > 0) {
     $$4478590 = $$3477; //@line 58604
     $$6494589 = $$5493597; //@line 58604
     while (1) {
      $344 = _fmt_u(HEAP32[$$6494589 >> 2] | 0, 0, $323) | 0; //@line 58607
      if ($344 >>> 0 > $8 >>> 0) {
       _memset($8 | 0, 48, $344 - $9 | 0) | 0; //@line 58612
       $$0463584 = $344; //@line 58613
       while (1) {
        $348 = $$0463584 + -1 | 0; //@line 58615
        if ($348 >>> 0 > $8 >>> 0) {
         $$0463584 = $348; //@line 58618
        } else {
         $$0463$lcssa = $348; //@line 58620
         break;
        }
       }
      } else {
       $$0463$lcssa = $344; //@line 58625
      }
      _out($0, $$0463$lcssa, ($$4478590 | 0) < 9 ? $$4478590 : 9); //@line 58629
      $$6494589 = $$6494589 + 4 | 0; //@line 58630
      $353 = $$4478590 + -9 | 0; //@line 58631
      if (!($$6494589 >>> 0 < $$7505 >>> 0 & ($$4478590 | 0) > 9)) {
       $$4478$lcssa = $353; //@line 58638
       break;
      } else {
       $$4478590 = $353; //@line 58636
      }
     }
    } else {
     $$4478$lcssa = $$3477; //@line 58643
    }
    _pad_684($0, 48, $$4478$lcssa + 9 | 0, 9, 0); //@line 58646
   } else {
    $$7505$ = $$lcssa673 ? $$7505 : $$9$ph + 4 | 0; //@line 58649
    if (($$3477 | 0) > -1) {
     $360 = $8 + 9 | 0; //@line 58652
     $361 = ($$pre$phi690Z2D | 0) == 0; //@line 58653
     $362 = $360; //@line 58654
     $363 = 0 - $9 | 0; //@line 58655
     $364 = $8 + 8 | 0; //@line 58656
     $$5602 = $$3477; //@line 58657
     $$7495601 = $$9$ph; //@line 58657
     while (1) {
      $366 = _fmt_u(HEAP32[$$7495601 >> 2] | 0, 0, $360) | 0; //@line 58660
      if (($366 | 0) == ($360 | 0)) {
       HEAP8[$364 >> 0] = 48; //@line 58663
       $$0 = $364; //@line 58664
      } else {
       $$0 = $366; //@line 58666
      }
      do {
       if (($$7495601 | 0) == ($$9$ph | 0)) {
        $372 = $$0 + 1 | 0; //@line 58671
        _out($0, $$0, 1); //@line 58672
        if ($361 & ($$5602 | 0) < 1) {
         $$2 = $372; //@line 58676
         break;
        }
        _out($0, 110590, 1); //@line 58679
        $$2 = $372; //@line 58680
       } else {
        if ($$0 >>> 0 <= $8 >>> 0) {
         $$2 = $$0; //@line 58684
         break;
        }
        _memset($8 | 0, 48, $$0 + $363 | 0) | 0; //@line 58689
        $$1598 = $$0; //@line 58690
        while (1) {
         $370 = $$1598 + -1 | 0; //@line 58692
         if ($370 >>> 0 > $8 >>> 0) {
          $$1598 = $370; //@line 58695
         } else {
          $$2 = $370; //@line 58697
          break;
         }
        }
       }
      } while (0);
      $375 = $362 - $$2 | 0; //@line 58704
      _out($0, $$2, ($$5602 | 0) > ($375 | 0) ? $375 : $$5602); //@line 58707
      $378 = $$5602 - $375 | 0; //@line 58708
      $$7495601 = $$7495601 + 4 | 0; //@line 58709
      if (!($$7495601 >>> 0 < $$7505$ >>> 0 & ($378 | 0) > -1)) {
       $$5$lcssa = $378; //@line 58716
       break;
      } else {
       $$5602 = $378; //@line 58714
      }
     }
    } else {
     $$5$lcssa = $$3477; //@line 58721
    }
    _pad_684($0, 48, $$5$lcssa + 18 | 0, 18, 0); //@line 58724
    _out($0, $$2513, $11 - $$2513 | 0); //@line 58728
   }
   _pad_684($0, 32, $2, $320, $4 ^ 8192); //@line 58731
   $$sink562 = $320; //@line 58732
  } else {
   $28 = ($5 & 32 | 0) != 0; //@line 58735
   $32 = $$0520 + 3 | 0; //@line 58740
   _pad_684($0, 32, $2, $32, $4 & -65537); //@line 58742
   _out($0, $$0521, $$0520); //@line 58743
   _out($0, $$0471 != $$0471 | 0.0 != 0.0 ? $28 ? 112508 : 110570 : $28 ? 110562 : 110566, 3); //@line 58744
   _pad_684($0, 32, $2, $32, $4 ^ 8192); //@line 58746
   $$sink562 = $32; //@line 58747
  }
 } while (0);
 STACKTOP = sp; //@line 58752
 return (($$sink562 | 0) < ($2 | 0) ? $2 : $$sink562) | 0; //@line 58752
}
function __ZN12monitor_desc13driver_statusEtj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$$0$i = 0, $$0 = 0, $$0$lcssa$i = 0, $$011$i = 0, $$0159 = 0, $$0160 = 0, $$0161 = 0, $$0162 = 0, $$0163 = 0, $$0164228 = 0, $$0165225 = 0, $$0167 = 0, $$0171224 = 0, $$0172226 = 0, $$0212 = 0, $$1166227 = 0, $$1168$in = 0, $$2169 = 0, $$5 = 0, $$pre$phi243Z2D = 0, $$pre$phiZ2D = 0, $$sink229 = 0, $$sroa$04$08$i = 0, $$sroa$04$08$i175 = 0, $$sroa$04$08$i179 = 0, $$sroa$04$08$i183 = 0, $$sroa$05$010$i = 0, $$sroa$07$014$i = 0, $107 = 0, $11 = 0, $115 = 0, $125 = 0, $131 = 0, $139 = 0, $146 = 0, $17 = 0, $187 = 0, $195 = 0, $201 = 0, $214 = 0, $220 = 0, $226 = 0, $232 = 0, $242 = 0, $244 = 0, $246 = 0, $253 = 0, $259 = 0, $268 = 0, $274 = 0, $29 = 0, $290 = 0, $30 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $333 = 0, $339 = 0, $345 = 0, $346 = 0, $354 = 0, $356 = 0, $36 = 0, $362 = 0, $368 = 0, $37 = 0, $374 = 0, $375 = 0, $376 = 0, $379 = 0, $391 = 0, $401 = 0, $402 = 0, $408 = 0, $411 = 0, $413 = 0, $415 = 0, $416 = 0, $424 = 0, $429 = 0, $43 = 0, $435 = 0, $443 = 0, $449 = 0, $45 = 0, $455 = 0, $463 = 0, $47 = 0, $470 = 0, $476 = 0, $482 = 0, $488 = 0, $494 = 0, $500 = 0, $501 = 0, $502 = 0, $508 = 0, $514 = 0, $520 = 0, $526 = 0, $532 = 0, $538 = 0, $541 = 0, $548 = 0, $554 = 0, $560 = 0, $566 = 0, $57 = 0, $572 = 0, $61 = 0, $62 = 0, $63 = 0, $71 = 0, $79 = 0, $96 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 25424
 STACKTOP = STACKTOP + 16 | 0; //@line 25425
 $vararg_buffer = sp; //@line 25426
 do {
  switch ($1 << 16 >> 16) {
  case 2:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2, HEAPU16[$0 + 804 >> 1] | 0); //@line 25438
    $11 = $2 + 6 | 0; //@line 25439
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($11, 0); //@line 25445
    $17 = $2 + 8 | 0; //@line 25446
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($17, HEAP32[$0 + 20 >> 2] | 0); //@line 25454
    $$5 = 0; //@line 25455
    STACKTOP = sp; //@line 25456
    return $$5 | 0; //@line 25456
   }
  case 3:
   {
    $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 25464
    $30 = $2 + 4 | 0; //@line 25465
    $36 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($30) | 0; //@line 25471
    $37 = $2 + 6 | 0; //@line 25472
    $43 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($37) | 0; //@line 25478
    if (!$29) {
     $$5 = -50; //@line 25481
     STACKTOP = sp; //@line 25482
     return $$5 | 0; //@line 25482
    }
    $45 = $43 & 65535; //@line 25484
    if ($45 >>> 0 > 255) {
     $$5 = -50; //@line 25487
     STACKTOP = sp; //@line 25488
     return $$5 | 0; //@line 25488
    }
    $47 = $36 & 65535; //@line 25490
    if (($47 | 0) == 65535) {
     $$0165225 = $29; //@line 25493
     $$0171224 = 0; //@line 25493
     while (1) {
      $57 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$0165225 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$0165225) | 0) & 255) * 3 | 0) + ($0 + 25) | 0; //@line 25503
      $61 = HEAP8[$57 + 1 >> 0] | 0; //@line 25507
      $62 = HEAP8[$57 + 2 >> 0] | 0; //@line 25508
      $63 = $$0165225 + 2 | 0; //@line 25509
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($63 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($63, (HEAPU8[$57 >> 0] | 0) * 257 | 0); //@line 25517
      $71 = $$0165225 + 4 | 0; //@line 25518
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($71 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($71, ($61 & 255) * 257 | 0); //@line 25526
      $79 = $$0165225 + 6 | 0; //@line 25527
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($79 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($79, ($62 & 255) * 257 | 0); //@line 25535
      if (($$0171224 | 0) == ($45 | 0)) {
       $$5 = 0; //@line 25540
       break;
      } else {
       $$0165225 = $$0165225 + 8 | 0; //@line 25543
       $$0171224 = $$0171224 + 1 | 0; //@line 25543
      }
     }
     STACKTOP = sp; //@line 25546
     return $$5 | 0; //@line 25546
    }
    if (($45 + $47 | 0) >>> 0 > 255) {
     $$5 = -50; //@line 25551
     STACKTOP = sp; //@line 25552
     return $$5 | 0; //@line 25552
    }
    $$0164228 = ($47 * 3 | 0) + ($0 + 25) | 0; //@line 25556
    $$0172226 = 0; //@line 25556
    $$1166227 = $29; //@line 25556
    while (1) {
     $96 = HEAP8[$$0164228 + 1 >> 0] | 0; //@line 25561
     $98 = HEAP8[$$0164228 + 2 >> 0] | 0; //@line 25563
     $99 = $$1166227 + 2 | 0; //@line 25564
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($99 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($99, (HEAPU8[$$0164228 >> 0] | 0) * 257 | 0); //@line 25572
     $107 = $$1166227 + 4 | 0; //@line 25573
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($107 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($107, ($96 & 255) * 257 | 0); //@line 25581
     $115 = $$1166227 + 6 | 0; //@line 25582
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($115 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($115, ($98 & 255) * 257 | 0); //@line 25590
     if (($$0172226 | 0) == ($45 | 0)) {
      $$5 = 0; //@line 25595
      break;
     } else {
      $$0164228 = $$0164228 + 3 | 0; //@line 25598
      $$0172226 = $$0172226 + 1 | 0; //@line 25598
      $$1166227 = $$1166227 + 8 | 0; //@line 25598
     }
    }
    STACKTOP = sp; //@line 25601
    return $$5 | 0; //@line 25601
   }
  case 4:
   {
    $125 = $2 + 6 | 0; //@line 25605
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($125 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($125, 1); //@line 25611
    $$5 = 0; //@line 25612
    STACKTOP = sp; //@line 25613
    return $$5 | 0; //@line 25613
   }
  case 5:
   {
    $131 = $2 + 8 | 0; //@line 25617
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($131 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($131, HEAP32[$0 + 20 >> 2] | 0); //@line 25625
    $139 = $2 + 6 | 0; //@line 25626
    $146 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($139 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($139) | 0) == 0; //@line 25633
    $$5 = $146 ? 0 : -50; //@line 25635
    STACKTOP = sp; //@line 25636
    return $$5 | 0; //@line 25636
   }
  case 6:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($2, HEAPU8[$0 + 793 >> 0] | 0); //@line 25648
    $$5 = 0; //@line 25649
    STACKTOP = sp; //@line 25650
    return $$5 | 0; //@line 25650
   }
  case 7:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($2, (HEAP8[$0 + 794 >> 0] ^ 1) & 255); //@line 25663
    $$5 = 0; //@line 25664
    STACKTOP = sp; //@line 25665
    return $$5 | 0; //@line 25665
   }
  case 8:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($2, HEAP32[$0 + 796 >> 2] | 0); //@line 25676
    $$5 = 0; //@line 25677
    STACKTOP = sp; //@line 25678
    return $$5 | 0; //@line 25678
   }
  case 9:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($2, HEAPU16[$0 + 812 >> 1] | 0); //@line 25690
    $$5 = 0; //@line 25691
    STACKTOP = sp; //@line 25692
    return $$5 | 0; //@line 25692
   }
  case 10:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2, HEAPU16[$0 + 804 >> 1] | 0); //@line 25704
    $187 = $2 + 2 | 0; //@line 25705
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($187 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($187, HEAP32[$0 + 808 >> 2] | 0); //@line 25713
    $195 = $2 + 6 | 0; //@line 25714
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($195 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($195, 0); //@line 25720
    $201 = $2 + 8 | 0; //@line 25721
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($201 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($201, HEAP32[$0 + 20 >> 2] | 0); //@line 25729
    $$5 = 0; //@line 25730
    STACKTOP = sp; //@line 25731
    return $$5 | 0; //@line 25731
   }
  case 12:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2, 8); //@line 25740
    $214 = $2 + 2 | 0; //@line 25741
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($214 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($214, 0); //@line 25747
    $220 = $2 + 3 | 0; //@line 25748
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($220 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($220, 0); //@line 25754
    $226 = $2 + 4 | 0; //@line 25755
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($226 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($226, 67); //@line 25761
    $232 = $2 + 8 | 0; //@line 25762
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($232 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($232, 0); //@line 25768
    $$5 = 0; //@line 25769
    STACKTOP = sp; //@line 25770
    return $$5 | 0; //@line 25770
   }
  case 13:
   {
    $242 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 25778
    $244 = HEAP32[$0 + 8 >> 2] | 0; //@line 25780
    $246 = HEAP32[$0 + 4 >> 2] | 0; //@line 25782
    if (($246 | 0) == ($244 | 0)) {
     $$5 = -50; //@line 25785
     STACKTOP = sp; //@line 25786
     return $$5 | 0; //@line 25786
    } else {
     $$sroa$04$08$i = $246; //@line 25788
    }
    while (1) {
     if ((HEAP32[$$sroa$04$08$i + 8 >> 2] | 0) == ($242 | 0)) {
      break;
     }
     $$sroa$04$08$i = $$sroa$04$08$i + 24 | 0; //@line 25794
     if (($$sroa$04$08$i | 0) == ($244 | 0)) {
      $$5 = -50; //@line 25800
      label = 61; //@line 25801
      break;
     }
    }
    if ((label | 0) == 61) {
     STACKTOP = sp; //@line 25808
     return $$5 | 0; //@line 25808
    }
    $253 = $2 + 8 | 0; //@line 25810
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($253 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($253, 1684366188); //@line 25816
    $259 = $2 + 12 | 0; //@line 25817
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($259 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($259, 0); //@line 25823
    $268 = $2 + 16 | 0; //@line 25828
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($268 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($268, ($242 | 0) == (HEAP32[$0 + 816 >> 2] | 0) ? 15 : 11); //@line 25834
    $$5 = 0; //@line 25835
    STACKTOP = sp; //@line 25836
    return $$5 | 0; //@line 25836
   }
  case 14:
   {
    $274 = $2 + 8 | 0; //@line 25840
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($274 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($274, HEAP32[$0 + 20 >> 2] | 0); //@line 25848
    $$5 = 0; //@line 25849
    STACKTOP = sp; //@line 25850
    return $$5 | 0; //@line 25850
   }
  case 16:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2, HEAPU16[$0 + 812 >> 1] | 0); //@line 25862
    $290 = $2 + 2 | 0; //@line 25863
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($290 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($290, HEAP32[$0 + 816 >> 2] | 0); //@line 25871
    $$5 = 0; //@line 25872
    STACKTOP = sp; //@line 25873
    return $$5 | 0; //@line 25873
   }
  case 17:
   {
    $302 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 25881
    L55 : do {
     switch ($302 | 0) {
     case 0:
      {
       $$2169 = HEAP32[$0 + 808 >> 2] | 0; //@line 25889
       $$pre$phi243Z2D = $0 + 4 | 0; //@line 25889
       $$pre$phiZ2D = $0 + 8 | 0; //@line 25889
       break;
      }
     case -2:
      {
       $303 = $0 + 8 | 0; //@line 25893
       $304 = HEAP32[$303 >> 2] | 0; //@line 25894
       $305 = $0 + 4 | 0; //@line 25895
       $306 = HEAP32[$305 >> 2] | 0; //@line 25896
       if (($306 | 0) == ($304 | 0)) {
        while (1) {}
       } else {
        $$0167 = 128; //@line 25902
       }
       while (1) {
        $$sroa$04$08$i175 = $306; //@line 25905
        do {
         if ((HEAP32[$$sroa$04$08$i175 + 8 >> 2] | 0) == ($$0167 | 0)) {
          $$2169 = $$0167; //@line 25912
          $$pre$phi243Z2D = $305; //@line 25912
          $$pre$phiZ2D = $303; //@line 25912
          break L55;
         }
         $$sroa$04$08$i175 = $$sroa$04$08$i175 + 24 | 0; //@line 25910
        } while (($$sroa$04$08$i175 | 0) != ($304 | 0));
        $$0167 = $$0167 + 1 | 0; //@line 25923
       }
       break;
      }
     default:
      {
       $316 = $0 + 8 | 0; //@line 25928
       $317 = HEAP32[$316 >> 2] | 0; //@line 25929
       $318 = $0 + 4 | 0; //@line 25930
       $319 = HEAP32[$318 >> 2] | 0; //@line 25931
       if (($319 | 0) == ($317 | 0)) {
        $$5 = -50; //@line 25934
        STACKTOP = sp; //@line 25935
        return $$5 | 0; //@line 25935
       } else {
        $$sroa$04$08$i179 = $319; //@line 25937
       }
       while (1) {
        if ((HEAP32[$$sroa$04$08$i179 + 8 >> 2] | 0) == ($302 | 0)) {
         $$1168$in = $302; //@line 25945
         break;
        }
        $$sroa$04$08$i179 = $$sroa$04$08$i179 + 24 | 0; //@line 25943
        if (($$sroa$04$08$i179 | 0) == ($317 | 0)) {
         $$5 = -50; //@line 25950
         label = 61; //@line 25951
         break;
        }
       }
       if ((label | 0) == 61) {
        STACKTOP = sp; //@line 25958
        return $$5 | 0; //@line 25958
       }
       L64 : do {
        $$1168$in = $$1168$in + 1 | 0; //@line 25961
        $$sroa$04$08$i183 = $319; //@line 25962
        do {
         if ((HEAP32[$$sroa$04$08$i183 + 8 >> 2] | 0) == ($$1168$in | 0)) {
          break L64;
         }
         $$sroa$04$08$i183 = $$sroa$04$08$i183 + 24 | 0; //@line 25967
        } while (($$sroa$04$08$i183 | 0) != ($317 | 0));
       } while ($$1168$in >>> 0 < 256);
       if (($$1168$in | 0) == 256) {
        $333 = $2 + 4 | 0; //@line 25987
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($333 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($333, -3); //@line 25993
        $$5 = 0; //@line 25994
        STACKTOP = sp; //@line 25995
        return $$5 | 0; //@line 25995
       } else {
        $$2169 = $$1168$in; //@line 25997
        $$pre$phi243Z2D = $318; //@line 25997
        $$pre$phiZ2D = $316; //@line 25997
       }
      }
     }
    } while (0);
    $339 = $2 + 4 | 0; //@line 26002
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($339 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($339, $$2169); //@line 26008
    $345 = HEAP32[$$pre$phiZ2D >> 2] | 0; //@line 26009
    $346 = HEAP32[$$pre$phi243Z2D >> 2] | 0; //@line 26010
    L85 : do {
     if (($346 | 0) == ($345 | 0)) {
      $$0 = 0; //@line 26014
      $$0212 = 0; //@line 26014
     } else {
      $$sroa$07$014$i = $346; //@line 26016
      while (1) {
       if ((HEAP32[$$sroa$07$014$i + 8 >> 2] | 0) == ($$2169 | 0)) {
        break;
       }
       $354 = $$sroa$07$014$i + 24 | 0; //@line 26024
       if (($354 | 0) == ($345 | 0)) {
        $$0 = 0; //@line 26027
        $$0212 = 0; //@line 26027
        break L85;
       } else {
        $$sroa$07$014$i = $354; //@line 26030
       }
      }
      $$0 = HEAP32[$$sroa$07$014$i >> 2] | 0; //@line 26036
      $$0212 = HEAP32[$$sroa$07$014$i + 4 >> 2] | 0; //@line 26036
     }
    } while (0);
    $356 = $2 + 8 | 0; //@line 26039
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($356 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($356, $$0); //@line 26045
    $362 = $2 + 12 | 0; //@line 26046
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($362 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($362, $$0212); //@line 26052
    $368 = $2 + 16 | 0; //@line 26053
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($368 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($368, 4915200); //@line 26059
    $374 = $2 + 20 | 0; //@line 26060
    $375 = HEAP32[$$pre$phiZ2D >> 2] | 0; //@line 26061
    $376 = HEAP32[$$pre$phi243Z2D >> 2] | 0; //@line 26062
    if (($376 | 0) == ($375 | 0)) {
     $$0$lcssa$i = 0; //@line 26065
    } else {
     $$011$i = 0; //@line 26067
     $$sroa$05$010$i = $376; //@line 26067
     while (1) {
      $379 = HEAP32[$$sroa$05$010$i + 12 >> 2] | 0; //@line 26070
      $$$0$i = ($379 | 0) > ($$011$i | 0) ? $379 : $$011$i; //@line 26072
      $$sroa$05$010$i = $$sroa$05$010$i + 24 | 0; //@line 26073
      if (($$sroa$05$010$i | 0) == ($375 | 0)) {
       $$0$lcssa$i = $$$0$i; //@line 26076
       break;
      } else {
       $$011$i = $$$0$i; //@line 26079
      }
     }
    }
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($374 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($374, HEAPU16[$0 + 824 + ($$0$lcssa$i << 1) >> 1] | 0); //@line 26091
    $391 = $2 + 22 | 0; //@line 26092
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($391 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($391, 0); //@line 26098
    $$5 = 0; //@line 26099
    STACKTOP = sp; //@line 26100
    return $$5 | 0; //@line 26100
   }
  case 18:
   {
    $401 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 26108
    $402 = $2 + 4 | 0; //@line 26109
    $408 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($402 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($402) | 0; //@line 26115
    HEAP8[$0 + 795 >> 0] = 1; //@line 26117
    $411 = HEAP32[$0 + 8 >> 2] | 0; //@line 26119
    $413 = HEAP32[$0 + 4 >> 2] | 0; //@line 26121
    if (($413 | 0) == ($411 | 0)) {
     $$5 = -50; //@line 26124
     STACKTOP = sp; //@line 26125
     return $$5 | 0; //@line 26125
    }
    $415 = $408 & 65535; //@line 26127
    $$sink229 = $413; //@line 26128
    while (1) {
     $416 = $$sink229 + 12 | 0; //@line 26130
     if ((HEAP16[$0 + 824 + (HEAP32[$416 >> 2] << 1) >> 1] | 0) == $415 << 16 >> 16) {
      if ((HEAP32[$$sink229 + 8 >> 2] | 0) == ($401 | 0)) {
       break;
      }
     }
     $538 = $$sink229 + 24 | 0; //@line 26143
     if (($538 | 0) == ($411 | 0)) {
      $$5 = -50; //@line 26146
      label = 61; //@line 26147
      break;
     } else {
      $$sink229 = $538; //@line 26150
     }
    }
    if ((label | 0) == 61) {
     STACKTOP = sp; //@line 26154
     return $$5 | 0; //@line 26154
    }
    $424 = $2 + 6 | 0; //@line 26156
    $429 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($424 >>> 16 << 2) >> 2] >> 2] & 127]($424) | 0; //@line 26161
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($429 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($429, 0); //@line 26167
    $435 = $429 + 4 | 0; //@line 26168
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($435 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($435, HEAP32[$$sink229 + 16 >> 2] | 0); //@line 26176
    $443 = $429 + 6 | 0; //@line 26177
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($443 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($443, 0); //@line 26183
    $449 = $429 + 8 | 0; //@line 26184
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($449 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($449, 0); //@line 26190
    $455 = $429 + 10 | 0; //@line 26191
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($455 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($455, HEAP32[$$sink229 + 4 >> 2] | 0); //@line 26199
    $463 = $429 + 12 | 0; //@line 26200
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($463 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($463, HEAP32[$$sink229 >> 2] | 0); //@line 26207
    $470 = $429 + 14 | 0; //@line 26208
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($470 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($470, 0); //@line 26214
    $476 = $429 + 16 | 0; //@line 26215
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($476 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($476, 0); //@line 26221
    $482 = $429 + 18 | 0; //@line 26222
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($482 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($482, 0); //@line 26228
    $488 = $429 + 22 | 0; //@line 26229
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($488 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($488, 4718592); //@line 26235
    $494 = $429 + 26 | 0; //@line 26236
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($494 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($494, 4718592); //@line 26242
    $500 = HEAP32[$416 >> 2] | 0; //@line 26243
    switch ($500 | 0) {
    case 4:
     {
      $$0159 = 2; //@line 26246
      $$0160 = 5; //@line 26246
      $$0161 = 3; //@line 26246
      $$0162 = 16; //@line 26246
      $$0163 = 16; //@line 26246
      break;
     }
    case 5:
     {
      $$0159 = 2; //@line 26250
      $$0160 = 8; //@line 26250
      $$0161 = 3; //@line 26250
      $$0162 = 32; //@line 26250
      $$0163 = 16; //@line 26250
      break;
     }
    default:
     {
      $501 = 1 << $500; //@line 26254
      $$0159 = 0; //@line 26255
      $$0160 = $501; //@line 26255
      $$0161 = 1; //@line 26255
      $$0162 = $501; //@line 26255
      $$0163 = 0; //@line 26255
     }
    }
    $502 = $429 + 30 | 0; //@line 26258
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($502 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($502, $$0163); //@line 26264
    $508 = $429 + 32 | 0; //@line 26265
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($508 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($508, $$0162); //@line 26271
    $514 = $429 + 34 | 0; //@line 26272
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($514 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($514, $$0161); //@line 26278
    $520 = $429 + 36 | 0; //@line 26279
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($520 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($520, $$0160); //@line 26285
    $526 = $2 + 10 | 0; //@line 26286
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($526 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($526, 1); //@line 26292
    $532 = $2 + 14 | 0; //@line 26293
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($532 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($532, $$0159); //@line 26299
    $$5 = 0; //@line 26300
    STACKTOP = sp; //@line 26301
    return $$5 | 0; //@line 26301
   }
  case 28:
   {
    $541 = 123608 + ($2 >>> 16 << 2) | 0; //@line 26306
    switch (FUNCTION_TABLE_ii[HEAP32[HEAP32[$541 >> 2] >> 2] & 127]($2) | 0) {
    case -1:
     {
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$541 >> 2] | 0) + 12 >> 2] & 31]($2, 1); //@line 26315
      $$5 = 0; //@line 26316
      STACKTOP = sp; //@line 26317
      return $$5 | 0; //@line 26317
     }
    case 1:
     {
      $548 = $2 + 4 | 0; //@line 26321
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($548 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($548, 8); //@line 26327
      $554 = $2 + 6 | 0; //@line 26328
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($554 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($554, 0); //@line 26334
      $560 = $2 + 7 | 0; //@line 26335
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($560 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($560, 0); //@line 26341
      $566 = $2 + 8 | 0; //@line 26342
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($566 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($566, 67); //@line 26348
      $572 = $2 + 12 | 0; //@line 26349
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($572 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($572, 0); //@line 26355
      $$5 = 0; //@line 26356
      STACKTOP = sp; //@line 26357
      return $$5 | 0; //@line 26357
     }
    default:
     {
      $$5 = -50; //@line 26361
      STACKTOP = sp; //@line 26362
      return $$5 | 0; //@line 26362
     }
    }
    break;
   }
  default:
   {
    HEAP32[$vararg_buffer >> 2] = $1 & 65535; //@line 26369
    _printf(96412, $vararg_buffer) | 0; //@line 26370
    $$5 = -18; //@line 26371
    STACKTOP = sp; //@line 26372
    return $$5 | 0; //@line 26372
   }
  }
 } while (0);
 return 0; //@line 26376
}
function _printf_core($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$$5 = 0, $$0 = 0, $$0228 = 0, $$0229322 = 0, $$0232 = 0, $$0235 = 0, $$0237 = 0, $$0240$lcssa = 0, $$0240$lcssa357 = 0, $$0240321 = 0, $$0243 = 0, $$0247 = 0, $$0249$lcssa = 0, $$0249306 = 0, $$0252 = 0, $$0253 = 0, $$0254 = 0, $$0259 = 0, $$0262$lcssa = 0, $$0262311 = 0, $$0269 = 0, $$1 = 0, $$1230333 = 0, $$1233 = 0, $$1236 = 0, $$1238 = 0, $$1241332 = 0, $$1244320 = 0, $$1248 = 0, $$1255 = 0, $$1260 = 0, $$1263 = 0, $$1263$ = 0, $$1270 = 0, $$2 = 0, $$2234 = 0, $$2239 = 0, $$2242305 = 0, $$2245 = 0, $$2251 = 0, $$2256 = 0, $$2261 = 0, $$2271 = 0, $$3265 = 0, $$3272 = 0, $$3303 = 0, $$4258355 = 0, $$4266 = 0, $$5 = 0, $$6268 = 0, $$lcssa295 = 0, $$pre347 = 0, $$pre349 = 0, $10 = 0, $11 = 0, $112 = 0, $116 = 0, $12 = 0, $123 = 0, $124 = 0, $126 = 0, $128 = 0, $13 = 0, $132 = 0, $137 = 0, $138 = 0, $14 = 0, $143 = 0, $146 = 0, $151 = 0, $152 = 0, $157 = 0, $164 = 0, $165 = 0, $176 = 0, $188 = 0, $195 = 0, $197 = 0, $20 = 0, $200 = 0, $202 = 0, $21 = 0, $210 = 0, $212 = 0, $215 = 0, $216 = 0, $220 = 0, $224 = 0, $226 = 0, $229 = 0, $23 = 0, $231 = 0, $232 = 0, $233 = 0, $24 = 0, $242 = 0, $243 = 0, $248 = 0, $25 = 0, $250 = 0, $251 = 0, $257 = 0, $269 = 0, $27 = 0, $272 = 0, $273 = 0, $285 = 0, $287 = 0, $292 = 0, $296 = 0, $298 = 0, $30 = 0, $31 = 0, $310 = 0, $312 = 0, $319 = 0, $329 = 0, $330 = 0, $331 = 0, $36 = 0, $38 = 0, $39 = 0, $44 = 0, $46 = 0, $48 = 0, $5 = 0, $50 = 0, $51 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $91 = 0, $94 = 0, $99 = 0, $isdigittmp = 0, $isdigittmp274 = 0, $isdigittmp276 = 0, $or$cond = 0, $or$cond283 = 0, $storemerge = 0, $storemerge273310 = 0, $storemerge278 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 56340
 STACKTOP = STACKTOP + 64 | 0; //@line 56341
 $5 = sp + 16 | 0; //@line 56342
 $6 = sp; //@line 56343
 $7 = sp + 24 | 0; //@line 56344
 $8 = sp + 8 | 0; //@line 56345
 $9 = sp + 20 | 0; //@line 56346
 HEAP32[$5 >> 2] = $1; //@line 56347
 $10 = ($0 | 0) != 0; //@line 56348
 $11 = $7 + 40 | 0; //@line 56349
 $12 = $11; //@line 56350
 $13 = $7 + 39 | 0; //@line 56351
 $14 = $8 + 4 | 0; //@line 56352
 $$0243 = 0; //@line 56353
 $$0247 = 0; //@line 56353
 $$0269 = 0; //@line 56353
 $21 = $1; //@line 56353
 L1 : while (1) {
  do {
   if (($$0247 | 0) > -1) {
    if (($$0243 | 0) > (2147483647 - $$0247 | 0)) {
     HEAP32[(___errno_location() | 0) >> 2] = 75; //@line 56362
     $$1248 = -1; //@line 56363
     break;
    } else {
     $$1248 = $$0243 + $$0247 | 0; //@line 56367
     break;
    }
   } else {
    $$1248 = $$0247; //@line 56371
   }
  } while (0);
  $20 = HEAP8[$21 >> 0] | 0; //@line 56374
  if (!($20 << 24 >> 24)) {
   label = 87; //@line 56377
   break;
  } else {
   $23 = $20; //@line 56380
   $25 = $21; //@line 56380
  }
  L9 : while (1) {
   switch ($23 << 24 >> 24) {
   case 37:
    {
     $$0249306 = $25; //@line 56385
     $27 = $25; //@line 56385
     label = 9; //@line 56386
     break L9;
     break;
    }
   case 0:
    {
     $$0249$lcssa = $25; //@line 56391
     $39 = $25; //@line 56391
     break L9;
     break;
    }
   default:
    {}
   }
   $24 = $25 + 1 | 0; //@line 56398
   HEAP32[$5 >> 2] = $24; //@line 56399
   $23 = HEAP8[$24 >> 0] | 0; //@line 56401
   $25 = $24; //@line 56401
  }
  L12 : do {
   if ((label | 0) == 9) {
    while (1) {
     label = 0; //@line 56406
     if ((HEAP8[$27 + 1 >> 0] | 0) != 37) {
      $$0249$lcssa = $$0249306; //@line 56411
      $39 = $27; //@line 56411
      break L12;
     }
     $30 = $$0249306 + 1 | 0; //@line 56414
     $31 = $27 + 2 | 0; //@line 56415
     HEAP32[$5 >> 2] = $31; //@line 56416
     if ((HEAP8[$31 >> 0] | 0) == 37) {
      $$0249306 = $30; //@line 56420
      $27 = $31; //@line 56420
      label = 9; //@line 56421
     } else {
      $$0249$lcssa = $30; //@line 56423
      $39 = $31; //@line 56423
      break;
     }
    }
   }
  } while (0);
  $36 = $$0249$lcssa - $21 | 0; //@line 56431
  if ($10) {
   _out($0, $21, $36); //@line 56433
  }
  if ($36 | 0) {
   $$0243 = $36; //@line 56437
   $$0247 = $$1248; //@line 56437
   $21 = $39; //@line 56437
   continue;
  }
  $38 = $39 + 1 | 0; //@line 56440
  $isdigittmp = (HEAP8[$38 >> 0] | 0) + -48 | 0; //@line 56443
  if ($isdigittmp >>> 0 < 10) {
   $44 = (HEAP8[$39 + 2 >> 0] | 0) == 36; //@line 56448
   $$0253 = $44 ? $isdigittmp : -1; //@line 56453
   $$1270 = $44 ? 1 : $$0269; //@line 56453
   $storemerge = $44 ? $39 + 3 | 0 : $38; //@line 56453
  } else {
   $$0253 = -1; //@line 56455
   $$1270 = $$0269; //@line 56455
   $storemerge = $38; //@line 56455
  }
  HEAP32[$5 >> 2] = $storemerge; //@line 56457
  $46 = HEAP8[$storemerge >> 0] | 0; //@line 56458
  $48 = ($46 << 24 >> 24) + -32 | 0; //@line 56460
  L24 : do {
   if ($48 >>> 0 < 32) {
    $$0262311 = 0; //@line 56464
    $329 = $46; //@line 56464
    $51 = $48; //@line 56464
    $storemerge273310 = $storemerge; //@line 56464
    while (1) {
     $50 = 1 << $51; //@line 56466
     if (!($50 & 75913)) {
      $$0262$lcssa = $$0262311; //@line 56470
      $$lcssa295 = $329; //@line 56470
      $62 = $storemerge273310; //@line 56470
      break L24;
     }
     $54 = $50 | $$0262311; //@line 56473
     $55 = $storemerge273310 + 1 | 0; //@line 56474
     HEAP32[$5 >> 2] = $55; //@line 56475
     $56 = HEAP8[$55 >> 0] | 0; //@line 56476
     $51 = ($56 << 24 >> 24) + -32 | 0; //@line 56478
     if ($51 >>> 0 >= 32) {
      $$0262$lcssa = $54; //@line 56483
      $$lcssa295 = $56; //@line 56483
      $62 = $55; //@line 56483
      break;
     } else {
      $$0262311 = $54; //@line 56481
      $329 = $56; //@line 56481
      $storemerge273310 = $55; //@line 56481
     }
    }
   } else {
    $$0262$lcssa = 0; //@line 56488
    $$lcssa295 = $46; //@line 56488
    $62 = $storemerge; //@line 56488
   }
  } while (0);
  if ($$lcssa295 << 24 >> 24 == 42) {
   $61 = $62 + 1 | 0; //@line 56493
   $isdigittmp276 = (HEAP8[$61 >> 0] | 0) + -48 | 0; //@line 56496
   if ($isdigittmp276 >>> 0 < 10) {
    if ((HEAP8[$62 + 2 >> 0] | 0) == 36) {
     HEAP32[$4 + ($isdigittmp276 << 2) >> 2] = 10; //@line 56504
     $$0259 = HEAP32[$3 + ((HEAP8[$61 >> 0] | 0) + -48 << 3) >> 2] | 0; //@line 56516
     $$2271 = 1; //@line 56516
     $storemerge278 = $62 + 3 | 0; //@line 56516
    } else {
     label = 23; //@line 56518
    }
   } else {
    label = 23; //@line 56521
   }
   if ((label | 0) == 23) {
    label = 0; //@line 56524
    if ($$1270 | 0) {
     $$0 = -1; //@line 56527
     break;
    }
    if ($10) {
     $86 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 56542
     $87 = HEAP32[$86 >> 2] | 0; //@line 56543
     HEAP32[$2 >> 2] = $86 + 4; //@line 56545
     $$0259 = $87; //@line 56546
     $$2271 = 0; //@line 56546
     $storemerge278 = $61; //@line 56546
    } else {
     $$0259 = 0; //@line 56548
     $$2271 = 0; //@line 56548
     $storemerge278 = $61; //@line 56548
    }
   }
   HEAP32[$5 >> 2] = $storemerge278; //@line 56551
   $88 = ($$0259 | 0) < 0; //@line 56552
   $$1260 = $88 ? 0 - $$0259 | 0 : $$0259; //@line 56557
   $$1263 = $88 ? $$0262$lcssa | 8192 : $$0262$lcssa; //@line 56557
   $$3272 = $$2271; //@line 56557
   $94 = $storemerge278; //@line 56557
  } else {
   $91 = _getint($5) | 0; //@line 56559
   if (($91 | 0) < 0) {
    $$0 = -1; //@line 56562
    break;
   }
   $$1260 = $91; //@line 56566
   $$1263 = $$0262$lcssa; //@line 56566
   $$3272 = $$1270; //@line 56566
   $94 = HEAP32[$5 >> 2] | 0; //@line 56566
  }
  do {
   if ((HEAP8[$94 >> 0] | 0) == 46) {
    if ((HEAP8[$94 + 1 >> 0] | 0) != 42) {
     HEAP32[$5 >> 2] = $94 + 1; //@line 56577
     $126 = _getint($5) | 0; //@line 56578
     $$0254 = $126; //@line 56580
     $$pre347 = HEAP32[$5 >> 2] | 0; //@line 56580
     break;
    }
    $99 = $94 + 2 | 0; //@line 56583
    $isdigittmp274 = (HEAP8[$99 >> 0] | 0) + -48 | 0; //@line 56586
    if ($isdigittmp274 >>> 0 < 10) {
     if ((HEAP8[$94 + 3 >> 0] | 0) == 36) {
      HEAP32[$4 + ($isdigittmp274 << 2) >> 2] = 10; //@line 56594
      $112 = HEAP32[$3 + ((HEAP8[$99 >> 0] | 0) + -48 << 3) >> 2] | 0; //@line 56601
      $116 = $94 + 4 | 0; //@line 56605
      HEAP32[$5 >> 2] = $116; //@line 56606
      $$0254 = $112; //@line 56607
      $$pre347 = $116; //@line 56607
      break;
     }
    }
    if ($$3272 | 0) {
     $$0 = -1; //@line 56613
     break L1;
    }
    if ($10) {
     $123 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 56628
     $124 = HEAP32[$123 >> 2] | 0; //@line 56629
     HEAP32[$2 >> 2] = $123 + 4; //@line 56631
     $330 = $124; //@line 56632
    } else {
     $330 = 0; //@line 56634
    }
    HEAP32[$5 >> 2] = $99; //@line 56636
    $$0254 = $330; //@line 56637
    $$pre347 = $99; //@line 56637
   } else {
    $$0254 = -1; //@line 56639
    $$pre347 = $94; //@line 56639
   }
  } while (0);
  $$0252 = 0; //@line 56642
  $128 = $$pre347; //@line 56642
  while (1) {
   if (((HEAP8[$128 >> 0] | 0) + -65 | 0) >>> 0 > 57) {
    $$0 = -1; //@line 56649
    break L1;
   }
   $132 = $128 + 1 | 0; //@line 56652
   HEAP32[$5 >> 2] = $132; //@line 56653
   $137 = HEAP8[(HEAP8[$128 >> 0] | 0) + -65 + (110062 + ($$0252 * 58 | 0)) >> 0] | 0; //@line 56658
   $138 = $137 & 255; //@line 56659
   if (($138 + -1 | 0) >>> 0 < 8) {
    $$0252 = $138; //@line 56663
    $128 = $132; //@line 56663
   } else {
    break;
   }
  }
  if (!($137 << 24 >> 24)) {
   $$0 = -1; //@line 56670
   break;
  }
  $143 = ($$0253 | 0) > -1; //@line 56674
  do {
   if ($137 << 24 >> 24 == 19) {
    if ($143) {
     $$0 = -1; //@line 56678
     break L1;
    } else {
     label = 49; //@line 56681
    }
   } else {
    if ($143) {
     HEAP32[$4 + ($$0253 << 2) >> 2] = $138; //@line 56686
     $146 = $3 + ($$0253 << 3) | 0; //@line 56688
     $151 = HEAP32[$146 + 4 >> 2] | 0; //@line 56693
     $152 = $6; //@line 56694
     HEAP32[$152 >> 2] = HEAP32[$146 >> 2]; //@line 56696
     HEAP32[$152 + 4 >> 2] = $151; //@line 56699
     label = 49; //@line 56700
     break;
    }
    if (!$10) {
     $$0 = 0; //@line 56704
     break L1;
    }
    _pop_arg($6, $138, $2); //@line 56707
   }
  } while (0);
  if ((label | 0) == 49) {
   label = 0; //@line 56711
   if (!$10) {
    $$0243 = 0; //@line 56713
    $$0247 = $$1248; //@line 56713
    $$0269 = $$3272; //@line 56713
    $21 = $132; //@line 56713
    continue;
   }
  }
  $157 = HEAP8[$128 >> 0] | 0; //@line 56718
  $$0235 = ($$0252 | 0) != 0 & ($157 & 15 | 0) == 3 ? $157 & -33 : $157; //@line 56724
  $164 = $$1263 & -65537; //@line 56727
  $$1263$ = ($$1263 & 8192 | 0) == 0 ? $$1263 : $164; //@line 56728
  L71 : do {
   switch ($$0235 | 0) {
   case 110:
    {
     switch (($$0252 & 255) << 24 >> 24) {
     case 0:
      {
       HEAP32[HEAP32[$6 >> 2] >> 2] = $$1248; //@line 56736
       $$0243 = 0; //@line 56737
       $$0247 = $$1248; //@line 56737
       $$0269 = $$3272; //@line 56737
       $21 = $132; //@line 56737
       continue L1;
       break;
      }
     case 1:
      {
       HEAP32[HEAP32[$6 >> 2] >> 2] = $$1248; //@line 56743
       $$0243 = 0; //@line 56744
       $$0247 = $$1248; //@line 56744
       $$0269 = $$3272; //@line 56744
       $21 = $132; //@line 56744
       continue L1;
       break;
      }
     case 2:
      {
       $176 = HEAP32[$6 >> 2] | 0; //@line 56752
       HEAP32[$176 >> 2] = $$1248; //@line 56754
       HEAP32[$176 + 4 >> 2] = (($$1248 | 0) < 0) << 31 >> 31; //@line 56757
       $$0243 = 0; //@line 56758
       $$0247 = $$1248; //@line 56758
       $$0269 = $$3272; //@line 56758
       $21 = $132; //@line 56758
       continue L1;
       break;
      }
     case 3:
      {
       HEAP16[HEAP32[$6 >> 2] >> 1] = $$1248; //@line 56765
       $$0243 = 0; //@line 56766
       $$0247 = $$1248; //@line 56766
       $$0269 = $$3272; //@line 56766
       $21 = $132; //@line 56766
       continue L1;
       break;
      }
     case 4:
      {
       HEAP8[HEAP32[$6 >> 2] >> 0] = $$1248; //@line 56773
       $$0243 = 0; //@line 56774
       $$0247 = $$1248; //@line 56774
       $$0269 = $$3272; //@line 56774
       $21 = $132; //@line 56774
       continue L1;
       break;
      }
     case 6:
      {
       HEAP32[HEAP32[$6 >> 2] >> 2] = $$1248; //@line 56780
       $$0243 = 0; //@line 56781
       $$0247 = $$1248; //@line 56781
       $$0269 = $$3272; //@line 56781
       $21 = $132; //@line 56781
       continue L1;
       break;
      }
     case 7:
      {
       $188 = HEAP32[$6 >> 2] | 0; //@line 56789
       HEAP32[$188 >> 2] = $$1248; //@line 56791
       HEAP32[$188 + 4 >> 2] = (($$1248 | 0) < 0) << 31 >> 31; //@line 56794
       $$0243 = 0; //@line 56795
       $$0247 = $$1248; //@line 56795
       $$0269 = $$3272; //@line 56795
       $21 = $132; //@line 56795
       continue L1;
       break;
      }
     default:
      {
       $$0243 = 0; //@line 56800
       $$0247 = $$1248; //@line 56800
       $$0269 = $$3272; //@line 56800
       $21 = $132; //@line 56800
       continue L1;
      }
     }
     break;
    }
   case 112:
    {
     $$1236 = 120; //@line 56810
     $$1255 = $$0254 >>> 0 > 8 ? $$0254 : 8; //@line 56810
     $$3265 = $$1263$ | 8; //@line 56810
     label = 61; //@line 56811
     break;
    }
   case 88:
   case 120:
    {
     $$1236 = $$0235; //@line 56815
     $$1255 = $$0254; //@line 56815
     $$3265 = $$1263$; //@line 56815
     label = 61; //@line 56816
     break;
    }
   case 111:
    {
     $210 = $6; //@line 56820
     $212 = HEAP32[$210 >> 2] | 0; //@line 56822
     $215 = HEAP32[$210 + 4 >> 2] | 0; //@line 56825
     $216 = _fmt_o($212, $215, $11) | 0; //@line 56826
     $220 = $12 - $216 | 0; //@line 56830
     $$0228 = $216; //@line 56835
     $$1233 = 0; //@line 56835
     $$1238 = 110526; //@line 56835
     $$2256 = ($$1263$ & 8 | 0) == 0 | ($$0254 | 0) > ($220 | 0) ? $$0254 : $220 + 1 | 0; //@line 56835
     $$4266 = $$1263$; //@line 56835
     $248 = $212; //@line 56835
     $250 = $215; //@line 56835
     label = 67; //@line 56836
     break;
    }
   case 105:
   case 100:
    {
     $224 = $6; //@line 56840
     $226 = HEAP32[$224 >> 2] | 0; //@line 56842
     $229 = HEAP32[$224 + 4 >> 2] | 0; //@line 56845
     if (($229 | 0) < 0) {
      $231 = _i64Subtract(0, 0, $226 | 0, $229 | 0) | 0; //@line 56848
      $232 = tempRet0; //@line 56849
      $233 = $6; //@line 56850
      HEAP32[$233 >> 2] = $231; //@line 56852
      HEAP32[$233 + 4 >> 2] = $232; //@line 56855
      $$0232 = 1; //@line 56856
      $$0237 = 110526; //@line 56856
      $242 = $231; //@line 56856
      $243 = $232; //@line 56856
      label = 66; //@line 56857
      break L71;
     } else {
      $$0232 = ($$1263$ & 2049 | 0) != 0 & 1; //@line 56869
      $$0237 = ($$1263$ & 2048 | 0) == 0 ? ($$1263$ & 1 | 0) == 0 ? 110526 : 110528 : 110527; //@line 56869
      $242 = $226; //@line 56869
      $243 = $229; //@line 56869
      label = 66; //@line 56870
      break L71;
     }
     break;
    }
   case 117:
    {
     $165 = $6; //@line 56876
     $$0232 = 0; //@line 56882
     $$0237 = 110526; //@line 56882
     $242 = HEAP32[$165 >> 2] | 0; //@line 56882
     $243 = HEAP32[$165 + 4 >> 2] | 0; //@line 56882
     label = 66; //@line 56883
     break;
    }
   case 99:
    {
     HEAP8[$13 >> 0] = HEAP32[$6 >> 2]; //@line 56894
     $$2 = $13; //@line 56895
     $$2234 = 0; //@line 56895
     $$2239 = 110526; //@line 56895
     $$2251 = $11; //@line 56895
     $$5 = 1; //@line 56895
     $$6268 = $164; //@line 56895
     break;
    }
   case 109:
    {
     $$1 = _strerror(HEAP32[(___errno_location() | 0) >> 2] | 0) | 0; //@line 56902
     label = 71; //@line 56903
     break;
    }
   case 115:
    {
     $269 = HEAP32[$6 >> 2] | 0; //@line 56907
     $$1 = $269 | 0 ? $269 : 110536; //@line 56910
     label = 71; //@line 56911
     break;
    }
   case 67:
    {
     HEAP32[$8 >> 2] = HEAP32[$6 >> 2]; //@line 56921
     HEAP32[$14 >> 2] = 0; //@line 56922
     HEAP32[$6 >> 2] = $8; //@line 56923
     $$4258355 = -1; //@line 56924
     $331 = $8; //@line 56924
     label = 75; //@line 56925
     break;
    }
   case 83:
    {
     $$pre349 = HEAP32[$6 >> 2] | 0; //@line 56929
     if (!$$0254) {
      _pad_684($0, 32, $$1260, 0, $$1263$); //@line 56932
      $$0240$lcssa357 = 0; //@line 56933
      label = 84; //@line 56934
     } else {
      $$4258355 = $$0254; //@line 56936
      $331 = $$pre349; //@line 56936
      label = 75; //@line 56937
     }
     break;
    }
   case 65:
   case 71:
   case 70:
   case 69:
   case 97:
   case 103:
   case 102:
   case 101:
    {
     $$0243 = _fmt_fp($0, +HEAPF64[$6 >> 3], $$1260, $$0254, $$1263$, $$0235) | 0; //@line 56944
     $$0247 = $$1248; //@line 56944
     $$0269 = $$3272; //@line 56944
     $21 = $132; //@line 56944
     continue L1;
     break;
    }
   default:
    {
     $$2 = $21; //@line 56949
     $$2234 = 0; //@line 56949
     $$2239 = 110526; //@line 56949
     $$2251 = $11; //@line 56949
     $$5 = $$0254; //@line 56949
     $$6268 = $$1263$; //@line 56949
    }
   }
  } while (0);
  L95 : do {
   if ((label | 0) == 61) {
    label = 0; //@line 56955
    $195 = $6; //@line 56956
    $197 = HEAP32[$195 >> 2] | 0; //@line 56958
    $200 = HEAP32[$195 + 4 >> 2] | 0; //@line 56961
    $202 = _fmt_x($197, $200, $11, $$1236 & 32) | 0; //@line 56963
    $or$cond283 = ($$3265 & 8 | 0) == 0 | ($197 | 0) == 0 & ($200 | 0) == 0; //@line 56969
    $$0228 = $202; //@line 56974
    $$1233 = $or$cond283 ? 0 : 2; //@line 56974
    $$1238 = $or$cond283 ? 110526 : 110526 + ($$1236 >> 4) | 0; //@line 56974
    $$2256 = $$1255; //@line 56974
    $$4266 = $$3265; //@line 56974
    $248 = $197; //@line 56974
    $250 = $200; //@line 56974
    label = 67; //@line 56975
   } else if ((label | 0) == 66) {
    label = 0; //@line 56978
    $$0228 = _fmt_u($242, $243, $11) | 0; //@line 56980
    $$1233 = $$0232; //@line 56980
    $$1238 = $$0237; //@line 56980
    $$2256 = $$0254; //@line 56980
    $$4266 = $$1263$; //@line 56980
    $248 = $242; //@line 56980
    $250 = $243; //@line 56980
    label = 67; //@line 56981
   } else if ((label | 0) == 71) {
    label = 0; //@line 56984
    $272 = _memchr($$1, 0, $$0254) | 0; //@line 56985
    $273 = ($272 | 0) == 0; //@line 56986
    $$2 = $$1; //@line 56993
    $$2234 = 0; //@line 56993
    $$2239 = 110526; //@line 56993
    $$2251 = $273 ? $$1 + $$0254 | 0 : $272; //@line 56993
    $$5 = $273 ? $$0254 : $272 - $$1 | 0; //@line 56993
    $$6268 = $164; //@line 56993
   } else if ((label | 0) == 75) {
    label = 0; //@line 56996
    $$0229322 = $331; //@line 56997
    $$0240321 = 0; //@line 56997
    $$1244320 = 0; //@line 56997
    while (1) {
     $285 = HEAP32[$$0229322 >> 2] | 0; //@line 56999
     if (!$285) {
      $$0240$lcssa = $$0240321; //@line 57002
      $$2245 = $$1244320; //@line 57002
      break;
     }
     $287 = _wctomb($9, $285) | 0; //@line 57005
     if (($287 | 0) < 0 | $287 >>> 0 > ($$4258355 - $$0240321 | 0) >>> 0) {
      $$0240$lcssa = $$0240321; //@line 57011
      $$2245 = $287; //@line 57011
      break;
     }
     $292 = $287 + $$0240321 | 0; //@line 57015
     if ($$4258355 >>> 0 > $292 >>> 0) {
      $$0229322 = $$0229322 + 4 | 0; //@line 57018
      $$0240321 = $292; //@line 57018
      $$1244320 = $287; //@line 57018
     } else {
      $$0240$lcssa = $292; //@line 57020
      $$2245 = $287; //@line 57020
      break;
     }
    }
    if (($$2245 | 0) < 0) {
     $$0 = -1; //@line 57026
     break L1;
    }
    _pad_684($0, 32, $$1260, $$0240$lcssa, $$1263$); //@line 57029
    if (!$$0240$lcssa) {
     $$0240$lcssa357 = 0; //@line 57032
     label = 84; //@line 57033
    } else {
     $$1230333 = $331; //@line 57035
     $$1241332 = 0; //@line 57035
     while (1) {
      $296 = HEAP32[$$1230333 >> 2] | 0; //@line 57037
      if (!$296) {
       $$0240$lcssa357 = $$0240$lcssa; //@line 57040
       label = 84; //@line 57041
       break L95;
      }
      $298 = _wctomb($9, $296) | 0; //@line 57044
      $$1241332 = $298 + $$1241332 | 0; //@line 57045
      if (($$1241332 | 0) > ($$0240$lcssa | 0)) {
       $$0240$lcssa357 = $$0240$lcssa; //@line 57048
       label = 84; //@line 57049
       break L95;
      }
      _out($0, $9, $298); //@line 57053
      if ($$1241332 >>> 0 >= $$0240$lcssa >>> 0) {
       $$0240$lcssa357 = $$0240$lcssa; //@line 57058
       label = 84; //@line 57059
       break;
      } else {
       $$1230333 = $$1230333 + 4 | 0; //@line 57056
      }
     }
    }
   }
  } while (0);
  if ((label | 0) == 67) {
   label = 0; //@line 57067
   $251 = ($248 | 0) != 0 | ($250 | 0) != 0; //@line 57073
   $or$cond = ($$2256 | 0) != 0 | $251; //@line 57075
   $257 = (($251 ^ 1) & 1) + ($12 - $$0228) | 0; //@line 57080
   $$2 = $or$cond ? $$0228 : $11; //@line 57085
   $$2234 = $$1233; //@line 57085
   $$2239 = $$1238; //@line 57085
   $$2251 = $11; //@line 57085
   $$5 = $or$cond ? ($$2256 | 0) > ($257 | 0) ? $$2256 : $257 : $$2256; //@line 57085
   $$6268 = ($$2256 | 0) > -1 ? $$4266 & -65537 : $$4266; //@line 57085
  } else if ((label | 0) == 84) {
   label = 0; //@line 57088
   _pad_684($0, 32, $$1260, $$0240$lcssa357, $$1263$ ^ 8192); //@line 57090
   $$0243 = ($$1260 | 0) > ($$0240$lcssa357 | 0) ? $$1260 : $$0240$lcssa357; //@line 57093
   $$0247 = $$1248; //@line 57093
   $$0269 = $$3272; //@line 57093
   $21 = $132; //@line 57093
   continue;
  }
  $310 = $$2251 - $$2 | 0; //@line 57098
  $$$5 = ($$5 | 0) < ($310 | 0) ? $310 : $$5; //@line 57100
  $312 = $$$5 + $$2234 | 0; //@line 57101
  $$2261 = ($$1260 | 0) < ($312 | 0) ? $312 : $$1260; //@line 57103
  _pad_684($0, 32, $$2261, $312, $$6268); //@line 57104
  _out($0, $$2239, $$2234); //@line 57105
  _pad_684($0, 48, $$2261, $312, $$6268 ^ 65536); //@line 57107
  _pad_684($0, 48, $$$5, $310, 0); //@line 57108
  _out($0, $$2, $310); //@line 57109
  _pad_684($0, 32, $$2261, $312, $$6268 ^ 8192); //@line 57111
  $$0243 = $$2261; //@line 57112
  $$0247 = $$1248; //@line 57112
  $$0269 = $$3272; //@line 57112
  $21 = $132; //@line 57112
 }
 L114 : do {
  if ((label | 0) == 87) {
   if (!$0) {
    if (!$$0269) {
     $$0 = 0; //@line 57120
    } else {
     $$2242305 = 1; //@line 57122
     while (1) {
      $319 = HEAP32[$4 + ($$2242305 << 2) >> 2] | 0; //@line 57125
      if (!$319) {
       $$3303 = $$2242305; //@line 57128
       break;
      }
      _pop_arg($3 + ($$2242305 << 3) | 0, $319, $2); //@line 57132
      $$2242305 = $$2242305 + 1 | 0; //@line 57133
      if (($$2242305 | 0) >= 10) {
       $$0 = 1; //@line 57138
       break L114;
      }
     }
     while (1) {
      if (HEAP32[$4 + ($$3303 << 2) >> 2] | 0) {
       $$0 = -1; //@line 57148
       break L114;
      }
      $$3303 = $$3303 + 1 | 0; //@line 57146
      if (($$3303 | 0) >= 10) {
       $$0 = 1; //@line 57155
       break;
      }
     }
    }
   } else {
    $$0 = $$1248; //@line 57161
   }
  }
 } while (0);
 STACKTOP = sp; //@line 57165
 return $$0 | 0; //@line 57165
}
function __ZN12monitor_desc14driver_controlEtjj($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$$1175 = 0, $$0$i = 0, $$0166219 = 0, $$0166219$us = 0, $$0168221 = 0, $$0168221$us = 0, $$0169 = 0, $$0170224 = 0, $$0171229 = 0, $$0172 = 0, $$0174228 = 0, $$0177226 = 0, $$0178 = 0, $$0180 = 0, $$0182 = 0, $$0184 = 0, $$0186220 = 0, $$0186220$us = 0, $$0187 = 0, $$0189 = 0, $$0191 = 0, $$0193218 = 0, $$0193218$us = 0, $$0194$off0 = 0, $$0195 = 0, $$1167222 = 0, $$1167222$us = 0, $$1173 = 0, $$1175$lcssa = 0, $$1175223 = 0, $$1179 = 0, $$1181 = 0, $$1181$us = 0, $$1183 = 0, $$1183$us = 0, $$1185 = 0, $$1185$us = 0, $$1188 = 0, $$1188$us = 0, $$1190 = 0, $$1190$us = 0, $$1192 = 0, $$1192$us = 0, $$7 = 0, $$byval_copy1 = 0, $$lcssa = 0, $$sroa$04$09$i = 0, $$sroa$04$09$i202 = 0, $107 = 0, $113 = 0, $114 = 0, $117 = 0, $12 = 0, $124 = 0, $126 = 0, $127 = 0, $13 = 0, $136 = 0, $137 = 0, $144 = 0, $146 = 0, $153 = 0, $155 = 0, $162 = 0, $188 = 0, $189 = 0, $196 = 0, $198 = 0, $205 = 0, $207 = 0, $21 = 0, $214 = 0, $227 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $257 = 0, $259 = 0, $266 = 0, $268 = 0, $275 = 0, $294 = 0, $301 = 0, $303 = 0, $310 = 0, $312 = 0, $319 = 0, $33 = 0, $332 = 0, $35 = 0, $352 = 0, $353 = 0, $362 = 0, $37 = 0, $370 = 0, $371 = 0, $373 = 0, $382 = 0, $384 = 0, $387 = 0, $389 = 0, $397 = 0, $4 = 0, $404 = 0, $406 = 0, $440 = 0, $441 = 0, $446 = 0, $447 = 0, $455 = 0, $47 = 0, $470 = 0, $472 = 0, $482 = 0, $492 = 0, $493 = 0, $498 = 0, $5 = 0, $51 = 0, $56 = 0, $61 = 0, $62 = 0, $68 = 0, $69 = 0, $75 = 0, $77 = 0, $79 = 0, $80 = 0, $83 = 0, $90 = 0, $96 = 0, $98 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 24490
 STACKTOP = STACKTOP + 16 | 0; //@line 24491
 $$byval_copy1 = sp + 12 | 0; //@line 24492
 $vararg_buffer = sp; //@line 24493
 $4 = sp + 8 | 0; //@line 24494
 $5 = sp + 4 | 0; //@line 24495
 do {
  switch ($1 << 16 >> 16) {
  case 2:
   {
    $12 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 65535; //@line 24505
    $13 = $2 + 8 | 0; //@line 24506
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, HEAP32[$0 + 20 >> 2] | 0); //@line 24514
    $21 = $2 + 6 | 0; //@line 24515
    if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($21) | 0) {
     $$7 = -50; //@line 24524
     STACKTOP = sp; //@line 24525
     return $$7 | 0; //@line 24525
    }
    if ((HEAP16[$0 + 804 >> 1] | 0) == $12 << 16 >> 16) {
     $$7 = 0; //@line 24531
     STACKTOP = sp; //@line 24532
     return $$7 | 0; //@line 24532
    }
    $33 = HEAP32[$0 + 808 >> 2] | 0; //@line 24535
    $35 = HEAP32[$0 + 8 >> 2] | 0; //@line 24537
    $37 = HEAP32[$0 + 4 >> 2] | 0; //@line 24539
    if (($37 | 0) == ($35 | 0)) {
     $$7 = -50; //@line 24542
     STACKTOP = sp; //@line 24543
     return $$7 | 0; //@line 24543
    } else {
     $$sroa$04$09$i = $37; //@line 24545
    }
    while (1) {
     if ((HEAP32[$$sroa$04$09$i + 8 >> 2] | 0) == ($33 | 0)) {
      if ((HEAP16[$0 + 824 + (HEAP32[$$sroa$04$09$i + 12 >> 2] << 1) >> 1] | 0) == $12 << 16 >> 16) {
       break;
      }
     }
     $47 = $$sroa$04$09$i + 24 | 0; //@line 24561
     if (($47 | 0) == ($35 | 0)) {
      $$7 = -50; //@line 24564
      label = 69; //@line 24565
      break;
     } else {
      $$sroa$04$09$i = $47; //@line 24568
     }
    }
    if ((label | 0) == 69) {
     STACKTOP = sp; //@line 24572
     return $$7 | 0; //@line 24572
    }
    if (($$sroa$04$09$i | 0) == ($35 | 0)) {
     $$7 = -50; //@line 24576
     STACKTOP = sp; //@line 24577
     return $$7 | 0; //@line 24577
    }
    HEAP32[$4 >> 2] = $$sroa$04$09$i; //@line 24580
    HEAP32[$$byval_copy1 >> 2] = HEAP32[$4 >> 2]; //@line 24581
    __ZN12monitor_desc11switch_modeENSt3__211__wrap_iterIPK10video_modeEEjj($0, $$byval_copy1, $2, $3); //@line 24582
    $$7 = 0; //@line 24583
    STACKTOP = sp; //@line 24584
    return $$7 | 0; //@line 24584
   }
  case 8:
  case 3:
   {
    $51 = $0 + 16 | 0; //@line 24588
    $56 = (HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] | 1 | 0) == 5; //@line 24593
    if (!(($1 << 16 >> 16 != 3 | $56 ^ 1) & ($1 << 16 >> 16 != 8 | $56))) {
     $$7 = -17; //@line 24601
     STACKTOP = sp; //@line 24602
     return $$7 | 0; //@line 24602
    }
    $61 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0; //@line 24608
    $62 = $2 + 4 | 0; //@line 24609
    $68 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($62 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($62) | 0; //@line 24615
    $69 = $2 + 6 | 0; //@line 24616
    $75 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($69 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($69) | 0; //@line 24622
    if (!$61) {
     $$7 = -50; //@line 24625
     STACKTOP = sp; //@line 24626
     return $$7 | 0; //@line 24626
    }
    $77 = $75 & 65535; //@line 24628
    if ($77 >>> 0 > 255) {
     $$7 = -50; //@line 24631
     STACKTOP = sp; //@line 24632
     return $$7 | 0; //@line 24632
    }
    $79 = $0 + 796 | 0; //@line 24634
    $80 = HEAP32[$79 >> 2] | 0; //@line 24635
    if (!$80) {
     $$0169 = 0; //@line 24638
     $$0194$off0 = 0; //@line 24638
     $$0195 = 0; //@line 24638
     $$1173 = 0; //@line 24638
     $$1179 = 0; //@line 24638
    } else {
     $83 = $80 + 4 | 0; //@line 24641
     $90 = $80 + 12 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($83 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($83) | 0) | 0; //@line 24648
     $96 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($90 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($90) | 0; //@line 24654
     $98 = (HEAP32[$79 >> 2] | 0) + 6 | 0; //@line 24656
     if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($98 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($98) | 0) == 1) {
      $$0172 = $96; //@line 24665
      $$0178 = $96; //@line 24665
     } else {
      $107 = (HEAP32[$79 >> 2] | 0) + 8 | 0; //@line 24668
      $113 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($107 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($107) | 0; //@line 24674
      $114 = $96 + $113 | 0; //@line 24675
      $$0172 = $114; //@line 24677
      $$0178 = $114 + $113 | 0; //@line 24677
     }
     $117 = (HEAP32[$79 >> 2] | 0) + 10 | 0; //@line 24680
     $$0169 = $96; //@line 24687
     $$0194$off0 = 1; //@line 24687
     $$0195 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($117 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($117) | 0; //@line 24687
     $$1173 = $$0172; //@line 24687
     $$1179 = $$0178; //@line 24687
    }
    $124 = $68 & 65535; //@line 24689
    L41 : do {
     if (($124 | 0) == 65535) {
      $126 = $0 + 793 | 0; //@line 24693
      $127 = 8 - $$0195 | 0; //@line 24694
      if ($56) {
       $$0166219$us = $61; //@line 24696
       $$0193218$us = 0; //@line 24696
       while (1) {
        $136 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$0166219$us >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$0166219$us) | 0) & 255) * 3 | 0) + ($0 + 25) | 0; //@line 24706
        $137 = $$0166219$us + 2 | 0; //@line 24707
        $144 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($137 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($137) | 0) >>> 8; //@line 24714
        $146 = $$0166219$us + 4 | 0; //@line 24716
        $153 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($146 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($146) | 0) >>> 8; //@line 24723
        $155 = $$0166219$us + 6 | 0; //@line 24725
        $162 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($155 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($155) | 0) >>> 8; //@line 24732
        if ($$0194$off0) {
         $$1188$us = HEAP8[$$1179 + (($162 & 255) >>> $127) >> 0] | 0; //@line 24747
         $$1190$us = HEAP8[$$1173 + (($153 & 255) >>> $127) >> 0] | 0; //@line 24747
         $$1192$us = HEAP8[$$0169 + (($144 & 255) >>> $127) >> 0] | 0; //@line 24747
        } else {
         $$1188$us = $162 & 255; //@line 24749
         $$1190$us = $153 & 255; //@line 24749
         $$1192$us = $144 & 255; //@line 24749
        }
        HEAP8[$136 >> 0] = $$1192$us; //@line 24752
        HEAP8[$136 + 1 >> 0] = $$1190$us; //@line 24754
        HEAP8[$136 + 2 >> 0] = $$1188$us; //@line 24755
        if (($$0193218$us | 0) == ($77 | 0)) {
         break L41;
        } else {
         $$0166219$us = $$0166219$us + 8 | 0; //@line 24762
         $$0193218$us = $$0193218$us + 1 | 0; //@line 24762
        }
       }
      } else {
       $$0166219 = $61; //@line 24766
       $$0193218 = 0; //@line 24766
      }
      while (1) {
       $188 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$0166219 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$0166219) | 0) & 255) * 3 | 0) + ($0 + 25) | 0; //@line 24777
       $189 = $$0166219 + 2 | 0; //@line 24778
       $196 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($189 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($189) | 0) >>> 8; //@line 24785
       $198 = $$0166219 + 4 | 0; //@line 24787
       $205 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($198 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($198) | 0) >>> 8; //@line 24794
       $207 = $$0166219 + 6 | 0; //@line 24796
       $214 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($207 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($207) | 0) >>> 8; //@line 24803
       if (!(HEAP8[$126 >> 0] | 0)) {
        $$0187 = $214 & 255; //@line 24808
        $$0189 = $205 & 255; //@line 24808
        $$0191 = $196 & 255; //@line 24808
       } else {
        $227 = ((($205 & 255) * 38666 | 0) + (($196 & 255) * 19660 | 0) + (($214 & 255) * 7209 | 0) | 0) >>> 16 & 255; //@line 24819
        $$0187 = $227; //@line 24820
        $$0189 = $227; //@line 24820
        $$0191 = $227; //@line 24820
       }
       if ($$0194$off0) {
        $$1188 = HEAP8[$$1179 + (($$0187 & 255) >>> $127) >> 0] | 0; //@line 24835
        $$1190 = HEAP8[$$1173 + (($$0189 & 255) >>> $127) >> 0] | 0; //@line 24835
        $$1192 = HEAP8[$$0169 + (($$0191 & 255) >>> $127) >> 0] | 0; //@line 24835
       } else {
        $$1188 = $$0187; //@line 24837
        $$1190 = $$0189; //@line 24837
        $$1192 = $$0191; //@line 24837
       }
       HEAP8[$188 >> 0] = $$1192; //@line 24840
       HEAP8[$188 + 1 >> 0] = $$1190; //@line 24842
       HEAP8[$188 + 2 >> 0] = $$1188; //@line 24843
       if (($$0193218 | 0) == ($77 | 0)) {
        break;
       } else {
        $$0166219 = $$0166219 + 8 | 0; //@line 24850
        $$0193218 = $$0193218 + 1 | 0; //@line 24850
       }
      }
     } else {
      if (($77 + $124 | 0) >>> 0 > 255) {
       $$7 = -50; //@line 24857
       STACKTOP = sp; //@line 24858
       return $$7 | 0; //@line 24858
      }
      $247 = ($124 * 3 | 0) + ($0 + 25) | 0; //@line 24861
      $248 = $0 + 793 | 0; //@line 24862
      $249 = 8 - $$0195 | 0; //@line 24863
      if ($56) {
       $$0168221$us = $247; //@line 24865
       $$0186220$us = 0; //@line 24865
       $$1167222$us = $61; //@line 24865
       while (1) {
        $250 = $$1167222$us + 2 | 0; //@line 24867
        $257 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($250 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($250) | 0) >>> 8; //@line 24874
        $259 = $$1167222$us + 4 | 0; //@line 24876
        $266 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($259 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($259) | 0) >>> 8; //@line 24883
        $268 = $$1167222$us + 6 | 0; //@line 24885
        $275 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($268 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($268) | 0) >>> 8; //@line 24892
        if ($$0194$off0) {
         $$1181$us = HEAP8[$$1179 + (($275 & 255) >>> $249) >> 0] | 0; //@line 24907
         $$1183$us = HEAP8[$$1173 + (($266 & 255) >>> $249) >> 0] | 0; //@line 24907
         $$1185$us = HEAP8[$$0169 + (($257 & 255) >>> $249) >> 0] | 0; //@line 24907
        } else {
         $$1181$us = $275 & 255; //@line 24909
         $$1183$us = $266 & 255; //@line 24909
         $$1185$us = $257 & 255; //@line 24909
        }
        HEAP8[$$0168221$us >> 0] = $$1185$us; //@line 24912
        HEAP8[$$0168221$us + 1 >> 0] = $$1183$us; //@line 24914
        HEAP8[$$0168221$us + 2 >> 0] = $$1181$us; //@line 24916
        if (($$0186220$us | 0) == ($77 | 0)) {
         break L41;
        } else {
         $$0168221$us = $$0168221$us + 3 | 0; //@line 24923
         $$0186220$us = $$0186220$us + 1 | 0; //@line 24923
         $$1167222$us = $$1167222$us + 8 | 0; //@line 24923
        }
       }
      } else {
       $$0168221 = $247; //@line 24927
       $$0186220 = 0; //@line 24927
       $$1167222 = $61; //@line 24927
      }
      while (1) {
       $294 = $$1167222 + 2 | 0; //@line 24930
       $301 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($294 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($294) | 0) >>> 8; //@line 24937
       $303 = $$1167222 + 4 | 0; //@line 24939
       $310 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($303 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($303) | 0) >>> 8; //@line 24946
       $312 = $$1167222 + 6 | 0; //@line 24948
       $319 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($312 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($312) | 0) >>> 8; //@line 24955
       if (!(HEAP8[$248 >> 0] | 0)) {
        $$0180 = $319 & 255; //@line 24960
        $$0182 = $310 & 255; //@line 24960
        $$0184 = $301 & 255; //@line 24960
       } else {
        $332 = ((($310 & 255) * 38666 | 0) + (($301 & 255) * 19660 | 0) + (($319 & 255) * 7209 | 0) | 0) >>> 16 & 255; //@line 24971
        $$0180 = $332; //@line 24972
        $$0182 = $332; //@line 24972
        $$0184 = $332; //@line 24972
       }
       if ($$0194$off0) {
        $$1181 = HEAP8[$$1179 + (($$0180 & 255) >>> $249) >> 0] | 0; //@line 24987
        $$1183 = HEAP8[$$1173 + (($$0182 & 255) >>> $249) >> 0] | 0; //@line 24987
        $$1185 = HEAP8[$$0169 + (($$0184 & 255) >>> $249) >> 0] | 0; //@line 24987
       } else {
        $$1181 = $$0180; //@line 24989
        $$1183 = $$0182; //@line 24989
        $$1185 = $$0184; //@line 24989
       }
       HEAP8[$$0168221 >> 0] = $$1185; //@line 24992
       HEAP8[$$0168221 + 1 >> 0] = $$1183; //@line 24994
       HEAP8[$$0168221 + 2 >> 0] = $$1181; //@line 24996
       if (($$0186220 | 0) == ($77 | 0)) {
        break;
       } else {
        $$0168221 = $$0168221 + 3 | 0; //@line 25003
        $$0186220 = $$0186220 + 1 | 0; //@line 25003
        $$1167222 = $$1167222 + 8 | 0; //@line 25003
       }
      }
     }
    } while (0);
    $352 = HEAP32[(HEAP32[$0 >> 2] | 0) + 12 >> 2] | 0; //@line 25010
    $353 = $0 + 25 | 0; //@line 25011
    switch (HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] | 0) {
    case 0:
     {
      $$0$i = 2; //@line 25017
      break;
     }
    case 1:
     {
      $$0$i = 4; //@line 25021
      break;
     }
    case 2:
     {
      $$0$i = 16; //@line 25025
      break;
     }
    case 3:
     {
      $$0$i = 256; //@line 25029
      break;
     }
    case 4:
     {
      $$0$i = 32; //@line 25033
      break;
     }
    case 5:
     {
      $$0$i = 256; //@line 25037
      break;
     }
    default:
     {
      $$0$i = 0; //@line 25041
     }
    }
    FUNCTION_TABLE_viii[$352 & 7]($0, $353, $$0$i); //@line 25044
    $$7 = 0; //@line 25045
    STACKTOP = sp; //@line 25046
    return $$7 | 0; //@line 25046
   }
  case 4:
   {
    __ZN12monitor_desc15set_gamma_tableEj($0, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($2 >>> 16 << 2) >> 2] >> 2] & 127]($2) | 0) | 0; //@line 25055
    $$7 = 0; //@line 25056
    STACKTOP = sp; //@line 25057
    return $$7 | 0; //@line 25057
   }
  case 5:
   {
    $362 = $2 + 6 | 0; //@line 25061
    if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($362 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($362) | 0) {
     $$7 = -50; //@line 25070
     STACKTOP = sp; //@line 25071
     return $$7 | 0; //@line 25071
    }
    $370 = $0 + 16 | 0; //@line 25073
    $371 = HEAP32[$370 >> 2] | 0; //@line 25074
    $373 = HEAP32[$371 + 12 >> 2] | 0; //@line 25076
    if (!(HEAP32[$371 + 4 >> 2] | 0)) {
     $389 = $373; //@line 25081
    } else {
     $382 = (($373 | 0) == 5) << 31 >> 31; //@line 25088
     $$0171229 = 0; //@line 25089
     $$0174228 = HEAP32[1508 + ($373 << 2) >> 2] | 0; //@line 25089
     $$0177226 = HEAP32[$0 + 20 >> 2] | 0; //@line 25089
     $384 = $371; //@line 25089
     while (1) {
      if (!(HEAP32[$384 + 16 >> 2] | 0)) {
       $$1175$lcssa = $$0174228; //@line 25095
       $$lcssa = 0; //@line 25095
       $387 = $384; //@line 25095
      } else {
       $$0170224 = 0; //@line 25097
       $$1175223 = $$0174228; //@line 25097
       while (1) {
        $397 = $$0170224 + $$0177226 | 0; //@line 25099
        FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($397 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($397, $$1175223); //@line 25105
        $$$1175 = $$1175223 ^ $382; //@line 25106
        $$0170224 = $$0170224 + 4 | 0; //@line 25107
        $404 = HEAP32[$370 >> 2] | 0; //@line 25108
        $406 = HEAP32[$404 + 16 >> 2] | 0; //@line 25110
        if ($$0170224 >>> 0 >= $406 >>> 0) {
         $$1175$lcssa = $$$1175; //@line 25115
         $$lcssa = $406; //@line 25115
         $387 = $404; //@line 25115
         break;
        } else {
         $$1175223 = $$$1175; //@line 25113
        }
       }
      }
      $$0171229 = $$0171229 + 1 | 0; //@line 25122
      if ($$0171229 >>> 0 >= (HEAP32[$387 + 4 >> 2] | 0) >>> 0) {
       break;
      } else {
       $$0174228 = ~$$1175$lcssa; //@line 25127
       $$0177226 = $$lcssa + $$0177226 | 0; //@line 25127
       $384 = $387; //@line 25127
      }
     }
     $389 = HEAP32[$387 + 12 >> 2] | 0; //@line 25134
    }
    if (($389 | 1 | 0) != 5) {
     $$7 = 0; //@line 25139
     STACKTOP = sp; //@line 25140
     return $$7 | 0; //@line 25140
    }
    __ZN12monitor_desc17load_ramp_paletteEv($0); //@line 25142
    $$7 = 0; //@line 25143
    STACKTOP = sp; //@line 25144
    return $$7 | 0; //@line 25144
   }
  case 6:
   {
    HEAP8[$0 + 793 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0) != 0 & 1; //@line 25157
    $$7 = 0; //@line 25158
    STACKTOP = sp; //@line 25159
    return $$7 | 0; //@line 25159
   }
  case 7:
   {
    HEAP8[$0 + 794 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0) == 0 & 1; //@line 25172
    $$7 = 0; //@line 25173
    STACKTOP = sp; //@line 25174
    return $$7 | 0; //@line 25174
   }
  case 9:
   {
    HEAP16[$0 + 812 >> 1] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0; //@line 25186
    $$7 = 0; //@line 25187
    STACKTOP = sp; //@line 25188
    return $$7 | 0; //@line 25188
   }
  case 10:
   {
    $440 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 65535; //@line 25198
    $441 = $2 + 2 | 0; //@line 25199
    $446 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($441 >>> 16 << 2) >> 2] >> 2] & 127]($441) | 0; //@line 25204
    $447 = $2 + 8 | 0; //@line 25205
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($447 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($447, HEAP32[$0 + 20 >> 2] | 0); //@line 25213
    $455 = $2 + 6 | 0; //@line 25214
    if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($455 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($455) | 0) {
     $$7 = -50; //@line 25223
     STACKTOP = sp; //@line 25224
     return $$7 | 0; //@line 25224
    }
    if ((HEAP16[$0 + 804 >> 1] | 0) == $440 << 16 >> 16) {
     if (($446 | 0) == (HEAP32[$0 + 808 >> 2] | 0)) {
      $$7 = 0; //@line 25234
      STACKTOP = sp; //@line 25235
      return $$7 | 0; //@line 25235
     }
    }
    $470 = HEAP32[$0 + 8 >> 2] | 0; //@line 25239
    $472 = HEAP32[$0 + 4 >> 2] | 0; //@line 25241
    if (($472 | 0) == ($470 | 0)) {
     $$7 = -50; //@line 25244
     STACKTOP = sp; //@line 25245
     return $$7 | 0; //@line 25245
    } else {
     $$sroa$04$09$i202 = $472; //@line 25247
    }
    while (1) {
     if ((HEAP32[$$sroa$04$09$i202 + 8 >> 2] | 0) == ($446 | 0)) {
      if ((HEAP16[$0 + 824 + (HEAP32[$$sroa$04$09$i202 + 12 >> 2] << 1) >> 1] | 0) == $440 << 16 >> 16) {
       break;
      }
     }
     $482 = $$sroa$04$09$i202 + 24 | 0; //@line 25263
     if (($482 | 0) == ($470 | 0)) {
      $$7 = -50; //@line 25266
      label = 69; //@line 25267
      break;
     } else {
      $$sroa$04$09$i202 = $482; //@line 25270
     }
    }
    if ((label | 0) == 69) {
     STACKTOP = sp; //@line 25274
     return $$7 | 0; //@line 25274
    }
    if (($$sroa$04$09$i202 | 0) == ($470 | 0)) {
     $$7 = -50; //@line 25278
     STACKTOP = sp; //@line 25279
     return $$7 | 0; //@line 25279
    }
    HEAP32[$5 >> 2] = $$sroa$04$09$i202; //@line 25282
    HEAP32[$$byval_copy1 >> 2] = HEAP32[$5 >> 2]; //@line 25283
    __ZN12monitor_desc11switch_modeENSt3__211__wrap_iterIPK10video_modeEEjj($0, $$byval_copy1, $2, $3); //@line 25284
    $$7 = 0; //@line 25285
    STACKTOP = sp; //@line 25286
    return $$7 | 0; //@line 25286
   }
  case 16:
   {
    $492 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 65535; //@line 25296
    $493 = $2 + 2 | 0; //@line 25297
    $498 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($493 >>> 16 << 2) >> 2] >> 2] & 127]($493) | 0; //@line 25302
    HEAP16[$0 + 812 >> 1] = $492; //@line 25304
    HEAP32[$0 + 816 >> 2] = $498; //@line 25306
    $$7 = 0; //@line 25307
    STACKTOP = sp; //@line 25308
    return $$7 | 0; //@line 25308
   }
  default:
   {
    HEAP32[$vararg_buffer >> 2] = $1 & 65535; //@line 25313
    _printf(96371, $vararg_buffer) | 0; //@line 25314
    $$7 = -17; //@line 25315
    STACKTOP = sp; //@line 25316
    return $$7 | 0; //@line 25316
   }
  }
 } while (0);
 return 0; //@line 25320
}
function __Z9VideoInitb($0) {
 $0 = $0 | 0;
 var $$ = 0, $$0 = 0, $$0$i116185 = 0, $$0$i116189193 = 0, $$0$i180 = 0, $$0$i184191 = 0, $$0101162 = 0, $$0105167 = 0, $$0106164 = 0, $$038$be$i = 0, $$03862$i = 0, $$03865$i = 0, $$042$off0$be$i = 0, $$042$off064$i = 0, $$096 = 0, $$098170 = 0, $$1 = 0, $$108 = 0, $$3 = 0, $$pn = 0, $$pr = 0, $$pr146 = 0, $$sink = 0, $$sink147160 = 0, $$sink148159 = 0, $1 = 0, $10 = 0, $101 = 0, $103 = 0, $108 = 0, $111 = 0, $115 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $127 = 0, $130 = 0, $136 = 0, $138 = 0, $14 = 0, $140 = 0, $141 = 0, $143 = 0, $144 = 0, $153 = 0, $158 = 0, $161 = 0, $167 = 0, $169 = 0, $17 = 0, $173 = 0, $174 = 0, $18 = 0, $181 = 0, $19 = 0, $2 = 0, $3 = 0, $34 = 0, $4 = 0, $48 = 0, $50 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $68 = 0, $7 = 0, $75 = 0, $78 = 0, $80 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $92 = 0, $95 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer14 = 0, $vararg_buffer18 = 0, $vararg_buffer2 = 0, $vararg_buffer22 = 0, $vararg_buffer6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 45278
 STACKTOP = STACKTOP + 944 | 0; //@line 45279
 $vararg_buffer22 = sp + 48 | 0; //@line 45280
 $vararg_buffer18 = sp + 40 | 0; //@line 45281
 $vararg_buffer14 = sp + 32 | 0; //@line 45282
 $vararg_buffer10 = sp + 24 | 0; //@line 45283
 $vararg_buffer6 = sp + 16 | 0; //@line 45284
 $vararg_buffer2 = sp + 8 | 0; //@line 45285
 $vararg_buffer = sp; //@line 45286
 $1 = sp + 688 | 0; //@line 45287
 $2 = sp + 432 | 0; //@line 45288
 $3 = sp + 176 | 0; //@line 45289
 $4 = sp + 64 | 0; //@line 45290
 HEAP8[659475] = $0 & 1; //@line 45292
 do {
  if (__Z13PrefsFindBoolPKc(104927) | 0) {
   $7 = __Z15PrefsFindStringPKci(104988, 0) | 0; //@line 45296
   $9 = $7 | 0 ? $7 : 102931; //@line 45298
   $10 = _fopen($9, 105328) | 0; //@line 45299
   if (!$10) {
    $14 = __Z9GetStringi(10024) | 0; //@line 45302
    $17 = _strerror(HEAP32[(___errno_location() | 0) >> 2] | 0) | 0; //@line 45305
    HEAP32[$vararg_buffer >> 2] = $9; //@line 45306
    HEAP32[$vararg_buffer + 4 >> 2] = $17; //@line 45308
    _sprintf($1, $14, $vararg_buffer) | 0; //@line 45309
    __Z12WarningAlertPKc($1); //@line 45310
    break;
   }
   _SDL_VideoDriverName($1 | 0, 256) | 0; //@line 45313
   do {
    if (!(_fgets($2, 255, $10) | 0)) {
     _fclose($10) | 0; //@line 45318
     label = 17; //@line 45319
    } else {
     $18 = $2 + 4 | 0; //@line 45321
     $$03865$i = 0; //@line 45322
     $$042$off064$i = 0; //@line 45322
     L9 : while (1) {
      $19 = _strlen($2) | 0; //@line 45324
      L11 : do {
       if (!$19) {
        $$038$be$i = $$03865$i; //@line 45328
        $$042$off0$be$i = $$042$off064$i; //@line 45328
       } else {
        HEAP8[$2 + ($19 + -1) >> 0] = 0; //@line 45332
        switch (HEAP8[$2 >> 0] | 0) {
        case 0:
        case 59:
        case 35:
         {
          $$038$be$i = $$03865$i; //@line 45336
          $$042$off0$be$i = $$042$off064$i; //@line 45336
          break L11;
          break;
         }
        default:
         {}
        }
        if ($$042$off064$i) {
         if (!(_strncmp($2, 102968, 3) | 0 | $$03865$i)) {
          $$038$be$i = $$03865$i; //@line 45348
          $$042$off0$be$i = 1; //@line 45348
          break;
         }
         HEAP32[$vararg_buffer2 >> 2] = $3; //@line 45351
         HEAP32[$vararg_buffer2 + 4 >> 2] = $4; //@line 45353
         if ((_sscanf($2, 102972, $vararg_buffer2) | 0) == 2) {
          $$038$be$i = $$03865$i + 1 | 0; //@line 45358
          $$042$off0$be$i = 1; //@line 45358
          break;
         } else {
          label = 15; //@line 45361
          break L9;
         }
        } else {
         if (_strncmp($2, 102978, 3) | 0) {
          $$038$be$i = $$03865$i; //@line 45368
          $$042$off0$be$i = 0; //@line 45368
          break;
         }
         $$038$be$i = $$03865$i; //@line 45374
         $$042$off0$be$i = (_strncmp($1, $18, _strlen($18) | 0) | 0) == 0; //@line 45374
         break;
        }
       }
      } while (0);
      if (!(_fgets($2, 255, $10) | 0)) {
       label = 16; //@line 45382
       break;
      } else {
       $$03865$i = $$038$be$i; //@line 45385
       $$042$off064$i = $$042$off0$be$i; //@line 45385
      }
     }
     if ((label | 0) == 15) {
      _fclose($10) | 0; //@line 45389
      $$03862$i = $$03865$i; //@line 45390
     } else if ((label | 0) == 16) {
      _fclose($10) | 0; //@line 45393
      if ($$042$off0$be$i) {
       $$03862$i = $$038$be$i; //@line 45395
      } else {
       label = 17; //@line 45397
       break;
      }
     }
     HEAP32[$vararg_buffer10 >> 2] = $1; //@line 45401
     HEAP32[$vararg_buffer10 + 4 >> 2] = $$03862$i; //@line 45403
     _printf(102982, $vararg_buffer10) | 0; //@line 45404
    }
   } while (0);
   if ((label | 0) == 17) {
    $34 = __Z9GetStringi(10025) | 0; //@line 45408
    HEAP32[$vararg_buffer6 >> 2] = $1; //@line 45409
    HEAP32[$vararg_buffer6 + 4 >> 2] = $9; //@line 45411
    _sprintf($3, $34, $vararg_buffer6) | 0; //@line 45412
    __Z12WarningAlertPKc($3); //@line 45413
   }
  }
 } while (0);
 HEAP32[30859] = __Z14PrefsFindInt32PKc(103028) | 0; //@line 45418
 if (!(HEAP8[659475] | 0)) {
  $$096 = __Z15PrefsFindStringPKci(103038, 0) | 0; //@line 45423
 } else {
  $$096 = 103045; //@line 45425
 }
 $$ = $0 ? 512 : 640; //@line 45427
 $$108 = $0 ? 384 : 480; //@line 45428
 HEAP32[$2 >> 2] = $$; //@line 45429
 HEAP32[$3 >> 2] = $$108; //@line 45430
 HEAP32[30856] = 0; //@line 45431
 do {
  if (!$$096) {
   $48 = $$; //@line 45435
   $50 = $$108; //@line 45435
  } else {
   HEAP32[$vararg_buffer14 >> 2] = $2; //@line 45437
   HEAP32[$vararg_buffer14 + 4 >> 2] = $3; //@line 45439
   if ((_sscanf($$096, 103057, $vararg_buffer14) | 0) == 2) {
    $$sink = 0; //@line 45443
    label = 25; //@line 45444
   } else {
    HEAP32[$vararg_buffer18 >> 2] = $2; //@line 45446
    HEAP32[$vararg_buffer18 + 4 >> 2] = $3; //@line 45448
    if ((_sscanf($$096, 103067, $vararg_buffer18) | 0) == 2) {
     $$sink = 1; //@line 45452
     label = 25; //@line 45453
    }
   }
   if ((label | 0) == 25) {
    HEAP32[30856] = $$sink; //@line 45457
   }
   $$pr = HEAP32[$2 >> 2] | 0; //@line 45459
   if (($$pr | 0) < 1) {
    HEAP32[$2 >> 2] = 800; //@line 45462
    $181 = 800; //@line 45463
   } else {
    if (($$pr | 0) > 800) {
     HEAP32[$2 >> 2] = 800; //@line 45467
     $181 = 800; //@line 45468
    } else {
     $181 = $$pr; //@line 45470
    }
   }
   $$pr146 = HEAP32[$3 >> 2] | 0; //@line 45473
   if (($$pr146 | 0) < 1) {
    HEAP32[$3 >> 2] = 600; //@line 45476
    $48 = $181; //@line 45477
    $50 = 600; //@line 45477
    break;
   }
   if (($$pr146 | 0) > 600) {
    HEAP32[$3 >> 2] = 600; //@line 45482
    $48 = $181; //@line 45483
    $50 = 600; //@line 45483
   } else {
    $48 = $181; //@line 45485
    $50 = $$pr146; //@line 45485
   }
  }
 } while (0);
 HEAP32[30862] = 32; //@line 45489
 dest = $4; //@line 45490
 src = 4396; //@line 45490
 stop = dest + 108 | 0; //@line 45490
 do {
  HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 45490
  dest = dest + 4 | 0; //@line 45490
  src = src + 4 | 0; //@line 45490
 } while ((dest | 0) < (stop | 0));
 HEAP32[$4 >> 2] = $48; //@line 45491
 HEAP32[$4 + 4 >> 2] = $50; //@line 45493
 L48 : do {
  if ((HEAP32[30856] | 0) == 1) {
   if ($48 | 0) {
    $53 = $1 + 4 | 0; //@line 45500
    $54 = $1 + 8 | 0; //@line 45501
    $55 = $1 + 16 | 0; //@line 45502
    $56 = $1 + 12 | 0; //@line 45503
    $$0106164 = 0; //@line 45504
    $108 = $48; //@line 45504
    $111 = $50; //@line 45504
    L51 : while (1) {
     if (($$0106164 | 0) > 0) {
      if (($108 | 0) < (HEAP32[$2 >> 2] | 0) ? ($111 | 0) < (HEAP32[$3 >> 2] | 0) : 0) {
       label = 66; //@line 45514
      }
     } else {
      label = 66; //@line 45517
     }
     L55 : do {
      if ((label | 0) == 66) {
       label = 0; //@line 45521
       if (!(($108 | 0) == 512 & ($111 | 0) == 384)) {
        $115 = HEAP32[$4 + ($$0106164 * 12 | 0) + 8 >> 2] | 0; //@line 45527
        $118 = $108 >>> 3; //@line 45531
        $119 = $108 >>> 2; //@line 45532
        $120 = $108 >>> 1; //@line 45533
        $121 = $108 << 2; //@line 45534
        $122 = $108 << 1; //@line 45535
        if (!(($108 | 0) > 800 | ($111 | 0) > 600)) {
         $$0101162 = 0; //@line 45537
         while (1) {
          $123 = HEAP32[30856] | 0; //@line 45539
          switch ($$0101162 | 0) {
          case 0:
           {
            $$0$i116185 = $118; //@line 45542
            $127 = 8; //@line 45542
            break;
           }
          case 1:
           {
            $$0$i116185 = $119; //@line 45546
            $127 = 8; //@line 45546
            break;
           }
          case 2:
           {
            $$0$i116185 = $120; //@line 45550
            $127 = 8; //@line 45550
            break;
           }
          case 5:
           {
            $$0$i116189193 = $121; //@line 45554
            label = 74; //@line 45555
            break;
           }
          case 4:
           {
            $$0$i116185 = $122; //@line 45559
            $127 = 16; //@line 45559
            break;
           }
          default:
           {
            if (($$0101162 | 0) < 4) {
             $$0$i116185 = $108; //@line 45565
             $127 = 8; //@line 45565
            } else {
             switch ($$0101162 | 0) {
             case 4:
              {
               $$0$i116185 = $108; //@line 45569
               $127 = 16; //@line 45569
               break;
              }
             case 5:
              {
               $$0$i116189193 = $108; //@line 45573
               label = 74; //@line 45574
               break;
              }
             default:
              {
               break L51;
              }
             }
            }
           }
          }
          if ((label | 0) == 74) {
           label = 0; //@line 45585
           $$0$i116185 = $$0$i116189193; //@line 45586
           $127 = 32; //@line 45586
          }
          if (_SDL_VideoModeOK($108 | 0, $111 | 0, $127 | 0, (($123 | 0) == 1 ? -2147483647 : 1) | 0) | 0) {
           HEAP32[$1 >> 2] = $108; //@line 45593
           HEAP32[$53 >> 2] = $111; //@line 45594
           HEAP32[$54 >> 2] = $115; //@line 45595
           HEAP32[$55 >> 2] = $$0$i116185; //@line 45596
           HEAP32[$56 >> 2] = $$0101162; //@line 45597
           $130 = HEAP32[30864] | 0; //@line 45598
           if (($130 | 0) == (HEAP32[30865] | 0)) {
            __ZNSt3__26vectorI10video_modeNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(123452, $1); //@line 45602
           } else {
            HEAP32[$130 >> 2] = HEAP32[$1 >> 2]; //@line 45604
            HEAP32[$130 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 45604
            HEAP32[$130 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 45604
            HEAP32[$130 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 45604
            HEAP32[$130 + 16 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 45604
            HEAP32[$130 + 20 >> 2] = HEAP32[$1 + 20 >> 2]; //@line 45604
            HEAP32[30864] = $130 + 24; //@line 45606
           }
          }
          $$0101162 = $$0101162 + 1 | 0; //@line 45609
          if (($$0101162 | 0) >= 6) {
           break L55;
          }
         }
        }
       }
      }
     } while (0);
     $136 = $$0106164 + 1 | 0; //@line 45621
     $138 = HEAP32[$4 + ($136 * 12 | 0) >> 2] | 0; //@line 45623
     if (!$138) {
      break L48;
     }
     $$0106164 = $136; //@line 45630
     $108 = $138; //@line 45630
     $111 = HEAP32[$4 + ($136 * 12 | 0) + 4 >> 2] | 0; //@line 45630
    }
    _abort(); //@line 45632
   }
  } else {
   if ($0) {
    if (!(_SDL_VideoModeOK(512, 342, 8, 1) | 0)) {
     break;
    }
    HEAP32[$1 >> 2] = 512; //@line 45642
    HEAP32[$1 + 4 >> 2] = 342; //@line 45644
    HEAP32[$1 + 8 >> 2] = 128; //@line 45646
    HEAP32[$1 + 16 >> 2] = 64; //@line 45648
    HEAP32[$1 + 12 >> 2] = 0; //@line 45650
    $68 = HEAP32[30864] | 0; //@line 45651
    if (($68 | 0) == (HEAP32[30865] | 0)) {
     __ZNSt3__26vectorI10video_modeNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(123452, $1); //@line 45655
    } else {
     HEAP32[$68 >> 2] = HEAP32[$1 >> 2]; //@line 45657
     HEAP32[$68 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 45657
     HEAP32[$68 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 45657
     HEAP32[$68 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 45657
     HEAP32[$68 + 16 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 45657
     HEAP32[$68 + 20 >> 2] = HEAP32[$1 + 20 >> 2]; //@line 45657
     HEAP32[30864] = $68 + 24; //@line 45659
    }
    break;
   }
   if ($48 | 0) {
    $58 = $1 + 4 | 0; //@line 45665
    $59 = $1 + 8 | 0; //@line 45666
    $60 = $1 + 16 | 0; //@line 45667
    $61 = $1 + 12 | 0; //@line 45668
    $$098170 = 0; //@line 45669
    $75 = $48; //@line 45669
    $78 = $50; //@line 45669
    L89 : while (1) {
     if (($$098170 | 0) > 0) {
      if (($75 | 0) < (HEAP32[$2 >> 2] | 0) ? ($78 | 0) < (HEAP32[$3 >> 2] | 0) : 0) {
       label = 47; //@line 45679
      }
     } else {
      label = 47; //@line 45682
     }
     L93 : do {
      if ((label | 0) == 47) {
       label = 0; //@line 45686
       $80 = HEAP32[$4 + ($$098170 * 12 | 0) + 8 >> 2] | 0; //@line 45688
       $83 = $75 >>> 3; //@line 45692
       $84 = $75 >>> 2; //@line 45693
       $85 = $75 >>> 1; //@line 45694
       $86 = $75 << 2; //@line 45695
       $87 = $75 << 1; //@line 45696
       if (!(($75 | 0) > 800 | ($78 | 0) > 600)) {
        $$0105167 = 0; //@line 45698
        while (1) {
         $88 = HEAP32[30856] | 0; //@line 45700
         switch ($$0105167 | 0) {
         case 0:
          {
           $$0$i180 = $83; //@line 45703
           $92 = 8; //@line 45703
           break;
          }
         case 1:
          {
           $$0$i180 = $84; //@line 45707
           $92 = 8; //@line 45707
           break;
          }
         case 2:
          {
           $$0$i180 = $85; //@line 45711
           $92 = 8; //@line 45711
           break;
          }
         case 5:
          {
           $$0$i184191 = $86; //@line 45715
           label = 54; //@line 45716
           break;
          }
         case 4:
          {
           $$0$i180 = $87; //@line 45720
           $92 = 16; //@line 45720
           break;
          }
         default:
          {
           if (($$0105167 | 0) < 4) {
            $$0$i180 = $75; //@line 45726
            $92 = 8; //@line 45726
           } else {
            switch ($$0105167 | 0) {
            case 4:
             {
              $$0$i180 = $75; //@line 45730
              $92 = 16; //@line 45730
              break;
             }
            case 5:
             {
              $$0$i184191 = $75; //@line 45734
              label = 54; //@line 45735
              break;
             }
            default:
             {
              break L89;
             }
            }
           }
          }
         }
         if ((label | 0) == 54) {
          label = 0; //@line 45746
          $$0$i180 = $$0$i184191; //@line 45747
          $92 = 32; //@line 45747
         }
         if (_SDL_VideoModeOK($75 | 0, $78 | 0, $92 | 0, (($88 | 0) == 1 ? -2147483647 : 1) | 0) | 0) {
          HEAP32[$1 >> 2] = $75; //@line 45754
          HEAP32[$58 >> 2] = $78; //@line 45755
          HEAP32[$59 >> 2] = $80; //@line 45756
          HEAP32[$60 >> 2] = $$0$i180; //@line 45757
          HEAP32[$61 >> 2] = $$0105167; //@line 45758
          $95 = HEAP32[30864] | 0; //@line 45759
          if (($95 | 0) == (HEAP32[30865] | 0)) {
           __ZNSt3__26vectorI10video_modeNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(123452, $1); //@line 45763
          } else {
           HEAP32[$95 >> 2] = HEAP32[$1 >> 2]; //@line 45765
           HEAP32[$95 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 45765
           HEAP32[$95 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 45765
           HEAP32[$95 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 45765
           HEAP32[$95 + 16 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 45765
           HEAP32[$95 + 20 >> 2] = HEAP32[$1 + 20 >> 2]; //@line 45765
           HEAP32[30864] = $95 + 24; //@line 45767
          }
         }
         $$0105167 = $$0105167 + 1 | 0; //@line 45770
         if (($$0105167 | 0) >= 6) {
          break L93;
         }
        }
       }
      }
     } while (0);
     $101 = $$098170 + 1 | 0; //@line 45781
     $103 = HEAP32[$4 + ($101 * 12 | 0) >> 2] | 0; //@line 45783
     if (!$103) {
      break L48;
     }
     $$098170 = $101; //@line 45790
     $75 = $103; //@line 45790
     $78 = HEAP32[$4 + ($101 * 12 | 0) + 4 >> 2] | 0; //@line 45790
    }
    _abort(); //@line 45792
   }
  }
 } while (0);
 $140 = HEAP32[30863] | 0; //@line 45797
 $141 = HEAP32[30864] | 0; //@line 45798
 if (($140 | 0) == ($141 | 0)) {
  __Z10ErrorAlerti(10001); //@line 45801
  $$0 = 0; //@line 45802
  STACKTOP = sp; //@line 45803
  return $$0 | 0; //@line 45803
 }
 $143 = HEAP32[$2 >> 2] | 0; //@line 45805
 $144 = HEAP32[$3 >> 2] | 0; //@line 45806
 $$sink147160 = $140; //@line 45807
 while (1) {
  if ((HEAP32[$$sink147160 >> 2] | 0) == ($143 | 0)) {
   if ((HEAP32[$$sink147160 + 4 >> 2] | 0) == ($144 | 0)) {
    if ((HEAP32[$$sink147160 + 12 >> 2] | 0) == 5) {
     label = 91; //@line 45820
     break;
    }
   }
  }
  $153 = $$sink147160 + 24 | 0; //@line 45825
  if (($153 | 0) == ($141 | 0)) {
   label = 92; //@line 45828
   break;
  } else {
   $$sink147160 = $153; //@line 45831
  }
 }
 if ((label | 0) == 91) {
  if (($$sink147160 | 0) == ($141 | 0)) {
   label = 92; //@line 45837
  } else {
   $$1 = 5; //@line 45839
   $$pn = $$sink147160; //@line 45839
  }
 }
 if ((label | 0) == 92) {
  $$1 = HEAP32[$140 + 12 >> 2] | 0; //@line 45845
  $$pn = $140; //@line 45845
 }
 $$3 = HEAP32[$$pn + 8 >> 2] | 0; //@line 45848
 _puts(103077) | 0; //@line 45849
 $158 = HEAP32[30863] | 0; //@line 45850
 if (($158 | 0) != ($141 | 0)) {
  $$sink148159 = $158; //@line 45853
  do {
   $161 = HEAP32[$$sink148159 + 12 >> 2] | 0; //@line 45856
   $167 = HEAP32[$$sink148159 + 4 >> 2] | 0; //@line 45862
   $169 = HEAP32[$$sink148159 + 8 >> 2] | 0; //@line 45864
   HEAP32[$vararg_buffer22 >> 2] = HEAP32[$$sink148159 >> 2]; //@line 45868
   HEAP32[$vararg_buffer22 + 4 >> 2] = $167; //@line 45870
   HEAP32[$vararg_buffer22 + 8 >> 2] = $169; //@line 45872
   HEAP32[$vararg_buffer22 + 12 >> 2] = ($161 | 0) == 4 ? 32768 : ($161 | 0) == 5 ? 16777216 : 1 << (1 << $161); //@line 45874
   _printf(103100, $vararg_buffer22) | 0; //@line 45875
   $$sink148159 = $$sink148159 + 24 | 0; //@line 45876
  } while (($$sink148159 | 0) != ($141 | 0));
 }
 $173 = __Znwj(836) | 0; //@line 45885
 __ZN12monitor_descC2ERKNSt3__26vectorI10video_modeNS0_9allocatorIS2_EEEE11video_depthj($173, 123452, $$1, $$3); //@line 45886
 HEAP32[$173 >> 2] = 4380; //@line 45887
 HEAP32[$1 >> 2] = $173; //@line 45888
 $174 = HEAP32[30549] | 0; //@line 45889
 if (($174 | 0) == (HEAP32[30550] | 0)) {
  __ZNSt3__26vectorIP12monitor_descNS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_(122192, $1); //@line 45893
 } else {
  HEAP32[$174 >> 2] = $173; //@line 45896
  HEAP32[30549] = (HEAP32[30549] | 0) + 4; //@line 45899
 }
 $$0 = __ZN16SDL_monitor_desc10video_openEv($173) | 0; //@line 45902
 STACKTOP = sp; //@line 45903
 return $$0 | 0; //@line 45903
}
function __ZL21rpc_message_recv_argsP13rpc_message_tPi($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i143 = 0, $$0$i149 = 0, $$0$i156 = 0, $$012$i = 0, $$012$i$ph$i = 0, $$012$i$ph$i139 = 0, $$012$i$ph$i145 = 0, $$012$i$ph$i152 = 0, $$012$i$ph$i158 = 0, $$012$i$ph$i165 = 0, $$012$i$ph$i172 = 0, $$012$i$ph$i179 = 0, $$0134460 = 0, $$014$i = 0, $$014$i$ph$i = 0, $$014$i$ph$i138 = 0, $$014$i$ph$i144 = 0, $$014$i$ph$i151 = 0, $$014$i$ph$i157 = 0, $$014$i$ph$i164 = 0, $$014$i$ph$i171 = 0, $$014$i$ph$i178 = 0, $$079$i = 0, $$079$i187 = 0, $$11123 = 0, $$113$ph$i = 0, $$1135451 = 0, $$115$ph$i = 0, $$16 = 0, $$2136432 = 0, $$3137433 = 0, $$5117$lcssa = 0, $$7119$lcssa = 0, $104 = 0, $105 = 0, $106 = 0, $109 = 0, $119 = 0, $123 = 0, $142 = 0, $146 = 0, $150 = 0, $16 = 0, $169 = 0, $17 = 0, $173 = 0, $176 = 0, $182 = 0, $184 = 0, $187 = 0, $188 = 0, $19 = 0, $192 = 0, $195 = 0, $198 = 0, $2 = 0, $204 = 0, $205 = 0, $207 = 0, $208 = 0, $210 = 0, $213 = 0, $214 = 0, $221 = 0, $228 = 0, $229 = 0, $231 = 0, $232 = 0, $31 = 0, $33 = 0, $44 = 0, $56 = 0, $69 = 0, $79 = 0, $8 = 0, $81 = 0, $9 = 0, $91 = 0, $97 = 0, $98 = 0, $vararg_buffer = 0, $vararg_buffer16 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 42749
 STACKTOP = STACKTOP + 16 | 0; //@line 42750
 $vararg_buffer16 = sp + 8 | 0; //@line 42751
 $vararg_buffer = sp; //@line 42752
 $2 = sp + 12 | 0; //@line 42753
 $8 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42765
 $9 = HEAP32[$8 >> 2] | 0; //@line 42766
 HEAP32[$1 >> 2] = $8 + 4; //@line 42768
 if (!$9) {
  $$16 = 0; //@line 42771
  STACKTOP = sp; //@line 42772
  return $$16 | 0; //@line 42772
 }
 $231 = $9; //@line 42774
 L4 : while (1) {
  $232 = $231; //@line 42776
  L6 : while (1) {
   $31 = $232; //@line 42778
   L8 : while (1) {
    $16 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42791
    $17 = HEAP32[$16 >> 2] | 0; //@line 42792
    HEAP32[$1 >> 2] = $16 + 4; //@line 42794
    $$012$i$ph$i = 4; //@line 42795
    $$014$i$ph$i = $2; //@line 42795
    while (1) {
     while (1) {
      $19 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i, $$012$i$ph$i, 0) | 0; //@line 42799
      if (($19 | 0) > 0) {
       break;
      }
      if (($19 | 0) != -1) {
       label = 11; //@line 42806
       break L4;
      }
      if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
       label = 11; //@line 42813
       break L4;
      }
     }
     $$012$i$ph$i = $$012$i$ph$i - $19 | 0; //@line 42817
     if (($$012$i$ph$i | 0) <= 0) {
      break;
     } else {
      $$014$i$ph$i = $$014$i$ph$i + $19 | 0; //@line 42821
     }
    }
    if ((_ntohl(HEAP32[$2 >> 2] | 0) | 0) != ($31 | 0)) {
     $$16 = -1006; //@line 42830
     label = 110; //@line 42831
     break L4;
    }
    L19 : do {
     switch ($31 | 0) {
     case -2e3:
      {
       $$012$i$ph$i139 = 1; //@line 42837
       $$014$i$ph$i138 = $2; //@line 42837
       L27 : while (1) {
        while (1) {
         $33 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i138, $$012$i$ph$i139, 0) | 0; //@line 42841
         if (($33 | 0) > 0) {
          break;
         }
         if (($33 | 0) != -1) {
          $$0$i143 = -1001; //@line 42848
          break L27;
         }
         if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
          $$0$i143 = -1001; //@line 42855
          break L27;
         }
        }
        $$012$i$ph$i139 = $$012$i$ph$i139 - $33 | 0; //@line 42859
        if (($$012$i$ph$i139 | 0) <= 0) {
         label = 20; //@line 42865
         break;
        } else {
         $$014$i$ph$i138 = $$014$i$ph$i138 + $33 | 0; //@line 42863
        }
       }
       if ((label | 0) == 20) {
        label = 0; //@line 42870
        HEAP8[$17 >> 0] = HEAP8[$2 >> 0] | 0; //@line 42872
        $$0$i143 = 0; //@line 42873
       }
       $$11123 = $$0$i143; //@line 42875
       label = 108; //@line 42876
       break;
      }
     case -2002:
     case -2001:
      {
       $$012$i$ph$i145 = 4; //@line 42880
       $$014$i$ph$i144 = $2; //@line 42880
       L38 : while (1) {
        while (1) {
         $44 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i144, $$012$i$ph$i145, 0) | 0; //@line 42884
         if (($44 | 0) > 0) {
          break;
         }
         if (($44 | 0) != -1) {
          $$0$i149 = -1001; //@line 42891
          break L38;
         }
         if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
          $$0$i149 = -1001; //@line 42898
          break L38;
         }
        }
        $$012$i$ph$i145 = $$012$i$ph$i145 - $44 | 0; //@line 42902
        if (($$012$i$ph$i145 | 0) <= 0) {
         label = 28; //@line 42908
         break;
        } else {
         $$014$i$ph$i144 = $$014$i$ph$i144 + $44 | 0; //@line 42906
        }
       }
       if ((label | 0) == 28) {
        label = 0; //@line 42913
        HEAP32[$17 >> 2] = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 42916
        $$0$i149 = 0; //@line 42917
       }
       $$11123 = $$0$i149; //@line 42919
       label = 108; //@line 42920
       break;
      }
     case -2003:
      {
       $$012$i$ph$i152 = 4; //@line 42924
       $$014$i$ph$i151 = $2; //@line 42924
       L49 : while (1) {
        while (1) {
         $56 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i151, $$012$i$ph$i152, 0) | 0; //@line 42928
         if (($56 | 0) > 0) {
          break;
         }
         if (($56 | 0) != -1) {
          $$0$i156 = -1001; //@line 42935
          break L49;
         }
         if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
          $$0$i156 = -1001; //@line 42942
          break L49;
         }
        }
        $$012$i$ph$i152 = $$012$i$ph$i152 - $56 | 0; //@line 42946
        if (($$012$i$ph$i152 | 0) <= 0) {
         label = 36; //@line 42952
         break;
        } else {
         $$014$i$ph$i151 = $$014$i$ph$i151 + $56 | 0; //@line 42950
        }
       }
       if ((label | 0) == 36) {
        label = 0; //@line 42957
        HEAP32[$17 >> 2] = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 42960
        $$0$i156 = 0; //@line 42961
       }
       $$11123 = $$0$i156; //@line 42963
       label = 108; //@line 42964
       break;
      }
     case -2004:
      {
       $$11123 = __Z23rpc_message_recv_stringP13rpc_message_tPPc($0, $17) | 0; //@line 42969
       label = 108; //@line 42970
       break;
      }
     case -2005:
      {
       $$012$i$ph$i158 = 4; //@line 42974
       $$014$i$ph$i157 = $2; //@line 42974
       while (1) {
        while (1) {
         $69 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i157, $$012$i$ph$i158, 0) | 0; //@line 42978
         if (($69 | 0) > 0) {
          break;
         }
         if (($69 | 0) != -1) {
          label = 45; //@line 42985
          break L4;
         }
         if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
          label = 45; //@line 42992
          break L4;
         }
        }
        $$012$i$ph$i158 = $$012$i$ph$i158 - $69 | 0; //@line 42996
        if (($$012$i$ph$i158 | 0) <= 0) {
         break;
        } else {
         $$014$i$ph$i157 = $$014$i$ph$i157 + $69 | 0; //@line 43000
        }
       }
       $79 = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 43006
       $$012$i$ph$i165 = 4; //@line 43007
       $$014$i$ph$i164 = $2; //@line 43007
       while (1) {
        while (1) {
         $81 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i164, $$012$i$ph$i165, 0) | 0; //@line 43011
         if (($81 | 0) > 0) {
          break;
         }
         if (($81 | 0) != -1) {
          label = 52; //@line 43018
          break L4;
         }
         if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
          label = 52; //@line 43025
          break L4;
         }
        }
        $$012$i$ph$i165 = $$012$i$ph$i165 - $81 | 0; //@line 43029
        if (($$012$i$ph$i165 | 0) <= 0) {
         break;
        } else {
         $$014$i$ph$i164 = $$014$i$ph$i164 + $81 | 0; //@line 43033
        }
       }
       $91 = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 43039
       $97 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43051
       $98 = HEAP32[$97 >> 2] | 0; //@line 43052
       HEAP32[$1 >> 2] = $97 + 4; //@line 43054
       HEAP32[$98 >> 2] = $91; //@line 43055
       $104 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43067
       $105 = HEAP32[$104 >> 2] | 0; //@line 43068
       HEAP32[$1 >> 2] = $104 + 4; //@line 43070
       switch ($79 | 0) {
       case -2002:
       case -2001:
        {
         break L6;
         break;
        }
       case -2003:
        {
         break L8;
         break;
        }
       case -2e3:
        {
         $106 = _malloc($91) | 0; //@line 43081
         if (!$106) {
          $$16 = -1002; //@line 43084
          label = 110; //@line 43085
          break L4;
         } else {
          $$012$i = $91; //@line 43088
          $$014$i = $106; //@line 43088
         }
         while (1) {
          $109 = _recv(HEAP32[$0 >> 2] | 0, $$014$i, $$012$i, 0) | 0; //@line 43092
          if (($109 | 0) > 0) {
           $$113$ph$i = $$012$i - $109 | 0; //@line 43097
           $$115$ph$i = $$014$i + $109 | 0; //@line 43097
          } else {
           if (($109 | 0) != -1) {
            label = 60; //@line 43101
            break L4;
           }
           if ((HEAP32[(___errno_location() | 0) >> 2] | 0) == 4) {
            $$113$ph$i = $$012$i; //@line 43108
            $$115$ph$i = $$014$i; //@line 43108
           } else {
            label = 60; //@line 43110
            break L4;
           }
          }
          if (($$113$ph$i | 0) > 0) {
           $$012$i = $$113$ph$i; //@line 43116
           $$014$i = $$115$ph$i; //@line 43116
          } else {
           break;
          }
         }
         HEAP32[$105 >> 2] = $106; //@line 43121
         break L19;
         break;
        }
       case -2004:
        {
         $173 = _malloc($91 << 2) | 0; //@line 43127
         if (!$173) {
          $$16 = -1002; //@line 43130
          label = 110; //@line 43131
          break L4;
         }
         if (!$91) {
          $$5117$lcssa = 0; //@line 43136
         } else {
          $$2136432 = 0; //@line 43138
          while (1) {
           $176 = __Z23rpc_message_recv_stringP13rpc_message_tPPc($0, $2) | 0; //@line 43140
           if (($176 | 0) < 0) {
            label = 87; //@line 43143
            break L4;
           }
           HEAP32[$173 + ($$2136432 << 2) >> 2] = HEAP32[$2 >> 2]; //@line 43148
           $$2136432 = $$2136432 + 1 | 0; //@line 43149
           if ($$2136432 >>> 0 >= $91 >>> 0) {
            $$5117$lcssa = $176; //@line 43154
            break;
           }
          }
         }
         HEAP32[$105 >> 2] = $173; //@line 43159
         $$11123 = $$5117$lcssa; //@line 43160
         label = 108; //@line 43161
         break L19;
         break;
        }
       default:
        {
         $182 = HEAP32[30850] | 0; //@line 43166
         $184 = HEAP32[30851] | 0; //@line 43168
         if (($182 | 0) != 0 & ($184 | 0) > 0) {
          $$079$i = 0; //@line 43172
         } else {
          label = 101; //@line 43174
          break L4;
         }
         while (1) {
          $188 = $182 + ($$079$i << 4) | 0; //@line 43178
          $187 = $$079$i + 1 | 0; //@line 43181
          if ((HEAP32[$188 >> 2] | 0) == ($79 | 0)) {
           break;
          }
          if (($187 | 0) < ($184 | 0)) {
           $$079$i = $187; //@line 43187
          } else {
           label = 101; //@line 43189
           break L4;
          }
         }
         if (!$188) {
          label = 101; //@line 43195
          break L4;
         }
         $192 = $182 + ($$079$i << 4) + 4 | 0; //@line 43198
         $195 = _malloc(Math_imul(HEAP32[$192 >> 2] | 0, $91) | 0) | 0; //@line 43201
         if (!$195) {
          $$16 = -1002; //@line 43204
          label = 110; //@line 43205
          break L4;
         }
         if (!$91) {
          $$7119$lcssa = 0; //@line 43210
         } else {
          $198 = $182 + ($$079$i << 4) + 12 | 0; //@line 43212
          $$3137433 = 0; //@line 43213
          while (1) {
           $204 = $195 + (Math_imul(HEAP32[$192 >> 2] | 0, $$3137433) | 0) | 0; //@line 43218
           $205 = FUNCTION_TABLE_iii[HEAP32[$198 >> 2] & 31]($0, $204) | 0; //@line 43219
           $$3137433 = $$3137433 + 1 | 0; //@line 43221
           if (($205 | 0) < 0) {
            label = 99; //@line 43223
            break L4;
           }
           if ($$3137433 >>> 0 >= $91 >>> 0) {
            $$7119$lcssa = $205; //@line 43230
            break;
           }
          }
         }
         HEAP32[$105 >> 2] = $195; //@line 43235
         $$11123 = $$7119$lcssa; //@line 43236
         label = 108; //@line 43237
         break L19;
        }
       }
       break;
      }
     default:
      {
       $208 = HEAP32[30850] | 0; //@line 43244
       $210 = HEAP32[30851] | 0; //@line 43246
       if (($208 | 0) != 0 & ($210 | 0) > 0) {
        $$079$i187 = 0; //@line 43250
       } else {
        label = 107; //@line 43252
        break L4;
       }
       while (1) {
        $214 = $208 + ($$079$i187 << 4) | 0; //@line 43256
        $213 = $$079$i187 + 1 | 0; //@line 43259
        if ((HEAP32[$214 >> 2] | 0) == ($31 | 0)) {
         break;
        }
        if (($213 | 0) < ($210 | 0)) {
         $$079$i187 = $213; //@line 43265
        } else {
         label = 107; //@line 43267
         break L4;
        }
       }
       if (!$214) {
        label = 107; //@line 43273
        break L4;
       }
       $$11123 = FUNCTION_TABLE_iii[HEAP32[$208 + ($$079$i187 << 4) + 12 >> 2] & 31]($0, $17) | 0; //@line 43279
       label = 108; //@line 43280
      }
     }
    } while (0);
    if ((label | 0) == 108) {
     label = 0; //@line 43285
     if ($$11123 | 0) {
      $$16 = $$11123; //@line 43288
      label = 110; //@line 43289
      break L4;
     }
    }
    $228 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43304
    $229 = HEAP32[$228 >> 2] | 0; //@line 43305
    HEAP32[$1 >> 2] = $228 + 4; //@line 43307
    if (!$229) {
     $$16 = 0; //@line 43310
     label = 110; //@line 43311
     break L4;
    } else {
     $31 = $229; //@line 43314
    }
   }
   $146 = _malloc($91 << 2) | 0; //@line 43318
   if (!$146) {
    $$16 = -1002; //@line 43321
    label = 110; //@line 43322
    break L4;
   }
   if ($91 | 0) {
    $$1135451 = 0; //@line 43327
    do {
     $$012$i$ph$i179 = 4; //@line 43329
     $$014$i$ph$i178 = $2; //@line 43329
     while (1) {
      while (1) {
       $150 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i178, $$012$i$ph$i179, 0) | 0; //@line 43333
       if (($150 | 0) > 0) {
        break;
       }
       if (($150 | 0) != -1) {
        label = 81; //@line 43340
        break L4;
       }
       if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
        label = 81; //@line 43347
        break L4;
       }
      }
      $$012$i$ph$i179 = $$012$i$ph$i179 - $150 | 0; //@line 43351
      if (($$012$i$ph$i179 | 0) <= 0) {
       break;
      } else {
       $$014$i$ph$i178 = $$014$i$ph$i178 + $150 | 0; //@line 43355
      }
     }
     HEAP32[$146 + ($$1135451 << 2) >> 2] = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 43363
     $$1135451 = $$1135451 + 1 | 0; //@line 43364
    } while ($$1135451 >>> 0 < $91 >>> 0);
   }
   HEAP32[$105 >> 2] = $146; //@line 43373
   $169 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43385
   $232 = HEAP32[$169 >> 2] | 0; //@line 43386
   HEAP32[$1 >> 2] = $169 + 4; //@line 43388
   if (!$232) {
    $$16 = 0; //@line 43391
    label = 110; //@line 43392
    break L4;
   }
  }
  $119 = _malloc($91 << 2) | 0; //@line 43399
  if (!$119) {
   $$16 = -1002; //@line 43402
   label = 110; //@line 43403
   break;
  }
  if ($91 | 0) {
   $$0134460 = 0; //@line 43408
   do {
    $$012$i$ph$i172 = 4; //@line 43410
    $$014$i$ph$i171 = $2; //@line 43410
    while (1) {
     while (1) {
      $123 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph$i171, $$012$i$ph$i172, 0) | 0; //@line 43414
      if (($123 | 0) > 0) {
       break;
      }
      if (($123 | 0) != -1) {
       label = 70; //@line 43421
       break L4;
      }
      if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
       label = 70; //@line 43428
       break L4;
      }
     }
     $$012$i$ph$i172 = $$012$i$ph$i172 - $123 | 0; //@line 43432
     if (($$012$i$ph$i172 | 0) <= 0) {
      break;
     } else {
      $$014$i$ph$i171 = $$014$i$ph$i171 + $123 | 0; //@line 43436
     }
    }
    HEAP32[$119 + ($$0134460 << 2) >> 2] = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 43444
    $$0134460 = $$0134460 + 1 | 0; //@line 43445
   } while ($$0134460 >>> 0 < $91 >>> 0);
  }
  HEAP32[$105 >> 2] = $119; //@line 43454
  $142 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43466
  $231 = HEAP32[$142 >> 2] | 0; //@line 43467
  HEAP32[$1 >> 2] = $142 + 4; //@line 43469
  if (!$231) {
   $$16 = 0; //@line 43472
   label = 110; //@line 43473
   break;
  }
 }
 switch (label | 0) {
 case 11:
  {
   $$16 = -1001; //@line 43481
   STACKTOP = sp; //@line 43482
   return $$16 | 0; //@line 43482
  }
 case 45:
  {
   $$16 = -1001; //@line 43486
   STACKTOP = sp; //@line 43487
   return $$16 | 0; //@line 43487
  }
 case 52:
  {
   $$16 = -1001; //@line 43491
   STACKTOP = sp; //@line 43492
   return $$16 | 0; //@line 43492
  }
 case 60:
  {
   _free($106); //@line 43496
   $$16 = -1001; //@line 43497
   STACKTOP = sp; //@line 43498
   return $$16 | 0; //@line 43498
  }
 case 70:
  {
   _free($119); //@line 43502
   $$16 = -1001; //@line 43503
   STACKTOP = sp; //@line 43504
   return $$16 | 0; //@line 43504
  }
 case 81:
  {
   _free($146); //@line 43508
   $$16 = -1001; //@line 43509
   STACKTOP = sp; //@line 43510
   return $$16 | 0; //@line 43510
  }
 case 87:
  {
   _free($173); //@line 43514
   $$16 = $176; //@line 43515
   STACKTOP = sp; //@line 43516
   return $$16 | 0; //@line 43516
  }
 case 99:
  {
   _free($195); //@line 43520
   $$16 = $205; //@line 43521
   STACKTOP = sp; //@line 43522
   return $$16 | 0; //@line 43522
  }
 case 101:
  {
   $207 = HEAP32[22038] | 0; //@line 43526
   HEAP32[$vararg_buffer >> 2] = -2005; //@line 43527
   _fprintf($207, 102288, $vararg_buffer) | 0; //@line 43528
   $$16 = -1007; //@line 43529
   STACKTOP = sp; //@line 43530
   return $$16 | 0; //@line 43530
  }
 case 107:
  {
   $221 = HEAP32[22038] | 0; //@line 43534
   HEAP32[$vararg_buffer16 >> 2] = $31; //@line 43535
   _fprintf($221, 102259, $vararg_buffer16) | 0; //@line 43536
   $$16 = -1007; //@line 43537
   STACKTOP = sp; //@line 43538
   return $$16 | 0; //@line 43538
  }
 case 110:
  {
   STACKTOP = sp; //@line 43542
   return $$16 | 0; //@line 43542
  }
 }
 return 0; //@line 43546
}
function _free($0) {
 $0 = $0 | 0;
 var $$0212$i = 0, $$0212$in$i = 0, $$0383 = 0, $$0384 = 0, $$0396 = 0, $$0403 = 0, $$1 = 0, $$1382 = 0, $$1387 = 0, $$1390 = 0, $$1398 = 0, $$1402 = 0, $$2 = 0, $$3 = 0, $$3400 = 0, $$pre$phi443Z2D = 0, $$pre$phi445Z2D = 0, $$pre$phiZ2D = 0, $10 = 0, $104 = 0, $105 = 0, $113 = 0, $114 = 0, $115 = 0, $122 = 0, $124 = 0, $13 = 0, $130 = 0, $135 = 0, $136 = 0, $139 = 0, $141 = 0, $143 = 0, $158 = 0, $16 = 0, $163 = 0, $165 = 0, $168 = 0, $17 = 0, $171 = 0, $174 = 0, $177 = 0, $178 = 0, $179 = 0, $181 = 0, $183 = 0, $184 = 0, $186 = 0, $187 = 0, $193 = 0, $194 = 0, $2 = 0, $207 = 0, $21 = 0, $210 = 0, $211 = 0, $217 = 0, $232 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $241 = 0, $242 = 0, $248 = 0, $253 = 0, $254 = 0, $257 = 0, $259 = 0, $26 = 0, $262 = 0, $267 = 0, $273 = 0, $277 = 0, $278 = 0, $28 = 0, $296 = 0, $298 = 0, $3 = 0, $305 = 0, $306 = 0, $307 = 0, $315 = 0, $41 = 0, $46 = 0, $48 = 0, $51 = 0, $53 = 0, $56 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $63 = 0, $65 = 0, $66 = 0, $68 = 0, $69 = 0, $7 = 0, $74 = 0, $75 = 0, $88 = 0, $9 = 0, $91 = 0, $92 = 0, $98 = 0, label = 0;
 if (!$0) {
  return;
 }
 $2 = $0 + -8 | 0; //@line 52524
 $3 = HEAP32[162839] | 0; //@line 52525
 if ($2 >>> 0 < $3 >>> 0) {
  _abort(); //@line 52528
 }
 $6 = HEAP32[$0 + -4 >> 2] | 0; //@line 52532
 $7 = $6 & 3; //@line 52533
 if (($7 | 0) == 1) {
  _abort(); //@line 52536
 }
 $9 = $6 & -8; //@line 52539
 $10 = $2 + $9 | 0; //@line 52540
 L10 : do {
  if (!($6 & 1)) {
   $13 = HEAP32[$2 >> 2] | 0; //@line 52545
   if (!$7) {
    return;
   }
   $16 = $2 + (0 - $13) | 0; //@line 52551
   $17 = $13 + $9 | 0; //@line 52552
   if ($16 >>> 0 < $3 >>> 0) {
    _abort(); //@line 52555
   }
   if (($16 | 0) == (HEAP32[162840] | 0)) {
    $104 = $10 + 4 | 0; //@line 52561
    $105 = HEAP32[$104 >> 2] | 0; //@line 52562
    if (($105 & 3 | 0) != 3) {
     $$1 = $16; //@line 52566
     $$1382 = $17; //@line 52566
     $113 = $16; //@line 52566
     break;
    }
    HEAP32[162837] = $17; //@line 52573
    HEAP32[$104 >> 2] = $105 & -2; //@line 52574
    HEAP32[$16 + 4 >> 2] = $17 | 1; //@line 52575
    HEAP32[$16 + $17 >> 2] = $17; //@line 52576
    return;
   }
   $21 = $13 >>> 3; //@line 52579
   if ($13 >>> 0 < 256) {
    $24 = HEAP32[$16 + 8 >> 2] | 0; //@line 52583
    $26 = HEAP32[$16 + 12 >> 2] | 0; //@line 52585
    $28 = 651380 + ($21 << 1 << 2) | 0; //@line 52587
    if (($24 | 0) != ($28 | 0)) {
     if ($24 >>> 0 < $3 >>> 0) {
      _abort(); //@line 52592
     }
     if ((HEAP32[$24 + 12 >> 2] | 0) != ($16 | 0)) {
      _abort(); //@line 52599
     }
    }
    if (($26 | 0) == ($24 | 0)) {
     HEAP32[162835] = HEAP32[162835] & ~(1 << $21); //@line 52609
     $$1 = $16; //@line 52610
     $$1382 = $17; //@line 52610
     $113 = $16; //@line 52610
     break;
    }
    if (($26 | 0) == ($28 | 0)) {
     $$pre$phi445Z2D = $26 + 8 | 0; //@line 52616
    } else {
     if ($26 >>> 0 < $3 >>> 0) {
      _abort(); //@line 52620
     }
     $41 = $26 + 8 | 0; //@line 52623
     if ((HEAP32[$41 >> 2] | 0) == ($16 | 0)) {
      $$pre$phi445Z2D = $41; //@line 52627
     } else {
      _abort(); //@line 52629
     }
    }
    HEAP32[$24 + 12 >> 2] = $26; //@line 52634
    HEAP32[$$pre$phi445Z2D >> 2] = $24; //@line 52635
    $$1 = $16; //@line 52636
    $$1382 = $17; //@line 52636
    $113 = $16; //@line 52636
    break;
   }
   $46 = HEAP32[$16 + 24 >> 2] | 0; //@line 52640
   $48 = HEAP32[$16 + 12 >> 2] | 0; //@line 52642
   do {
    if (($48 | 0) == ($16 | 0)) {
     $59 = $16 + 16 | 0; //@line 52646
     $60 = $59 + 4 | 0; //@line 52647
     $61 = HEAP32[$60 >> 2] | 0; //@line 52648
     if (!$61) {
      $63 = HEAP32[$59 >> 2] | 0; //@line 52651
      if (!$63) {
       $$3 = 0; //@line 52654
       break;
      } else {
       $$1387 = $63; //@line 52657
       $$1390 = $59; //@line 52657
      }
     } else {
      $$1387 = $61; //@line 52660
      $$1390 = $60; //@line 52660
     }
     while (1) {
      $65 = $$1387 + 20 | 0; //@line 52663
      $66 = HEAP32[$65 >> 2] | 0; //@line 52664
      if ($66 | 0) {
       $$1387 = $66; //@line 52667
       $$1390 = $65; //@line 52667
       continue;
      }
      $68 = $$1387 + 16 | 0; //@line 52670
      $69 = HEAP32[$68 >> 2] | 0; //@line 52671
      if (!$69) {
       break;
      } else {
       $$1387 = $69; //@line 52676
       $$1390 = $68; //@line 52676
      }
     }
     if ($$1390 >>> 0 < $3 >>> 0) {
      _abort(); //@line 52681
     } else {
      HEAP32[$$1390 >> 2] = 0; //@line 52684
      $$3 = $$1387; //@line 52685
      break;
     }
    } else {
     $51 = HEAP32[$16 + 8 >> 2] | 0; //@line 52690
     if ($51 >>> 0 < $3 >>> 0) {
      _abort(); //@line 52693
     }
     $53 = $51 + 12 | 0; //@line 52696
     if ((HEAP32[$53 >> 2] | 0) != ($16 | 0)) {
      _abort(); //@line 52700
     }
     $56 = $48 + 8 | 0; //@line 52703
     if ((HEAP32[$56 >> 2] | 0) == ($16 | 0)) {
      HEAP32[$53 >> 2] = $48; //@line 52707
      HEAP32[$56 >> 2] = $51; //@line 52708
      $$3 = $48; //@line 52709
      break;
     } else {
      _abort(); //@line 52712
     }
    }
   } while (0);
   if (!$46) {
    $$1 = $16; //@line 52719
    $$1382 = $17; //@line 52719
    $113 = $16; //@line 52719
   } else {
    $74 = HEAP32[$16 + 28 >> 2] | 0; //@line 52722
    $75 = 651644 + ($74 << 2) | 0; //@line 52723
    do {
     if (($16 | 0) == (HEAP32[$75 >> 2] | 0)) {
      HEAP32[$75 >> 2] = $$3; //@line 52728
      if (!$$3) {
       HEAP32[162836] = HEAP32[162836] & ~(1 << $74); //@line 52735
       $$1 = $16; //@line 52736
       $$1382 = $17; //@line 52736
       $113 = $16; //@line 52736
       break L10;
      }
     } else {
      if ($46 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 52743
      } else {
       HEAP32[$46 + 16 + (((HEAP32[$46 + 16 >> 2] | 0) != ($16 | 0) & 1) << 2) >> 2] = $$3; //@line 52751
       if (!$$3) {
        $$1 = $16; //@line 52754
        $$1382 = $17; //@line 52754
        $113 = $16; //@line 52754
        break L10;
       } else {
        break;
       }
      }
     }
    } while (0);
    $88 = HEAP32[162839] | 0; //@line 52762
    if ($$3 >>> 0 < $88 >>> 0) {
     _abort(); //@line 52765
    }
    HEAP32[$$3 + 24 >> 2] = $46; //@line 52769
    $91 = $16 + 16 | 0; //@line 52770
    $92 = HEAP32[$91 >> 2] | 0; //@line 52771
    do {
     if ($92 | 0) {
      if ($92 >>> 0 < $88 >>> 0) {
       _abort(); //@line 52777
      } else {
       HEAP32[$$3 + 16 >> 2] = $92; //@line 52781
       HEAP32[$92 + 24 >> 2] = $$3; //@line 52783
       break;
      }
     }
    } while (0);
    $98 = HEAP32[$91 + 4 >> 2] | 0; //@line 52789
    if (!$98) {
     $$1 = $16; //@line 52792
     $$1382 = $17; //@line 52792
     $113 = $16; //@line 52792
    } else {
     if ($98 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
      _abort(); //@line 52797
     } else {
      HEAP32[$$3 + 20 >> 2] = $98; //@line 52801
      HEAP32[$98 + 24 >> 2] = $$3; //@line 52803
      $$1 = $16; //@line 52804
      $$1382 = $17; //@line 52804
      $113 = $16; //@line 52804
      break;
     }
    }
   }
  } else {
   $$1 = $2; //@line 52810
   $$1382 = $9; //@line 52810
   $113 = $2; //@line 52810
  }
 } while (0);
 if ($113 >>> 0 >= $10 >>> 0) {
  _abort(); //@line 52815
 }
 $114 = $10 + 4 | 0; //@line 52818
 $115 = HEAP32[$114 >> 2] | 0; //@line 52819
 if (!($115 & 1)) {
  _abort(); //@line 52823
 }
 if (!($115 & 2)) {
  $122 = HEAP32[162840] | 0; //@line 52831
  if (($10 | 0) == (HEAP32[162841] | 0)) {
   $124 = (HEAP32[162838] | 0) + $$1382 | 0; //@line 52834
   HEAP32[162838] = $124; //@line 52835
   HEAP32[162841] = $$1; //@line 52836
   HEAP32[$$1 + 4 >> 2] = $124 | 1; //@line 52839
   if (($$1 | 0) != ($122 | 0)) {
    return;
   }
   HEAP32[162840] = 0; //@line 52844
   HEAP32[162837] = 0; //@line 52845
   return;
  }
  if (($10 | 0) == ($122 | 0)) {
   $130 = (HEAP32[162837] | 0) + $$1382 | 0; //@line 52851
   HEAP32[162837] = $130; //@line 52852
   HEAP32[162840] = $113; //@line 52853
   HEAP32[$$1 + 4 >> 2] = $130 | 1; //@line 52856
   HEAP32[$113 + $130 >> 2] = $130; //@line 52858
   return;
  }
  $135 = ($115 & -8) + $$1382 | 0; //@line 52862
  $136 = $115 >>> 3; //@line 52863
  L108 : do {
   if ($115 >>> 0 < 256) {
    $139 = HEAP32[$10 + 8 >> 2] | 0; //@line 52868
    $141 = HEAP32[$10 + 12 >> 2] | 0; //@line 52870
    $143 = 651380 + ($136 << 1 << 2) | 0; //@line 52872
    if (($139 | 0) != ($143 | 0)) {
     if ($139 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
      _abort(); //@line 52878
     }
     if ((HEAP32[$139 + 12 >> 2] | 0) != ($10 | 0)) {
      _abort(); //@line 52885
     }
    }
    if (($141 | 0) == ($139 | 0)) {
     HEAP32[162835] = HEAP32[162835] & ~(1 << $136); //@line 52895
     break;
    }
    if (($141 | 0) == ($143 | 0)) {
     $$pre$phi443Z2D = $141 + 8 | 0; //@line 52901
    } else {
     if ($141 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
      _abort(); //@line 52906
     }
     $158 = $141 + 8 | 0; //@line 52909
     if ((HEAP32[$158 >> 2] | 0) == ($10 | 0)) {
      $$pre$phi443Z2D = $158; //@line 52913
     } else {
      _abort(); //@line 52915
     }
    }
    HEAP32[$139 + 12 >> 2] = $141; //@line 52920
    HEAP32[$$pre$phi443Z2D >> 2] = $139; //@line 52921
   } else {
    $163 = HEAP32[$10 + 24 >> 2] | 0; //@line 52924
    $165 = HEAP32[$10 + 12 >> 2] | 0; //@line 52926
    do {
     if (($165 | 0) == ($10 | 0)) {
      $177 = $10 + 16 | 0; //@line 52930
      $178 = $177 + 4 | 0; //@line 52931
      $179 = HEAP32[$178 >> 2] | 0; //@line 52932
      if (!$179) {
       $181 = HEAP32[$177 >> 2] | 0; //@line 52935
       if (!$181) {
        $$3400 = 0; //@line 52938
        break;
       } else {
        $$1398 = $181; //@line 52941
        $$1402 = $177; //@line 52941
       }
      } else {
       $$1398 = $179; //@line 52944
       $$1402 = $178; //@line 52944
      }
      while (1) {
       $183 = $$1398 + 20 | 0; //@line 52947
       $184 = HEAP32[$183 >> 2] | 0; //@line 52948
       if ($184 | 0) {
        $$1398 = $184; //@line 52951
        $$1402 = $183; //@line 52951
        continue;
       }
       $186 = $$1398 + 16 | 0; //@line 52954
       $187 = HEAP32[$186 >> 2] | 0; //@line 52955
       if (!$187) {
        break;
       } else {
        $$1398 = $187; //@line 52960
        $$1402 = $186; //@line 52960
       }
      }
      if ($$1402 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 52966
      } else {
       HEAP32[$$1402 >> 2] = 0; //@line 52969
       $$3400 = $$1398; //@line 52970
       break;
      }
     } else {
      $168 = HEAP32[$10 + 8 >> 2] | 0; //@line 52975
      if ($168 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 52979
      }
      $171 = $168 + 12 | 0; //@line 52982
      if ((HEAP32[$171 >> 2] | 0) != ($10 | 0)) {
       _abort(); //@line 52986
      }
      $174 = $165 + 8 | 0; //@line 52989
      if ((HEAP32[$174 >> 2] | 0) == ($10 | 0)) {
       HEAP32[$171 >> 2] = $165; //@line 52993
       HEAP32[$174 >> 2] = $168; //@line 52994
       $$3400 = $165; //@line 52995
       break;
      } else {
       _abort(); //@line 52998
      }
     }
    } while (0);
    if ($163 | 0) {
     $193 = HEAP32[$10 + 28 >> 2] | 0; //@line 53006
     $194 = 651644 + ($193 << 2) | 0; //@line 53007
     do {
      if (($10 | 0) == (HEAP32[$194 >> 2] | 0)) {
       HEAP32[$194 >> 2] = $$3400; //@line 53012
       if (!$$3400) {
        HEAP32[162836] = HEAP32[162836] & ~(1 << $193); //@line 53019
        break L108;
       }
      } else {
       if ($163 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
        _abort(); //@line 53026
       } else {
        HEAP32[$163 + 16 + (((HEAP32[$163 + 16 >> 2] | 0) != ($10 | 0) & 1) << 2) >> 2] = $$3400; //@line 53034
        if (!$$3400) {
         break L108;
        } else {
         break;
        }
       }
      }
     } while (0);
     $207 = HEAP32[162839] | 0; //@line 53044
     if ($$3400 >>> 0 < $207 >>> 0) {
      _abort(); //@line 53047
     }
     HEAP32[$$3400 + 24 >> 2] = $163; //@line 53051
     $210 = $10 + 16 | 0; //@line 53052
     $211 = HEAP32[$210 >> 2] | 0; //@line 53053
     do {
      if ($211 | 0) {
       if ($211 >>> 0 < $207 >>> 0) {
        _abort(); //@line 53059
       } else {
        HEAP32[$$3400 + 16 >> 2] = $211; //@line 53063
        HEAP32[$211 + 24 >> 2] = $$3400; //@line 53065
        break;
       }
      }
     } while (0);
     $217 = HEAP32[$210 + 4 >> 2] | 0; //@line 53071
     if ($217 | 0) {
      if ($217 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 53077
      } else {
       HEAP32[$$3400 + 20 >> 2] = $217; //@line 53081
       HEAP32[$217 + 24 >> 2] = $$3400; //@line 53083
       break;
      }
     }
    }
   }
  } while (0);
  HEAP32[$$1 + 4 >> 2] = $135 | 1; //@line 53092
  HEAP32[$113 + $135 >> 2] = $135; //@line 53094
  if (($$1 | 0) == (HEAP32[162840] | 0)) {
   HEAP32[162837] = $135; //@line 53098
   return;
  } else {
   $$2 = $135; //@line 53101
  }
 } else {
  HEAP32[$114 >> 2] = $115 & -2; //@line 53105
  HEAP32[$$1 + 4 >> 2] = $$1382 | 1; //@line 53108
  HEAP32[$113 + $$1382 >> 2] = $$1382; //@line 53110
  $$2 = $$1382; //@line 53111
 }
 $232 = $$2 >>> 3; //@line 53113
 if ($$2 >>> 0 < 256) {
  $235 = 651380 + ($232 << 1 << 2) | 0; //@line 53117
  $236 = HEAP32[162835] | 0; //@line 53118
  $237 = 1 << $232; //@line 53119
  if (!($236 & $237)) {
   HEAP32[162835] = $236 | $237; //@line 53124
   $$0403 = $235; //@line 53126
   $$pre$phiZ2D = $235 + 8 | 0; //@line 53126
  } else {
   $241 = $235 + 8 | 0; //@line 53128
   $242 = HEAP32[$241 >> 2] | 0; //@line 53129
   if ($242 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
    _abort(); //@line 53133
   } else {
    $$0403 = $242; //@line 53136
    $$pre$phiZ2D = $241; //@line 53136
   }
  }
  HEAP32[$$pre$phiZ2D >> 2] = $$1; //@line 53139
  HEAP32[$$0403 + 12 >> 2] = $$1; //@line 53141
  HEAP32[$$1 + 8 >> 2] = $$0403; //@line 53143
  HEAP32[$$1 + 12 >> 2] = $235; //@line 53145
  return;
 }
 $248 = $$2 >>> 8; //@line 53148
 if (!$248) {
  $$0396 = 0; //@line 53151
 } else {
  if ($$2 >>> 0 > 16777215) {
   $$0396 = 31; //@line 53155
  } else {
   $253 = ($248 + 1048320 | 0) >>> 16 & 8; //@line 53159
   $254 = $248 << $253; //@line 53160
   $257 = ($254 + 520192 | 0) >>> 16 & 4; //@line 53163
   $259 = $254 << $257; //@line 53165
   $262 = ($259 + 245760 | 0) >>> 16 & 2; //@line 53168
   $267 = 14 - ($257 | $253 | $262) + ($259 << $262 >>> 15) | 0; //@line 53173
   $$0396 = $$2 >>> ($267 + 7 | 0) & 1 | $267 << 1; //@line 53179
  }
 }
 $273 = 651644 + ($$0396 << 2) | 0; //@line 53182
 HEAP32[$$1 + 28 >> 2] = $$0396; //@line 53184
 HEAP32[$$1 + 20 >> 2] = 0; //@line 53187
 HEAP32[$$1 + 16 >> 2] = 0; //@line 53188
 $277 = HEAP32[162836] | 0; //@line 53189
 $278 = 1 << $$0396; //@line 53190
 do {
  if (!($277 & $278)) {
   HEAP32[162836] = $277 | $278; //@line 53196
   HEAP32[$273 >> 2] = $$1; //@line 53197
   HEAP32[$$1 + 24 >> 2] = $273; //@line 53199
   HEAP32[$$1 + 12 >> 2] = $$1; //@line 53201
   HEAP32[$$1 + 8 >> 2] = $$1; //@line 53203
  } else {
   $$0383 = $$2 << (($$0396 | 0) == 31 ? 0 : 25 - ($$0396 >>> 1) | 0); //@line 53211
   $$0384 = HEAP32[$273 >> 2] | 0; //@line 53211
   while (1) {
    if ((HEAP32[$$0384 + 4 >> 2] & -8 | 0) == ($$2 | 0)) {
     label = 124; //@line 53218
     break;
    }
    $296 = $$0384 + 16 + ($$0383 >>> 31 << 2) | 0; //@line 53222
    $298 = HEAP32[$296 >> 2] | 0; //@line 53224
    if (!$298) {
     label = 121; //@line 53227
     break;
    } else {
     $$0383 = $$0383 << 1; //@line 53230
     $$0384 = $298; //@line 53230
    }
   }
   if ((label | 0) == 121) {
    if ($296 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
     _abort(); //@line 53237
    } else {
     HEAP32[$296 >> 2] = $$1; //@line 53240
     HEAP32[$$1 + 24 >> 2] = $$0384; //@line 53242
     HEAP32[$$1 + 12 >> 2] = $$1; //@line 53244
     HEAP32[$$1 + 8 >> 2] = $$1; //@line 53246
     break;
    }
   } else if ((label | 0) == 124) {
    $305 = $$0384 + 8 | 0; //@line 53251
    $306 = HEAP32[$305 >> 2] | 0; //@line 53252
    $307 = HEAP32[162839] | 0; //@line 53253
    if ($306 >>> 0 >= $307 >>> 0 & $$0384 >>> 0 >= $307 >>> 0) {
     HEAP32[$306 + 12 >> 2] = $$1; //@line 53259
     HEAP32[$305 >> 2] = $$1; //@line 53260
     HEAP32[$$1 + 8 >> 2] = $306; //@line 53262
     HEAP32[$$1 + 12 >> 2] = $$0384; //@line 53264
     HEAP32[$$1 + 24 >> 2] = 0; //@line 53266
     break;
    } else {
     _abort(); //@line 53269
    }
   }
  }
 } while (0);
 $315 = (HEAP32[162843] | 0) + -1 | 0; //@line 53276
 HEAP32[162843] = $315; //@line 53277
 if (!$315) {
  $$0212$in$i = 651796; //@line 53280
 } else {
  return;
 }
 while (1) {
  $$0212$i = HEAP32[$$0212$in$i >> 2] | 0; //@line 53285
  if (!$$0212$i) {
   break;
  } else {
   $$0212$in$i = $$0212$i + 8 | 0; //@line 53291
  }
 }
 HEAP32[162843] = -1; //@line 53294
 return;
}
function __Z12EtherControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph$lcssa$i$i$i$i = 0, $$0$ph13$i$i$i = 0, $$0$ph13$i$i$i$i = 0, $$017$i = 0, $$018$i = 0, $$020$i = 0, $$02132$i = 0, $$024$i$i = 0, $$025$i33$i = 0, $$040 = 0, $$05$i$i$i$i$i = 0, $$07$ph12$i$i$i = 0, $$07$ph12$i$i$i$i = 0, $$0710$i$i$i = 0, $$0710$i$i$i$i = 0, $$11923$i = 0, $$3$ph = 0, $$6 = 0, $$in$i$i = 0, $10 = 0, $106 = 0, $108 = 0, $109 = 0, $112 = 0, $114 = 0, $115 = 0, $117 = 0, $126 = 0, $131 = 0, $139 = 0, $145 = 0, $151 = 0, $161 = 0, $163 = 0, $168 = 0, $175 = 0, $180 = 0, $2 = 0, $21 = 0, $243 = 0, $251 = 0, $253 = 0, $259 = 0, $264 = 0, $28 = 0, $29 = 0, $3 = 0, $34 = 0, $39 = 0, $4 = 0, $47 = 0, $54 = 0, $56 = 0, $59 = 0, $60 = 0, $63 = 0, $64 = 0, $70 = 0, $74 = 0, $79 = 0, $86 = 0, $91 = 0, $99 = 0, $sext = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 15446
 STACKTOP = STACKTOP + 1552 | 0; //@line 15447
 $vararg_buffer = sp; //@line 15448
 $2 = sp + 24 | 0; //@line 15449
 $3 = sp + 8 | 0; //@line 15450
 $4 = $0 + 26 | 0; //@line 15451
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 15457
 switch (($10 & 65535) << 16 >> 16) {
 case 246:
  {
   if (!((HEAP8[657350] | 0) != 0 & (HEAP8[657351] | 0) == 0)) {
    $$6 = 0; //@line 15467
    STACKTOP = sp; //@line 15468
    return $$6 | 0; //@line 15468
   }
   $$6 = __Z19ether_add_multicastj($0) | 0; //@line 15471
   STACKTOP = sp; //@line 15472
   return $$6 | 0; //@line 15472
  }
 case 245:
  {
   if (!((HEAP8[657350] | 0) != 0 & (HEAP8[657351] | 0) == 0)) {
    $$6 = 0; //@line 15482
    STACKTOP = sp; //@line 15483
    return $$6 | 0; //@line 15483
   }
   $$6 = __Z19ether_del_multicastj($0) | 0; //@line 15486
   STACKTOP = sp; //@line 15487
   return $$6 | 0; //@line 15487
  }
 case 247:
  {
   $21 = $0 + 28 | 0; //@line 15491
   $28 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($21) | 0) & 65535; //@line 15498
   $29 = $0 + 30 | 0; //@line 15499
   $34 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($29 >>> 16 << 2) >> 2] >> 2] & 127]($29) | 0; //@line 15504
   if (!(HEAP8[657350] | 0)) {
    $$6 = 0; //@line 15508
    STACKTOP = sp; //@line 15509
    return $$6 | 0; //@line 15509
   }
   if (!(HEAP8[657351] | 0)) {
    $$6 = __Z15ether_attach_phtj($28, $34) | 0; //@line 15515
    STACKTOP = sp; //@line 15516
    return $$6 | 0; //@line 15516
   }
   $39 = HEAP32[28479] | 0; //@line 15518
   do {
    if (!$39) {
     $$02132$i = 113916; //@line 15522
     $$025$i33$i = 113916; //@line 15522
     label = 24; //@line 15523
    } else {
     $$0$ph13$i$i$i = 113916; //@line 15525
     $$07$ph12$i$i$i = $39; //@line 15525
     L23 : while (1) {
      $$0710$i$i$i = $$07$ph12$i$i$i; //@line 15527
      while (1) {
       if ((HEAPU16[$$0710$i$i$i + 16 >> 1] | 0) >= ($28 & 65535)) {
        break;
       }
       $47 = HEAP32[$$0710$i$i$i + 4 >> 2] | 0; //@line 15536
       if (!$47) {
        $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i; //@line 15539
        break L23;
       } else {
        $$0710$i$i$i = $47; //@line 15542
       }
      }
      $$07$ph12$i$i$i = HEAP32[$$0710$i$i$i >> 2] | 0; //@line 15545
      if (!$$07$ph12$i$i$i) {
       $$0$ph$lcssa$i$i$i = $$0710$i$i$i; //@line 15548
       break;
      } else {
       $$0$ph13$i$i$i = $$0710$i$i$i; //@line 15551
      }
     }
     if (($$0$ph$lcssa$i$i$i | 0) != 113916) {
      if (($28 & 65535) >= (HEAPU16[$$0$ph$lcssa$i$i$i + 16 >> 1] | 0)) {
       $$6 = -94; //@line 15560
       STACKTOP = sp; //@line 15561
       return $$6 | 0; //@line 15561
      }
     }
     $$0$i$i = 113916; //@line 15564
     $$024$i$i = $39; //@line 15564
     $63 = $39; //@line 15564
     while (1) {
      $54 = HEAP16[$$024$i$i + 16 >> 1] | 0; //@line 15567
      if (($28 & 65535) < ($54 & 65535)) {
       $56 = HEAP32[$$024$i$i >> 2] | 0; //@line 15570
       if (!$56) {
        label = 19; //@line 15573
        break;
       } else {
        $$0$ph$i$i = $$024$i$i; //@line 15576
        $$in$i$i = $56; //@line 15576
       }
      } else {
       if (($54 & 65535) >= ($28 & 65535)) {
        label = 23; //@line 15581
        break;
       }
       $59 = $$024$i$i + 4 | 0; //@line 15584
       $60 = HEAP32[$59 >> 2] | 0; //@line 15585
       if (!$60) {
        label = 22; //@line 15588
        break;
       } else {
        $$0$ph$i$i = $59; //@line 15591
        $$in$i$i = $60; //@line 15591
       }
      }
      $$0$i$i = $$0$ph$i$i; //@line 15594
      $$024$i$i = $$in$i$i; //@line 15594
      $63 = $$in$i$i; //@line 15594
     }
     if ((label | 0) == 19) {
      $$02132$i = $$024$i$i; //@line 15597
      $$025$i33$i = $$024$i$i; //@line 15597
      label = 24; //@line 15598
      break;
     } else if ((label | 0) == 22) {
      $$02132$i = $$024$i$i; //@line 15602
      $$025$i33$i = $59; //@line 15602
      label = 24; //@line 15603
      break;
     } else if ((label | 0) == 23) {
      if (!$63) {
       $$02132$i = $$024$i$i; //@line 15609
       $$025$i33$i = $$0$i$i; //@line 15609
       label = 24; //@line 15610
       break;
      } else {
       $$0$i = $63; //@line 15613
       break;
      }
     }
    }
   } while (0);
   if ((label | 0) == 24) {
    $64 = __Znwj(24) | 0; //@line 15620
    HEAP16[$64 + 16 >> 1] = $28; //@line 15622
    HEAP32[$64 + 20 >> 2] = 0; //@line 15624
    HEAP32[$64 >> 2] = 0; //@line 15625
    HEAP32[$64 + 4 >> 2] = 0; //@line 15627
    HEAP32[$64 + 8 >> 2] = $$02132$i; //@line 15629
    HEAP32[$$025$i33$i >> 2] = $64; //@line 15630
    $70 = HEAP32[HEAP32[28478] >> 2] | 0; //@line 15632
    if (!$70) {
     $74 = $64; //@line 15635
    } else {
     HEAP32[28478] = $70; //@line 15638
     $74 = HEAP32[$$025$i33$i >> 2] | 0; //@line 15640
    }
    __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[28479] | 0, $74); //@line 15643
    HEAP32[28480] = (HEAP32[28480] | 0) + 1; //@line 15646
    $$0$i = $64; //@line 15647
   }
   HEAP32[$$0$i + 20 >> 2] = $34; //@line 15650
   $$6 = 0; //@line 15651
   STACKTOP = sp; //@line 15652
   return $$6 | 0; //@line 15652
  }
 case 248:
  {
   $79 = $0 + 28 | 0; //@line 15656
   $86 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($79 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($79) | 0) & 65535; //@line 15663
   if (!(HEAP8[657350] | 0)) {
    $$6 = 0; //@line 15667
    STACKTOP = sp; //@line 15668
    return $$6 | 0; //@line 15668
   }
   if (!(HEAP8[657351] | 0)) {
    $$6 = __Z15ether_detach_pht($86) | 0; //@line 15674
    STACKTOP = sp; //@line 15675
    return $$6 | 0; //@line 15675
   }
   $91 = HEAP32[28479] | 0; //@line 15677
   if (!$91) {
    $$6 = -94; //@line 15680
    STACKTOP = sp; //@line 15681
    return $$6 | 0; //@line 15681
   } else {
    $$0$ph13$i$i$i$i = 113916; //@line 15683
    $$07$ph12$i$i$i$i = $91; //@line 15683
   }
   L62 : while (1) {
    $$0710$i$i$i$i = $$07$ph12$i$i$i$i; //@line 15686
    while (1) {
     if ((HEAPU16[$$0710$i$i$i$i + 16 >> 1] | 0) >= ($86 & 65535)) {
      break;
     }
     $99 = HEAP32[$$0710$i$i$i$i + 4 >> 2] | 0; //@line 15695
     if (!$99) {
      $$0$ph$lcssa$i$i$i$i = $$0$ph13$i$i$i$i; //@line 15698
      break L62;
     } else {
      $$0710$i$i$i$i = $99; //@line 15701
     }
    }
    $$07$ph12$i$i$i$i = HEAP32[$$0710$i$i$i$i >> 2] | 0; //@line 15704
    if (!$$07$ph12$i$i$i$i) {
     $$0$ph$lcssa$i$i$i$i = $$0710$i$i$i$i; //@line 15707
     break;
    } else {
     $$0$ph13$i$i$i$i = $$0710$i$i$i$i; //@line 15710
    }
   }
   if (($$0$ph$lcssa$i$i$i$i | 0) == 113916) {
    $$6 = -94; //@line 15715
    STACKTOP = sp; //@line 15716
    return $$6 | 0; //@line 15716
   }
   if (($86 & 65535) < (HEAPU16[$$0$ph$lcssa$i$i$i$i + 16 >> 1] | 0)) {
    $$6 = -94; //@line 15722
    STACKTOP = sp; //@line 15723
    return $$6 | 0; //@line 15723
   }
   $106 = HEAP32[$$0$ph$lcssa$i$i$i$i + 4 >> 2] | 0; //@line 15726
   if (!$106) {
    $108 = $$0$ph$lcssa$i$i$i$i + 8 | 0; //@line 15729
    $109 = HEAP32[$108 >> 2] | 0; //@line 15730
    if ((HEAP32[$109 >> 2] | 0) == ($$0$ph$lcssa$i$i$i$i | 0)) {
     $$05$i$i$i$i$i = $109; //@line 15734
    } else {
     $115 = $108; //@line 15736
     do {
      $114 = HEAP32[$115 >> 2] | 0; //@line 15738
      $115 = $114 + 8 | 0; //@line 15739
      $117 = HEAP32[$115 >> 2] | 0; //@line 15740
     } while ((HEAP32[$117 >> 2] | 0) != ($114 | 0));
     $$05$i$i$i$i$i = $117; //@line 15744
    }
   } else {
    $$0$i$i$i$i$i$i = $106; //@line 15752
    while (1) {
     $112 = HEAP32[$$0$i$i$i$i$i$i >> 2] | 0; //@line 15754
     if (!$112) {
      break;
     } else {
      $$0$i$i$i$i$i$i = $112; //@line 15759
     }
    }
    $$05$i$i$i$i$i = $$0$i$i$i$i$i$i; //@line 15762
   }
   if ((HEAP32[28478] | 0) == ($$0$ph$lcssa$i$i$i$i | 0)) {
    HEAP32[28478] = $$05$i$i$i$i$i; //@line 15768
   }
   HEAP32[28480] = (HEAP32[28480] | 0) + -1; //@line 15772
   __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($91, $$0$ph$lcssa$i$i$i$i); //@line 15773
   __ZdlPv($$0$ph$lcssa$i$i$i$i); //@line 15774
   $$6 = 0; //@line 15775
   STACKTOP = sp; //@line 15776
   return $$6 | 0; //@line 15776
  }
 case 249:
  {
   $126 = $0 + 30 | 0; //@line 15780
   $131 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($126 >>> 16 << 2) >> 2] >> 2] & 127]($126) | 0; //@line 15785
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($131 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($131) | 0) >>> 0 < 14) {
    $$6 = -92; //@line 15794
    STACKTOP = sp; //@line 15795
    return $$6 | 0; //@line 15795
   }
   $139 = $131 + 2 | 0; //@line 15797
   $145 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($139 >>> 16 << 2) >> 2] >> 2] & 127]($139) | 0) + 6 | 0; //@line 15803
   $151 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($145 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($145) | 0; //@line 15809
   HEAP8[$151 >> 0] = HEAP8[657344] | 0; //@line 15810
   HEAP8[$151 + 1 >> 0] = HEAP8[657345] | 0; //@line 15810
   HEAP8[$151 + 2 >> 0] = HEAP8[657346] | 0; //@line 15810
   HEAP8[$151 + 3 >> 0] = HEAP8[657347] | 0; //@line 15810
   HEAP8[$151 + 4 >> 0] = HEAP8[657348] | 0; //@line 15810
   HEAP8[$151 + 5 >> 0] = HEAP8[657349] | 0; //@line 15810
   if (!(HEAP8[657350] | 0)) {
    $$6 = 0; //@line 15814
    STACKTOP = sp; //@line 15815
    return $$6 | 0; //@line 15815
   }
   if (!(HEAP8[657351] | 0)) {
    $$6 = __Z11ether_writej($131) | 0; //@line 15821
    STACKTOP = sp; //@line 15822
    return $$6 | 0; //@line 15822
   }
   $$017$i = $131; //@line 15824
   $$018$i = 0; //@line 15824
   $$020$i = $2; //@line 15824
   while (1) {
    $161 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$017$i >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$017$i) | 0; //@line 15831
    if (!$161) {
     $$11923$i = $$018$i; //@line 15834
     break;
    }
    $163 = $$017$i + 2 | 0; //@line 15837
    $168 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($163 >>> 16 << 2) >> 2] >> 2] & 127]($163) | 0; //@line 15842
    _memcpy($$020$i | 0, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($168 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($168) | 0, $161 | 0) | 0; //@line 15849
    $175 = $161 + $$018$i | 0; //@line 15850
    if (($175 | 0) < 1514) {
     $$017$i = $$017$i + 6 | 0; //@line 15855
     $$018$i = $175; //@line 15855
     $$020$i = $$020$i + $161 | 0; //@line 15855
    } else {
     $$11923$i = $175; //@line 15857
     break;
    }
   }
   $180 = HEAP8[$2 >> 0] | 0; //@line 15862
   L102 : do {
    if (($$11923$i | 0) > 5 & $180 << 24 >> 24 == 66) {
     if ((HEAP8[$2 + 1 >> 0] | 0) == 50) {
      $$040 = HEAPU8[$2 + 3 >> 0] << 16 | HEAPU8[$2 + 2 >> 0] << 24 | HEAPU8[$2 + 4 >> 0] << 8 | HEAPU8[$2 + 5 >> 0]; //@line 15889
      label = 67; //@line 15890
     } else {
      $$3$ph = -91; //@line 15892
     }
    } else {
     switch ($180 << 24 >> 24) {
     case 9:
      {
       if (HEAP8[$2 + 1 >> 0] | 0) {
        $$3$ph = -91; //@line 15901
        break L102;
       }
       if ((HEAP8[$2 + 2 >> 0] | 0) != 7) {
        $$3$ph = -91; //@line 15908
        break L102;
       }
       if ((HEAP8[$2 + 3 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15915
        break L102;
       }
       if ((HEAP8[$2 + 4 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15922
        break L102;
       }
       if ((HEAP8[$2 + 5 >> 0] | 0) == -1) {
        $$040 = -1; //@line 15929
        label = 67; //@line 15930
        break L102;
       } else {
        $$3$ph = -91; //@line 15933
        break L102;
       }
       break;
      }
     case -1:
      {
       if ((HEAP8[$2 + 1 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15943
        break L102;
       }
       if ((HEAP8[$2 + 2 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15950
        break L102;
       }
       if ((HEAP8[$2 + 3 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15957
        break L102;
       }
       if ((HEAP8[$2 + 4 >> 0] | 0) != -1) {
        $$3$ph = -91; //@line 15964
        break L102;
       }
       if ((HEAP8[$2 + 5 >> 0] | 0) == -1) {
        $$040 = -1; //@line 15971
        label = 67; //@line 15972
        break L102;
       } else {
        $$3$ph = -91; //@line 15975
        break L102;
       }
       break;
      }
     default:
      {
       $$3$ph = -91; //@line 15981
       break L102;
      }
     }
    }
   } while (0);
   if ((label | 0) == 67) {
    HEAP16[$3 >> 1] = 2; //@line 15988
    HEAP32[$3 + 4 >> 2] = _htonl($$040) | 0; //@line 15991
    HEAP16[$3 + 2 >> 1] = _htons(HEAP16[325961] | 0) | 0; //@line 15995
    if ((_sendto(HEAP32[370] | 0, $2, $$11923$i, 0, $3, 16) | 0) < 0) {
     $$3$ph = -95; //@line 16000
    } else {
     $$6 = 0; //@line 16002
     STACKTOP = sp; //@line 16003
     return $$6 | 0; //@line 16003
    }
   }
   $$6 = $$3$ph; //@line 16006
   STACKTOP = sp; //@line 16007
   return $$6 | 0; //@line 16007
  }
 case 252:
  {
   dest = $2 + 6 | 0; //@line 16012
   stop = dest + 12 | 0; //@line 16012
   do {
    HEAP8[dest >> 0] = 0; //@line 16012
    dest = dest + 1 | 0; //@line 16012
   } while ((dest | 0) < (stop | 0));
   HEAP8[$2 >> 0] = HEAP8[657344] | 0; //@line 16013
   HEAP8[$2 + 1 >> 0] = HEAP8[657345] | 0; //@line 16013
   HEAP8[$2 + 2 >> 0] = HEAP8[657346] | 0; //@line 16013
   HEAP8[$2 + 3 >> 0] = HEAP8[657347] | 0; //@line 16013
   HEAP8[$2 + 4 >> 0] = HEAP8[657348] | 0; //@line 16013
   HEAP8[$2 + 5 >> 0] = HEAP8[657349] | 0; //@line 16013
   $243 = $0 + 34 | 0; //@line 16014
   $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($243 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($243) | 0) << 16; //@line 16021
   $251 = $0 + 36 | 0; //@line 16023
   $253 = ($sext | 0) > 1179648 ? 18 : $sext >> 16; //@line 16025
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($251 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($251, $253); //@line 16031
   $259 = $0 + 30 | 0; //@line 16032
   $264 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($259 >>> 16 << 2) >> 2] >> 2] & 127]($259) | 0; //@line 16037
   _memcpy(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($264 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($264) | 0, $2 | 0, $253 | 0) | 0; //@line 16044
   $$6 = 0; //@line 16045
   STACKTOP = sp; //@line 16046
   return $$6 | 0; //@line 16046
  }
 case 253:
  {
   $$6 = 0; //@line 16050
   STACKTOP = sp; //@line 16051
   return $$6 | 0; //@line 16051
  }
 case 1:
  {
   $$6 = -1; //@line 16055
   STACKTOP = sp; //@line 16056
   return $$6 | 0; //@line 16056
  }
 default:
  {
   HEAP32[$vararg_buffer >> 2] = $10 & 65535; //@line 16061
   _printf(93557, $vararg_buffer) | 0; //@line 16062
   $$6 = -17; //@line 16063
   STACKTOP = sp; //@line 16064
   return $$6 | 0; //@line 16064
  }
 }
 return 0; //@line 16067
}
function _dispose_chunk($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0419 = 0, $$0420 = 0, $$0431 = 0, $$0438 = 0, $$1 = 0, $$1418 = 0, $$1426 = 0, $$1429 = 0, $$1433 = 0, $$1437 = 0, $$2 = 0, $$3 = 0, $$3435 = 0, $$pre$phi24Z2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $100 = 0, $101 = 0, $108 = 0, $11 = 0, $110 = 0, $111 = 0, $116 = 0, $118 = 0, $12 = 0, $124 = 0, $129 = 0, $13 = 0, $130 = 0, $133 = 0, $135 = 0, $137 = 0, $150 = 0, $155 = 0, $157 = 0, $160 = 0, $162 = 0, $165 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $172 = 0, $174 = 0, $175 = 0, $177 = 0, $178 = 0, $183 = 0, $184 = 0, $197 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $207 = 0, $22 = 0, $222 = 0, $225 = 0, $226 = 0, $227 = 0, $231 = 0, $232 = 0, $238 = 0, $24 = 0, $243 = 0, $244 = 0, $247 = 0, $249 = 0, $252 = 0, $257 = 0, $263 = 0, $267 = 0, $268 = 0, $286 = 0, $288 = 0, $295 = 0, $296 = 0, $297 = 0, $37 = 0, $4 = 0, $42 = 0, $44 = 0, $47 = 0, $49 = 0, $52 = 0, $55 = 0, $56 = 0, $57 = 0, $59 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $7 = 0, $70 = 0, $71 = 0, $84 = 0, $87 = 0, $88 = 0, $94 = 0, label = 0;
 $2 = $0 + $1 | 0; //@line 53826
 $4 = HEAP32[$0 + 4 >> 2] | 0; //@line 53828
 L1 : do {
  if (!($4 & 1)) {
   $7 = HEAP32[$0 >> 2] | 0; //@line 53833
   if (!($4 & 3)) {
    return;
   }
   $11 = $0 + (0 - $7) | 0; //@line 53840
   $12 = $7 + $1 | 0; //@line 53841
   $13 = HEAP32[162839] | 0; //@line 53842
   if ($11 >>> 0 < $13 >>> 0) {
    _abort(); //@line 53845
   }
   if (($11 | 0) == (HEAP32[162840] | 0)) {
    $100 = $2 + 4 | 0; //@line 53851
    $101 = HEAP32[$100 >> 2] | 0; //@line 53852
    if (($101 & 3 | 0) != 3) {
     $$1 = $11; //@line 53856
     $$1418 = $12; //@line 53856
     break;
    }
    HEAP32[162837] = $12; //@line 53863
    HEAP32[$100 >> 2] = $101 & -2; //@line 53864
    HEAP32[$11 + 4 >> 2] = $12 | 1; //@line 53865
    HEAP32[$11 + $12 >> 2] = $12; //@line 53866
    return;
   }
   $17 = $7 >>> 3; //@line 53869
   if ($7 >>> 0 < 256) {
    $20 = HEAP32[$11 + 8 >> 2] | 0; //@line 53873
    $22 = HEAP32[$11 + 12 >> 2] | 0; //@line 53875
    $24 = 651380 + ($17 << 1 << 2) | 0; //@line 53877
    if (($20 | 0) != ($24 | 0)) {
     if ($20 >>> 0 < $13 >>> 0) {
      _abort(); //@line 53882
     }
     if ((HEAP32[$20 + 12 >> 2] | 0) != ($11 | 0)) {
      _abort(); //@line 53889
     }
    }
    if (($22 | 0) == ($20 | 0)) {
     HEAP32[162835] = HEAP32[162835] & ~(1 << $17); //@line 53899
     $$1 = $11; //@line 53900
     $$1418 = $12; //@line 53900
     break;
    }
    if (($22 | 0) == ($24 | 0)) {
     $$pre$phi26Z2D = $22 + 8 | 0; //@line 53906
    } else {
     if ($22 >>> 0 < $13 >>> 0) {
      _abort(); //@line 53910
     }
     $37 = $22 + 8 | 0; //@line 53913
     if ((HEAP32[$37 >> 2] | 0) == ($11 | 0)) {
      $$pre$phi26Z2D = $37; //@line 53917
     } else {
      _abort(); //@line 53919
     }
    }
    HEAP32[$20 + 12 >> 2] = $22; //@line 53924
    HEAP32[$$pre$phi26Z2D >> 2] = $20; //@line 53925
    $$1 = $11; //@line 53926
    $$1418 = $12; //@line 53926
    break;
   }
   $42 = HEAP32[$11 + 24 >> 2] | 0; //@line 53930
   $44 = HEAP32[$11 + 12 >> 2] | 0; //@line 53932
   do {
    if (($44 | 0) == ($11 | 0)) {
     $55 = $11 + 16 | 0; //@line 53936
     $56 = $55 + 4 | 0; //@line 53937
     $57 = HEAP32[$56 >> 2] | 0; //@line 53938
     if (!$57) {
      $59 = HEAP32[$55 >> 2] | 0; //@line 53941
      if (!$59) {
       $$3 = 0; //@line 53944
       break;
      } else {
       $$1426 = $59; //@line 53947
       $$1429 = $55; //@line 53947
      }
     } else {
      $$1426 = $57; //@line 53950
      $$1429 = $56; //@line 53950
     }
     while (1) {
      $61 = $$1426 + 20 | 0; //@line 53953
      $62 = HEAP32[$61 >> 2] | 0; //@line 53954
      if ($62 | 0) {
       $$1426 = $62; //@line 53957
       $$1429 = $61; //@line 53957
       continue;
      }
      $64 = $$1426 + 16 | 0; //@line 53960
      $65 = HEAP32[$64 >> 2] | 0; //@line 53961
      if (!$65) {
       break;
      } else {
       $$1426 = $65; //@line 53966
       $$1429 = $64; //@line 53966
      }
     }
     if ($$1429 >>> 0 < $13 >>> 0) {
      _abort(); //@line 53971
     } else {
      HEAP32[$$1429 >> 2] = 0; //@line 53974
      $$3 = $$1426; //@line 53975
      break;
     }
    } else {
     $47 = HEAP32[$11 + 8 >> 2] | 0; //@line 53980
     if ($47 >>> 0 < $13 >>> 0) {
      _abort(); //@line 53983
     }
     $49 = $47 + 12 | 0; //@line 53986
     if ((HEAP32[$49 >> 2] | 0) != ($11 | 0)) {
      _abort(); //@line 53990
     }
     $52 = $44 + 8 | 0; //@line 53993
     if ((HEAP32[$52 >> 2] | 0) == ($11 | 0)) {
      HEAP32[$49 >> 2] = $44; //@line 53997
      HEAP32[$52 >> 2] = $47; //@line 53998
      $$3 = $44; //@line 53999
      break;
     } else {
      _abort(); //@line 54002
     }
    }
   } while (0);
   if (!$42) {
    $$1 = $11; //@line 54009
    $$1418 = $12; //@line 54009
   } else {
    $70 = HEAP32[$11 + 28 >> 2] | 0; //@line 54012
    $71 = 651644 + ($70 << 2) | 0; //@line 54013
    do {
     if (($11 | 0) == (HEAP32[$71 >> 2] | 0)) {
      HEAP32[$71 >> 2] = $$3; //@line 54018
      if (!$$3) {
       HEAP32[162836] = HEAP32[162836] & ~(1 << $70); //@line 54025
       $$1 = $11; //@line 54026
       $$1418 = $12; //@line 54026
       break L1;
      }
     } else {
      if ($42 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 54033
      } else {
       HEAP32[$42 + 16 + (((HEAP32[$42 + 16 >> 2] | 0) != ($11 | 0) & 1) << 2) >> 2] = $$3; //@line 54041
       if (!$$3) {
        $$1 = $11; //@line 54044
        $$1418 = $12; //@line 54044
        break L1;
       } else {
        break;
       }
      }
     }
    } while (0);
    $84 = HEAP32[162839] | 0; //@line 54052
    if ($$3 >>> 0 < $84 >>> 0) {
     _abort(); //@line 54055
    }
    HEAP32[$$3 + 24 >> 2] = $42; //@line 54059
    $87 = $11 + 16 | 0; //@line 54060
    $88 = HEAP32[$87 >> 2] | 0; //@line 54061
    do {
     if ($88 | 0) {
      if ($88 >>> 0 < $84 >>> 0) {
       _abort(); //@line 54067
      } else {
       HEAP32[$$3 + 16 >> 2] = $88; //@line 54071
       HEAP32[$88 + 24 >> 2] = $$3; //@line 54073
       break;
      }
     }
    } while (0);
    $94 = HEAP32[$87 + 4 >> 2] | 0; //@line 54079
    if (!$94) {
     $$1 = $11; //@line 54082
     $$1418 = $12; //@line 54082
    } else {
     if ($94 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
      _abort(); //@line 54087
     } else {
      HEAP32[$$3 + 20 >> 2] = $94; //@line 54091
      HEAP32[$94 + 24 >> 2] = $$3; //@line 54093
      $$1 = $11; //@line 54094
      $$1418 = $12; //@line 54094
      break;
     }
    }
   }
  } else {
   $$1 = $0; //@line 54100
   $$1418 = $1; //@line 54100
  }
 } while (0);
 $108 = HEAP32[162839] | 0; //@line 54103
 if ($2 >>> 0 < $108 >>> 0) {
  _abort(); //@line 54106
 }
 $110 = $2 + 4 | 0; //@line 54109
 $111 = HEAP32[$110 >> 2] | 0; //@line 54110
 if (!($111 & 2)) {
  $116 = HEAP32[162840] | 0; //@line 54116
  if (($2 | 0) == (HEAP32[162841] | 0)) {
   $118 = (HEAP32[162838] | 0) + $$1418 | 0; //@line 54119
   HEAP32[162838] = $118; //@line 54120
   HEAP32[162841] = $$1; //@line 54121
   HEAP32[$$1 + 4 >> 2] = $118 | 1; //@line 54124
   if (($$1 | 0) != ($116 | 0)) {
    return;
   }
   HEAP32[162840] = 0; //@line 54129
   HEAP32[162837] = 0; //@line 54130
   return;
  }
  if (($2 | 0) == ($116 | 0)) {
   $124 = (HEAP32[162837] | 0) + $$1418 | 0; //@line 54136
   HEAP32[162837] = $124; //@line 54137
   HEAP32[162840] = $$1; //@line 54138
   HEAP32[$$1 + 4 >> 2] = $124 | 1; //@line 54141
   HEAP32[$$1 + $124 >> 2] = $124; //@line 54143
   return;
  }
  $129 = ($111 & -8) + $$1418 | 0; //@line 54147
  $130 = $111 >>> 3; //@line 54148
  L96 : do {
   if ($111 >>> 0 < 256) {
    $133 = HEAP32[$2 + 8 >> 2] | 0; //@line 54153
    $135 = HEAP32[$2 + 12 >> 2] | 0; //@line 54155
    $137 = 651380 + ($130 << 1 << 2) | 0; //@line 54157
    if (($133 | 0) != ($137 | 0)) {
     if ($133 >>> 0 < $108 >>> 0) {
      _abort(); //@line 54162
     }
     if ((HEAP32[$133 + 12 >> 2] | 0) != ($2 | 0)) {
      _abort(); //@line 54169
     }
    }
    if (($135 | 0) == ($133 | 0)) {
     HEAP32[162835] = HEAP32[162835] & ~(1 << $130); //@line 54179
     break;
    }
    if (($135 | 0) == ($137 | 0)) {
     $$pre$phi24Z2D = $135 + 8 | 0; //@line 54185
    } else {
     if ($135 >>> 0 < $108 >>> 0) {
      _abort(); //@line 54189
     }
     $150 = $135 + 8 | 0; //@line 54192
     if ((HEAP32[$150 >> 2] | 0) == ($2 | 0)) {
      $$pre$phi24Z2D = $150; //@line 54196
     } else {
      _abort(); //@line 54198
     }
    }
    HEAP32[$133 + 12 >> 2] = $135; //@line 54203
    HEAP32[$$pre$phi24Z2D >> 2] = $133; //@line 54204
   } else {
    $155 = HEAP32[$2 + 24 >> 2] | 0; //@line 54207
    $157 = HEAP32[$2 + 12 >> 2] | 0; //@line 54209
    do {
     if (($157 | 0) == ($2 | 0)) {
      $168 = $2 + 16 | 0; //@line 54213
      $169 = $168 + 4 | 0; //@line 54214
      $170 = HEAP32[$169 >> 2] | 0; //@line 54215
      if (!$170) {
       $172 = HEAP32[$168 >> 2] | 0; //@line 54218
       if (!$172) {
        $$3435 = 0; //@line 54221
        break;
       } else {
        $$1433 = $172; //@line 54224
        $$1437 = $168; //@line 54224
       }
      } else {
       $$1433 = $170; //@line 54227
       $$1437 = $169; //@line 54227
      }
      while (1) {
       $174 = $$1433 + 20 | 0; //@line 54230
       $175 = HEAP32[$174 >> 2] | 0; //@line 54231
       if ($175 | 0) {
        $$1433 = $175; //@line 54234
        $$1437 = $174; //@line 54234
        continue;
       }
       $177 = $$1433 + 16 | 0; //@line 54237
       $178 = HEAP32[$177 >> 2] | 0; //@line 54238
       if (!$178) {
        break;
       } else {
        $$1433 = $178; //@line 54243
        $$1437 = $177; //@line 54243
       }
      }
      if ($$1437 >>> 0 < $108 >>> 0) {
       _abort(); //@line 54248
      } else {
       HEAP32[$$1437 >> 2] = 0; //@line 54251
       $$3435 = $$1433; //@line 54252
       break;
      }
     } else {
      $160 = HEAP32[$2 + 8 >> 2] | 0; //@line 54257
      if ($160 >>> 0 < $108 >>> 0) {
       _abort(); //@line 54260
      }
      $162 = $160 + 12 | 0; //@line 54263
      if ((HEAP32[$162 >> 2] | 0) != ($2 | 0)) {
       _abort(); //@line 54267
      }
      $165 = $157 + 8 | 0; //@line 54270
      if ((HEAP32[$165 >> 2] | 0) == ($2 | 0)) {
       HEAP32[$162 >> 2] = $157; //@line 54274
       HEAP32[$165 >> 2] = $160; //@line 54275
       $$3435 = $157; //@line 54276
       break;
      } else {
       _abort(); //@line 54279
      }
     }
    } while (0);
    if ($155 | 0) {
     $183 = HEAP32[$2 + 28 >> 2] | 0; //@line 54287
     $184 = 651644 + ($183 << 2) | 0; //@line 54288
     do {
      if (($2 | 0) == (HEAP32[$184 >> 2] | 0)) {
       HEAP32[$184 >> 2] = $$3435; //@line 54293
       if (!$$3435) {
        HEAP32[162836] = HEAP32[162836] & ~(1 << $183); //@line 54300
        break L96;
       }
      } else {
       if ($155 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
        _abort(); //@line 54307
       } else {
        HEAP32[$155 + 16 + (((HEAP32[$155 + 16 >> 2] | 0) != ($2 | 0) & 1) << 2) >> 2] = $$3435; //@line 54315
        if (!$$3435) {
         break L96;
        } else {
         break;
        }
       }
      }
     } while (0);
     $197 = HEAP32[162839] | 0; //@line 54325
     if ($$3435 >>> 0 < $197 >>> 0) {
      _abort(); //@line 54328
     }
     HEAP32[$$3435 + 24 >> 2] = $155; //@line 54332
     $200 = $2 + 16 | 0; //@line 54333
     $201 = HEAP32[$200 >> 2] | 0; //@line 54334
     do {
      if ($201 | 0) {
       if ($201 >>> 0 < $197 >>> 0) {
        _abort(); //@line 54340
       } else {
        HEAP32[$$3435 + 16 >> 2] = $201; //@line 54344
        HEAP32[$201 + 24 >> 2] = $$3435; //@line 54346
        break;
       }
      }
     } while (0);
     $207 = HEAP32[$200 + 4 >> 2] | 0; //@line 54352
     if ($207 | 0) {
      if ($207 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 54358
      } else {
       HEAP32[$$3435 + 20 >> 2] = $207; //@line 54362
       HEAP32[$207 + 24 >> 2] = $$3435; //@line 54364
       break;
      }
     }
    }
   }
  } while (0);
  HEAP32[$$1 + 4 >> 2] = $129 | 1; //@line 54373
  HEAP32[$$1 + $129 >> 2] = $129; //@line 54375
  if (($$1 | 0) == (HEAP32[162840] | 0)) {
   HEAP32[162837] = $129; //@line 54379
   return;
  } else {
   $$2 = $129; //@line 54382
  }
 } else {
  HEAP32[$110 >> 2] = $111 & -2; //@line 54386
  HEAP32[$$1 + 4 >> 2] = $$1418 | 1; //@line 54389
  HEAP32[$$1 + $$1418 >> 2] = $$1418; //@line 54391
  $$2 = $$1418; //@line 54392
 }
 $222 = $$2 >>> 3; //@line 54394
 if ($$2 >>> 0 < 256) {
  $225 = 651380 + ($222 << 1 << 2) | 0; //@line 54398
  $226 = HEAP32[162835] | 0; //@line 54399
  $227 = 1 << $222; //@line 54400
  if (!($226 & $227)) {
   HEAP32[162835] = $226 | $227; //@line 54405
   $$0438 = $225; //@line 54407
   $$pre$phiZ2D = $225 + 8 | 0; //@line 54407
  } else {
   $231 = $225 + 8 | 0; //@line 54409
   $232 = HEAP32[$231 >> 2] | 0; //@line 54410
   if ($232 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
    _abort(); //@line 54414
   } else {
    $$0438 = $232; //@line 54417
    $$pre$phiZ2D = $231; //@line 54417
   }
  }
  HEAP32[$$pre$phiZ2D >> 2] = $$1; //@line 54420
  HEAP32[$$0438 + 12 >> 2] = $$1; //@line 54422
  HEAP32[$$1 + 8 >> 2] = $$0438; //@line 54424
  HEAP32[$$1 + 12 >> 2] = $225; //@line 54426
  return;
 }
 $238 = $$2 >>> 8; //@line 54429
 if (!$238) {
  $$0431 = 0; //@line 54432
 } else {
  if ($$2 >>> 0 > 16777215) {
   $$0431 = 31; //@line 54436
  } else {
   $243 = ($238 + 1048320 | 0) >>> 16 & 8; //@line 54440
   $244 = $238 << $243; //@line 54441
   $247 = ($244 + 520192 | 0) >>> 16 & 4; //@line 54444
   $249 = $244 << $247; //@line 54446
   $252 = ($249 + 245760 | 0) >>> 16 & 2; //@line 54449
   $257 = 14 - ($247 | $243 | $252) + ($249 << $252 >>> 15) | 0; //@line 54454
   $$0431 = $$2 >>> ($257 + 7 | 0) & 1 | $257 << 1; //@line 54460
  }
 }
 $263 = 651644 + ($$0431 << 2) | 0; //@line 54463
 HEAP32[$$1 + 28 >> 2] = $$0431; //@line 54465
 HEAP32[$$1 + 20 >> 2] = 0; //@line 54468
 HEAP32[$$1 + 16 >> 2] = 0; //@line 54469
 $267 = HEAP32[162836] | 0; //@line 54470
 $268 = 1 << $$0431; //@line 54471
 if (!($267 & $268)) {
  HEAP32[162836] = $267 | $268; //@line 54476
  HEAP32[$263 >> 2] = $$1; //@line 54477
  HEAP32[$$1 + 24 >> 2] = $263; //@line 54479
  HEAP32[$$1 + 12 >> 2] = $$1; //@line 54481
  HEAP32[$$1 + 8 >> 2] = $$1; //@line 54483
  return;
 }
 $$0419 = $$2 << (($$0431 | 0) == 31 ? 0 : 25 - ($$0431 >>> 1) | 0); //@line 54492
 $$0420 = HEAP32[$263 >> 2] | 0; //@line 54492
 while (1) {
  if ((HEAP32[$$0420 + 4 >> 2] & -8 | 0) == ($$2 | 0)) {
   label = 121; //@line 54499
   break;
  }
  $286 = $$0420 + 16 + ($$0419 >>> 31 << 2) | 0; //@line 54503
  $288 = HEAP32[$286 >> 2] | 0; //@line 54505
  if (!$288) {
   label = 118; //@line 54508
   break;
  } else {
   $$0419 = $$0419 << 1; //@line 54511
   $$0420 = $288; //@line 54511
  }
 }
 if ((label | 0) == 118) {
  if ($286 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
   _abort(); //@line 54518
  }
  HEAP32[$286 >> 2] = $$1; //@line 54521
  HEAP32[$$1 + 24 >> 2] = $$0420; //@line 54523
  HEAP32[$$1 + 12 >> 2] = $$1; //@line 54525
  HEAP32[$$1 + 8 >> 2] = $$1; //@line 54527
  return;
 } else if ((label | 0) == 121) {
  $295 = $$0420 + 8 | 0; //@line 54531
  $296 = HEAP32[$295 >> 2] | 0; //@line 54532
  $297 = HEAP32[162839] | 0; //@line 54533
  if (!($296 >>> 0 >= $297 >>> 0 & $$0420 >>> 0 >= $297 >>> 0)) {
   _abort(); //@line 54538
  }
  HEAP32[$296 + 12 >> 2] = $$1; //@line 54542
  HEAP32[$295 >> 2] = $$1; //@line 54543
  HEAP32[$$1 + 8 >> 2] = $296; //@line 54545
  HEAP32[$$1 + 12 >> 2] = $$0420; //@line 54547
  HEAP32[$$1 + 24 >> 2] = 0; //@line 54549
  return;
 }
}
function __ZL21rpc_message_send_argsP13rpc_message_tPi($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0118198 = 0, $$079$i = 0, $$079$i156 = 0, $$11 = 0, $$1119196 = 0, $$2120195 = 0, $$3121200 = 0, $$6 = 0, $10 = 0, $101 = 0, $102 = 0, $103 = 0, $106 = 0, $107 = 0, $11 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $121 = 0, $122 = 0, $123 = 0, $125 = 0, $13 = 0, $133 = 0, $134 = 0, $138 = 0, $139 = 0, $14 = 0, $143 = 0, $144 = 0, $145 = 0, $155 = 0, $156 = 0, $160 = 0, $161 = 0, $165 = 0, $166 = 0, $167 = 0, $177 = 0, $178 = 0, $18 = 0, $184 = 0, $186 = 0, $188 = 0, $19 = 0, $191 = 0, $192 = 0, $20 = 0, $201 = 0, $202 = 0, $204 = 0, $205 = 0, $211 = 0, $212 = 0, $214 = 0, $215 = 0, $217 = 0, $220 = 0, $221 = 0, $226 = 0, $232 = 0, $233 = 0, $235 = 0, $242 = 0, $243 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $35 = 0, $37 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $52 = 0, $53 = 0, $54 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $79 = 0, $8 = 0, $80 = 0, $87 = 0, $88 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $vararg_buffer = 0, $vararg_buffer37 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 42060
 STACKTOP = STACKTOP + 16 | 0; //@line 42061
 $vararg_buffer37 = sp + 8 | 0; //@line 42062
 $vararg_buffer = sp; //@line 42063
 $7 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42075
 $8 = HEAP32[$7 >> 2] | 0; //@line 42076
 HEAP32[$1 >> 2] = $7 + 4; //@line 42078
 if (!$8) {
  $$6 = 0; //@line 42081
  STACKTOP = sp; //@line 42082
  return $$6 | 0; //@line 42082
 }
 $10 = $0 + 4 | 0; //@line 42084
 $11 = $0 + 8 | 0; //@line 42085
 $12 = $8; //@line 42086
 L4 : while (1) {
  $13 = _htonl($12) | 0; //@line 42088
  $14 = HEAP32[$10 >> 2] | 0; //@line 42089
  if (($14 + 4 | 0) >>> 0 > 1023) {
   $18 = (_send(HEAP32[$0 >> 2] | 0, $11, $14, 0) | 0) == ($14 | 0); //@line 42095
   HEAP32[$10 >> 2] = 0; //@line 42096
   if ($18) {
    $20 = 0; //@line 42098
   } else {
    $$6 = -1001; //@line 42100
    label = 51; //@line 42101
    break;
   }
  } else {
   $20 = $14; //@line 42105
  }
  $19 = $0 + 8 + $20 | 0; //@line 42107
  HEAP8[$19 >> 0] = $13; //@line 42108
  HEAP8[$19 + 1 >> 0] = $13 >> 8; //@line 42108
  HEAP8[$19 + 2 >> 0] = $13 >> 16; //@line 42108
  HEAP8[$19 + 3 >> 0] = $13 >> 24; //@line 42108
  HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42111
  L9 : do {
   switch ($12 | 0) {
   case -2e3:
    {
     $28 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42126
     $29 = HEAP32[$28 >> 2] | 0; //@line 42127
     HEAP32[$1 >> 2] = $28 + 4; //@line 42129
     $30 = $29 & 255; //@line 42130
     $31 = HEAP32[$10 >> 2] | 0; //@line 42131
     if (($31 + 1 | 0) >>> 0 > 1023) {
      $35 = (_send(HEAP32[$0 >> 2] | 0, $11, $31, 0) | 0) == ($31 | 0); //@line 42137
      HEAP32[$10 >> 2] = 0; //@line 42138
      if ($35) {
       $37 = 0; //@line 42140
      } else {
       $$6 = -1001; //@line 42142
       label = 51; //@line 42143
       break L4;
      }
     } else {
      $37 = $31; //@line 42147
     }
     HEAP8[$0 + 8 + $37 >> 0] = $30; //@line 42150
     HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 1; //@line 42153
     break;
    }
   case -2002:
   case -2001:
    {
     $45 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42168
     $46 = HEAP32[$45 >> 2] | 0; //@line 42169
     HEAP32[$1 >> 2] = $45 + 4; //@line 42171
     $47 = _htonl($46) | 0; //@line 42172
     $48 = HEAP32[$10 >> 2] | 0; //@line 42173
     if (($48 + 4 | 0) >>> 0 > 1023) {
      $52 = (_send(HEAP32[$0 >> 2] | 0, $11, $48, 0) | 0) == ($48 | 0); //@line 42179
      HEAP32[$10 >> 2] = 0; //@line 42180
      if ($52) {
       $54 = 0; //@line 42182
      } else {
       $$6 = -1001; //@line 42184
       label = 51; //@line 42185
       break L4;
      }
     } else {
      $54 = $48; //@line 42189
     }
     $53 = $0 + 8 + $54 | 0; //@line 42191
     HEAP8[$53 >> 0] = $47; //@line 42192
     HEAP8[$53 + 1 >> 0] = $47 >> 8; //@line 42192
     HEAP8[$53 + 2 >> 0] = $47 >> 16; //@line 42192
     HEAP8[$53 + 3 >> 0] = $47 >> 24; //@line 42192
     HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42195
     break;
    }
   case -2003:
    {
     $62 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42210
     $63 = HEAP32[$62 >> 2] | 0; //@line 42211
     HEAP32[$1 >> 2] = $62 + 4; //@line 42213
     $64 = _htonl($63) | 0; //@line 42214
     $65 = HEAP32[$10 >> 2] | 0; //@line 42215
     if (($65 + 4 | 0) >>> 0 > 1023) {
      $69 = (_send(HEAP32[$0 >> 2] | 0, $11, $65, 0) | 0) == ($65 | 0); //@line 42221
      HEAP32[$10 >> 2] = 0; //@line 42222
      if ($69) {
       $71 = 0; //@line 42224
      } else {
       $$6 = -1001; //@line 42226
       label = 51; //@line 42227
       break L4;
      }
     } else {
      $71 = $65; //@line 42231
     }
     $70 = $0 + 8 + $71 | 0; //@line 42233
     HEAP8[$70 >> 0] = $64; //@line 42234
     HEAP8[$70 + 1 >> 0] = $64 >> 8; //@line 42234
     HEAP8[$70 + 2 >> 0] = $64 >> 16; //@line 42234
     HEAP8[$70 + 3 >> 0] = $64 >> 24; //@line 42234
     HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42237
     break;
    }
   case -2004:
    {
     $79 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42252
     $80 = HEAP32[$79 >> 2] | 0; //@line 42253
     HEAP32[$1 >> 2] = $79 + 4; //@line 42255
     $$11 = __Z23rpc_message_send_stringP13rpc_message_tPKc($0, $80) | 0; //@line 42257
     label = 49; //@line 42258
     break;
    }
   case -2005:
    {
     $87 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42273
     $88 = HEAP32[$87 >> 2] | 0; //@line 42274
     HEAP32[$1 >> 2] = $87 + 4; //@line 42276
     $94 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42288
     $95 = HEAP32[$94 >> 2] | 0; //@line 42289
     HEAP32[$1 >> 2] = $94 + 4; //@line 42291
     $96 = _htonl($88) | 0; //@line 42292
     $97 = HEAP32[$10 >> 2] | 0; //@line 42293
     if (($97 + 4 | 0) >>> 0 > 1023) {
      $101 = (_send(HEAP32[$0 >> 2] | 0, $11, $97, 0) | 0) == ($97 | 0); //@line 42299
      HEAP32[$10 >> 2] = 0; //@line 42300
      if ($101) {
       $103 = 0; //@line 42302
      } else {
       $$6 = -1001; //@line 42304
       label = 51; //@line 42305
       break L4;
      }
     } else {
      $103 = $97; //@line 42309
     }
     $102 = $0 + 8 + $103 | 0; //@line 42311
     HEAP8[$102 >> 0] = $96; //@line 42312
     HEAP8[$102 + 1 >> 0] = $96 >> 8; //@line 42312
     HEAP8[$102 + 2 >> 0] = $96 >> 16; //@line 42312
     HEAP8[$102 + 3 >> 0] = $96 >> 24; //@line 42312
     HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42315
     $106 = _htonl($95) | 0; //@line 42316
     $107 = HEAP32[$10 >> 2] | 0; //@line 42317
     if (($107 + 4 | 0) >>> 0 > 1023) {
      $111 = (_send(HEAP32[$0 >> 2] | 0, $11, $107, 0) | 0) == ($107 | 0); //@line 42323
      HEAP32[$10 >> 2] = 0; //@line 42324
      if ($111) {
       $113 = 0; //@line 42326
      } else {
       $$6 = -1001; //@line 42328
       label = 51; //@line 42329
       break L4;
      }
     } else {
      $113 = $107; //@line 42333
     }
     $112 = $0 + 8 + $113 | 0; //@line 42335
     HEAP8[$112 >> 0] = $106; //@line 42336
     HEAP8[$112 + 1 >> 0] = $106 >> 8; //@line 42336
     HEAP8[$112 + 2 >> 0] = $106 >> 16; //@line 42336
     HEAP8[$112 + 3 >> 0] = $106 >> 24; //@line 42336
     HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42339
     switch ($88 | 0) {
     case -2e3:
      {
       $121 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42353
       $122 = HEAP32[$121 >> 2] | 0; //@line 42354
       HEAP32[$1 >> 2] = $121 + 4; //@line 42356
       $123 = HEAP32[$10 >> 2] | 0; //@line 42357
       $125 = (_send(HEAP32[$0 >> 2] | 0, $11, $123, 0) | 0) == ($123 | 0); //@line 42360
       HEAP32[$10 >> 2] = 0; //@line 42361
       if (!$125) {
        $$6 = -1001; //@line 42363
        label = 51; //@line 42364
        break L4;
       }
       if ((_send(HEAP32[$0 >> 2] | 0, $122, $95, 0) | 0) == ($95 | 0)) {
        break L9;
       } else {
        $$6 = -1001; //@line 42373
        label = 51; //@line 42374
        break L4;
       }
       break;
      }
     case -2002:
     case -2001:
      {
       $133 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42391
       $134 = HEAP32[$133 >> 2] | 0; //@line 42392
       HEAP32[$1 >> 2] = $133 + 4; //@line 42394
       if (($95 | 0) > 0) {
        $$0118198 = 0; //@line 42397
       } else {
        break L9;
       }
       do {
        $138 = _htonl(HEAP32[$134 + ($$0118198 << 2) >> 2] | 0) | 0; //@line 42404
        $139 = HEAP32[$10 >> 2] | 0; //@line 42405
        if (($139 + 4 | 0) >>> 0 > 1023) {
         $143 = (_send(HEAP32[$0 >> 2] | 0, $11, $139, 0) | 0) == ($139 | 0); //@line 42411
         HEAP32[$10 >> 2] = 0; //@line 42412
         if ($143) {
          $145 = 0; //@line 42414
         } else {
          $$6 = -1001; //@line 42416
          label = 51; //@line 42417
          break L4;
         }
        } else {
         $145 = $139; //@line 42421
        }
        $144 = $0 + 8 + $145 | 0; //@line 42423
        HEAP8[$144 >> 0] = $138; //@line 42424
        HEAP8[$144 + 1 >> 0] = $138 >> 8; //@line 42424
        HEAP8[$144 + 2 >> 0] = $138 >> 16; //@line 42424
        HEAP8[$144 + 3 >> 0] = $138 >> 24; //@line 42424
        HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42427
        $$0118198 = $$0118198 + 1 | 0; //@line 42428
       } while (($$0118198 | 0) < ($95 | 0));
       break;
      }
     case -2003:
      {
       $155 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42450
       $156 = HEAP32[$155 >> 2] | 0; //@line 42451
       HEAP32[$1 >> 2] = $155 + 4; //@line 42453
       if (($95 | 0) > 0) {
        $$1119196 = 0; //@line 42456
       } else {
        break L9;
       }
       do {
        $160 = _htonl(HEAP32[$156 + ($$1119196 << 2) >> 2] | 0) | 0; //@line 42463
        $161 = HEAP32[$10 >> 2] | 0; //@line 42464
        if (($161 + 4 | 0) >>> 0 > 1023) {
         $165 = (_send(HEAP32[$0 >> 2] | 0, $11, $161, 0) | 0) == ($161 | 0); //@line 42470
         HEAP32[$10 >> 2] = 0; //@line 42471
         if ($165) {
          $167 = 0; //@line 42473
         } else {
          $$6 = -1001; //@line 42475
          label = 51; //@line 42476
          break L4;
         }
        } else {
         $167 = $161; //@line 42480
        }
        $166 = $0 + 8 + $167 | 0; //@line 42482
        HEAP8[$166 >> 0] = $160; //@line 42483
        HEAP8[$166 + 1 >> 0] = $160 >> 8; //@line 42483
        HEAP8[$166 + 2 >> 0] = $160 >> 16; //@line 42483
        HEAP8[$166 + 3 >> 0] = $160 >> 24; //@line 42483
        HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 4; //@line 42486
        $$1119196 = $$1119196 + 1 | 0; //@line 42487
       } while (($$1119196 | 0) < ($95 | 0));
       break;
      }
     case -2004:
      {
       $177 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42509
       $178 = HEAP32[$177 >> 2] | 0; //@line 42510
       HEAP32[$1 >> 2] = $177 + 4; //@line 42512
       if (($95 | 0) > 0) {
        $$2120195 = 0; //@line 42515
       } else {
        break L9;
       }
       while (1) {
        $184 = __Z23rpc_message_send_stringP13rpc_message_tPKc($0, HEAP32[$178 + ($$2120195 << 2) >> 2] | 0) | 0; //@line 42522
        $$2120195 = $$2120195 + 1 | 0; //@line 42524
        if (($184 | 0) < 0) {
         $$6 = $184; //@line 42526
         label = 51; //@line 42527
         break L4;
        }
        if (($$2120195 | 0) >= ($95 | 0)) {
         $$11 = $184; //@line 42534
         label = 49; //@line 42535
         break;
        }
       }
       break;
      }
     default:
      {
       $186 = HEAP32[30850] | 0; //@line 42542
       $188 = HEAP32[30851] | 0; //@line 42544
       if (($186 | 0) != 0 & ($188 | 0) > 0) {
        $$079$i = 0; //@line 42548
       } else {
        label = 42; //@line 42550
        break L4;
       }
       while (1) {
        $192 = $186 + ($$079$i << 4) | 0; //@line 42554
        $191 = $$079$i + 1 | 0; //@line 42557
        if ((HEAP32[$192 >> 2] | 0) == ($88 | 0)) {
         break;
        }
        if (($191 | 0) < ($188 | 0)) {
         $$079$i = $191; //@line 42563
        } else {
         label = 42; //@line 42565
         break L4;
        }
       }
       if (!$192) {
        label = 42; //@line 42571
        break L4;
       }
       $201 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42585
       $202 = HEAP32[$201 >> 2] | 0; //@line 42586
       HEAP32[$1 >> 2] = $201 + 4; //@line 42588
       if (($95 | 0) <= 0) {
        break L9;
       }
       $204 = $186 + ($$079$i << 4) + 8 | 0; //@line 42593
       $205 = $186 + ($$079$i << 4) + 4 | 0; //@line 42594
       $$3121200 = 0; //@line 42595
       while (1) {
        $211 = $202 + (Math_imul(HEAP32[$205 >> 2] | 0, $$3121200) | 0) | 0; //@line 42600
        $212 = FUNCTION_TABLE_iii[HEAP32[$204 >> 2] & 31]($0, $211) | 0; //@line 42601
        $$3121200 = $$3121200 + 1 | 0; //@line 42603
        if (($212 | 0) < 0) {
         $$6 = $212; //@line 42605
         label = 51; //@line 42606
         break L4;
        }
        if (($$3121200 | 0) >= ($95 | 0)) {
         $$11 = $212; //@line 42613
         label = 49; //@line 42614
         break;
        }
       }
      }
     }
     break;
    }
   default:
    {
     $215 = HEAP32[30850] | 0; //@line 42623
     $217 = HEAP32[30851] | 0; //@line 42625
     if (($215 | 0) != 0 & ($217 | 0) > 0) {
      $$079$i156 = 0; //@line 42629
     } else {
      label = 48; //@line 42631
      break L4;
     }
     while (1) {
      $221 = $215 + ($$079$i156 << 4) | 0; //@line 42635
      $220 = $$079$i156 + 1 | 0; //@line 42638
      if ((HEAP32[$221 >> 2] | 0) == ($12 | 0)) {
       break;
      }
      if (($220 | 0) < ($217 | 0)) {
       $$079$i156 = $220; //@line 42644
      } else {
       label = 48; //@line 42646
       break L4;
      }
     }
     if (!$221) {
      label = 48; //@line 42652
      break L4;
     }
     $226 = HEAP32[$215 + ($$079$i156 << 4) + 8 >> 2] | 0; //@line 42656
     $232 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42668
     $233 = HEAP32[$232 >> 2] | 0; //@line 42669
     HEAP32[$1 >> 2] = $232 + 4; //@line 42671
     $$11 = FUNCTION_TABLE_iii[$226 & 31]($0, $233) | 0; //@line 42673
     label = 49; //@line 42674
    }
   }
  } while (0);
  if ((label | 0) == 49) {
   label = 0; //@line 42679
   if ($$11 | 0) {
    $$6 = $$11; //@line 42682
    label = 51; //@line 42683
    break;
   }
  }
  $242 = (HEAP32[$1 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 42698
  $243 = HEAP32[$242 >> 2] | 0; //@line 42699
  HEAP32[$1 >> 2] = $242 + 4; //@line 42701
  if (!$243) {
   $$6 = 0; //@line 42704
   label = 51; //@line 42705
   break;
  } else {
   $12 = $243; //@line 42708
  }
 }
 if ((label | 0) == 42) {
  $214 = HEAP32[22038] | 0; //@line 42712
  HEAP32[$vararg_buffer >> 2] = -2005; //@line 42713
  _fprintf($214, 102224, $vararg_buffer) | 0; //@line 42714
  $$6 = -1007; //@line 42715
  STACKTOP = sp; //@line 42716
  return $$6 | 0; //@line 42716
 } else if ((label | 0) == 48) {
  $235 = HEAP32[22038] | 0; //@line 42719
  HEAP32[$vararg_buffer37 >> 2] = $12; //@line 42720
  _fprintf($235, 102259, $vararg_buffer37) | 0; //@line 42721
  $$6 = -1007; //@line 42722
  STACKTOP = sp; //@line 42723
  return $$6 | 0; //@line 42723
 } else if ((label | 0) == 51) {
  STACKTOP = sp; //@line 42726
  return $$6 | 0; //@line 42726
 }
 return 0; //@line 42728
}
function ___intscan($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$0154222 = 0, $$0157 = 0, $$0159 = 0, $$1155192 = 0, $$1158 = 0, $$1160 = 0, $$1160169 = 0, $$1165 = 0, $$1165167 = 0, $$1165168 = 0, $$166 = 0, $$2156210 = 0, $$2161$be = 0, $$2161$lcssa = 0, $$3162$be = 0, $$3162215 = 0, $$4163$be = 0, $$4163$lcssa = 0, $$5$be = 0, $$6$be = 0, $$6$lcssa = 0, $$7$be = 0, $$7198 = 0, $$8 = 0, $$9$be = 0, $104 = 0, $123 = 0, $124 = 0, $131 = 0, $133 = 0, $134 = 0, $138 = 0, $139 = 0, $147 = 0, $152 = 0, $153 = 0, $155 = 0, $158 = 0, $16 = 0, $160 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $189 = 0, $190 = 0, $198 = 0, $20 = 0, $204 = 0, $206 = 0, $207 = 0, $209 = 0, $21 = 0, $211 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $225 = 0, $226 = 0, $227 = 0, $242 = 0, $263 = 0, $265 = 0, $275 = 0, $28 = 0, $284 = 0, $287 = 0, $289 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $32 = 0, $40 = 0, $42 = 0, $50 = 0, $54 = 0, $6 = 0, $7 = 0, $70 = 0, $74 = 0, $75 = 0, $86 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $93 = 0, $94 = 0, $96 = 0, label = 0;
 L1 : do {
  if ($1 >>> 0 > 36) {
   HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 54954
   $289 = 0; //@line 54955
   $290 = 0; //@line 54955
  } else {
   $6 = $0 + 4 | 0; //@line 54957
   $7 = $0 + 100 | 0; //@line 54958
   do {
    $9 = HEAP32[$6 >> 2] | 0; //@line 54960
    if ($9 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
     HEAP32[$6 >> 2] = $9 + 1; //@line 54965
     $16 = HEAPU8[$9 >> 0] | 0; //@line 54968
    } else {
     $16 = ___shgetc($0) | 0; //@line 54971
    }
   } while ((_isspace($16) | 0) != 0);
   L11 : do {
    switch ($16 | 0) {
    case 43:
    case 45:
     {
      $20 = (($16 | 0) == 45) << 31 >> 31; //@line 54983
      $21 = HEAP32[$6 >> 2] | 0; //@line 54984
      if ($21 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
       HEAP32[$6 >> 2] = $21 + 1; //@line 54989
       $$0157 = $20; //@line 54992
       $$0159 = HEAPU8[$21 >> 0] | 0; //@line 54992
       break L11;
      } else {
       $$0157 = $20; //@line 54996
       $$0159 = ___shgetc($0) | 0; //@line 54996
       break L11;
      }
      break;
     }
    default:
     {
      $$0157 = 0; //@line 55002
      $$0159 = $16; //@line 55002
     }
    }
   } while (0);
   $28 = ($1 | 0) == 0; //@line 55006
   do {
    if (($1 | 16 | 0) == 16 & ($$0159 | 0) == 48) {
     $32 = HEAP32[$6 >> 2] | 0; //@line 55013
     if ($32 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
      HEAP32[$6 >> 2] = $32 + 1; //@line 55018
      $40 = HEAPU8[$32 >> 0] | 0; //@line 55021
     } else {
      $40 = ___shgetc($0) | 0; //@line 55024
     }
     if (($40 | 32 | 0) != 120) {
      if ($28) {
       $$1160169 = $40; //@line 55030
       $$1165168 = 8; //@line 55030
       label = 46; //@line 55031
       break;
      } else {
       $$1160 = $40; //@line 55034
       $$1165 = $1; //@line 55034
       label = 32; //@line 55035
       break;
      }
     }
     $42 = HEAP32[$6 >> 2] | 0; //@line 55039
     if ($42 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
      HEAP32[$6 >> 2] = $42 + 1; //@line 55044
      $50 = HEAPU8[$42 >> 0] | 0; //@line 55047
     } else {
      $50 = ___shgetc($0) | 0; //@line 55050
     }
     if ((HEAPU8[109797 + $50 >> 0] | 0) > 15) {
      $54 = (HEAP32[$7 >> 2] | 0) != 0; //@line 55057
      if ($54) {
       HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + -1; //@line 55061
      }
      if (!$2) {
       ___shlim($0, 0); //@line 55065
       $289 = 0; //@line 55066
       $290 = 0; //@line 55066
       break L1;
      }
      if (!$54) {
       $289 = 0; //@line 55070
       $290 = 0; //@line 55070
       break L1;
      }
      HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + -1; //@line 55075
      $289 = 0; //@line 55076
      $290 = 0; //@line 55076
      break L1;
     } else {
      $$1160169 = $50; //@line 55079
      $$1165168 = 16; //@line 55079
      label = 46; //@line 55080
     }
    } else {
     $$166 = $28 ? 10 : $1; //@line 55083
     if ((HEAPU8[109797 + $$0159 >> 0] | 0) >>> 0 < $$166 >>> 0) {
      $$1160 = $$0159; //@line 55089
      $$1165 = $$166; //@line 55089
      label = 32; //@line 55090
     } else {
      if (HEAP32[$7 >> 2] | 0) {
       HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + -1; //@line 55097
      }
      ___shlim($0, 0); //@line 55099
      HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 55101
      $289 = 0; //@line 55102
      $290 = 0; //@line 55102
      break L1;
     }
    }
   } while (0);
   L43 : do {
    if ((label | 0) == 32) {
     if (($$1165 | 0) == 10) {
      $70 = $$1160 + -48 | 0; //@line 55111
      if ($70 >>> 0 < 10) {
       $$0154222 = 0; //@line 55114
       $74 = $70; //@line 55114
       do {
        $$0154222 = ($$0154222 * 10 | 0) + $74 | 0; //@line 55117
        $75 = HEAP32[$6 >> 2] | 0; //@line 55118
        if ($75 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
         HEAP32[$6 >> 2] = $75 + 1; //@line 55123
         $$2161$be = HEAPU8[$75 >> 0] | 0; //@line 55126
        } else {
         $$2161$be = ___shgetc($0) | 0; //@line 55129
        }
        $74 = $$2161$be + -48 | 0; //@line 55131
       } while ($74 >>> 0 < 10 & $$0154222 >>> 0 < 429496729);
       $$2161$lcssa = $$2161$be; //@line 55141
       $291 = $$0154222; //@line 55141
       $292 = 0; //@line 55141
      } else {
       $$2161$lcssa = $$1160; //@line 55143
       $291 = 0; //@line 55143
       $292 = 0; //@line 55143
      }
      $86 = $$2161$lcssa + -48 | 0; //@line 55145
      if ($86 >>> 0 < 10) {
       $$3162215 = $$2161$lcssa; //@line 55148
       $88 = $291; //@line 55148
       $89 = $292; //@line 55148
       $93 = $86; //@line 55148
       while (1) {
        $90 = ___muldi3($88 | 0, $89 | 0, 10, 0) | 0; //@line 55150
        $91 = tempRet0; //@line 55151
        $94 = (($93 | 0) < 0) << 31 >> 31; //@line 55153
        $96 = ~$94; //@line 55155
        if ($91 >>> 0 > $96 >>> 0 | ($91 | 0) == ($96 | 0) & $90 >>> 0 > ~$93 >>> 0) {
         $$1165167 = 10; //@line 55162
         $$8 = $$3162215; //@line 55162
         $293 = $88; //@line 55162
         $294 = $89; //@line 55162
         label = 72; //@line 55163
         break L43;
        }
        $88 = _i64Add($90 | 0, $91 | 0, $93 | 0, $94 | 0) | 0; //@line 55166
        $89 = tempRet0; //@line 55167
        $104 = HEAP32[$6 >> 2] | 0; //@line 55168
        if ($104 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
         HEAP32[$6 >> 2] = $104 + 1; //@line 55173
         $$3162$be = HEAPU8[$104 >> 0] | 0; //@line 55176
        } else {
         $$3162$be = ___shgetc($0) | 0; //@line 55179
        }
        $93 = $$3162$be + -48 | 0; //@line 55181
        if (!($93 >>> 0 < 10 & ($89 >>> 0 < 429496729 | ($89 | 0) == 429496729 & $88 >>> 0 < 2576980378))) {
         break;
        } else {
         $$3162215 = $$3162$be; //@line 55190
        }
       }
       if ($93 >>> 0 > 9) {
        $$1158 = $$0157; //@line 55197
        $263 = $89; //@line 55197
        $265 = $88; //@line 55197
       } else {
        $$1165167 = 10; //@line 55199
        $$8 = $$3162$be; //@line 55199
        $293 = $88; //@line 55199
        $294 = $89; //@line 55199
        label = 72; //@line 55200
       }
      } else {
       $$1158 = $$0157; //@line 55203
       $263 = $292; //@line 55203
       $265 = $291; //@line 55203
      }
     } else {
      $$1160169 = $$1160; //@line 55206
      $$1165168 = $$1165; //@line 55206
      label = 46; //@line 55207
     }
    }
   } while (0);
   L63 : do {
    if ((label | 0) == 46) {
     if (!($$1165168 + -1 & $$1165168)) {
      $131 = HEAP8[110053 + (($$1165168 * 23 | 0) >>> 5 & 7) >> 0] | 0; //@line 55222
      $133 = HEAP8[109797 + $$1160169 >> 0] | 0; //@line 55224
      $134 = $133 & 255; //@line 55225
      if ($134 >>> 0 < $$1165168 >>> 0) {
       $$1155192 = 0; //@line 55228
       $138 = $134; //@line 55228
       do {
        $$1155192 = $138 | $$1155192 << $131; //@line 55231
        $139 = HEAP32[$6 >> 2] | 0; //@line 55232
        if ($139 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
         HEAP32[$6 >> 2] = $139 + 1; //@line 55237
         $$4163$be = HEAPU8[$139 >> 0] | 0; //@line 55240
        } else {
         $$4163$be = ___shgetc($0) | 0; //@line 55243
        }
        $147 = HEAP8[109797 + $$4163$be >> 0] | 0; //@line 55246
        $138 = $147 & 255; //@line 55247
       } while ($$1155192 >>> 0 < 134217728 & $138 >>> 0 < $$1165168 >>> 0);
       $$4163$lcssa = $$4163$be; //@line 55257
       $155 = $147; //@line 55257
       $158 = 0; //@line 55257
       $160 = $$1155192; //@line 55257
      } else {
       $$4163$lcssa = $$1160169; //@line 55259
       $155 = $133; //@line 55259
       $158 = 0; //@line 55259
       $160 = 0; //@line 55259
      }
      $152 = _bitshift64Lshr(-1, -1, $131 | 0) | 0; //@line 55261
      $153 = tempRet0; //@line 55262
      if (($155 & 255) >>> 0 >= $$1165168 >>> 0 | ($158 >>> 0 > $153 >>> 0 | ($158 | 0) == ($153 | 0) & $160 >>> 0 > $152 >>> 0)) {
       $$1165167 = $$1165168; //@line 55272
       $$8 = $$4163$lcssa; //@line 55272
       $293 = $160; //@line 55272
       $294 = $158; //@line 55272
       label = 72; //@line 55273
       break;
      } else {
       $164 = $160; //@line 55276
       $165 = $158; //@line 55276
       $169 = $155; //@line 55276
      }
      while (1) {
       $166 = _bitshift64Shl($164 | 0, $165 | 0, $131 | 0) | 0; //@line 55279
       $167 = tempRet0; //@line 55280
       $170 = $169 & 255 | $166; //@line 55282
       $171 = HEAP32[$6 >> 2] | 0; //@line 55283
       if ($171 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
        HEAP32[$6 >> 2] = $171 + 1; //@line 55288
        $$5$be = HEAPU8[$171 >> 0] | 0; //@line 55291
       } else {
        $$5$be = ___shgetc($0) | 0; //@line 55294
       }
       $169 = HEAP8[109797 + $$5$be >> 0] | 0; //@line 55297
       if (($169 & 255) >>> 0 >= $$1165168 >>> 0 | ($167 >>> 0 > $153 >>> 0 | ($167 | 0) == ($153 | 0) & $170 >>> 0 > $152 >>> 0)) {
        $$1165167 = $$1165168; //@line 55307
        $$8 = $$5$be; //@line 55307
        $293 = $170; //@line 55307
        $294 = $167; //@line 55307
        label = 72; //@line 55308
        break L63;
       } else {
        $164 = $170; //@line 55311
        $165 = $167; //@line 55311
       }
      }
     }
     $123 = HEAP8[109797 + $$1160169 >> 0] | 0; //@line 55316
     $124 = $123 & 255; //@line 55317
     if ($124 >>> 0 < $$1165168 >>> 0) {
      $$2156210 = 0; //@line 55320
      $189 = $124; //@line 55320
      do {
       $$2156210 = $189 + (Math_imul($$2156210, $$1165168) | 0) | 0; //@line 55323
       $190 = HEAP32[$6 >> 2] | 0; //@line 55324
       if ($190 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
        HEAP32[$6 >> 2] = $190 + 1; //@line 55329
        $$6$be = HEAPU8[$190 >> 0] | 0; //@line 55332
       } else {
        $$6$be = ___shgetc($0) | 0; //@line 55335
       }
       $198 = HEAP8[109797 + $$6$be >> 0] | 0; //@line 55338
       $189 = $198 & 255; //@line 55339
      } while ($$2156210 >>> 0 < 119304647 & $189 >>> 0 < $$1165168 >>> 0);
      $$6$lcssa = $$6$be; //@line 55349
      $204 = $198; //@line 55349
      $295 = $$2156210; //@line 55349
      $296 = 0; //@line 55349
     } else {
      $$6$lcssa = $$1160169; //@line 55351
      $204 = $123; //@line 55351
      $295 = 0; //@line 55351
      $296 = 0; //@line 55351
     }
     if (($204 & 255) >>> 0 < $$1165168 >>> 0) {
      $206 = ___udivdi3(-1, -1, $$1165168 | 0, 0) | 0; //@line 55356
      $207 = tempRet0; //@line 55357
      $$7198 = $$6$lcssa; //@line 55358
      $209 = $296; //@line 55358
      $211 = $295; //@line 55358
      $218 = $204; //@line 55358
      while (1) {
       if ($209 >>> 0 > $207 >>> 0 | ($209 | 0) == ($207 | 0) & $211 >>> 0 > $206 >>> 0) {
        $$1165167 = $$1165168; //@line 55366
        $$8 = $$7198; //@line 55366
        $293 = $211; //@line 55366
        $294 = $209; //@line 55366
        label = 72; //@line 55367
        break L63;
       }
       $215 = ___muldi3($211 | 0, $209 | 0, $$1165168 | 0, 0) | 0; //@line 55370
       $216 = tempRet0; //@line 55371
       $217 = $218 & 255; //@line 55372
       if ($216 >>> 0 > 4294967295 | ($216 | 0) == -1 & $215 >>> 0 > ~$217 >>> 0) {
        $$1165167 = $$1165168; //@line 55380
        $$8 = $$7198; //@line 55380
        $293 = $211; //@line 55380
        $294 = $209; //@line 55380
        label = 72; //@line 55381
        break L63;
       }
       $225 = _i64Add($217 | 0, 0, $215 | 0, $216 | 0) | 0; //@line 55384
       $226 = tempRet0; //@line 55385
       $227 = HEAP32[$6 >> 2] | 0; //@line 55386
       if ($227 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
        HEAP32[$6 >> 2] = $227 + 1; //@line 55391
        $$7$be = HEAPU8[$227 >> 0] | 0; //@line 55394
       } else {
        $$7$be = ___shgetc($0) | 0; //@line 55397
       }
       $218 = HEAP8[109797 + $$7$be >> 0] | 0; //@line 55400
       if (($218 & 255) >>> 0 >= $$1165168 >>> 0) {
        $$1165167 = $$1165168; //@line 55406
        $$8 = $$7$be; //@line 55406
        $293 = $225; //@line 55406
        $294 = $226; //@line 55406
        label = 72; //@line 55407
        break;
       } else {
        $$7198 = $$7$be; //@line 55404
        $209 = $226; //@line 55404
        $211 = $225; //@line 55404
       }
      }
     } else {
      $$1165167 = $$1165168; //@line 55412
      $$8 = $$6$lcssa; //@line 55412
      $293 = $295; //@line 55412
      $294 = $296; //@line 55412
      label = 72; //@line 55413
     }
    }
   } while (0);
   if ((label | 0) == 72) {
    if ((HEAPU8[109797 + $$8 >> 0] | 0) >>> 0 < $$1165167 >>> 0) {
     do {
      $242 = HEAP32[$6 >> 2] | 0; //@line 55424
      if ($242 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
       HEAP32[$6 >> 2] = $242 + 1; //@line 55429
       $$9$be = HEAPU8[$242 >> 0] | 0; //@line 55432
      } else {
       $$9$be = ___shgetc($0) | 0; //@line 55435
      }
     } while ((HEAPU8[109797 + $$9$be >> 0] | 0) >>> 0 < $$1165167 >>> 0);
     HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 55446
     $$1158 = ($3 & 1 | 0) == 0 & 0 == 0 ? $$0157 : 0; //@line 55452
     $263 = $4; //@line 55452
     $265 = $3; //@line 55452
    } else {
     $$1158 = $$0157; //@line 55454
     $263 = $294; //@line 55454
     $265 = $293; //@line 55454
    }
   }
   if (HEAP32[$7 >> 2] | 0) {
    HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + -1; //@line 55462
   }
   if (!($263 >>> 0 < $4 >>> 0 | ($263 | 0) == ($4 | 0) & $265 >>> 0 < $3 >>> 0)) {
    if (!(($3 & 1 | 0) != 0 | 0 != 0 | ($$1158 | 0) != 0)) {
     HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 55478
     $275 = _i64Add($3 | 0, $4 | 0, -1, -1) | 0; //@line 55479
     $289 = tempRet0; //@line 55481
     $290 = $275; //@line 55481
     break;
    }
    if ($263 >>> 0 > $4 >>> 0 | ($263 | 0) == ($4 | 0) & $265 >>> 0 > $3 >>> 0) {
     HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 55491
     $289 = $4; //@line 55492
     $290 = $3; //@line 55492
     break;
    }
   }
   $284 = (($$1158 | 0) < 0) << 31 >> 31; //@line 55497
   $287 = _i64Subtract($265 ^ $$1158 | 0, $263 ^ $284 | 0, $$1158 | 0, $284 | 0) | 0; //@line 55500
   $289 = tempRet0; //@line 55502
   $290 = $287; //@line 55502
  }
 } while (0);
 tempRet0 = $289; //@line 55505
 return $290 | 0; //@line 55506
}
function __ZN8tinyxml211XMLDocument8IdentifyEPcPPNS_7XMLNodeE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$0$lcssa$i37 = 0, $$0$lcssa$i46 = 0, $$0$lcssa$i58 = 0, $$0$lcssa$i70 = 0, $$0$lcssa$i82 = 0, $$0$lcssa$i86100 = 0, $$0$lcssa$i86101 = 0, $$0$lcssa$i86102 = 0, $$0$lcssa$i86103 = 0, $$0$lcssa$i86104 = 0, $$019$lcssa$i = 0, $$019$lcssa$i45 = 0, $$019$lcssa$i57 = 0, $$019$lcssa$i69 = 0, $$019$lcssa$i81 = 0, $$01923$i = 0, $$01923$i40 = 0, $$01923$i52 = 0, $$01923$i64 = 0, $$01923$i76 = 0, $$02022$i = 0, $$02022$i41 = 0, $$02022$i53 = 0, $$02022$i65 = 0, $$02022$i77 = 0, $$024$i = 0, $$024$i39 = 0, $$024$i51 = 0, $$024$i63 = 0, $$024$i75 = 0, $$03$i = 0, $$034 = 0, $$035$in = 0, $10 = 0, $100 = 0, $104 = 0, $107 = 0, $110 = 0, $111 = 0, $116 = 0, $119 = 0, $120 = 0, $122 = 0, $127 = 0, $128 = 0, $130 = 0, $133 = 0, $15 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $3 = 0, $30 = 0, $31 = 0, $33 = 0, $37 = 0, $40 = 0, $43 = 0, $44 = 0, $49 = 0, $52 = 0, $53 = 0, $55 = 0, $59 = 0, $6 = 0, $62 = 0, $65 = 0, $66 = 0, $71 = 0, $74 = 0, $75 = 0, $77 = 0, $82 = 0, $85 = 0, $88 = 0, $89 = 0, $9 = 0, $94 = 0, $97 = 0, $98 = 0, label = 0;
 $3 = HEAP8[$1 >> 0] | 0; //@line 36629
 L1 : do {
  if ($3 << 24 >> 24 > -1) {
   $$03$i = $1; //@line 36633
   $6 = $3; //@line 36633
   while (1) {
    if (!(_isspace($6 & 255) | 0)) {
     break;
    }
    $9 = $$03$i + 1 | 0; //@line 36641
    $10 = HEAP8[$9 >> 0] | 0; //@line 36642
    if ($10 << 24 >> 24 > -1) {
     $$03$i = $9; //@line 36645
     $6 = $10; //@line 36645
    } else {
     $$0$lcssa$i86100 = $9; //@line 36647
     $133 = $10; //@line 36647
     break L1;
    }
   }
   if (!$$03$i) {
    $$0 = 0; //@line 36653
    return $$0 | 0; //@line 36654
   }
   if (!($6 << 24 >> 24)) {
    $$0 = $$03$i; //@line 36658
    return $$0 | 0; //@line 36659
   } else {
    $$0$lcssa$i86100 = $$03$i; //@line 36661
    $133 = $6; //@line 36661
   }
  } else {
   $$0$lcssa$i86100 = $1; //@line 36664
   $133 = $3; //@line 36664
  }
 } while (0);
 L11 : do {
  if (($$0$lcssa$i86100 | 0) == 97310) {
   $$0$lcssa$i86104 = 97310; //@line 36670
   label = 12; //@line 36671
  } else {
   $$01923$i = 97310; //@line 36673
   $$02022$i = $$0$lcssa$i86100; //@line 36673
   $$024$i = 0; //@line 36673
   $18 = $133; //@line 36673
   while (1) {
    $15 = HEAP8[$$01923$i >> 0] | 0; //@line 36675
    if (!(($$024$i | 0) < 2 & ($15 << 24 >> 24 ? $18 << 24 >> 24 == $15 << 24 >> 24 : 0))) {
     $$0$lcssa$i37 = $$024$i; //@line 36682
     $$019$lcssa$i = $$01923$i; //@line 36682
     $27 = $18; //@line 36682
     break;
    }
    $$02022$i = $$02022$i + 1 | 0; //@line 36685
    $21 = $$01923$i + 1 | 0; //@line 36686
    $22 = $$024$i + 1 | 0; //@line 36687
    $18 = HEAP8[$$02022$i >> 0] | 0; //@line 36688
    if (!($18 << 24 >> 24)) {
     $$0$lcssa$i37 = $22; //@line 36691
     $$019$lcssa$i = $21; //@line 36691
     $27 = 0; //@line 36691
     break;
    } else {
     $$01923$i = $21; //@line 36694
     $$024$i = $22; //@line 36694
    }
   }
   if (($$0$lcssa$i37 | 0) == 2) {
    $$0$lcssa$i86104 = $$0$lcssa$i86100; //@line 36699
    label = 12; //@line 36700
   } else {
    if (!($27 << 24 >> 24)) {
     if (!(HEAP8[$$019$lcssa$i >> 0] | 0)) {
      $$0$lcssa$i86104 = $$0$lcssa$i86100; //@line 36707
      label = 12; //@line 36708
      break;
     }
    }
    do {
     if (($$0$lcssa$i86100 | 0) == 97313) {
      $$0$lcssa$i86103 = 97313; //@line 36715
     } else {
      $$01923$i40 = 97313; //@line 36717
      $$02022$i41 = $$0$lcssa$i86100; //@line 36717
      $$024$i39 = 0; //@line 36717
      $40 = $133; //@line 36717
      while (1) {
       $37 = HEAP8[$$01923$i40 >> 0] | 0; //@line 36719
       if (!(($$024$i39 | 0) < 4 & ($37 << 24 >> 24 ? $40 << 24 >> 24 == $37 << 24 >> 24 : 0))) {
        $$0$lcssa$i46 = $$024$i39; //@line 36726
        $$019$lcssa$i45 = $$01923$i40; //@line 36726
        $49 = $40; //@line 36726
        break;
       }
       $$02022$i41 = $$02022$i41 + 1 | 0; //@line 36729
       $43 = $$01923$i40 + 1 | 0; //@line 36730
       $44 = $$024$i39 + 1 | 0; //@line 36731
       $40 = HEAP8[$$02022$i41 >> 0] | 0; //@line 36732
       if (!($40 << 24 >> 24)) {
        $$0$lcssa$i46 = $44; //@line 36735
        $$019$lcssa$i45 = $43; //@line 36735
        $49 = 0; //@line 36735
        break;
       } else {
        $$01923$i40 = $43; //@line 36738
        $$024$i39 = $44; //@line 36738
       }
      }
      if (($$0$lcssa$i46 | 0) == 4) {
       $$0$lcssa$i86103 = $$0$lcssa$i86100; //@line 36743
      } else {
       if (!($49 << 24 >> 24)) {
        if (!(HEAP8[$$019$lcssa$i45 >> 0] | 0)) {
         $$0$lcssa$i86103 = $$0$lcssa$i86100; //@line 36750
         break;
        }
       }
       do {
        if (($$0$lcssa$i86100 | 0) == 97318) {
         $$0$lcssa$i86102 = 97318; //@line 36757
        } else {
         $$01923$i76 = 97318; //@line 36759
         $$02022$i77 = $$0$lcssa$i86100; //@line 36759
         $$024$i75 = 0; //@line 36759
         $62 = $133; //@line 36759
         while (1) {
          $59 = HEAP8[$$01923$i76 >> 0] | 0; //@line 36761
          if (!(($$024$i75 | 0) < 9 & ($59 << 24 >> 24 ? $62 << 24 >> 24 == $59 << 24 >> 24 : 0))) {
           $$0$lcssa$i82 = $$024$i75; //@line 36768
           $$019$lcssa$i81 = $$01923$i76; //@line 36768
           $71 = $62; //@line 36768
           break;
          }
          $$02022$i77 = $$02022$i77 + 1 | 0; //@line 36771
          $65 = $$01923$i76 + 1 | 0; //@line 36772
          $66 = $$024$i75 + 1 | 0; //@line 36773
          $62 = HEAP8[$$02022$i77 >> 0] | 0; //@line 36774
          if (!($62 << 24 >> 24)) {
           $$0$lcssa$i82 = $66; //@line 36777
           $$019$lcssa$i81 = $65; //@line 36777
           $71 = 0; //@line 36777
           break;
          } else {
           $$01923$i76 = $65; //@line 36780
           $$024$i75 = $66; //@line 36780
          }
         }
         if (($$0$lcssa$i82 | 0) == 9) {
          $$0$lcssa$i86102 = $$0$lcssa$i86100; //@line 36785
         } else {
          if (!($71 << 24 >> 24)) {
           if (!(HEAP8[$$019$lcssa$i81 >> 0] | 0)) {
            $$0$lcssa$i86102 = $$0$lcssa$i86100; //@line 36792
            break;
           }
          }
          do {
           if (($$0$lcssa$i86100 | 0) == 97328) {
            $$0$lcssa$i86101 = 97328; //@line 36799
           } else {
            $$01923$i64 = 97328; //@line 36801
            $$02022$i65 = $$0$lcssa$i86100; //@line 36801
            $$024$i63 = 0; //@line 36801
            $85 = $133; //@line 36801
            while (1) {
             $82 = HEAP8[$$01923$i64 >> 0] | 0; //@line 36803
             if (!(($$024$i63 | 0) < 2 & ($82 << 24 >> 24 ? $85 << 24 >> 24 == $82 << 24 >> 24 : 0))) {
              $$0$lcssa$i70 = $$024$i63; //@line 36810
              $$019$lcssa$i69 = $$01923$i64; //@line 36810
              $94 = $85; //@line 36810
              break;
             }
             $$02022$i65 = $$02022$i65 + 1 | 0; //@line 36813
             $88 = $$01923$i64 + 1 | 0; //@line 36814
             $89 = $$024$i63 + 1 | 0; //@line 36815
             $85 = HEAP8[$$02022$i65 >> 0] | 0; //@line 36816
             if (!($85 << 24 >> 24)) {
              $$0$lcssa$i70 = $89; //@line 36819
              $$019$lcssa$i69 = $88; //@line 36819
              $94 = 0; //@line 36819
              break;
             } else {
              $$01923$i64 = $88; //@line 36822
              $$024$i63 = $89; //@line 36822
             }
            }
            if (($$0$lcssa$i70 | 0) == 2) {
             $$0$lcssa$i86101 = $$0$lcssa$i86100; //@line 36827
            } else {
             if (!($94 << 24 >> 24)) {
              if (!(HEAP8[$$019$lcssa$i69 >> 0] | 0)) {
               $$0$lcssa$i86101 = $$0$lcssa$i86100; //@line 36834
               break;
              }
             }
             do {
              if (($$0$lcssa$i86100 | 0) != 97331) {
               $$01923$i52 = 97331; //@line 36841
               $$02022$i53 = $$0$lcssa$i86100; //@line 36841
               $$024$i51 = 0; //@line 36841
               $107 = $133; //@line 36841
               while (1) {
                $104 = HEAP8[$$01923$i52 >> 0] | 0; //@line 36843
                if (!(($$024$i51 | 0) < 1 & ($104 << 24 >> 24 ? $107 << 24 >> 24 == $104 << 24 >> 24 : 0))) {
                 $$0$lcssa$i58 = $$024$i51; //@line 36850
                 $$019$lcssa$i57 = $$01923$i52; //@line 36850
                 $116 = $107; //@line 36850
                 break;
                }
                $$02022$i53 = $$02022$i53 + 1 | 0; //@line 36853
                $110 = $$01923$i52 + 1 | 0; //@line 36854
                $111 = $$024$i51 + 1 | 0; //@line 36855
                $107 = HEAP8[$$02022$i53 >> 0] | 0; //@line 36856
                if (!($107 << 24 >> 24)) {
                 $$0$lcssa$i58 = $111; //@line 36859
                 $$019$lcssa$i57 = $110; //@line 36859
                 $116 = 0; //@line 36859
                 break;
                } else {
                 $$01923$i52 = $110; //@line 36862
                 $$024$i51 = $111; //@line 36862
                }
               }
               if (($$0$lcssa$i58 | 0) != 1) {
                if (!($116 << 24 >> 24)) {
                 if (!(HEAP8[$$019$lcssa$i57 >> 0] | 0)) {
                  break;
                 }
                }
                $127 = $0 + 220 | 0; //@line 36875
                $128 = __ZN8tinyxml28MemPoolTILi48EE5AllocEv($127) | 0; //@line 36876
                HEAP32[$128 + 4 >> 2] = $0; //@line 36878
                $130 = $128 + 8 | 0; //@line 36879
                HEAP32[$130 >> 2] = 0; //@line 36880
                HEAP32[$130 + 4 >> 2] = 0; //@line 36880
                HEAP32[$130 + 8 >> 2] = 0; //@line 36880
                HEAP32[$130 + 12 >> 2] = 0; //@line 36880
                HEAP32[$130 + 16 >> 2] = 0; //@line 36880
                HEAP32[$130 + 20 >> 2] = 0; //@line 36880
                HEAP32[$130 + 24 >> 2] = 0; //@line 36880
                HEAP32[$130 + 28 >> 2] = 0; //@line 36880
                HEAP32[$128 >> 2] = 1904; //@line 36881
                HEAP8[$128 + 44 >> 0] = 0; //@line 36883
                HEAP32[$128 + 40 >> 2] = $127; //@line 36885
                $$034 = $1; //@line 36886
                $$035$in = $128; //@line 36886
                break L11;
               }
              }
             } while (0);
             $119 = $0 + 68 | 0; //@line 36891
             $120 = __ZN8tinyxml28MemPoolTILi52EE5AllocEv($119) | 0; //@line 36892
             HEAP32[$120 + 4 >> 2] = $0; //@line 36894
             $122 = $120 + 8 | 0; //@line 36895
             HEAP32[$122 >> 2] = 0; //@line 36896
             HEAP32[$122 + 4 >> 2] = 0; //@line 36896
             HEAP32[$122 + 8 >> 2] = 0; //@line 36896
             HEAP32[$122 + 12 >> 2] = 0; //@line 36896
             HEAP32[$122 + 16 >> 2] = 0; //@line 36896
             HEAP32[$122 + 20 >> 2] = 0; //@line 36896
             HEAP32[$122 + 24 >> 2] = 0; //@line 36896
             HEAP32[$122 + 28 >> 2] = 0; //@line 36896
             HEAP32[$120 >> 2] = 2064; //@line 36897
             HEAP32[$120 + 44 >> 2] = 0; //@line 36899
             HEAP32[$120 + 48 >> 2] = 0; //@line 36901
             HEAP32[$120 + 40 >> 2] = $119; //@line 36903
             $$034 = $$0$lcssa$i86100 + 1 | 0; //@line 36905
             $$035$in = $120; //@line 36905
             break L11;
            }
           }
          } while (0);
          $97 = $0 + 296 | 0; //@line 36910
          $98 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($97) | 0; //@line 36911
          HEAP32[$98 + 4 >> 2] = $0; //@line 36913
          $100 = $98 + 8 | 0; //@line 36914
          HEAP32[$100 >> 2] = 0; //@line 36915
          HEAP32[$100 + 4 >> 2] = 0; //@line 36915
          HEAP32[$100 + 8 >> 2] = 0; //@line 36915
          HEAP32[$100 + 12 >> 2] = 0; //@line 36915
          HEAP32[$100 + 16 >> 2] = 0; //@line 36915
          HEAP32[$100 + 20 >> 2] = 0; //@line 36915
          HEAP32[$100 + 24 >> 2] = 0; //@line 36915
          HEAP32[$100 + 28 >> 2] = 0; //@line 36915
          HEAP32[$98 >> 2] = 1984; //@line 36916
          HEAP32[$98 + 40 >> 2] = $97; //@line 36918
          $$034 = $$0$lcssa$i86101 + 2 | 0; //@line 36920
          $$035$in = $98; //@line 36920
          break L11;
         }
        }
       } while (0);
       $74 = $0 + 220 | 0; //@line 36925
       $75 = __ZN8tinyxml28MemPoolTILi48EE5AllocEv($74) | 0; //@line 36926
       HEAP32[$75 + 4 >> 2] = $0; //@line 36928
       $77 = $75 + 8 | 0; //@line 36929
       HEAP32[$77 >> 2] = 0; //@line 36930
       HEAP32[$77 + 4 >> 2] = 0; //@line 36930
       HEAP32[$77 + 8 >> 2] = 0; //@line 36930
       HEAP32[$77 + 12 >> 2] = 0; //@line 36930
       HEAP32[$77 + 16 >> 2] = 0; //@line 36930
       HEAP32[$77 + 20 >> 2] = 0; //@line 36930
       HEAP32[$77 + 24 >> 2] = 0; //@line 36930
       HEAP32[$77 + 28 >> 2] = 0; //@line 36930
       HEAP32[$75 >> 2] = 1904; //@line 36931
       HEAP32[$75 + 40 >> 2] = $74; //@line 36934
       HEAP8[$75 + 44 >> 0] = 1; //@line 36936
       $$034 = $$0$lcssa$i86102 + 9 | 0; //@line 36937
       $$035$in = $75; //@line 36937
       break L11;
      }
     }
    } while (0);
    $52 = $0 + 296 | 0; //@line 36942
    $53 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($52) | 0; //@line 36943
    HEAP32[$53 + 4 >> 2] = $0; //@line 36945
    $55 = $53 + 8 | 0; //@line 36946
    HEAP32[$55 >> 2] = 0; //@line 36947
    HEAP32[$55 + 4 >> 2] = 0; //@line 36947
    HEAP32[$55 + 8 >> 2] = 0; //@line 36947
    HEAP32[$55 + 12 >> 2] = 0; //@line 36947
    HEAP32[$55 + 16 >> 2] = 0; //@line 36947
    HEAP32[$55 + 20 >> 2] = 0; //@line 36947
    HEAP32[$55 + 24 >> 2] = 0; //@line 36947
    HEAP32[$55 + 28 >> 2] = 0; //@line 36947
    HEAP32[$53 >> 2] = 1824; //@line 36948
    HEAP32[$53 + 40 >> 2] = $52; //@line 36950
    $$034 = $$0$lcssa$i86103 + 4 | 0; //@line 36952
    $$035$in = $53; //@line 36952
   }
  }
 } while (0);
 if ((label | 0) == 12) {
  $30 = $0 + 296 | 0; //@line 36957
  $31 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($30) | 0; //@line 36958
  HEAP32[$31 + 4 >> 2] = $0; //@line 36960
  $33 = $31 + 8 | 0; //@line 36961
  HEAP32[$33 >> 2] = 0; //@line 36962
  HEAP32[$33 + 4 >> 2] = 0; //@line 36962
  HEAP32[$33 + 8 >> 2] = 0; //@line 36962
  HEAP32[$33 + 12 >> 2] = 0; //@line 36962
  HEAP32[$33 + 16 >> 2] = 0; //@line 36962
  HEAP32[$33 + 20 >> 2] = 0; //@line 36962
  HEAP32[$33 + 24 >> 2] = 0; //@line 36962
  HEAP32[$33 + 28 >> 2] = 0; //@line 36962
  HEAP32[$31 >> 2] = 1744; //@line 36963
  HEAP32[$31 + 40 >> 2] = $30; //@line 36965
  $$034 = $$0$lcssa$i86104 + 2 | 0; //@line 36967
  $$035$in = $31; //@line 36967
 }
 HEAP32[$2 >> 2] = $$035$in; //@line 36969
 $$0 = $$034; //@line 36970
 return $$0 | 0; //@line 36971
}
function __Z11CDROMStatusjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$043$lcssa = 0, $$04367 = 0, $$1 = 0, $$144 = 0, $$sroa$03$0$lcssa$i = 0, $$sroa$03$07$i = 0, $$sroa$049$066 = 0, $$sroa$056$0 = 0, $10 = 0, $104 = 0, $105 = 0, $107 = 0, $115 = 0, $124 = 0, $126 = 0, $128 = 0, $134 = 0, $139 = 0, $146 = 0, $152 = 0, $158 = 0, $16 = 0, $160 = 0, $173 = 0, $184 = 0, $186 = 0, $192 = 0, $198 = 0, $2 = 0, $206 = 0, $212 = 0, $218 = 0, $22 = 0, $23 = 0, $24 = 0, $29 = 0, $30 = 0, $36 = 0, $42 = 0, $48 = 0, $56 = 0, $68 = 0, $74 = 0, $8 = 0, $80 = 0, $86 = 0, $9 = 0, $92 = 0, $98 = 0, $trunc = 0, $vararg_buffer = 0, dest = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 22220
 STACKTOP = STACKTOP + 16 | 0; //@line 22221
 $vararg_buffer = sp; //@line 22222
 $2 = $0 + 22 | 0; //@line 22223
 $8 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0; //@line 22229
 $9 = HEAP32[28494] | 0; //@line 22230
 $10 = HEAP32[28493] | 0; //@line 22231
 L1 : do {
  if (($10 | 0) == ($9 | 0)) {
   $$sroa$03$0$lcssa$i = $9; //@line 22235
  } else {
   $$sroa$03$07$i = $10; //@line 22237
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($8 | 0)) {
     $$sroa$03$0$lcssa$i = $$sroa$03$07$i; //@line 22242
     break L1;
    }
    $$sroa$03$07$i = $$sroa$03$07$i + 840 | 0; //@line 22245
    if (($$sroa$03$07$i | 0) == ($9 | 0)) {
     $$sroa$03$0$lcssa$i = $9; //@line 22248
     break;
    }
   }
  }
 } while (0);
 $16 = $0 + 26 | 0; //@line 22256
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 22262
 $23 = $22 & 65535; //@line 22263
 $trunc = $22 & 65535; //@line 22264
 switch ($trunc << 16 >> 16) {
 case 43:
  {
   $24 = $0 + 28 | 0; //@line 22267
   $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($24 >>> 16 << 2) >> 2] >> 2] & 127]($24) | 0; //@line 22272
   if (($29 | 0) >= 1886745191) {
    if (($29 | 0) < 1986359923) {
     if (($29 | 0) < 1937337955) {
      switch ($29 | 0) {
      case 1886745191:
       {
        break;
       }
      default:
       {
        $$1 = -18; //@line 22284
        STACKTOP = sp; //@line 22285
        return $$1 | 0; //@line 22285
       }
      }
      $80 = $0 + 32 | 0; //@line 22288
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($80 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($80, 0); //@line 22294
      $$1 = 0; //@line 22295
      STACKTOP = sp; //@line 22296
      return $$1 | 0; //@line 22296
     } else {
      switch ($29 | 0) {
      case 1937337955:
       {
        break;
       }
      default:
       {
        $$1 = -18; //@line 22303
        STACKTOP = sp; //@line 22304
        return $$1 | 0; //@line 22304
       }
      }
      $48 = $0 + 32 | 0; //@line 22307
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($48, 16777216); //@line 22313
      $$1 = 0; //@line 22314
      STACKTOP = sp; //@line 22315
      return $$1 | 0; //@line 22315
     }
    }
    if (($29 | 0) < 1986883440) {
     switch ($29 | 0) {
     case 1986359923:
      {
       break;
      }
     default:
      {
       $$1 = -18; //@line 22325
       STACKTOP = sp; //@line 22326
       return $$1 | 0; //@line 22326
      }
     }
     $30 = $0 + 32 | 0; //@line 22329
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, 86016e3); //@line 22335
     $$1 = 0; //@line 22336
     STACKTOP = sp; //@line 22337
     return $$1 | 0; //@line 22337
    }
    if (($29 | 0) < 2003395685) {
     switch ($29 | 0) {
     case 1986883440:
      {
       break;
      }
     default:
      {
       $$1 = -18; //@line 22346
       STACKTOP = sp; //@line 22347
       return $$1 | 0; //@line 22347
      }
     }
     $98 = $0 + 32 | 0; //@line 22350
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($98 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($98, 0); //@line 22356
     $$1 = 0; //@line 22357
     STACKTOP = sp; //@line 22358
     return $$1 | 0; //@line 22358
    } else {
     switch ($29 | 0) {
     case 2003395685:
      {
       break;
      }
     default:
      {
       $$1 = -18; //@line 22365
       STACKTOP = sp; //@line 22366
       return $$1 | 0; //@line 22366
      }
     }
     $74 = $0 + 32 | 0; //@line 22369
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($74, 0); //@line 22375
     $$1 = 0; //@line 22376
     STACKTOP = sp; //@line 22377
     return $$1 | 0; //@line 22377
    }
   }
   if (($29 | 0) < 1701471587) {
    if (($29 | 0) >= 1684371060) {
     switch ($29 | 0) {
     case 1684371060:
      {
       break;
      }
     default:
      {
       $$1 = -18; //@line 22389
       STACKTOP = sp; //@line 22390
       return $$1 | 0; //@line 22390
      }
     }
     $36 = $0 + 32 | 0; //@line 22393
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($36, 1667527277); //@line 22399
     $$1 = 0; //@line 22400
     STACKTOP = sp; //@line 22401
     return $$1 | 0; //@line 22401
    }
    switch ($29 | 0) {
    case 1651470196:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 22408
      STACKTOP = sp; //@line 22409
      return $$1 | 0; //@line 22409
     }
    }
    $56 = $0 + 32 | 0; //@line 22414
    if (($$sroa$03$0$lcssa$i | 0) == (HEAP32[28494] | 0)) {
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($56 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($56, 0); //@line 22421
    } else {
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($56 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($56, HEAP32[$$sroa$03$0$lcssa$i >> 2] | 0); //@line 22429
    }
    $68 = $0 + 34 | 0; //@line 22431
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($68 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($68, 65474); //@line 22437
    $$1 = 0; //@line 22438
    STACKTOP = sp; //@line 22439
    return $$1 | 0; //@line 22439
   }
   if (($29 | 0) < 1718383987) {
    switch ($29 | 0) {
    case 1701471587:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 22448
      STACKTOP = sp; //@line 22449
      return $$1 | 0; //@line 22449
     }
    }
    $86 = $0 + 32 | 0; //@line 22452
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($86 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($86, 196611); //@line 22458
    $$1 = 0; //@line 22459
    STACKTOP = sp; //@line 22460
    return $$1 | 0; //@line 22460
   }
   if (($29 | 0) < 1768846438) {
    switch ($29 | 0) {
    case 1718383987:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 22469
      STACKTOP = sp; //@line 22470
      return $$1 | 0; //@line 22470
     }
    }
    $92 = $0 + 32 | 0; //@line 22473
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($92 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($92, 0); //@line 22479
    $$1 = 0; //@line 22480
    STACKTOP = sp; //@line 22481
    return $$1 | 0; //@line 22481
   } else {
    switch ($29 | 0) {
    case 1768846438:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 22488
      STACKTOP = sp; //@line 22489
      return $$1 | 0; //@line 22489
     }
    }
    $42 = $0 + 32 | 0; //@line 22492
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($42 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($42, 1650553705); //@line 22498
    $$1 = 0; //@line 22499
    STACKTOP = sp; //@line 22500
    return $$1 | 0; //@line 22500
   }
   break;
  }
 case 97:
  {
   $104 = HEAP32[28494] | 0; //@line 22505
   $105 = HEAP32[28493] | 0; //@line 22506
   if (($105 | 0) == ($104 | 0)) {
    $$043$lcssa = 0; //@line 22509
   } else {
    $$04367 = 0; //@line 22511
    $$sroa$049$066 = $105; //@line 22511
    while (1) {
     $107 = HEAP32[$$sroa$049$066 >> 2] | 0; //@line 22513
     $$144 = ($107 | 0) < 7 ? (1 << $107 | $$04367 & 255) & 255 : $$04367; //@line 22519
     $$sroa$049$066 = $$sroa$049$066 + 840 | 0; //@line 22520
     if (($$sroa$049$066 | 0) == ($104 | 0)) {
      $$043$lcssa = $$144; //@line 22523
      break;
     } else {
      $$04367 = $$144; //@line 22526
     }
    }
   }
   $115 = $0 + 29 | 0; //@line 22530
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($115 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($115, $$043$lcssa & 255); //@line 22537
   $$1 = 0; //@line 22538
   STACKTOP = sp; //@line 22539
   return $$1 | 0; //@line 22539
  }
 default:
  {
   if (($$sroa$03$0$lcssa$i | 0) == (HEAP32[28494] | 0)) {
    $124 = HEAP32[28493] | 0; //@line 22546
    if (($124 | 0) == ($$sroa$03$0$lcssa$i | 0)) {
     $$1 = -56; //@line 22549
     STACKTOP = sp; //@line 22550
     return $$1 | 0; //@line 22550
    } else {
     $$sroa$056$0 = $124; //@line 22552
    }
   } else {
    $$sroa$056$0 = $$sroa$03$0$lcssa$i; //@line 22555
   }
   switch ($trunc << 16 >> 16) {
   case 6:
    {
     $126 = $0 + 28 | 0; //@line 22559
     $128 = 123608 + ($126 >>> 16 << 2) | 0; //@line 22561
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$128 >> 2] | 0) + 4 >> 2] & 127]($126) | 0)) {
      $$1 = -50; //@line 22568
      STACKTOP = sp; //@line 22569
      return $$1 | 0; //@line 22569
     }
     $134 = $0 + 30 | 0; //@line 22571
     $139 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($134 >>> 16 << 2) >> 2] >> 2] & 127]($134) | 0; //@line 22576
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[$128 >> 2] | 0) + 16 >> 2] & 31]($126, 1); //@line 22580
     $146 = (__Z14SysGetFileSizePv(HEAP32[$$sroa$056$0 + 4 >> 2] | 0) | 0) / 512 | 0; //@line 22584
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($139 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($139, $146); //@line 22590
     $152 = $139 + 4 | 0; //@line 22591
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($152 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($152, 0); //@line 22597
     $$1 = 0; //@line 22598
     STACKTOP = sp; //@line 22599
     return $$1 | 0; //@line 22599
    }
   case 8:
    {
     $158 = $0 + 28 | 0; //@line 22603
     $160 = HEAP32[$$sroa$056$0 + 836 >> 2] | 0; //@line 22605
     dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($158 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($158) | 0; //@line 22618
     src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($160 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($160) | 0; //@line 22618
     stop = dest + 22 | 0; //@line 22618
     do {
      HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 22618
      dest = dest + 1 | 0; //@line 22618
      src = src + 1 | 0; //@line 22618
     } while ((dest | 0) < (stop | 0));
     $$1 = 0; //@line 22619
     STACKTOP = sp; //@line 22620
     return $$1 | 0; //@line 22620
    }
   case 70:
    {
     $173 = $0 + 28 | 0; //@line 22624
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($173 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($173, (HEAPU8[$$sroa$056$0 + 833 >> 0] | 0) << 8); //@line 22634
     $$1 = 0; //@line 22635
     STACKTOP = sp; //@line 22636
     return $$1 | 0; //@line 22636
    }
   case 95:
    {
     $184 = HEAP32[$$sroa$056$0 + 12 >> 2] | 0; //@line 22641
     $186 = $0 + 28 | 0; //@line 22643
     if (($184 | 0) <= 0) {
      $$1 = -18; //@line 22645
      STACKTOP = sp; //@line 22646
      return $$1 | 0; //@line 22646
     }
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($186 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($186, $184); //@line 22653
     $$1 = 0; //@line 22654
     STACKTOP = sp; //@line 22655
     return $$1 | 0; //@line 22655
    }
   case 96:
    {
     $192 = $0 + 28 | 0; //@line 22659
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($192 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($192, 3); //@line 22665
     $$1 = 0; //@line 22666
     STACKTOP = sp; //@line 22667
     return $$1 | 0; //@line 22667
    }
   case 98:
    {
     $198 = $0 + 28 | 0; //@line 22671
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($198 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($198, HEAP32[$$sroa$056$0 + 8 >> 2] | 0); //@line 22679
     $$1 = 0; //@line 22680
     STACKTOP = sp; //@line 22681
     return $$1 | 0; //@line 22681
    }
   case 120:
    {
     $206 = $0 + 28 | 0; //@line 22685
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($206 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($206, 0); //@line 22691
     $$1 = 0; //@line 22692
     STACKTOP = sp; //@line 22693
     return $$1 | 0; //@line 22693
    }
   case 121:
    {
     $212 = $0 + 28 | 0; //@line 22697
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($212 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($212, 512); //@line 22703
     $218 = $0 + 30 | 0; //@line 22704
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($218 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($218, 3072); //@line 22710
     $$1 = 0; //@line 22711
     STACKTOP = sp; //@line 22712
     return $$1 | 0; //@line 22712
    }
   default:
    {
     HEAP32[$vararg_buffer >> 2] = $23; //@line 22716
     _printf(96198, $vararg_buffer) | 0; //@line 22717
     $$1 = -18; //@line 22718
     STACKTOP = sp; //@line 22719
     return $$1 | 0; //@line 22719
    }
   }
  }
 }
 return 0; //@line 22724
}
function __Z9PrefsInitPKcRiRPPc($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i$i = 0, $$0$i$i103 = 0, $$0$i$i84 = 0, $$0$i$i93 = 0, $$0$i$ph = 0, $$0119 = 0, $$014$i$i = 0, $$014$i$i100 = 0, $$014$i$i90 = 0, $$01416$i$i = 0, $$01416$i$i87 = 0, $$01416$i$i97 = 0, $$01418$i$i = 0, $$01418$i$i88 = 0, $$01418$i$i98 = 0, $$06$i$i = 0, $$06$i5$i = 0, $$078$lcssa = 0, $$078116 = 0, $$079124 = 0, $$080126 = 0, $$2 = 0, $$sink$i$i = 0, $$sink$i$i105 = 0, $$sink$i$i86 = 0, $$sink$i$i95 = 0, $10 = 0, $107 = 0, $109 = 0, $114 = 0, $116 = 0, $118 = 0, $130 = 0, $132 = 0, $137 = 0, $139 = 0, $144 = 0, $145 = 0, $149 = 0, $152 = 0, $154 = 0, $155 = 0, $164 = 0, $19 = 0, $3 = 0, $38 = 0, $40 = 0, $42 = 0, $43 = 0, $5 = 0, $50 = 0, $51 = 0, $53 = 0, $58 = 0, $60 = 0, $79 = 0, $81 = 0, $86 = 0, $88 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 249
 STACKTOP = STACKTOP + 16 | 0; //@line 250
 $vararg_buffer1 = sp + 8 | 0; //@line 251
 $vararg_buffer = sp; //@line 252
 __Z16AddPrefsDefaultsv(); //@line 253
 __Z24AddPlatformPrefsDefaultsv(); //@line 254
 __Z9LoadPrefsPKc($0); //@line 255
 $3 = HEAP32[$1 >> 2] | 0; //@line 256
 if (($3 | 0) <= 1) {
  STACKTOP = sp; //@line 259
  return;
 }
 $5 = HEAP32[22038] | 0; //@line 261
 $$080126 = 1; //@line 262
 $40 = $3; //@line 262
 do {
  $9 = (HEAP32[$2 >> 2] | 0) + ($$080126 << 2) | 0; //@line 265
  $10 = HEAP32[$9 >> 2] | 0; //@line 266
  L6 : do {
   if (!$10) {
    $$2 = $$080126; //@line 270
   } else {
    if ((_strlen($10) | 0) >>> 0 < 3) {
     $$2 = $$080126; //@line 275
    } else {
     if ((HEAP8[$10 >> 0] | 0) == 45) {
      if ((HEAP8[$10 + 1 >> 0] | 0) == 45) {
       $19 = $10 + 2 | 0; //@line 284
       L11 : do {
        if ((HEAP32[91] | 0) == 3) {
         label = 11; //@line 289
        } else {
         $$06$i$i = 360; //@line 291
         while (1) {
          if (!(_strcmp(HEAP32[$$06$i$i >> 2] | 0, $19) | 0)) {
           $$0$i$ph = $$06$i$i; //@line 297
           break L11;
          }
          if ((HEAP32[$$06$i$i + 20 >> 2] | 0) == 3) {
           label = 11; //@line 305
           break;
          } else {
           $$06$i$i = $$06$i$i + 16 | 0; //@line 308
          }
         }
        }
       } while (0);
       L15 : do {
        if ((label | 0) == 11) {
         label = 0; //@line 315
         if ((HEAP32[1316] | 0) == 3) {
          $$2 = $$080126; //@line 319
          break L6;
         } else {
          $$06$i5$i = 5260; //@line 322
         }
         while (1) {
          if (!(_strcmp(HEAP32[$$06$i5$i >> 2] | 0, $19) | 0)) {
           $$0$i$ph = $$06$i5$i; //@line 329
           break L15;
          }
          if ((HEAP32[$$06$i5$i + 20 >> 2] | 0) == 3) {
           $$2 = $$080126; //@line 337
           break L6;
          } else {
           $$06$i5$i = $$06$i5$i + 16 | 0; //@line 340
          }
         }
        }
       } while (0);
       HEAP32[$9 >> 2] = 0; //@line 345
       $38 = $$080126 + 1 | 0; //@line 346
       if (($38 | 0) >= ($40 | 0)) {
        HEAP32[$vararg_buffer >> 2] = $10; //@line 349
        _fprintf($5, 88929, $vararg_buffer) | 0; //@line 350
        $$2 = $38; //@line 351
        break;
       }
       $42 = (HEAP32[$2 >> 2] | 0) + ($38 << 2) | 0; //@line 355
       $43 = HEAP32[$42 >> 2] | 0; //@line 356
       HEAP32[$42 >> 2] = 0; //@line 357
       switch (HEAP32[$$0$i$ph + 4 >> 2] | 0) {
       case 0:
        {
         if (!(HEAP8[$$0$i$ph + 8 >> 0] | 0)) {
          __Z18PrefsReplaceStringPKcS0_i($19, $43, 0); //@line 366
          $$2 = $38; //@line 367
          break L6;
         }
         $50 = (_strlen($43) | 0) + 1 | 0; //@line 371
         $51 = _malloc($50) | 0; //@line 372
         if (!$51) {
          $$2 = $38; //@line 375
          break L6;
         }
         _memcpy($51 | 0, $43 | 0, $50 | 0) | 0; //@line 378
         $53 = __Znwj(16) | 0; //@line 379
         HEAP32[$53 >> 2] = 0; //@line 380
         HEAP32[$53 + 4 >> 2] = ___strdup($19) | 0; //@line 383
         HEAP32[$53 + 8 >> 2] = 0; //@line 385
         HEAP32[$53 + 12 >> 2] = $51; //@line 387
         $58 = HEAP32[28198] | 0; //@line 388
         if (!$58) {
          $$sink$i$i = 112792; //@line 391
         } else {
          $$0$i$i = $58; //@line 393
          while (1) {
           $60 = HEAP32[$$0$i$i >> 2] | 0; //@line 395
           if (!$60) {
            break;
           } else {
            $$0$i$i = $60; //@line 400
           }
          }
          $$sink$i$i = $$0$i$i; //@line 403
         }
         HEAP32[$$sink$i$i >> 2] = $53; //@line 405
         $$2 = $38; //@line 406
         break L6;
         break;
        }
       case 1:
        {
         if (_strcmp($43, 88970) | 0) {
          if (_strcmp($43, 88975) | 0) {
           if (_strcmp($43, 88978) | 0) {
            if (_strcmp($43, 88982) | 0) {
             if (_strcmp($43, 88988) | 0) {
              if (_strcmp($43, 88992) | 0) {
               HEAP32[$vararg_buffer1 >> 2] = $10; //@line 429
               _fprintf($5, 88995, $vararg_buffer1) | 0; //@line 430
               $$2 = $38; //@line 431
               break L6;
              }
             }
            }
            $$01416$i$i87 = HEAP32[28198] | 0; //@line 436
            L45 : do {
             if ($$01416$i$i87 | 0) {
              $$01418$i$i88 = $$01416$i$i87; //@line 440
              while (1) {
               if ((HEAP32[$$01418$i$i88 + 8 >> 2] | 0) == 1) {
                if (!(_strcmp(HEAP32[$$01418$i$i88 + 4 >> 2] | 0, $19) | 0)) {
                 break;
                }
               }
               $$014$i$i90 = HEAP32[$$01418$i$i88 >> 2] | 0; //@line 454
               if (!$$014$i$i90) {
                break L45;
               } else {
                $$01418$i$i88 = $$014$i$i90; //@line 459
               }
              }
              HEAP8[HEAP32[$$01418$i$i88 + 12 >> 2] >> 0] = 0; //@line 464
              $$2 = $38; //@line 465
              break L6;
             }
            } while (0);
            $107 = _malloc(1) | 0; //@line 469
            if (!$107) {
             $$2 = $38; //@line 472
             break L6;
            }
            HEAP8[$107 >> 0] = 0; //@line 475
            $109 = __Znwj(16) | 0; //@line 476
            HEAP32[$109 >> 2] = 0; //@line 477
            HEAP32[$109 + 4 >> 2] = ___strdup($19) | 0; //@line 480
            HEAP32[$109 + 8 >> 2] = 1; //@line 482
            HEAP32[$109 + 12 >> 2] = $107; //@line 484
            $114 = HEAP32[28198] | 0; //@line 485
            if (!$114) {
             $$sink$i$i95 = 112792; //@line 488
            } else {
             $$0$i$i93 = $114; //@line 490
             while (1) {
              $116 = HEAP32[$$0$i$i93 >> 2] | 0; //@line 492
              if (!$116) {
               break;
              } else {
               $$0$i$i93 = $116; //@line 497
              }
             }
             $$sink$i$i95 = $$0$i$i93; //@line 500
            }
            HEAP32[$$sink$i$i95 >> 2] = $109; //@line 502
            $$2 = $38; //@line 503
            break L6;
           }
          }
         }
         $$01416$i$i = HEAP32[28198] | 0; //@line 508
         L60 : do {
          if ($$01416$i$i | 0) {
           $$01418$i$i = $$01416$i$i; //@line 512
           while (1) {
            if ((HEAP32[$$01418$i$i + 8 >> 2] | 0) == 1) {
             if (!(_strcmp(HEAP32[$$01418$i$i + 4 >> 2] | 0, $19) | 0)) {
              break;
             }
            }
            $$014$i$i = HEAP32[$$01418$i$i >> 2] | 0; //@line 526
            if (!$$014$i$i) {
             break L60;
            } else {
             $$01418$i$i = $$014$i$i; //@line 531
            }
           }
           HEAP8[HEAP32[$$01418$i$i + 12 >> 2] >> 0] = 1; //@line 536
           $$2 = $38; //@line 537
           break L6;
          }
         } while (0);
         $79 = _malloc(1) | 0; //@line 541
         if (!$79) {
          $$2 = $38; //@line 544
          break L6;
         }
         HEAP8[$79 >> 0] = 1; //@line 547
         $81 = __Znwj(16) | 0; //@line 548
         HEAP32[$81 >> 2] = 0; //@line 549
         HEAP32[$81 + 4 >> 2] = ___strdup($19) | 0; //@line 552
         HEAP32[$81 + 8 >> 2] = 1; //@line 554
         HEAP32[$81 + 12 >> 2] = $79; //@line 556
         $86 = HEAP32[28198] | 0; //@line 557
         if (!$86) {
          $$sink$i$i86 = 112792; //@line 560
         } else {
          $$0$i$i84 = $86; //@line 562
          while (1) {
           $88 = HEAP32[$$0$i$i84 >> 2] | 0; //@line 564
           if (!$88) {
            break;
           } else {
            $$0$i$i84 = $88; //@line 569
           }
          }
          $$sink$i$i86 = $$0$i$i84; //@line 572
         }
         HEAP32[$$sink$i$i86 >> 2] = $81; //@line 574
         $$2 = $38; //@line 575
         break L6;
         break;
        }
       case 2:
        {
         $118 = _atoi($43) | 0; //@line 580
         $$01416$i$i97 = HEAP32[28198] | 0; //@line 581
         L75 : do {
          if ($$01416$i$i97 | 0) {
           $$01418$i$i98 = $$01416$i$i97; //@line 585
           while (1) {
            if ((HEAP32[$$01418$i$i98 + 8 >> 2] | 0) == 2) {
             if (!(_strcmp(HEAP32[$$01418$i$i98 + 4 >> 2] | 0, $19) | 0)) {
              break;
             }
            }
            $$014$i$i100 = HEAP32[$$01418$i$i98 >> 2] | 0; //@line 599
            if (!$$014$i$i100) {
             break L75;
            } else {
             $$01418$i$i98 = $$014$i$i100; //@line 604
            }
           }
           HEAP32[HEAP32[$$01418$i$i98 + 12 >> 2] >> 2] = $118; //@line 609
           $$2 = $38; //@line 610
           break L6;
          }
         } while (0);
         $130 = _malloc(4) | 0; //@line 614
         if (!$130) {
          $$2 = $38; //@line 617
          break L6;
         }
         HEAP8[$130 >> 0] = $118; //@line 620
         HEAP8[$130 + 1 >> 0] = $118 >> 8; //@line 620
         HEAP8[$130 + 2 >> 0] = $118 >> 16; //@line 620
         HEAP8[$130 + 3 >> 0] = $118 >> 24; //@line 620
         $132 = __Znwj(16) | 0; //@line 621
         HEAP32[$132 >> 2] = 0; //@line 622
         HEAP32[$132 + 4 >> 2] = ___strdup($19) | 0; //@line 625
         HEAP32[$132 + 8 >> 2] = 2; //@line 627
         HEAP32[$132 + 12 >> 2] = $130; //@line 629
         $137 = HEAP32[28198] | 0; //@line 630
         if (!$137) {
          $$sink$i$i105 = 112792; //@line 633
         } else {
          $$0$i$i103 = $137; //@line 635
          while (1) {
           $139 = HEAP32[$$0$i$i103 >> 2] | 0; //@line 637
           if (!$139) {
            break;
           } else {
            $$0$i$i103 = $139; //@line 642
           }
          }
          $$sink$i$i105 = $$0$i$i103; //@line 645
         }
         HEAP32[$$sink$i$i105 >> 2] = $132; //@line 647
         $$2 = $38; //@line 648
         break L6;
         break;
        }
       default:
        {
         $$2 = $38; //@line 653
         break L6;
        }
       }
      } else {
       $$2 = $$080126; //@line 658
      }
     } else {
      $$2 = $$080126; //@line 661
     }
    }
   }
  } while (0);
  $$080126 = $$2 + 1 | 0; //@line 666
  $40 = HEAP32[$1 >> 2] | 0; //@line 667
 } while (($$080126 | 0) < ($40 | 0));
 if (($40 | 0) > 1) {
  $$079124 = 1; //@line 677
  $144 = $40; //@line 677
 } else {
  STACKTOP = sp; //@line 679
  return;
 }
 while (1) {
  if (($$079124 | 0) < ($144 | 0)) {
   $145 = HEAP32[$2 >> 2] | 0; //@line 684
   $$078116 = $$079124; //@line 685
   while (1) {
    if (HEAP32[$145 + ($$078116 << 2) >> 2] | 0) {
     $$078$lcssa = $$078116; //@line 691
     break;
    }
    $149 = $$078116 + 1 | 0; //@line 694
    if (($149 | 0) < ($144 | 0)) {
     $$078116 = $149; //@line 697
    } else {
     $$078$lcssa = $149; //@line 699
     break;
    }
   }
   if (($$078$lcssa | 0) > ($$079124 | 0)) {
    $152 = $$078$lcssa - $$079124 | 0; //@line 705
    if (($$078$lcssa | 0) < ($144 | 0)) {
     $$0119 = $$078$lcssa; //@line 708
     do {
      $155 = HEAP32[$2 >> 2] | 0; //@line 710
      HEAP32[$155 + ($$0119 - $152 << 2) >> 2] = HEAP32[$155 + ($$0119 << 2) >> 2]; //@line 715
      $$0119 = $$0119 + 1 | 0; //@line 716
     } while (($$0119 | 0) < ($144 | 0));
    }
    $154 = $144 - $152 | 0; //@line 725
    HEAP32[$1 >> 2] = $154; //@line 726
    $164 = $154; //@line 727
   } else {
    $164 = $144; //@line 729
   }
  } else {
   $164 = $144; //@line 732
  }
  $$079124 = $$079124 + 1 | 0; //@line 734
  if (($$079124 | 0) >= ($164 | 0)) {
   break;
  } else {
   $144 = $164; //@line 737
  }
 }
 STACKTOP = sp; //@line 742
 return;
}
function _hexfloat($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$0 = 0, $$0133 = 0, $$0142 = 0, $$0146 = 0, $$0148 = 0, $$0151 = 0.0, $$0152 = 0.0, $$0155 = 0.0, $$0159 = 0, $$0165 = 0.0, $$0166 = 0, $$0166169 = 0, $$0166170 = 0, $$1$ph = 0, $$1147 = 0, $$1149 = 0, $$1153 = 0.0, $$1156 = 0.0, $$1160 = 0, $$2 = 0, $$2$lcssa = 0, $$2144 = 0, $$2150 = 0, $$2154 = 0.0, $$2157 = 0.0, $$2161 = 0, $$3145 = 0, $$3158$lcssa = 0.0, $$3158179 = 0.0, $$3162$lcssa = 0, $$3162183 = 0, $$4 = 0.0, $$4163$lcssa = 0, $$4163178 = 0, $$5164 = 0, $$pre$phiZ2D = 0.0, $100 = 0, $101 = 0, $107 = 0, $108 = 0, $109 = 0, $119 = 0, $120 = 0, $133 = 0, $135 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $144 = 0, $146 = 0, $156 = 0, $158 = 0, $169 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $179 = 0, $182 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $196 = 0.0, $197 = 0, $21 = 0, $210 = 0.0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $29 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $5 = 0, $53 = 0, $55 = 0, $6 = 0, $67 = 0.0, $7 = 0, $74 = 0, $76 = 0, $84 = 0, $85 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond168 = 0, label = 0;
 $5 = $0 + 4 | 0; //@line 60036
 $6 = HEAP32[$5 >> 2] | 0; //@line 60037
 $7 = $0 + 100 | 0; //@line 60038
 if ($6 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
  HEAP32[$5 >> 2] = $6 + 1; //@line 60043
  $$0 = HEAPU8[$6 >> 0] | 0; //@line 60046
  $$0142 = 0; //@line 60046
 } else {
  $$0 = ___shgetc($0) | 0; //@line 60049
  $$0142 = 0; //@line 60049
 }
 L4 : while (1) {
  switch ($$0 | 0) {
  case 46:
   {
    label = 8; //@line 60054
    break L4;
    break;
   }
  case 48:
   {
    break;
   }
  default:
   {
    $$0146 = 0; //@line 60062
    $$0148 = 0; //@line 60062
    $$0152 = 1.0; //@line 60062
    $$0155 = 0.0; //@line 60062
    $$0159 = 0; //@line 60062
    $$2 = $$0; //@line 60062
    $$2144 = $$0142; //@line 60062
    $101 = 0; //@line 60062
    $53 = 0; //@line 60062
    $55 = 0; //@line 60062
    $99 = 0; //@line 60062
    break L4;
   }
  }
  $14 = HEAP32[$5 >> 2] | 0; //@line 60066
  if ($14 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
   HEAP32[$5 >> 2] = $14 + 1; //@line 60071
   $$0 = HEAPU8[$14 >> 0] | 0; //@line 60074
   $$0142 = 1; //@line 60074
   continue;
  } else {
   $$0 = ___shgetc($0) | 0; //@line 60078
   $$0142 = 1; //@line 60078
   continue;
  }
 }
 if ((label | 0) == 8) {
  $21 = HEAP32[$5 >> 2] | 0; //@line 60083
  if ($21 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
   HEAP32[$5 >> 2] = $21 + 1; //@line 60088
   $$1$ph = HEAPU8[$21 >> 0] | 0; //@line 60091
  } else {
   $$1$ph = ___shgetc($0) | 0; //@line 60094
  }
  if (($$1$ph | 0) == 48) {
   $36 = 0; //@line 60098
   $37 = 0; //@line 60098
   while (1) {
    $29 = HEAP32[$5 >> 2] | 0; //@line 60100
    if ($29 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
     HEAP32[$5 >> 2] = $29 + 1; //@line 60105
     $41 = HEAPU8[$29 >> 0] | 0; //@line 60108
    } else {
     $41 = ___shgetc($0) | 0; //@line 60111
    }
    $38 = _i64Add($36 | 0, $37 | 0, -1, -1) | 0; //@line 60113
    $39 = tempRet0; //@line 60114
    if (($41 | 0) == 48) {
     $36 = $38; //@line 60117
     $37 = $39; //@line 60117
    } else {
     $$0146 = 1; //@line 60119
     $$0148 = 0; //@line 60119
     $$0152 = 1.0; //@line 60119
     $$0155 = 0.0; //@line 60119
     $$0159 = 0; //@line 60119
     $$2 = $41; //@line 60119
     $$2144 = 1; //@line 60119
     $101 = $39; //@line 60119
     $53 = 0; //@line 60119
     $55 = 0; //@line 60119
     $99 = $38; //@line 60119
     break;
    }
   }
  } else {
   $$0146 = 1; //@line 60124
   $$0148 = 0; //@line 60124
   $$0152 = 1.0; //@line 60124
   $$0155 = 0.0; //@line 60124
   $$0159 = 0; //@line 60124
   $$2 = $$1$ph; //@line 60124
   $$2144 = $$0142; //@line 60124
   $101 = 0; //@line 60124
   $53 = 0; //@line 60124
   $55 = 0; //@line 60124
   $99 = 0; //@line 60124
  }
 }
 while (1) {
  $42 = $$2 + -48 | 0; //@line 60128
  $44 = ($$2 | 0) == 46; //@line 60130
  if ($42 >>> 0 >= 10) {
   if (!($44 | (($$2 | 32) + -97 | 0) >>> 0 < 6)) {
    $$2$lcssa = $$2; //@line 60137
    break;
   }
  }
  if ($44) {
   if (!$$0146) {
    $$1147 = 1; //@line 60144
    $$2150 = $$0148; //@line 60144
    $$2154 = $$0152; //@line 60144
    $$2157 = $$0155; //@line 60144
    $$2161 = $$0159; //@line 60144
    $$3145 = $$2144; //@line 60144
    $214 = $55; //@line 60144
    $215 = $53; //@line 60144
    $216 = $55; //@line 60144
    $217 = $53; //@line 60144
   } else {
    $$2$lcssa = 46; //@line 60146
    break;
   }
  } else {
   $$0133 = ($$2 | 0) > 57 ? ($$2 | 32) + -87 | 0 : $42; //@line 60153
   do {
    if (($53 | 0) < 0 | ($53 | 0) == 0 & $55 >>> 0 < 8) {
     $$1149 = $$0148; //@line 60163
     $$1153 = $$0152; //@line 60163
     $$1156 = $$0155; //@line 60163
     $$1160 = $$0133 + ($$0159 << 4) | 0; //@line 60163
    } else {
     if (($53 | 0) < 0 | ($53 | 0) == 0 & $55 >>> 0 < 14) {
      $67 = $$0152 * .0625; //@line 60172
      $$1149 = $$0148; //@line 60175
      $$1153 = $67; //@line 60175
      $$1156 = $$0155 + $67 * +($$0133 | 0); //@line 60175
      $$1160 = $$0159; //@line 60175
      break;
     } else {
      $or$cond = ($$0148 | 0) != 0 | ($$0133 | 0) == 0; //@line 60180
      $$1149 = $or$cond ? $$0148 : 1; //@line 60185
      $$1153 = $$0152; //@line 60185
      $$1156 = $or$cond ? $$0155 : $$0155 + $$0152 * .5; //@line 60185
      $$1160 = $$0159; //@line 60185
      break;
     }
    }
   } while (0);
   $74 = _i64Add($55 | 0, $53 | 0, 1, 0) | 0; //@line 60190
   $$1147 = $$0146; //@line 60192
   $$2150 = $$1149; //@line 60192
   $$2154 = $$1153; //@line 60192
   $$2157 = $$1156; //@line 60192
   $$2161 = $$1160; //@line 60192
   $$3145 = 1; //@line 60192
   $214 = $99; //@line 60192
   $215 = $101; //@line 60192
   $216 = $74; //@line 60192
   $217 = tempRet0; //@line 60192
  }
  $76 = HEAP32[$5 >> 2] | 0; //@line 60194
  if ($76 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
   HEAP32[$5 >> 2] = $76 + 1; //@line 60199
   $$0146 = $$1147; //@line 60202
   $$0148 = $$2150; //@line 60202
   $$0152 = $$2154; //@line 60202
   $$0155 = $$2157; //@line 60202
   $$0159 = $$2161; //@line 60202
   $$2 = HEAPU8[$76 >> 0] | 0; //@line 60202
   $$2144 = $$3145; //@line 60202
   $101 = $215; //@line 60202
   $53 = $217; //@line 60202
   $55 = $216; //@line 60202
   $99 = $214; //@line 60202
   continue;
  } else {
   $$0146 = $$1147; //@line 60206
   $$0148 = $$2150; //@line 60206
   $$0152 = $$2154; //@line 60206
   $$0155 = $$2157; //@line 60206
   $$0159 = $$2161; //@line 60206
   $$2 = ___shgetc($0) | 0; //@line 60206
   $$2144 = $$3145; //@line 60206
   $101 = $215; //@line 60206
   $53 = $217; //@line 60206
   $55 = $216; //@line 60206
   $99 = $214; //@line 60206
   continue;
  }
 }
 do {
  if (!$$2144) {
   $84 = HEAP32[$7 >> 2] | 0; //@line 60213
   $85 = ($84 | 0) != 0; //@line 60214
   if ($85) {
    HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + -1; //@line 60218
   }
   if (!$4) {
    ___shlim($0, 0); //@line 60222
   } else {
    if ($85) {
     HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + -1; //@line 60227
    }
    if (!(($$0146 | 0) == 0 | ($84 | 0) == 0)) {
     HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + -1; //@line 60235
    }
   }
   $$0165 = +($3 | 0) * 0.0; //@line 60240
  } else {
   $97 = ($$0146 | 0) == 0; //@line 60242
   $98 = $97 ? $55 : $99; //@line 60243
   $100 = $97 ? $53 : $101; //@line 60244
   if (($53 | 0) < 0 | ($53 | 0) == 0 & $55 >>> 0 < 8) {
    $$3162183 = $$0159; //@line 60251
    $108 = $55; //@line 60251
    $109 = $53; //@line 60251
    while (1) {
     $107 = $$3162183 << 4; //@line 60253
     $108 = _i64Add($108 | 0, $109 | 0, 1, 0) | 0; //@line 60254
     $109 = tempRet0; //@line 60255
     if (!(($109 | 0) < 0 | ($109 | 0) == 0 & $108 >>> 0 < 8)) {
      $$3162$lcssa = $107; //@line 60264
      break;
     } else {
      $$3162183 = $107; //@line 60262
     }
    }
   } else {
    $$3162$lcssa = $$0159; //@line 60269
   }
   if (($$2$lcssa | 32 | 0) == 112) {
    $119 = _scanexp($0, $4) | 0; //@line 60274
    $120 = tempRet0; //@line 60275
    if (($119 | 0) == 0 & ($120 | 0) == -2147483648) {
     if (!$4) {
      ___shlim($0, 0); //@line 60282
      $$0165 = 0.0; //@line 60283
      break;
     }
     if (!(HEAP32[$7 >> 2] | 0)) {
      $137 = 0; //@line 60289
      $138 = 0; //@line 60289
     } else {
      HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + -1; //@line 60293
      $137 = 0; //@line 60294
      $138 = 0; //@line 60294
     }
    } else {
     $137 = $119; //@line 60297
     $138 = $120; //@line 60297
    }
   } else {
    if (!(HEAP32[$7 >> 2] | 0)) {
     $137 = 0; //@line 60303
     $138 = 0; //@line 60303
    } else {
     HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + -1; //@line 60307
     $137 = 0; //@line 60308
     $138 = 0; //@line 60308
    }
   }
   $133 = _bitshift64Shl($98 | 0, $100 | 0, 2) | 0; //@line 60311
   $135 = _i64Add($133 | 0, tempRet0 | 0, -32, -1) | 0; //@line 60313
   $139 = _i64Add($135 | 0, tempRet0 | 0, $137 | 0, $138 | 0) | 0; //@line 60315
   $140 = tempRet0; //@line 60316
   if (!$$3162$lcssa) {
    $$0165 = +($3 | 0) * 0.0; //@line 60321
    break;
   }
   $144 = 0 - $2 | 0; //@line 60324
   $146 = (($144 | 0) < 0) << 31 >> 31; //@line 60326
   if (($140 | 0) > ($146 | 0) | ($140 | 0) == ($146 | 0) & $139 >>> 0 > $144 >>> 0) {
    HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 60334
    $$0165 = +($3 | 0) * 1.7976931348623157e+308 * 1.7976931348623157e+308; //@line 60338
    break;
   }
   $156 = $2 + -106 | 0; //@line 60341
   $158 = (($156 | 0) < 0) << 31 >> 31; //@line 60343
   if (($140 | 0) < ($158 | 0) | ($140 | 0) == ($158 | 0) & $139 >>> 0 < $156 >>> 0) {
    HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 60351
    $$0165 = +($3 | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308; //@line 60355
    break;
   }
   if (($$3162$lcssa | 0) > -1) {
    $$3158179 = $$0155; //@line 60360
    $$4163178 = $$3162$lcssa; //@line 60360
    $173 = $139; //@line 60360
    $174 = $140; //@line 60360
    while (1) {
     $169 = !($$3158179 >= .5); //@line 60362
     $$5164 = $$4163178 << 1 | ($169 ^ 1) & 1; //@line 60367
     $$4 = $$3158179 + ($169 ? $$3158179 : $$3158179 + -1.0); //@line 60369
     $175 = _i64Add($173 | 0, $174 | 0, -1, -1) | 0; //@line 60370
     $176 = tempRet0; //@line 60371
     if (($$5164 | 0) > -1) {
      $$3158179 = $$4; //@line 60374
      $$4163178 = $$5164; //@line 60374
      $173 = $175; //@line 60374
      $174 = $176; //@line 60374
     } else {
      $$3158$lcssa = $$4; //@line 60376
      $$4163$lcssa = $$5164; //@line 60376
      $184 = $175; //@line 60376
      $185 = $176; //@line 60376
      break;
     }
    }
   } else {
    $$3158$lcssa = $$0155; //@line 60381
    $$4163$lcssa = $$3162$lcssa; //@line 60381
    $184 = $139; //@line 60381
    $185 = $140; //@line 60381
   }
   $179 = (($1 | 0) < 0) << 31 >> 31; //@line 60384
   $182 = _i64Subtract(32, 0, $2 | 0, (($2 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 60387
   $186 = _i64Add($182 | 0, tempRet0 | 0, $184 | 0, $185 | 0) | 0; //@line 60389
   $187 = tempRet0; //@line 60390
   if (($179 | 0) > ($187 | 0) | ($179 | 0) == ($187 | 0) & $1 >>> 0 > $186 >>> 0) {
    if (($186 | 0) > 0) {
     $$0166 = $186; //@line 60399
     label = 59; //@line 60400
    } else {
     $$0166170 = 0; //@line 60402
     $197 = 84; //@line 60402
     label = 61; //@line 60403
    }
   } else {
    $$0166 = $1; //@line 60406
    label = 59; //@line 60407
   }
   if ((label | 0) == 59) {
    if (($$0166 | 0) < 53) {
     $$0166170 = $$0166; //@line 60413
     $197 = 84 - $$0166 | 0; //@line 60413
     label = 61; //@line 60414
    } else {
     $$0151 = 0.0; //@line 60417
     $$0166169 = $$0166; //@line 60417
     $$pre$phiZ2D = +($3 | 0); //@line 60417
    }
   }
   if ((label | 0) == 61) {
    $196 = +($3 | 0); //@line 60421
    $$0151 = +_copysignl(+_scalbn(1.0, $197), $196); //@line 60424
    $$0166169 = $$0166170; //@line 60424
    $$pre$phiZ2D = $196; //@line 60424
   }
   $or$cond168 = ($$4163$lcssa & 1 | 0) == 0 & ($$3158$lcssa != 0.0 & ($$0166169 | 0) < 32); //@line 60431
   $210 = $$pre$phiZ2D * ($or$cond168 ? 0.0 : $$3158$lcssa) + ($$0151 + $$pre$phiZ2D * +((($or$cond168 & 1) + $$4163$lcssa | 0) >>> 0)) - $$0151; //@line 60440
   if (!($210 != 0.0)) {
    HEAP32[(___errno_location() | 0) >> 2] = 34; //@line 60444
   }
   $$0165 = +_scalbnl($210, $184); //@line 60447
  }
 } while (0);
 return +$$0165;
}
function __ZL17get_item_and_pathjjRP6FSItemb($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i12 = 0, $$012$i = 0, $$012$i20 = 0, $$014$i = 0, $$014$i15 = 0, $$015$i = 0, $$015$i16 = 0, $$058$i = 0, $$058$i6 = 0, $$059$ph39 = 0, $$06$i = 0, $$067$i$pn = 0, $$067$i7$pn = 0, $$07$i = 0, $$07$i$sink = 0, $$09$i = 0, $$09$i5 = 0, $$1 = 0, $$160 = 0, $$162 = 0, $101 = 0, $103 = 0, $105 = 0, $110 = 0, $122 = 0, $128 = 0, $132 = 0, $136 = 0, $14 = 0, $140 = 0, $15 = 0, $152 = 0, $153 = 0, $155 = 0, $16 = 0, $164 = 0, $170 = 0, $174 = 0, $18 = 0, $180 = 0, $191 = 0, $197 = 0, $201 = 0, $205 = 0, $209 = 0, $21 = 0, $221 = 0, $222 = 0, $224 = 0, $23 = 0, $233 = 0, $244 = 0, $252 = 0, $253 = 0, $27 = 0, $29 = 0, $3 = 0, $33 = 0, $35 = 0, $39 = 0, $4 = 0, $41 = 0, $45 = 0, $47 = 0, $5 = 0, $6 = 0, $64 = 0, $8 = 0, $80 = 0, $84 = 0, $93 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 34723
 STACKTOP = STACKTOP + 144 | 0; //@line 34724
 $3 = sp + 72 | 0; //@line 34725
 $4 = sp + 4 | 0; //@line 34726
 $5 = sp; //@line 34727
 $6 = __ZL15get_current_dirjjRjb($0, $1, $5, 0) | 0; //@line 34728
 if ($6 << 16 >> 16) {
  $$1 = $6; //@line 34731
  STACKTOP = sp; //@line 34732
  return $$1 | 0; //@line 34732
 }
 $8 = HEAP32[$5 >> 2] | 0; //@line 34734
 $$06$i = HEAP32[30826] | 0; //@line 34735
 if (!$$06$i) {
  $$1 = -120; //@line 34738
  STACKTOP = sp; //@line 34739
  return $$1 | 0; //@line 34739
 } else {
  $$07$i = $$06$i; //@line 34741
 }
 while (1) {
  if ((HEAP32[$$07$i + 4 >> 2] | 0) == ($8 | 0)) {
   break;
  }
  $$0$i = HEAP32[$$07$i >> 2] | 0; //@line 34750
  if (!$$0$i) {
   $$1 = -120; //@line 34753
   label = 44; //@line 34754
   break;
  } else {
   $$07$i = $$0$i; //@line 34757
  }
 }
 if ((label | 0) == 44) {
  STACKTOP = sp; //@line 34761
  return $$1 | 0; //@line 34761
 }
 $14 = HEAP32[30848] | 0; //@line 34763
 $15 = $14 + 296 | 0; //@line 34764
 $16 = $0 + 18 | 0; //@line 34765
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 34767
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$18 >> 2] >> 2] & 127]($16) | 0; //@line 34770
 $23 = 123608 + ($15 >>> 16 << 2) | 0; //@line 34772
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 12 >> 2] & 31]($15, $21); //@line 34776
 $27 = $14 + 300 | 0; //@line 34777
 $29 = 123608 + ($27 >>> 16 << 2) | 0; //@line 34779
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, 0); //@line 34783
 $33 = $14 + 302 | 0; //@line 34784
 $35 = 123608 + ($33 >>> 16 << 2) | 0; //@line 34786
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$35 >> 2] | 0) + 16 >> 2] & 31]($33, 0); //@line 34790
 $39 = $14 + 304 | 0; //@line 34791
 $41 = 123608 + ($39 >>> 16 << 2) | 0; //@line 34793
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$41 >> 2] | 0) + 20 >> 2] & 31]($39, 0); //@line 34797
 $45 = $14 + 305 | 0; //@line 34798
 $47 = 123608 + ($45 >>> 16 << 2) | 0; //@line 34800
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$47 >> 2] | 0) + 20 >> 2] & 31]($45, 0); //@line 34804
 HEAP32[$4 + 32 >> 2] = $27; //@line 34806
 HEAP32[$4 + 36 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[$23 >> 2] >> 2] & 127]($15) | 0; //@line 34811
 _Execute68k((HEAP32[30848] | 0) + 656 | 0, $4); //@line 34814
 do {
  if (!(HEAP32[$4 >> 2] & 65535)) {
   HEAP32[$3 + 32 >> 2] = $15; //@line 34821
   _Execute68k((HEAP32[30848] | 0) + 644 | 0, $3); //@line 34824
   $64 = HEAP32[$3 >> 2] & 65535; //@line 34826
   if ($64 << 16 >> 16) {
    $$1 = $64; //@line 34829
    STACKTOP = sp; //@line 34830
    return $$1 | 0; //@line 34830
   }
   if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0)) {
    if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$47 >> 2] | 0) + 8 >> 2] & 127]($45) | 0) {
     $80 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0) + 1 | 0; //@line 34848
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $80); //@line 34852
    }
   }
   $84 = $3 + 32 | 0; //@line 34855
   $$059$ph39 = $$07$i; //@line 34856
   $101 = $8; //@line 34856
   L21 : while (1) {
    do {
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$41 >> 2] | 0) + 8 >> 2] & 127]($39) | 0)) {
      label = 29; //@line 34865
      break L21;
     }
     HEAP32[$84 >> 2] = $15; //@line 34868
     _Execute68k((HEAP32[30848] | 0) + 644 | 0, $3); //@line 34871
     $93 = HEAP32[$3 >> 2] & 65535; //@line 34873
     if ($93 << 16 >> 16) {
      $$1 = $93; //@line 34876
      label = 44; //@line 34877
      break L21;
     }
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0)) {
      label = 15; //@line 34886
      break;
     }
    } while (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$41 >> 2] | 0) + 8 >> 2] & 127]($39) | 0));
    if ((label | 0) == 15) {
     label = 0; //@line 34899
     if (($101 | 0) == 2) {
      $$160 = $$059$ph39; //@line 34902
      $$162 = -37; //@line 34902
      $253 = 2; //@line 34902
     } else {
      $103 = HEAP32[$$059$ph39 + 12 >> 2] | 0; //@line 34905
      $105 = HEAP32[$103 + 4 >> 2] | 0; //@line 34907
      HEAP32[$5 >> 2] = $105; //@line 34908
      $$160 = $103; //@line 34909
      $$162 = 0; //@line 34909
      $253 = $105; //@line 34909
     }
     $110 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0) + 1 | 0; //@line 34915
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $110); //@line 34919
     if (!($$162 << 16 >> 16)) {
      $$059$ph39 = $$160; //@line 34922
      $101 = $253; //@line 34922
      continue;
     } else {
      $$1 = $$162; //@line 34925
      label = 44; //@line 34926
      break;
     }
    }
    $122 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$23 >> 2] >> 2] & 127]($15) | 0; //@line 34932
    $128 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($122 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($122) | 0; //@line 34938
    $132 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 34942
    $136 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0; //@line 34946
    if (!$136) {
     $$0$lcssa$i = $3; //@line 34949
    } else {
     $$058$i = $136; //@line 34952
     $$067$i$pn = $128 + $132 | 0; //@line 34952
     $$09$i = $3; //@line 34952
     while (1) {
      $$067$i$pn = $$067$i$pn + 1 | 0; //@line 34954
      $$058$i = $$058$i + -1 | 0; //@line 34955
      $140 = HEAP8[$$067$i$pn >> 0] | 0; //@line 34956
      HEAP8[$$09$i >> 0] = $140 << 24 >> 24 == 47 ? 58 : $140; //@line 34960
      if (!$$058$i) {
       break;
      } else {
       $$09$i = $$09$i + 1 | 0; //@line 34965
      }
     }
     $$0$lcssa$i = $3 + $136 | 0; //@line 34969
    }
    HEAP8[$$0$lcssa$i >> 0] = 0; //@line 34971
    $$014$i = HEAP32[30826] | 0; //@line 34972
    L40 : do {
     if (!$$014$i) {
      label = 27; //@line 34976
     } else {
      $$015$i = $$014$i; //@line 34978
      while (1) {
       if ((HEAP32[$$015$i + 12 >> 2] | 0) == ($$059$ph39 | 0)) {
        if (!(_strcmp($$015$i + 20 | 0, $3) | 0)) {
         $$012$i = $$015$i; //@line 34988
         break L40;
        }
       }
       $$015$i = HEAP32[$$015$i >> 2] | 0; //@line 34992
       if (!$$015$i) {
        label = 27; //@line 34995
        break;
       }
      }
     }
    } while (0);
    if ((label | 0) == 27) {
     label = 0; //@line 35004
     $152 = __Z25macroman_to_host_encodingPKc($3) | 0; //@line 35005
     $153 = __Znwj(60) | 0; //@line 35006
     HEAP32[HEAP32[30827] >> 2] = $153; //@line 35008
     HEAP32[$153 >> 2] = 0; //@line 35009
     HEAP32[30827] = $153; //@line 35010
     $155 = HEAP32[383] | 0; //@line 35011
     HEAP32[383] = $155 + 1; //@line 35013
     HEAP32[$153 + 4 >> 2] = $155; //@line 35015
     HEAP32[$153 + 8 >> 2] = HEAP32[$$059$ph39 + 4 >> 2]; //@line 35019
     HEAP32[$153 + 12 >> 2] = $$059$ph39; //@line 35021
     $164 = __Znaj((_strlen($152) | 0) + 1 | 0) | 0; //@line 35024
     HEAP32[$153 + 16 >> 2] = $164; //@line 35026
     _strcpy($164, $152) | 0; //@line 35027
     _strncpy($153 + 20 | 0, $3, 31) | 0; //@line 35029
     HEAP8[$153 + 51 >> 0] = 0; //@line 35031
     HEAP32[$153 + 52 >> 2] = 0; //@line 35033
     $$012$i = $153; //@line 35034
    }
    $170 = HEAP32[$$012$i + 4 >> 2] | 0; //@line 35037
    HEAP32[$5 >> 2] = $170; //@line 35038
    $174 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 35042
    $180 = $174 + 1 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0) | 0; //@line 35048
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $180); //@line 35052
    $$059$ph39 = $$012$i; //@line 35053
    $101 = $170; //@line 35053
   }
   if ((label | 0) == 29) {
    if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0)) {
     $$07$i$sink = $$059$ph39; //@line 35062
     label = 42; //@line 35063
     break;
    }
    $191 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$23 >> 2] >> 2] & 127]($15) | 0; //@line 35068
    $197 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($191 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($191) | 0; //@line 35074
    $201 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 35078
    $205 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$35 >> 2] | 0) + 4 >> 2] & 127]($33) | 0; //@line 35082
    if (!$205) {
     $$0$lcssa$i12 = $3; //@line 35085
    } else {
     $$058$i6 = $205; //@line 35088
     $$067$i7$pn = $197 + $201 | 0; //@line 35088
     $$09$i5 = $3; //@line 35088
     while (1) {
      $$067$i7$pn = $$067$i7$pn + 1 | 0; //@line 35090
      $$058$i6 = $$058$i6 + -1 | 0; //@line 35091
      $209 = HEAP8[$$067$i7$pn >> 0] | 0; //@line 35092
      HEAP8[$$09$i5 >> 0] = $209 << 24 >> 24 == 47 ? 58 : $209; //@line 35096
      if (!$$058$i6) {
       break;
      } else {
       $$09$i5 = $$09$i5 + 1 | 0; //@line 35101
      }
     }
     $$0$lcssa$i12 = $3 + $205 | 0; //@line 35105
    }
    HEAP8[$$0$lcssa$i12 >> 0] = 0; //@line 35107
    $$014$i15 = HEAP32[30826] | 0; //@line 35108
    L60 : do {
     if (!$$014$i15) {
      label = 38; //@line 35112
     } else {
      $$015$i16 = $$014$i15; //@line 35114
      while (1) {
       if ((HEAP32[$$015$i16 + 12 >> 2] | 0) == ($$059$ph39 | 0)) {
        if (!(_strcmp($$015$i16 + 20 | 0, $3) | 0)) {
         $$012$i20 = $$015$i16; //@line 35124
         break L60;
        }
       }
       $$015$i16 = HEAP32[$$015$i16 >> 2] | 0; //@line 35128
       if (!$$015$i16) {
        label = 38; //@line 35131
        break;
       }
      }
     }
    } while (0);
    if ((label | 0) == 38) {
     $221 = __Z25macroman_to_host_encodingPKc($3) | 0; //@line 35140
     $222 = __Znwj(60) | 0; //@line 35141
     HEAP32[HEAP32[30827] >> 2] = $222; //@line 35143
     HEAP32[$222 >> 2] = 0; //@line 35144
     HEAP32[30827] = $222; //@line 35145
     $224 = HEAP32[383] | 0; //@line 35146
     HEAP32[383] = $224 + 1; //@line 35148
     HEAP32[$222 + 4 >> 2] = $224; //@line 35150
     HEAP32[$222 + 8 >> 2] = HEAP32[$$059$ph39 + 4 >> 2]; //@line 35154
     HEAP32[$222 + 12 >> 2] = $$059$ph39; //@line 35156
     $233 = __Znaj((_strlen($221) | 0) + 1 | 0) | 0; //@line 35159
     HEAP32[$222 + 16 >> 2] = $233; //@line 35161
     _strcpy($233, $221) | 0; //@line 35162
     _strncpy($222 + 20 | 0, $3, 31) | 0; //@line 35164
     HEAP8[$222 + 51 >> 0] = 0; //@line 35166
     HEAP32[$222 + 52 >> 2] = 0; //@line 35168
     $$012$i20 = $222; //@line 35169
    }
    HEAP32[$2 >> 2] = $$012$i20; //@line 35171
    $252 = $$012$i20; //@line 35172
    break;
   } else if ((label | 0) == 44) {
    STACKTOP = sp; //@line 35176
    return $$1 | 0; //@line 35176
   }
  } else {
   if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[$18 >> 2] >> 2] & 127]($16) | 0)) {
    $$07$i$sink = $$07$i; //@line 35184
    label = 42; //@line 35185
   } else {
    $244 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$18 >> 2] >> 2] & 127]($16) | 0; //@line 35189
    if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($244 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($244) | 0)) {
     $$07$i$sink = $$07$i; //@line 35198
     label = 42; //@line 35199
    } else {
     $$1 = -37; //@line 35201
     STACKTOP = sp; //@line 35202
     return $$1 | 0; //@line 35202
    }
   }
  }
 } while (0);
 if ((label | 0) == 42) {
  HEAP32[$2 >> 2] = $$07$i$sink; //@line 35208
  $252 = $$07$i$sink; //@line 35209
 }
 __ZL19get_path_for_fsitemP6FSItem($252); //@line 35211
 $$1 = 0; //@line 35212
 STACKTOP = sp; //@line 35213
 return $$1 | 0; //@line 35213
}
function __ZL27video_refresh_window_staticv() {
 var $$0$lcssa321$i = 0, $$0225257$i4 = 0, $$0226256$i5 = 0, $$0227$lcssa$i = 0, $$0227265$i = 0, $$0231$i = 0, $$0232$i = 0, $$0233271$i = 0, $$0237270$i = 0, $$0241269$i = 0, $$0245306$i = 0, $$0279$i = 0, $$1$i = 0, $$1228$i = 0, $$1234260$i = 0, $$1238259$i = 0, $$1242258$i = 0, $$1246$i = 0, $$1246$in$i = 0, $$2$lcssa322$i = 0, $$2229$lcssa$i = 0, $$2229292$i = 0, $$2235298$i = 0, $$2239297$i = 0, $$2243296$i = 0, $$2247278$i = 0, $$2302$i = 0, $$3$i = 0, $$3230$i = 0, $$3236288$i = 0, $$3240287$i = 0, $$3244286$i = 0, $$3248264$i = 0, $$4255$i6 = 0, $$5301$i = 0, $$6291$i = 0, $$7283$i = 0, $$pre$i = 0, $$pre317$i = 0, $101 = 0, $107 = 0, $11 = 0, $110 = 0, $112 = 0, $114 = 0, $115 = 0, $12 = 0, $126 = 0, $13 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $146 = 0, $150 = 0, $151 = 0, $163 = 0, $167 = 0, $17 = 0, $175 = 0, $176 = 0, $178 = 0, $180 = 0, $184 = 0, $19 = 0, $192 = 0, $199 = 0, $2 = 0, $21 = 0, $22 = 0, $28 = 0, $38 = 0, $40 = 0, $42 = 0, $44 = 0, $51 = 0, $53 = 0, $59 = 0, $64 = 0, $65 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $86 = 0, label = 0;
 if (HEAP8[659473] | 0) {
  HEAP8[659473] = 0; //@line 44785
  $2 = HEAP32[30855] | 0; //@line 44786
  if ($2 | 0) {
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$2 >> 2] | 0) + 32 >> 2] & 4095]($2); //@line 44792
  }
 }
 $8 = (HEAP32[30858] | 0) + 1 | 0; //@line 44796
 HEAP32[30858] = $8; //@line 44797
 if (($8 | 0) < (HEAP32[30859] | 0)) {
  return;
 }
 HEAP32[30858] = 0; //@line 44803
 $11 = HEAP32[30855] | 0; //@line 44804
 $12 = $11 + 8 | 0; //@line 44805
 $13 = HEAP32[$12 >> 2] | 0; //@line 44806
 $14 = $13 + 12 | 0; //@line 44807
 if ((HEAP32[$14 >> 2] | 0) > 2) {
  $17 = HEAP32[30807] | 0; //@line 44811
  if (!$17) {
   ___assert_fail(102512, 102524, 2404, 102547); //@line 44814
  }
  $19 = $13 + 4 | 0; //@line 44817
  $21 = HEAP32[$13 + 16 >> 2] | 0; //@line 44819
  $22 = HEAP32[30860] | 0; //@line 44820
  if (!$22) {
   ___assert_fail(102574, 102524, 2445, 102547); //@line 44823
  }
  $28 = Math_imul($21 - (($21 >>> 0) % ((HEAP32[$13 >> 2] | 0) >>> 0) | 0) | 0, HEAP32[$19 >> 2] | 0) | 0; //@line 44830
  FUNCTION_TABLE_viii[$17 & 7]($22, HEAP32[30852] | 0, $28); //@line 44832
  _emscripten_asm_const_iiiiii(1, HEAP32[30860] | 0, HEAP32[$13 >> 2] | 0, HEAP32[$19 >> 2] | 0, 32, (HEAP32[$14 >> 2] | 1 | 0) != 5 | 0) | 0; //@line 44840
  return;
 }
 _puts(102626) | 0; //@line 44843
 $38 = HEAP32[$12 >> 2] | 0; //@line 44844
 $40 = HEAP32[$38 + 16 >> 2] | 0; //@line 44846
 $42 = HEAP32[$38 + 4 >> 2] | 0; //@line 44848
 $$pre$i = HEAP32[30852] | 0; //@line 44850
 $$pre317$i = HEAP32[30854] | 0; //@line 44851
 L18 : do {
  if (!$42) {
   $$0231$i = 0; //@line 44854
  } else {
   $$0245306$i = 0; //@line 44856
   while (1) {
    $44 = Math_imul($$0245306$i, $40) | 0; //@line 44858
    if (_memcmp($$pre$i + $44 | 0, $$pre317$i + $44 | 0, $40) | 0) {
     $$0231$i = $$0245306$i; //@line 44864
     break L18;
    }
    $$0245306$i = $$0245306$i + 1 | 0; //@line 44867
    if ($$0245306$i >>> 0 >= $42 >>> 0) {
     $$0231$i = 0; //@line 44872
     break;
    }
   }
  }
 } while (0);
 $51 = $$0231$i + -1 | 0; //@line 44878
 $$1246$in$i = $42; //@line 44879
 while (1) {
  $$1246$i = $$1246$in$i + -1 | 0; //@line 44881
  if (($$1246$i | 0) < ($$0231$i | 0)) {
   $$0232$i = $51; //@line 44884
   break;
  }
  $53 = Math_imul($$1246$i, $40) | 0; //@line 44887
  if (!(_memcmp($$pre$i + $53 | 0, $$pre317$i + $53 | 0, $40) | 0)) {
   $$1246$in$i = $$1246$i; //@line 44893
  } else {
   $$0232$i = $$1246$i; //@line 44895
   break;
  }
 }
 $59 = $$0232$i - $$0231$i + 1 | 0; //@line 44900
 if (!$59) {
  return;
 }
 $64 = $11 + 16 | 0; //@line 44908
 $65 = HEAP32[$64 >> 2] | 0; //@line 44909
 $68 = HEAPU16[$65 + 16 >> 1] | 0; //@line 44912
 $69 = HEAP32[$38 >> 2] | 0; //@line 44913
 if ((HEAP32[$38 + 12 >> 2] | 0) < 3) {
  $70 = ($69 >>> 0) / ($40 >>> 0) | 0; //@line 44915
  $71 = ($69 >>> 0) / ($70 >>> 0) | 0; //@line 44916
  $72 = ($$0232$i | 0) < ($$0231$i | 0); //@line 44917
  if ($72) {
   $$0$lcssa321$i = $71; //@line 44919
   $$0227$lcssa$i = $71; //@line 44919
  } else {
   $$0279$i = $71; //@line 44921
   $$2247278$i = $$0231$i; //@line 44921
   while (1) {
    $73 = Math_imul($$2247278$i, $40) | 0; //@line 44923
    L35 : do {
     if (($$0279$i | 0) > 0) {
      $$0233271$i = $$pre317$i + $73 | 0; //@line 44929
      $$0237270$i = $$pre$i + $73 | 0; //@line 44929
      $$0241269$i = 0; //@line 44929
      while (1) {
       if ((HEAP8[$$0237270$i >> 0] | 0) != (HEAP8[$$0233271$i >> 0] | 0)) {
        $$1$i = $$0241269$i; //@line 44935
        break L35;
       }
       $$0241269$i = $$0241269$i + 1 | 0; //@line 44940
       if (($$0241269$i | 0) >= ($$0279$i | 0)) {
        $$1$i = $$0279$i; //@line 44945
        break;
       } else {
        $$0233271$i = $$0233271$i + 1 | 0; //@line 44943
        $$0237270$i = $$0237270$i + 1 | 0; //@line 44943
       }
      }
     } else {
      $$1$i = $$0279$i; //@line 44950
     }
    } while (0);
    if (($$2247278$i | 0) < ($$0232$i | 0)) {
     $$0279$i = $$1$i; //@line 44956
     $$2247278$i = $$2247278$i + 1 | 0; //@line 44956
    } else {
     $$0227265$i = $$1$i; //@line 44958
     $$3248264$i = $$0231$i; //@line 44958
     break;
    }
   }
   while (1) {
    $86 = Math_imul($$3248264$i, $40) | 0; //@line 44963
    L43 : do {
     if (($71 | 0) > ($$0227265$i | 0)) {
      $$1234260$i = $$pre317$i + $86 + $40 | 0; //@line 44971
      $$1238259$i = $$pre$i + $86 + $40 | 0; //@line 44971
      $$1242258$i = $71; //@line 44971
      while (1) {
       $$1238259$i = $$1238259$i + -1 | 0; //@line 44973
       $$1234260$i = $$1234260$i + -1 | 0; //@line 44974
       if ((HEAP8[$$1238259$i >> 0] | 0) != (HEAP8[$$1234260$i >> 0] | 0)) {
        $$1228$i = $$1242258$i; //@line 44979
        break L43;
       }
       $$1242258$i = $$1242258$i + -1 | 0; //@line 44982
       if (($$1242258$i | 0) <= ($$0227265$i | 0)) {
        $$1228$i = $$0227265$i; //@line 44987
        break;
       }
      }
     } else {
      $$1228$i = $$0227265$i; //@line 44992
     }
    } while (0);
    if (($$3248264$i | 0) < ($$0232$i | 0)) {
     $$0227265$i = $$1228$i; //@line 44998
     $$3248264$i = $$3248264$i + 1 | 0; //@line 44998
    } else {
     $$0$lcssa321$i = $$1$i; //@line 45000
     $$0227$lcssa$i = $$1228$i; //@line 45000
     break;
    }
   }
  }
  $101 = Math_imul($$0$lcssa321$i, $70) | 0; //@line 45005
  $107 = $70 + -1 - $101 + (Math_imul($$0227$lcssa$i, $70) | 0) & 0 - $70; //@line 45011
  if ($72 | ($107 | 0) == 0) {
   return;
  }
  $110 = $101 + (Math_imul($68, $$0231$i) | 0) | 0; //@line 45018
  $112 = $$0$lcssa321$i + (Math_imul($$0231$i, $40) | 0) | 0; //@line 45020
  $114 = $$pre$i + $112 | 0; //@line 45022
  $115 = ($107 | 0) / ($70 | 0) | 0; //@line 45023
  _memcpy($$pre317$i + $112 | 0, $114 | 0, $115 | 0) | 0; //@line 45024
  FUNCTION_TABLE_viii[HEAP32[30807] & 7]((HEAP32[(HEAP32[$64 >> 2] | 0) + 20 >> 2] | 0) + $110 | 0, $114, $115); //@line 45030
  if (($$0232$i | 0) > ($$0231$i | 0)) {
   $$0225257$i4 = $110; //@line 45033
   $$0226256$i5 = $112; //@line 45033
   $$4255$i6 = $$0231$i; //@line 45033
  } else {
   return;
  }
  do {
   $$4255$i6 = $$4255$i6 + 1 | 0; //@line 45038
   $$0225257$i4 = $$0225257$i4 + $68 | 0; //@line 45039
   $$0226256$i5 = $$0226256$i5 + $40 | 0; //@line 45040
   $126 = (HEAP32[30852] | 0) + $$0226256$i5 | 0; //@line 45044
   _memcpy((HEAP32[30854] | 0) + $$0226256$i5 | 0, $126 | 0, $115 | 0) | 0; //@line 45045
   FUNCTION_TABLE_viii[HEAP32[30807] & 7]((HEAP32[(HEAP32[$64 >> 2] | 0) + 20 >> 2] | 0) + $$0225257$i4 | 0, $126, $115); //@line 45051
  } while (($$4255$i6 | 0) != ($$0232$i | 0));
  return;
 }
 $132 = ($40 >>> 0) / ($69 >>> 0) | 0; //@line 45061
 $133 = ($$0232$i | 0) < ($$0231$i | 0); //@line 45062
 if ($133) {
  $$2$lcssa322$i = $69; //@line 45064
  $$2229$lcssa$i = $69; //@line 45064
 } else {
  $$2302$i = $69; //@line 45066
  $$5301$i = $$0231$i; //@line 45066
  while (1) {
   $135 = Math_imul($$5301$i, $40) | 0; //@line 45068
   $136 = Math_imul($$2302$i, $132) | 0; //@line 45069
   L62 : do {
    if (($136 | 0) > 0) {
     $$2235298$i = $$pre317$i + $135 | 0; //@line 45075
     $$2239297$i = $$pre$i + $135 | 0; //@line 45075
     $$2243296$i = 0; //@line 45075
     while (1) {
      if ((HEAP8[$$2239297$i >> 0] | 0) != (HEAP8[$$2235298$i >> 0] | 0)) {
       break;
      }
      $146 = $$2243296$i + 1 | 0; //@line 45085
      if (($146 | 0) < ($136 | 0)) {
       $$2235298$i = $$2235298$i + 1 | 0; //@line 45088
       $$2239297$i = $$2239297$i + 1 | 0; //@line 45088
       $$2243296$i = $146; //@line 45088
      } else {
       $$3$i = $$2302$i; //@line 45090
       break L62;
      }
     }
     $$3$i = ($$2243296$i | 0) / ($132 | 0) | 0; //@line 45095
    } else {
     $$3$i = $$2302$i; //@line 45097
    }
   } while (0);
   if (($$5301$i | 0) < ($$0232$i | 0)) {
    $$2302$i = $$3$i; //@line 45103
    $$5301$i = $$5301$i + 1 | 0; //@line 45103
   } else {
    break;
   }
  }
  $134 = Math_imul($132, $69) | 0; //@line 45108
  $$2229292$i = $$3$i; //@line 45109
  $$6291$i = $$0231$i; //@line 45109
  while (1) {
   $150 = Math_imul($$6291$i, $40) | 0; //@line 45111
   $151 = Math_imul($$2229292$i, $132) | 0; //@line 45112
   L72 : do {
    if (($134 | 0) > ($151 | 0)) {
     $$3236288$i = $$pre317$i + $150 + $40 | 0; //@line 45120
     $$3240287$i = $$pre$i + $150 + $40 | 0; //@line 45120
     $$3244286$i = $134; //@line 45120
     while (1) {
      $$3240287$i = $$3240287$i + -1 | 0; //@line 45122
      $$3236288$i = $$3236288$i + -1 | 0; //@line 45123
      if ((HEAP8[$$3240287$i >> 0] | 0) != (HEAP8[$$3236288$i >> 0] | 0)) {
       break;
      }
      $163 = $$3244286$i + -1 | 0; //@line 45130
      if (($163 | 0) <= ($151 | 0)) {
       $$3230$i = $$2229292$i; //@line 45135
       break L72;
      } else {
       $$3244286$i = $163; //@line 45133
      }
     }
     $$3230$i = ($$3244286$i | 0) / ($132 | 0) | 0; //@line 45140
    } else {
     $$3230$i = $$2229292$i; //@line 45142
    }
   } while (0);
   if (($$6291$i | 0) < ($$0232$i | 0)) {
    $$2229292$i = $$3230$i; //@line 45148
    $$6291$i = $$6291$i + 1 | 0; //@line 45148
   } else {
    $$2$lcssa322$i = $$3$i; //@line 45150
    $$2229$lcssa$i = $$3230$i; //@line 45150
    break;
   }
  }
 }
 $167 = $$2229$lcssa$i - $$2$lcssa322$i | 0; //@line 45155
 if (!$167) {
  return;
 }
 if (!(HEAP32[$65 + 24 >> 2] | 0)) {
  if (HEAP32[$65 >> 2] & 16389 | 0) {
   label = 50; //@line 45168
  }
 } else {
  label = 50; //@line 45171
 }
 if ((label | 0) == 50) {
  _SDL_LockSurface($65 | 0) | 0; //@line 45174
 }
 if (!$133) {
  $175 = Math_imul($$2$lcssa322$i, $132) | 0; //@line 45177
  $176 = Math_imul($167, $132) | 0; //@line 45178
  $$7283$i = $$0231$i; //@line 45179
  while (1) {
   $178 = (Math_imul($$7283$i, $40) | 0) + $175 | 0; //@line 45182
   $180 = (Math_imul($$7283$i, $68) | 0) + $175 | 0; //@line 45184
   $184 = (HEAP32[30852] | 0) + $178 | 0; //@line 45188
   _memcpy((HEAP32[30854] | 0) + $178 | 0, $184 | 0, $176 | 0) | 0; //@line 45189
   FUNCTION_TABLE_viii[HEAP32[30807] & 7]((HEAP32[(HEAP32[$64 >> 2] | 0) + 20 >> 2] | 0) + $180 | 0, $184, $176); //@line 45195
   if (($$7283$i | 0) < ($$0232$i | 0)) {
    $$7283$i = $$7283$i + 1 | 0; //@line 45199
   } else {
    break;
   }
  }
 }
 $192 = HEAP32[$64 >> 2] | 0; //@line 45205
 if (!(HEAP32[$192 + 24 >> 2] | 0)) {
  if (!(HEAP32[$192 >> 2] & 16389)) {
   $199 = $192; //@line 45214
  } else {
   label = 56; //@line 45216
  }
 } else {
  label = 56; //@line 45219
 }
 if ((label | 0) == 56) {
  _SDL_UnlockSurface($192 | 0); //@line 45222
  $199 = HEAP32[$64 >> 2] | 0; //@line 45224
 }
 _SDL_UpdateRect($199 | 0, $$2$lcssa322$i | 0, $$0231$i | 0, $167 | 0, $59 | 0); //@line 45226
 return;
}
function __Z9CheckLoadjsPhj($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$01$i = 0, $$01$i189 = 0, $$01$i193 = 0, $$01$i197 = 0, $$01$i201 = 0, $$01$i205 = 0, $$01$i209 = 0, $$01$i213 = 0, $$01$i217 = 0, $$01$i221 = 0, $$01$i225 = 0, $$01$i229 = 0, $$01$i233 = 0, $100 = 0, $102 = 0, $106 = 0, $108 = 0, $11 = 0, $110 = 0, $113 = 0, $116 = 0, $119 = 0, $125 = 0, $127 = 0, $130 = 0, $134 = 0, $136 = 0, $139 = 0, $141 = 0, $144 = 0, $149 = 0, $18 = 0, $187 = 0, $189 = 0, $192 = 0, $197 = 0, $199 = 0, $20 = 0, $201 = 0, $204 = 0, $217 = 0, $219 = 0, $222 = 0, $225 = 0, $227 = 0, $229 = 0, $23 = 0, $32 = 0, $34 = 0, $37 = 0, $39 = 0, $47 = 0, $49 = 0, $51 = 0, $54 = 0, $6 = 0, $68 = 0, $70 = 0, $73 = 0, $78 = 0, $8 = 0, $80 = 0, $83 = 0, $85 = 0, $92 = 0, $94 = 0, $97 = 0, label = 0;
 if (($0 | 0) == 1651470196 & $1 << 16 >> 16 == 3) {
  $6 = $3 + -8 | 0; //@line 10453
  if (!$6) {
   return;
  } else {
   $$01$i = 0; //@line 10458
  }
  while (1) {
   $8 = $2 + $$01$i | 0; //@line 10461
   if (!(_memcmp($8, 92802, 8) | 0)) {
    break;
   }
   $11 = $$01$i + 1 | 0; //@line 10467
   if ($11 >>> 0 < $6 >>> 0) {
    $$01$i = $11; //@line 10470
   } else {
    label = 87; //@line 10472
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i) {
   return;
  }
  HEAP16[$8 + 6 >> 1] = _htons(28936) | 0; //@line 10485
  return;
 }
 if (($0 | 0) == 1347699528 & $1 << 16 >> 16 == 630) {
  $18 = $3 + -6 | 0; //@line 10492
  if (!$18) {
   $39 = 2; //@line 10495
  } else {
   $$01$i189 = 0; //@line 10497
   while (1) {
    $20 = $2 + $$01$i189 | 0; //@line 10499
    if (!(_memcmp($20, 92810, 6) | 0)) {
     label = 11; //@line 10503
     break;
    }
    $23 = $$01$i189 + 1 | 0; //@line 10506
    if ($23 >>> 0 < $18 >>> 0) {
     $$01$i189 = $23; //@line 10509
    } else {
     break;
    }
   }
   if ((label | 0) == 11) {
    if ($$01$i189 | 0) {
     HEAP16[$20 + 4 >> 1] = _htons(20081) | 0; //@line 10519
     HEAP16[$20 + 14 >> 1] = _htons(20081) | 0; //@line 10522
     HEAP16[$20 + 24 >> 1] = _htons(20081) | 0; //@line 10525
    }
   }
   $32 = $3 + -4 | 0; //@line 10528
   if (!$32) {
    return;
   } else {
    $39 = $32; //@line 10533
   }
  }
  $$01$i193 = 0; //@line 10536
  while (1) {
   $34 = $2 + $$01$i193 | 0; //@line 10538
   if (!(_memcmp($34, 92816, 4) | 0)) {
    break;
   }
   $37 = $$01$i193 + 1 | 0; //@line 10544
   if ($37 >>> 0 < $39 >>> 0) {
    $$01$i193 = $37; //@line 10547
   } else {
    label = 87; //@line 10549
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i193) {
   return;
  }
  HEAP16[$34 + 2 >> 1] = _htons(20081) | 0; //@line 10562
  HEAP16[$34 + 10 >> 1] = _htons(20081) | 0; //@line 10565
  HEAP16[$34 + 18 >> 1] = _htons(20081) | 0; //@line 10568
  return;
 }
 $47 = ($0 | 0) == 1886675816; //@line 10571
 if ($47 & $1 << 16 >> 16 == 26) {
  $49 = $3 + -4 | 0; //@line 10575
  if (!$49) {
   return;
  } else {
   $$01$i197 = 0; //@line 10580
  }
  while (1) {
   $51 = $2 + $$01$i197 | 0; //@line 10583
   if (!(_memcmp($51, 92820, 4) | 0)) {
    break;
   }
   $54 = $$01$i197 + 1 | 0; //@line 10589
   if ($54 >>> 0 < $49 >>> 0) {
    $$01$i197 = $54; //@line 10592
   } else {
    label = 87; //@line 10594
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i197) {
   return;
  }
  HEAP16[$51 >> 1] = _htons(((HEAP32[30896] | 0) + 210448 | 0) >>> 16 & 65535) | 0; //@line 10611
  HEAP16[$51 + 2 >> 1] = _htons((HEAP32[30896] | 0) + 13840 & 65535) | 0; //@line 10616
  return;
 }
 if ($47 & $1 << 16 >> 16 == 34) {
  $68 = $3 + -10 | 0; //@line 10622
  if (!$68) {
   $85 = 6; //@line 10625
  } else {
   $$01$i201 = 0; //@line 10627
   while (1) {
    $70 = $2 + $$01$i201 | 0; //@line 10629
    if (!(_memcmp($70, 92824, 10) | 0)) {
     label = 29; //@line 10633
     break;
    }
    $73 = $$01$i201 + 1 | 0; //@line 10636
    if ($73 >>> 0 < $68 >>> 0) {
     $$01$i201 = $73; //@line 10639
    } else {
     break;
    }
   }
   if ((label | 0) == 29) {
    if ($$01$i201 | 0) {
     HEAP16[$70 + 14 >> 1] = _htons(20081) | 0; //@line 10649
    }
   }
   $78 = $3 + -4 | 0; //@line 10652
   if (!$78) {
    return;
   } else {
    $85 = $78; //@line 10657
   }
  }
  $$01$i205 = 0; //@line 10660
  while (1) {
   $80 = $2 + $$01$i205 | 0; //@line 10662
   if (!(_memcmp($80, 92834, 4) | 0)) {
    break;
   }
   $83 = $$01$i205 + 1 | 0; //@line 10668
   if ($83 >>> 0 < $85 >>> 0) {
    $$01$i205 = $83; //@line 10671
   } else {
    label = 87; //@line 10673
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i205) {
   return;
  }
  HEAP16[$80 >> 1] = _htons(20081) | 0; //@line 10686
  HEAP16[$80 + 2 >> 1] = _htons(20081) | 0; //@line 10688
  return;
 }
 if (($0 | 0) == 1735418728 & $1 << 16 >> 16 == 750) {
  $92 = $3 + -10 | 0; //@line 10695
  L79 : do {
   if ($92 | 0) {
    $$01$i209 = 0; //@line 10699
    while (1) {
     $94 = $2 + $$01$i209 | 0; //@line 10701
     if (!(_memcmp($94, 92838, 10) | 0)) {
      break;
     }
     $97 = $$01$i209 + 1 | 0; //@line 10707
     if ($97 >>> 0 < $92 >>> 0) {
      $$01$i209 = $97; //@line 10710
     } else {
      break L79;
     }
    }
    if ($$01$i209 | 0) {
     $100 = $94 + 4 | 0; //@line 10717
     $102 = $100 + 2 | 0; //@line 10719
     HEAP16[$100 >> 1] = _htons(28976) | 0; //@line 10720
     HEAP16[$102 >> 1] = _htons(28672) | 0; //@line 10723
     HEAP16[$102 + 2 >> 1] = _htons(20085) | 0; //@line 10725
    }
   }
  } while (0);
  __ZL15patch_idle_timePhji($2, $3); //@line 10729
  return;
 }
 $106 = ($0 | 0) == 1819304808; //@line 10732
 if ($106 & $1 << 16 >> 16 == 24) {
  $108 = $3 + -4 | 0; //@line 10736
  if (!$108) {
   return;
  } else {
   $$01$i213 = 0; //@line 10741
  }
  while (1) {
   $110 = $2 + $$01$i213 | 0; //@line 10744
   if (!(_memcmp($110, 92848, 4) | 0)) {
    break;
   }
   $113 = $$01$i213 + 1 | 0; //@line 10750
   if ($113 >>> 0 < $108 >>> 0) {
    $$01$i213 = $113; //@line 10753
   } else {
    label = 87; //@line 10755
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i213) {
   return;
  }
  $116 = $110 + 2 | 0; //@line 10766
  HEAP16[$116 >> 1] = _htons(20081) | 0; //@line 10769
  $119 = $116 + 2 + 6 | 0; //@line 10770
  HEAP16[$119 >> 1] = _htons(20081) | 0; //@line 10773
  HEAP16[$119 + 2 + 14 >> 1] = _htons(20081) | 0; //@line 10776
  return;
 }
 if ($106 & $1 << 16 >> 16 == 31) {
  $125 = $3 + -10 | 0; //@line 10782
  if (!$125) {
   $141 = 2; //@line 10785
   label = 57; //@line 10786
  } else {
   $$01$i217 = 0; //@line 10788
   while (1) {
    $127 = $2 + $$01$i217 | 0; //@line 10790
    if (!(_memcmp($127, 92852, 10) | 0)) {
     label = 54; //@line 10794
     break;
    }
    $130 = $$01$i217 + 1 | 0; //@line 10797
    if ($130 >>> 0 < $125 >>> 0) {
     $$01$i217 = $130; //@line 10800
    } else {
     break;
    }
   }
   if ((label | 0) == 54) {
    if ($$01$i217 | 0) {
     HEAP16[$127 >> 1] = _htons(20085) | 0; //@line 10809
    }
   }
   $134 = $3 + -8 | 0; //@line 10812
   if ($134 | 0) {
    $141 = $134; //@line 10815
    label = 57; //@line 10816
   }
  }
  L113 : do {
   if ((label | 0) == 57) {
    $$01$i221 = 0; //@line 10821
    while (1) {
     $136 = $2 + $$01$i221 | 0; //@line 10823
     if (!(_memcmp($136, 92862, 8) | 0)) {
      break;
     }
     $139 = $$01$i221 + 1 | 0; //@line 10829
     if ($139 >>> 0 < $141 >>> 0) {
      $$01$i221 = $139; //@line 10832
     } else {
      break L113;
     }
    }
    if ($$01$i221 | 0) {
     $144 = $136 + 2 | 0; //@line 10840
     HEAP16[$136 >> 1] = _htons(28968) | 0; //@line 10841
     HEAP16[$144 >> 1] = _htons(11849) | 0; //@line 10844
     HEAP16[$144 + 2 >> 1] = _htons(20176) | 0; //@line 10846
    }
   }
  } while (0);
  __ZL15patch_idle_timePhji($2, $3); //@line 10850
  return;
 }
 $149 = $1 << 16 >> 16 == -16563; //@line 10854
 if (($0 | 0) == 1953001063 & $149) {
  HEAP32[$2 + 12 >> 2] = _htonl(HEAP32[30823] | 0) | 0; //@line 10860
  return;
 }
 if (($0 | 0) == 1936287348 & $149) {
  HEAP16[$2 >> 1] = _htons(20054) | 0; //@line 10868
  HEAP16[$2 + 2 >> 1] = _htons(0) | 0; //@line 10871
  HEAP16[$2 + 4 >> 1] = _htons(18663) | 0; //@line 10874
  HEAP16[$2 + 6 >> 1] = _htons(-32744) | 0; //@line 10877
  HEAP16[$2 + 8 >> 1] = _htons(9838) | 0; //@line 10880
  HEAP16[$2 + 10 >> 1] = _htons(12) | 0; //@line 10883
  HEAP16[$2 + 12 >> 1] = _htons(10350) | 0; //@line 10886
  HEAP16[$2 + 14 >> 1] = _htons(8) | 0; //@line 10889
  HEAP16[$2 + 16 >> 1] = _htons(28973) | 0; //@line 10892
  HEAP16[$2 + 18 >> 1] = _htons(11584) | 0; //@line 10895
  HEAP16[$2 + 20 >> 1] = _htons(16) | 0; //@line 10898
  HEAP16[$2 + 22 >> 1] = _htons(19679) | 0; //@line 10901
  HEAP16[$2 + 24 >> 1] = _htons(6145) | 0; //@line 10904
  HEAP16[$2 + 26 >> 1] = _htons(20062) | 0; //@line 10907
  HEAP16[$2 + 28 >> 1] = _htons(20084) | 0; //@line 10910
  HEAP16[$2 + 30 >> 1] = _htons(8) | 0; //@line 10912
  return;
 }
 if (($0 | 0) == 1768846196 & $1 << 16 >> 16 == -19069) {
  $187 = $3 + -6 | 0; //@line 10919
  if (!$187) {
   return;
  } else {
   $$01$i225 = 0; //@line 10924
  }
  while (1) {
   $189 = $2 + $$01$i225 | 0; //@line 10927
   if (!(_memcmp($189, 92870, 6) | 0)) {
    break;
   }
   $192 = $$01$i225 + 1 | 0; //@line 10933
   if ($192 >>> 0 < $187 >>> 0) {
    $$01$i225 = $192; //@line 10936
   } else {
    label = 87; //@line 10938
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i225) {
   return;
  }
  HEAP16[$189 + 4 >> 1] = _htons(20081) | 0; //@line 10951
  return;
 }
 $197 = ($0 | 0) == 1146246738; //@line 10954
 if ($197 & $1 << 16 >> 16 == -20066) {
  $199 = $3 + -14 | 0; //@line 10958
  if (!$199) {
   return;
  } else {
   $$01$i229 = 0; //@line 10963
  }
  while (1) {
   $201 = $2 + $$01$i229 | 0; //@line 10966
   if (!(_memcmp($201, 92876, 14) | 0)) {
    break;
   }
   $204 = $$01$i229 + 1 | 0; //@line 10972
   if ($204 >>> 0 < $199 >>> 0) {
    $$01$i229 = $204; //@line 10975
   } else {
    label = 87; //@line 10977
    break;
   }
  }
  if ((label | 0) == 87) {
   return;
  }
  if (!$$01$i229) {
   return;
  }
  HEAP16[$201 + 12 >> 1] = _htons(31232) | 0; //@line 10990
  return;
 }
 if (($0 | 0) == 1819569259 & $1 << 16 >> 16 == 0) {
  HEAP16[$2 >> 1] = _htons(20176) | 0; //@line 10999
  HEAP16[$2 + 2 >> 1] = _htons(28672) | 0; //@line 11002
  HEAP16[$2 + 4 >> 1] = _htons(20085) | 0; //@line 11004
  return;
 }
 if (!($197 & $1 << 16 >> 16 == 41)) {
  return;
 }
 $217 = $3 + -18 | 0; //@line 11012
 if (!$217) {
  return;
 } else {
  $$01$i233 = 0; //@line 11017
 }
 while (1) {
  $219 = $2 + $$01$i233 | 0; //@line 11020
  if (!(_memcmp($219, 92890, 18) | 0)) {
   break;
  }
  $222 = $$01$i233 + 1 | 0; //@line 11026
  if ($222 >>> 0 < $217 >>> 0) {
   $$01$i233 = $222; //@line 11029
  } else {
   label = 87; //@line 11031
   break;
  }
 }
 if ((label | 0) == 87) {
  return;
 }
 if (!$$01$i233) {
  return;
 }
 $225 = $219 + 4 | 0; //@line 11042
 $227 = $225 + 2 | 0; //@line 11044
 HEAP16[$225 >> 1] = _htons(12348) | 0; //@line 11045
 $229 = $227 + 2 | 0; //@line 11047
 HEAP16[$227 >> 1] = _htons(654) | 0; //@line 11048
 HEAP16[$229 >> 1] = _htons(20081) | 0; //@line 11051
 HEAP16[$229 + 2 >> 1] = _htons(20081) | 0; //@line 11053
 return;
}
function __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$0$i$i = 0, $$0112 = 0, $$1 = 0, $$1113 = 0, $$2 = 0, $$2$ph = 0, $$2114 = 0, $$3115 = 0, $$4 = 0, $$4116 = 0, $$5117 = 0, $$6 = 0, $$lcssa154 = 0, $$pre = 0, $$pre158 = 0, $$sink118 = 0, $$sink193 = 0, $10 = 0, $103 = 0, $104 = 0, $107 = 0, $11 = 0, $110 = 0, $115 = 0, $116 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $126 = 0, $129 = 0, $13 = 0, $134 = 0, $135 = 0, $136 = 0, $139 = 0, $14 = 0, $142 = 0, $147 = 0, $150 = 0, $151 = 0, $156 = 0, $163 = 0, $164 = 0, $17 = 0, $171 = 0, $172 = 0, $175 = 0, $178 = 0, $181 = 0, $186 = 0, $187 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $197 = 0, $2 = 0, $200 = 0, $24 = 0, $26 = 0, $28 = 0, $29 = 0, $36 = 0, $39 = 0, $48 = 0, $5 = 0, $54 = 0, $57 = 0, $59 = 0, $61 = 0, $62 = 0, $63 = 0, $66 = 0, $69 = 0, $7 = 0, $73 = 0, $77 = 0, $83 = 0, $90 = 0, $98 = 0, label = 0;
 $2 = HEAP32[$1 >> 2] | 0; //@line 16289
 if (!$2) {
  $10 = 0; //@line 16292
  $12 = $1; //@line 16292
 } else {
  $5 = HEAP32[$1 + 4 >> 2] | 0; //@line 16295
  if (!$5) {
   $10 = $2; //@line 16298
   $12 = $1; //@line 16298
  } else {
   $$0$i$i = $5; //@line 16300
   while (1) {
    $7 = HEAP32[$$0$i$i >> 2] | 0; //@line 16302
    if (!$7) {
     $10 = 0; //@line 16305
     $12 = $$0$i$i; //@line 16305
     break;
    } else {
     $$0$i$i = $7; //@line 16308
    }
   }
  }
 }
 $11 = $12 + 4 | 0; //@line 16314
 $13 = HEAP32[($10 | 0 ? $12 : $11) >> 2] | 0; //@line 16316
 $14 = ($13 | 0) == 0; //@line 16317
 $$pre158 = $12 + 8 | 0; //@line 16318
 if (!$14) {
  HEAP32[$13 + 8 >> 2] = HEAP32[$$pre158 >> 2]; //@line 16322
 }
 $17 = HEAP32[$$pre158 >> 2] | 0; //@line 16324
 if ((HEAP32[$17 >> 2] | 0) == ($12 | 0)) {
  HEAP32[$17 >> 2] = $13; //@line 16328
  if (($12 | 0) == ($0 | 0)) {
   $$0 = $13; //@line 16331
   $$0112 = 0; //@line 16331
  } else {
   $$sink118 = $17 + 4 | 0; //@line 16334
   label = 10; //@line 16335
  }
 } else {
  HEAP32[$17 + 4 >> 2] = $13; //@line 16339
  $$sink118 = $17; //@line 16340
  label = 10; //@line 16341
 }
 if ((label | 0) == 10) {
  $$0 = $0; //@line 16345
  $$0112 = HEAP32[$$sink118 >> 2] | 0; //@line 16345
 }
 $24 = $12 + 12 | 0; //@line 16347
 $26 = (HEAP8[$24 >> 0] | 0) == 0; //@line 16349
 if (($12 | 0) == ($1 | 0)) {
  $$1 = $$0; //@line 16352
 } else {
  $28 = $1 + 8 | 0; //@line 16354
  $29 = HEAP32[$28 >> 2] | 0; //@line 16355
  HEAP32[$$pre158 >> 2] = $29; //@line 16356
  HEAP32[((HEAP32[HEAP32[$28 >> 2] >> 2] | 0) == ($1 | 0) ? $29 : $29 + 4 | 0) >> 2] = $12; //@line 16364
  $36 = HEAP32[$1 >> 2] | 0; //@line 16365
  HEAP32[$12 >> 2] = $36; //@line 16366
  HEAP32[$36 + 8 >> 2] = $12; //@line 16368
  $39 = HEAP32[$1 + 4 >> 2] | 0; //@line 16370
  HEAP32[$11 >> 2] = $39; //@line 16371
  if ($39 | 0) {
   HEAP32[$39 + 8 >> 2] = $12; //@line 16375
  }
  HEAP8[$24 >> 0] = HEAP8[$1 + 12 >> 0] | 0; //@line 16379
  $$1 = ($$0 | 0) == ($1 | 0) ? $12 : $$0; //@line 16382
 }
 if ($26 | ($$1 | 0) == 0) {
  return;
 }
 if ($14) {
  $$1113 = $$0112; //@line 16390
  $$2 = $$1; //@line 16390
 } else {
  HEAP8[$13 + 12 >> 0] = 1; //@line 16393
  return;
 }
 while (1) {
  $54 = HEAP32[$$1113 + 8 >> 2] | 0; //@line 16398
  $57 = $$1113 + 12 | 0; //@line 16401
  $59 = (HEAP8[$57 >> 0] | 0) != 0; //@line 16403
  if ((HEAP32[$54 >> 2] | 0) == ($$1113 | 0)) {
   if ($59) {
    $$4116 = $$1113; //@line 16406
    $$6 = $$2; //@line 16406
   } else {
    HEAP8[$57 >> 0] = 1; //@line 16408
    HEAP8[$54 + 12 >> 0] = 0; //@line 16410
    $134 = HEAP32[$54 >> 2] | 0; //@line 16411
    $135 = $134 + 4 | 0; //@line 16412
    $136 = HEAP32[$135 >> 2] | 0; //@line 16413
    HEAP32[$54 >> 2] = $136; //@line 16414
    if ($136 | 0) {
     HEAP32[$136 + 8 >> 2] = $54; //@line 16418
    }
    $139 = $54 + 8 | 0; //@line 16420
    HEAP32[$134 + 8 >> 2] = HEAP32[$139 >> 2]; //@line 16423
    $142 = HEAP32[$139 >> 2] | 0; //@line 16424
    HEAP32[((HEAP32[$142 >> 2] | 0) == ($54 | 0) ? $142 : $142 + 4 | 0) >> 2] = $134; //@line 16429
    HEAP32[$135 >> 2] = $54; //@line 16430
    HEAP32[$139 >> 2] = $134; //@line 16431
    $147 = HEAP32[$$1113 + 4 >> 2] | 0; //@line 16433
    $$4116 = HEAP32[$147 >> 2] | 0; //@line 16437
    $$6 = ($$2 | 0) == ($147 | 0) ? $$1113 : $$2; //@line 16437
   }
   $150 = HEAP32[$$4116 >> 2] | 0; //@line 16439
   $151 = ($150 | 0) == 0; //@line 16440
   if (!$151) {
    if (!(HEAP8[$150 + 12 >> 0] | 0)) {
     label = 50; //@line 16446
     break;
    }
   }
   $156 = HEAP32[$$4116 + 4 >> 2] | 0; //@line 16451
   if ($156 | 0) {
    if (!(HEAP8[$156 + 12 >> 0] | 0)) {
     label = 49; //@line 16458
     break;
    }
   }
   HEAP8[$$4116 + 12 >> 0] = 0; //@line 16463
   $163 = HEAP32[$$4116 + 8 >> 2] | 0; //@line 16465
   $164 = $163 + 12 | 0; //@line 16466
   if (($163 | 0) == ($$6 | 0) | (HEAP8[$164 >> 0] | 0) == 0) {
    label = 48; //@line 16472
    break;
   } else {
    $$2$ph = $$6; //@line 16475
    $$sink193 = $163; //@line 16475
   }
  } else {
   if ($59) {
    $$2114 = $$1113; //@line 16479
    $$4 = $$2; //@line 16479
   } else {
    HEAP8[$57 >> 0] = 1; //@line 16481
    HEAP8[$54 + 12 >> 0] = 0; //@line 16483
    $61 = $54 + 4 | 0; //@line 16484
    $62 = HEAP32[$61 >> 2] | 0; //@line 16485
    $63 = HEAP32[$62 >> 2] | 0; //@line 16486
    HEAP32[$61 >> 2] = $63; //@line 16487
    if ($63 | 0) {
     HEAP32[$63 + 8 >> 2] = $54; //@line 16491
    }
    $66 = $54 + 8 | 0; //@line 16493
    HEAP32[$62 + 8 >> 2] = HEAP32[$66 >> 2]; //@line 16496
    $69 = HEAP32[$66 >> 2] | 0; //@line 16497
    HEAP32[((HEAP32[$69 >> 2] | 0) == ($54 | 0) ? $69 : $69 + 4 | 0) >> 2] = $62; //@line 16502
    HEAP32[$62 >> 2] = $54; //@line 16503
    HEAP32[$66 >> 2] = $62; //@line 16504
    $73 = HEAP32[$$1113 >> 2] | 0; //@line 16505
    $$2114 = HEAP32[$73 + 4 >> 2] | 0; //@line 16510
    $$4 = ($$2 | 0) == ($73 | 0) ? $$1113 : $$2; //@line 16510
   }
   $77 = HEAP32[$$2114 >> 2] | 0; //@line 16512
   if ($77 | 0) {
    if (!(HEAP8[$77 + 12 >> 0] | 0)) {
     label = 31; //@line 16519
     break;
    }
   }
   $83 = HEAP32[$$2114 + 4 >> 2] | 0; //@line 16524
   if ($83 | 0) {
    if (!(HEAP8[$83 + 12 >> 0] | 0)) {
     $98 = $83; //@line 16531
     label = 32; //@line 16532
     break;
    }
   }
   HEAP8[$$2114 + 12 >> 0] = 0; //@line 16537
   $90 = HEAP32[$$2114 + 8 >> 2] | 0; //@line 16539
   if (($90 | 0) == ($$4 | 0)) {
    $$lcssa154 = $$4; //@line 16542
    label = 30; //@line 16543
    break;
   }
   if (!(HEAP8[$90 + 12 >> 0] | 0)) {
    $$lcssa154 = $90; //@line 16550
    label = 30; //@line 16551
    break;
   } else {
    $$2$ph = $$4; //@line 16554
    $$sink193 = $90; //@line 16554
   }
  }
  $48 = HEAP32[$$sink193 + 8 >> 2] | 0; //@line 16558
  $$1113 = HEAP32[((HEAP32[$48 >> 2] | 0) == ($$sink193 | 0) ? $48 + 4 | 0 : $48) >> 2] | 0; //@line 16564
  $$2 = $$2$ph; //@line 16564
 }
 if ((label | 0) == 30) {
  HEAP8[$$lcssa154 + 12 >> 0] = 1; //@line 16568
  return;
 } else if ((label | 0) == 31) {
  $$pre = HEAP32[$$2114 + 4 >> 2] | 0; //@line 16573
  if (!$$pre) {
   label = 33; //@line 16576
  } else {
   $98 = $$pre; //@line 16578
   label = 32; //@line 16579
  }
 } else if ((label | 0) == 48) {
  HEAP8[$164 >> 0] = 1; //@line 16583
  return;
 } else if ((label | 0) == 49) {
  if ($151) {
   label = 51; //@line 16588
  } else {
   label = 50; //@line 16590
  }
 }
 if ((label | 0) == 32) {
  if (!(HEAP8[$98 + 12 >> 0] | 0)) {
   $$3115 = $$2114; //@line 16598
   $120 = $98; //@line 16598
   label = 36; //@line 16599
  } else {
   label = 33; //@line 16601
  }
 } else if ((label | 0) == 50) {
  if (!(HEAP8[$150 + 12 >> 0] | 0)) {
   $$5117 = $$4116; //@line 16609
   $191 = $150; //@line 16609
   label = 54; //@line 16610
  } else {
   label = 51; //@line 16612
  }
 }
 if ((label | 0) == 33) {
  HEAP8[$77 + 12 >> 0] = 1; //@line 16617
  HEAP8[$$2114 + 12 >> 0] = 0; //@line 16619
  $103 = $77 + 4 | 0; //@line 16620
  $104 = HEAP32[$103 >> 2] | 0; //@line 16621
  HEAP32[$$2114 >> 2] = $104; //@line 16622
  if ($104 | 0) {
   HEAP32[$104 + 8 >> 2] = $$2114; //@line 16626
  }
  $107 = $$2114 + 8 | 0; //@line 16628
  HEAP32[$77 + 8 >> 2] = HEAP32[$107 >> 2]; //@line 16631
  $110 = HEAP32[$107 >> 2] | 0; //@line 16632
  HEAP32[((HEAP32[$110 >> 2] | 0) == ($$2114 | 0) ? $110 : $110 + 4 | 0) >> 2] = $77; //@line 16637
  HEAP32[$103 >> 2] = $$2114; //@line 16638
  HEAP32[$107 >> 2] = $77; //@line 16639
  $$3115 = $77; //@line 16640
  $120 = $$2114; //@line 16640
  label = 36; //@line 16641
 } else if ((label | 0) == 51) {
  $171 = $$4116 + 4 | 0; //@line 16644
  $172 = HEAP32[$171 >> 2] | 0; //@line 16645
  HEAP8[$172 + 12 >> 0] = 1; //@line 16647
  HEAP8[$$4116 + 12 >> 0] = 0; //@line 16649
  $175 = HEAP32[$172 >> 2] | 0; //@line 16650
  HEAP32[$171 >> 2] = $175; //@line 16651
  if ($175 | 0) {
   HEAP32[$175 + 8 >> 2] = $$4116; //@line 16655
  }
  $178 = $$4116 + 8 | 0; //@line 16657
  HEAP32[$172 + 8 >> 2] = HEAP32[$178 >> 2]; //@line 16660
  $181 = HEAP32[$178 >> 2] | 0; //@line 16661
  HEAP32[((HEAP32[$181 >> 2] | 0) == ($$4116 | 0) ? $181 : $181 + 4 | 0) >> 2] = $172; //@line 16666
  HEAP32[$172 >> 2] = $$4116; //@line 16667
  HEAP32[$178 >> 2] = $172; //@line 16668
  $$5117 = $172; //@line 16669
  $191 = $$4116; //@line 16669
  label = 54; //@line 16670
 }
 if ((label | 0) == 36) {
  $115 = HEAP32[$$3115 + 8 >> 2] | 0; //@line 16674
  $116 = $115 + 12 | 0; //@line 16675
  HEAP8[$$3115 + 12 >> 0] = HEAP8[$116 >> 0] | 0; //@line 16678
  HEAP8[$116 >> 0] = 1; //@line 16679
  HEAP8[$120 + 12 >> 0] = 1; //@line 16681
  $121 = $115 + 4 | 0; //@line 16682
  $122 = HEAP32[$121 >> 2] | 0; //@line 16683
  $123 = HEAP32[$122 >> 2] | 0; //@line 16684
  HEAP32[$121 >> 2] = $123; //@line 16685
  if ($123 | 0) {
   HEAP32[$123 + 8 >> 2] = $115; //@line 16689
  }
  $126 = $115 + 8 | 0; //@line 16691
  HEAP32[$122 + 8 >> 2] = HEAP32[$126 >> 2]; //@line 16694
  $129 = HEAP32[$126 >> 2] | 0; //@line 16695
  HEAP32[((HEAP32[$129 >> 2] | 0) == ($115 | 0) ? $129 : $129 + 4 | 0) >> 2] = $122; //@line 16700
  HEAP32[$122 >> 2] = $115; //@line 16701
  HEAP32[$126 >> 2] = $122; //@line 16702
  return;
 } else if ((label | 0) == 54) {
  $186 = HEAP32[$$5117 + 8 >> 2] | 0; //@line 16707
  $187 = $186 + 12 | 0; //@line 16708
  HEAP8[$$5117 + 12 >> 0] = HEAP8[$187 >> 0] | 0; //@line 16711
  HEAP8[$187 >> 0] = 1; //@line 16712
  HEAP8[$191 + 12 >> 0] = 1; //@line 16714
  $192 = HEAP32[$186 >> 2] | 0; //@line 16715
  $193 = $192 + 4 | 0; //@line 16716
  $194 = HEAP32[$193 >> 2] | 0; //@line 16717
  HEAP32[$186 >> 2] = $194; //@line 16718
  if ($194 | 0) {
   HEAP32[$194 + 8 >> 2] = $186; //@line 16722
  }
  $197 = $186 + 8 | 0; //@line 16724
  HEAP32[$192 + 8 >> 2] = HEAP32[$197 >> 2]; //@line 16727
  $200 = HEAP32[$197 >> 2] | 0; //@line 16728
  HEAP32[((HEAP32[$200 >> 2] | 0) == ($186 | 0) ? $200 : $200 + 4 | 0) >> 2] = $192; //@line 16733
  HEAP32[$193 >> 2] = $186; //@line 16734
  HEAP32[$197 >> 2] = $192; //@line 16735
  return;
 }
}
function _main($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$077102116 = 0, $$078100 = 0, $$07989 = 0, $$08095 = 0, $$081$lcssa = 0, $$08190 = 0, $$1 = 0, $$lcssa114 = 0, $$pre = 0, $$pre109 = 0, $$sink = 0, $103 = 0, $107 = 0, $110 = 0, $113 = 0, $116 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $2 = 0, $21 = 0, $25 = 0, $28 = 0, $3 = 0, $33 = 0, $36 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $54 = 0, $57 = 0, $59 = 0, $60 = 0, $69 = 0, $70 = 0, $72 = 0, $74 = 0, $8 = 0, $80 = 0, $83 = 0, $89 = 0, $9 = 0, $91 = 0, $92 = 0, $96 = 0, $99 = 0, $vararg_buffer = 0, $vararg_buffer13 = 0, $vararg_buffer16 = 0, $vararg_buffer19 = 0, $vararg_buffer2 = 0, $vararg_buffer22 = 0, $vararg_buffer24 = 0, $vararg_buffer5 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 48104
 STACKTOP = STACKTOP + 96 | 0; //@line 48105
 $vararg_buffer24 = sp + 72 | 0; //@line 48106
 $vararg_buffer22 = sp + 64 | 0; //@line 48107
 $vararg_buffer19 = sp + 56 | 0; //@line 48108
 $vararg_buffer16 = sp + 48 | 0; //@line 48109
 $vararg_buffer13 = sp + 40 | 0; //@line 48110
 $vararg_buffer8 = sp + 24 | 0; //@line 48111
 $vararg_buffer5 = sp + 16 | 0; //@line 48112
 $vararg_buffer2 = sp + 8 | 0; //@line 48113
 $vararg_buffer = sp; //@line 48114
 $2 = sp + 80 | 0; //@line 48115
 $3 = sp + 76 | 0; //@line 48116
 HEAP32[$2 >> 2] = $0; //@line 48117
 HEAP32[$3 >> 2] = $1; //@line 48118
 _puts(104473) | 0; //@line 48119
 HEAP32[30894] = 0; //@line 48120
 HEAP32[30897] = 0; //@line 48121
 _srand(_time(0) | 0); //@line 48123
 _tzset(); //@line 48124
 $5 = __Z9GetStringi(0) | 0; //@line 48125
 HEAP32[$vararg_buffer >> 2] = 1; //@line 48126
 HEAP32[$vararg_buffer + 4 >> 2] = 0; //@line 48128
 _printf($5, $vararg_buffer) | 0; //@line 48129
 HEAP32[$vararg_buffer2 >> 2] = __Z9GetStringi(1) | 0; //@line 48131
 _printf(104483, $vararg_buffer2) | 0; //@line 48132
 if (($0 | 0) > 1) {
  $8 = $1 + 4 | 0; //@line 48135
  $9 = HEAP32[$8 >> 2] | 0; //@line 48136
  if (!(_strcmp($9, 104488) | 0)) {
   $$lcssa114 = $1; //@line 48140
   $13 = HEAP32[$$lcssa114 >> 2] | 0; //@line 48141
   __ZL5usagePKc($13); //@line 48142
  } else {
   $$077102116 = 1; //@line 48145
   $14 = $9; //@line 48145
   $18 = $8; //@line 48145
  }
  while (1) {
   do {
    if (!(_strcmp($14, 104495) | 0)) {
     $17 = $$077102116 + 1 | 0; //@line 48152
     HEAP32[$18 >> 2] = 0; //@line 48153
     if (($17 | 0) < ($0 | 0)) {
      $21 = (HEAP32[$3 >> 2] | 0) + ($17 << 2) | 0; //@line 48157
      HEAP32[30885] = HEAP32[$21 >> 2]; //@line 48159
      HEAP32[$21 >> 2] = 0; //@line 48160
      $$1 = $17; //@line 48161
     } else {
      $$1 = $17; //@line 48163
     }
    } else {
     if (!(_strcmp($14, 104512) | 0)) {
      $25 = $$077102116 + 1 | 0; //@line 48169
      HEAP32[$18 >> 2] = 0; //@line 48170
      if (($25 | 0) >= ($0 | 0)) {
       $$1 = $25; //@line 48173
       break;
      }
      $28 = (HEAP32[$3 >> 2] | 0) + ($25 << 2) | 0; //@line 48177
      HEAP32[28204] = _strtol(HEAP32[$28 >> 2] | 0, 0, 0) | 0; //@line 48180
      HEAP32[$28 >> 2] = 0; //@line 48181
      $$1 = $25; //@line 48182
      break;
     }
     if (!(_strcmp($14, 104520) | 0)) {
      $33 = $$077102116 + 1 | 0; //@line 48188
      HEAP32[$18 >> 2] = 0; //@line 48189
      if (($33 | 0) >= ($0 | 0)) {
       $$1 = $33; //@line 48192
       break;
      }
      $36 = (HEAP32[$3 >> 2] | 0) + ($33 << 2) | 0; //@line 48196
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(123548, HEAP32[$36 >> 2] | 0) | 0; //@line 48198
      HEAP32[$36 >> 2] = 0; //@line 48199
      $$1 = $33; //@line 48200
      break;
     } else {
      if (_strcmp($14, 104529) | 0) {
       $$1 = $$077102116; //@line 48206
       break;
      }
      HEAP32[$18 >> 2] = 0; //@line 48209
      HEAP8[651928] = 1; //@line 48210
      $$1 = $$077102116; //@line 48211
      break;
     }
    }
   } while (0);
   $$077102116 = $$1 + 1 | 0; //@line 48216
   if (($$077102116 | 0) >= ($0 | 0)) {
    break;
   }
   $$pre = HEAP32[$3 >> 2] | 0; //@line 48221
   $18 = $$pre + ($$077102116 << 2) | 0; //@line 48222
   $14 = HEAP32[$18 >> 2] | 0; //@line 48223
   if (!(_strcmp($14, 104488) | 0)) {
    $$lcssa114 = $$pre; //@line 48227
    label = 4; //@line 48228
    break;
   }
  }
  if ((label | 0) == 4) {
   $13 = HEAP32[$$lcssa114 >> 2] | 0; //@line 48235
   __ZL5usagePKc($13); //@line 48236
  }
  $$pre109 = HEAP32[$2 >> 2] | 0; //@line 48239
  if (($$pre109 | 0) > 1) {
   $$078100 = 1; //@line 48242
   $47 = $$pre109; //@line 48242
   while (1) {
    if (($$078100 | 0) < ($47 | 0)) {
     $48 = HEAP32[$3 >> 2] | 0; //@line 48246
     $$08190 = $$078100; //@line 48247
     while (1) {
      if (HEAP32[$48 + ($$08190 << 2) >> 2] | 0) {
       $$081$lcssa = $$08190; //@line 48253
       break;
      }
      $54 = $$08190 + 1 | 0; //@line 48256
      if (($54 | 0) < ($47 | 0)) {
       $$08190 = $54; //@line 48259
      } else {
       $$081$lcssa = $54; //@line 48261
       break;
      }
     }
     if (($$081$lcssa | 0) > ($$078100 | 0)) {
      $57 = $$081$lcssa - $$078100 | 0; //@line 48267
      if (($$081$lcssa | 0) < ($47 | 0)) {
       $$08095 = $$081$lcssa; //@line 48270
       do {
        $60 = HEAP32[$3 >> 2] | 0; //@line 48272
        HEAP32[$60 + ($$08095 - $57 << 2) >> 2] = HEAP32[$60 + ($$08095 << 2) >> 2]; //@line 48277
        $$08095 = $$08095 + 1 | 0; //@line 48278
       } while (($$08095 | 0) < ($47 | 0));
      }
      $59 = $47 - $57 | 0; //@line 48287
      HEAP32[$2 >> 2] = $59; //@line 48288
      $69 = $59; //@line 48289
     } else {
      $69 = $47; //@line 48291
     }
    } else {
     $69 = $47; //@line 48294
    }
    $$078100 = $$078100 + 1 | 0; //@line 48296
    if (($$078100 | 0) >= ($69 | 0)) {
     break;
    } else {
     $47 = $69; //@line 48299
    }
   }
  }
 }
 $49 = HEAP32[30885] | 0; //@line 48306
 if ($49 | 0) {
  $70 = __Z15rpc_init_clientPKc($49) | 0; //@line 48309
  HEAP32[30886] = $70; //@line 48310
  if (!$70) {
   _fwrite(104658, 54, 1, HEAP32[22038] | 0) | 0; //@line 48314
   STACKTOP = sp; //@line 48315
   return 1; //@line 48315
  }
 }
 __Z9PrefsInitPKcRiRPPc(0, $2, $3); //@line 48318
 $72 = HEAP32[$2 >> 2] | 0; //@line 48319
 L44 : do {
  if (($72 | 0) > 1) {
   $74 = HEAP32[$3 >> 2] | 0; //@line 48323
   $$07989 = 1; //@line 48324
   while (1) {
    $80 = HEAP32[$74 + ($$07989 << 2) >> 2] | 0; //@line 48327
    $$07989 = $$07989 + 1 | 0; //@line 48330
    if ((HEAP8[$80 >> 0] | 0) == 45) {
     break;
    }
    if (($$07989 | 0) >= ($72 | 0)) {
     break L44;
    }
   }
   $83 = HEAP32[22038] | 0; //@line 48341
   HEAP32[$vararg_buffer5 >> 2] = $80; //@line 48342
   _fprintf($83, 104539, $vararg_buffer5) | 0; //@line 48343
   __ZL5usagePKc(HEAP32[HEAP32[$3 >> 2] >> 2] | 0); //@line 48346
  }
 } while (0);
 if (!(HEAP32[30886] | 0)) {
  if (!(__Z13PrefsFindBoolPKc(104565) | 0)) {
   if (!(__Z11PrefsEditorv() | 0)) {
    __Z12QuitEmulatorv(); //@line 48357
   }
  }
 }
 $89 = (__Z14PrefsFindInt32PKc(104571) | 0) & -1048576; //@line 48363
 HEAP32[30895] = $89; //@line 48364
 do {
  if ($89 >>> 0 < 1048576) {
   $91 = __Z9GetStringi(2e3) | 0; //@line 48368
   $92 = HEAP32[30886] | 0; //@line 48369
   if ($92 | 0) {
    HEAP32[$vararg_buffer8 >> 2] = -2004; //@line 48372
    HEAP32[$vararg_buffer8 + 4 >> 2] = $91; //@line 48374
    HEAP32[$vararg_buffer8 + 8 >> 2] = 0; //@line 48376
    if (!(__Z17rpc_method_invokeP16rpc_connection_tiz($92, 2, $vararg_buffer8) | 0)) {
     $96 = HEAP32[30886] | 0; //@line 48380
     HEAP32[$vararg_buffer13 >> 2] = 0; //@line 48381
     if (!(__Z25rpc_method_wait_for_replyP16rpc_connection_tz($96, $vararg_buffer13) | 0)) {
      $$sink = 1048576; //@line 48385
      label = 44; //@line 48386
      break;
     }
    }
   }
   $99 = __Z9GetStringi(6) | 0; //@line 48391
   HEAP32[$vararg_buffer16 >> 2] = $91; //@line 48392
   _printf($99, $vararg_buffer16) | 0; //@line 48393
   $$sink = 1048576; //@line 48394
   label = 44; //@line 48395
  } else {
   if ($89 >>> 0 > 1072693248) {
    $$sink = 1072693248; //@line 48399
    label = 44; //@line 48400
   }
  }
 } while (0);
 if ((label | 0) == 44) {
  HEAP32[30895] = $$sink; //@line 48405
 }
 $103 = __Z10vm_acquireji((HEAP32[30895] | 0) + 1048576 | 0, 10) | 0; //@line 48409
 if (!$103) {
  __Z10ErrorAlerti(1e3); //@line 48412
  __Z12QuitEmulatorv(); //@line 48413
 }
 HEAP32[30894] = $103; //@line 48416
 HEAP32[30897] = $103 + (HEAP32[30895] | 0); //@line 48419
 $107 = __Z15PrefsFindStringPKci(104579, 0) | 0; //@line 48420
 HEAP32[$vararg_buffer19 >> 2] = $107; //@line 48421
 _printf(104583, $vararg_buffer19) | 0; //@line 48422
 $110 = _open($107 | 0 ? $107 : 104596, 0, $vararg_buffer22) | 0; //@line 48425
 if (($110 | 0) < 0) {
  __Z10ErrorAlerti(1004); //@line 48428
  __Z12QuitEmulatorv(); //@line 48429
 }
 HEAP32[$vararg_buffer24 >> 2] = __Z9GetStringi(2) | 0; //@line 48433
 _printf(104600, $vararg_buffer24) | 0; //@line 48434
 $113 = _lseek($110, 0, 2) | 0; //@line 48435
 HEAP32[30898] = $113; //@line 48436
 L72 : do {
  if (($113 | 0) < 262144) {
   if (($113 | 0) < 131072) {
    switch ($113 | 0) {
    case 65536:
     {
      break L72;
      break;
     }
    default:
     {}
    }
    __Z10ErrorAlerti(1006); //@line 48450
    _close($110) | 0; //@line 48451
    __Z12QuitEmulatorv(); //@line 48452
   } else {
    switch ($113 | 0) {
    case 131072:
     {
      break L72;
      break;
     }
    default:
     {}
    }
    __Z10ErrorAlerti(1006); //@line 48463
    _close($110) | 0; //@line 48464
    __Z12QuitEmulatorv(); //@line 48465
   }
  } else {
   if (($113 | 0) < 524288) {
    switch ($113 | 0) {
    case 262144:
     {
      break L72;
      break;
     }
    default:
     {}
    }
    __Z10ErrorAlerti(1006); //@line 48479
    _close($110) | 0; //@line 48480
    __Z12QuitEmulatorv(); //@line 48481
   }
   if (($113 | 0) < 1048576) {
    switch ($113 | 0) {
    case 524288:
     {
      break L72;
      break;
     }
    default:
     {}
    }
    __Z10ErrorAlerti(1006); //@line 48494
    _close($110) | 0; //@line 48495
    __Z12QuitEmulatorv(); //@line 48496
   } else {
    switch ($113 | 0) {
    case 1048576:
     {
      break L72;
      break;
     }
    default:
     {}
    }
    __Z10ErrorAlerti(1006); //@line 48507
    _close($110) | 0; //@line 48508
    __Z12QuitEmulatorv(); //@line 48509
   }
  }
 } while (0);
 _lseek($110, 0, 0) | 0; //@line 48514
 $116 = _read($110, HEAP32[30897] | 0, HEAP32[30898] | 0) | 0; //@line 48517
 if (($116 | 0) != (HEAP32[30898] | 0)) {
  __Z10ErrorAlerti(1005); //@line 48521
  _close($110) | 0; //@line 48522
  __Z12QuitEmulatorv(); //@line 48523
 }
 _puts(104603) | 0; //@line 48526
 if (__Z7InitAllPKc(0) | 0) {
  _puts(104625) | 0; //@line 48529
  _puts(104634) | 0; //@line 48530
  __Z10Start680x0v(); //@line 48531
  _puts(104653) | 0; //@line 48532
  __Z12QuitEmulatorv(); //@line 48533
 } else {
  __Z12QuitEmulatorv(); //@line 48536
 }
 return 0; //@line 48539
}
function __Z9LoadPrefsPKc($0) {
 $0 = $0 | 0;
 var $$0$i$i55 = 0, $$0$i$i56 = 0, $$0$i7$i = 0, $$0$i7$i28 = 0, $$0$i8$i = 0, $$0$i8$i29 = 0, $$016$i$i = 0, $$016$i$i24 = 0, $$017$i$i = 0, $$017$i$i25 = 0, $$pre$phi35Z2D = 0, $$pre$phi39Z2D = 0, $$pre$phi46Z2D = 0, $$pre$phi50Z2D = 0, $$pre34$pre$phiZZ2D = 0, $$pre38$pre$phiZZ2D = 0, $$pre45$pre$phiZZ2D = 0, $$pre49$pre$phiZZ2D = 0, $1 = 0, $10 = 0, $104 = 0, $107 = 0, $108 = 0, $11 = 0, $112 = 0, $114 = 0, $115 = 0, $119 = 0, $120 = 0, $125 = 0, $138 = 0, $144 = 0, $16 = 0, $19 = 0, $2 = 0, $20 = 0, $24 = 0, $26 = 0, $27 = 0, $3 = 0, $31 = 0, $32 = 0, $37 = 0, $4 = 0, $40 = 0, $42 = 0, $43 = 0, $47 = 0, $49 = 0, $50 = 0, $54 = 0, $55 = 0, $6 = 0, $80 = 0, $86 = 0, $92 = 0, $94 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 48733
 STACKTOP = STACKTOP + 64 | 0; //@line 48734
 $vararg_buffer = sp; //@line 48735
 $1 = sp + 40 | 0; //@line 48736
 $2 = sp + 28 | 0; //@line 48737
 $3 = sp + 16 | 0; //@line 48738
 $4 = sp + 4 | 0; //@line 48739
 if (!$0) {
  $86 = HEAP8[123559] | 0; //@line 48742
  if (!(($86 << 24 >> 24 < 0 ? HEAP32[30888] | 0 : $86 & 255) | 0)) {
   $92 = _getenv(105352) | 0; //@line 48749
   if ($92 | 0) {
    HEAP32[$2 >> 2] = 0; //@line 48752
    HEAP32[$2 + 4 >> 2] = 0; //@line 48752
    HEAP32[$2 + 8 >> 2] = 0; //@line 48752
    $94 = _strlen($92) | 0; //@line 48753
    if ($94 >>> 0 > 4294967279) {
     __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($2); //@line 48756
    }
    if ($94 >>> 0 < 11) {
     $104 = $2 + 11 | 0; //@line 48762
     HEAP8[$104 >> 0] = $94; //@line 48763
     if (!$94) {
      $$017$i$i25 = $2; //@line 48766
      $$pre$phi35Z2D = $104; //@line 48766
     } else {
      $$016$i$i24 = $2; //@line 48768
      $$pre34$pre$phiZZ2D = $104; //@line 48768
      label = 38; //@line 48769
     }
    } else {
     $98 = $94 + 16 & -16; //@line 48773
     $99 = __Znwj($98) | 0; //@line 48774
     HEAP32[$2 >> 2] = $99; //@line 48775
     HEAP32[$2 + 8 >> 2] = $98 | -2147483648; //@line 48778
     HEAP32[$2 + 4 >> 2] = $94; //@line 48780
     $$016$i$i24 = $99; //@line 48782
     $$pre34$pre$phiZZ2D = $2 + 11 | 0; //@line 48782
     label = 38; //@line 48783
    }
    if ((label | 0) == 38) {
     _memcpy($$016$i$i24 | 0, $92 | 0, $94 | 0) | 0; //@line 48786
     $$017$i$i25 = $$016$i$i24; //@line 48787
     $$pre$phi35Z2D = $$pre34$pre$phiZZ2D; //@line 48787
    }
    HEAP8[$$017$i$i25 + $94 >> 0] = 0; //@line 48790
    HEAP32[$1 >> 2] = 0; //@line 48791
    HEAP32[$1 + 4 >> 2] = 0; //@line 48791
    HEAP32[$1 + 8 >> 2] = 0; //@line 48791
    $107 = HEAP8[$$pre$phi35Z2D >> 0] | 0; //@line 48792
    $108 = $107 << 24 >> 24 < 0; //@line 48793
    $112 = $108 ? HEAP32[$2 + 4 >> 2] | 0 : $107 & 255; //@line 48797
    $114 = $108 ? HEAP32[$2 >> 2] | 0 : $2; //@line 48799
    $115 = $112 + 1 | 0; //@line 48800
    if ($115 >>> 0 > 4294967279) {
     __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($1); //@line 48803
    }
    if ($115 >>> 0 < 11) {
     $125 = $1 + 11 | 0; //@line 48809
     HEAP8[$125 >> 0] = $112; //@line 48810
     if (!$112) {
      $$0$i8$i29 = $1; //@line 48813
      $$pre$phi39Z2D = $125; //@line 48813
     } else {
      $$0$i7$i28 = $1; //@line 48815
      $$pre38$pre$phiZZ2D = $125; //@line 48815
      label = 44; //@line 48816
     }
    } else {
     $119 = $112 + 17 & -16; //@line 48820
     $120 = __Znwj($119) | 0; //@line 48821
     HEAP32[$1 >> 2] = $120; //@line 48822
     HEAP32[$1 + 8 >> 2] = $119 | -2147483648; //@line 48825
     HEAP32[$1 + 4 >> 2] = $112; //@line 48827
     $$0$i7$i28 = $120; //@line 48829
     $$pre38$pre$phiZZ2D = $1 + 11 | 0; //@line 48829
     label = 44; //@line 48830
    }
    if ((label | 0) == 44) {
     _memcpy($$0$i7$i28 | 0, $114 | 0, $112 | 0) | 0; //@line 48833
     $$0$i8$i29 = $$0$i7$i28; //@line 48834
     $$pre$phi39Z2D = $$pre38$pre$phiZZ2D; //@line 48834
    }
    HEAP8[$$0$i8$i29 + $112 >> 0] = 0; //@line 48837
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc($1, 47); //@line 48838
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(123560, $1) | 0; //@line 48839
    if ((HEAP8[$$pre$phi39Z2D >> 0] | 0) < 0) {
     __ZdlPv(HEAP32[$1 >> 2] | 0); //@line 48844
    }
    if ((HEAP8[$$pre$phi35Z2D >> 0] | 0) < 0) {
     __ZdlPv(HEAP32[$2 >> 2] | 0); //@line 48850
    }
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(123560, 105357) | 0; //@line 48853
  } else {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(123560, 123548) | 0; //@line 48855
  }
  $138 = _fopen((HEAP8[123571] | 0) < 0 ? HEAP32[30890] | 0 : 123560, 105328) | 0; //@line 48861
  if ($138 | 0) {
   __Z19LoadPrefsFromStreamP8_IO_FILE($138); //@line 48864
   _fclose($138) | 0; //@line 48865
   STACKTOP = sp; //@line 48866
   return;
  }
  $144 = _fopen((HEAP8[123571] | 0) < 0 ? HEAP32[30890] | 0 : 123560, 105376) | 0; //@line 48872
  if (!$144) {
   STACKTOP = sp; //@line 48875
   return;
  }
  __Z17SavePrefsToStreamP8_IO_FILE($144); //@line 48877
  _fclose($144) | 0; //@line 48878
  STACKTOP = sp; //@line 48879
  return;
 }
 HEAP32[$3 >> 2] = 0; //@line 48881
 HEAP32[$3 + 4 >> 2] = 0; //@line 48881
 HEAP32[$3 + 8 >> 2] = 0; //@line 48881
 $6 = _strlen($0) | 0; //@line 48882
 if ($6 >>> 0 > 4294967279) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($3); //@line 48885
 }
 if ($6 >>> 0 < 11) {
  $16 = $3 + 11 | 0; //@line 48891
  HEAP8[$16 >> 0] = $6; //@line 48892
  if (!$6) {
   $$017$i$i = $3; //@line 48895
   $$pre$phi46Z2D = $16; //@line 48895
  } else {
   $$016$i$i = $3; //@line 48897
   $$pre45$pre$phiZZ2D = $16; //@line 48897
   label = 7; //@line 48898
  }
 } else {
  $10 = $6 + 16 & -16; //@line 48902
  $11 = __Znwj($10) | 0; //@line 48903
  HEAP32[$3 >> 2] = $11; //@line 48904
  HEAP32[$3 + 8 >> 2] = $10 | -2147483648; //@line 48907
  HEAP32[$3 + 4 >> 2] = $6; //@line 48909
  $$016$i$i = $11; //@line 48911
  $$pre45$pre$phiZZ2D = $3 + 11 | 0; //@line 48911
  label = 7; //@line 48912
 }
 if ((label | 0) == 7) {
  _memcpy($$016$i$i | 0, $0 | 0, $6 | 0) | 0; //@line 48915
  $$017$i$i = $$016$i$i; //@line 48916
  $$pre$phi46Z2D = $$pre45$pre$phiZZ2D; //@line 48916
 }
 HEAP8[$$017$i$i + $6 >> 0] = 0; //@line 48919
 HEAP32[$2 >> 2] = 0; //@line 48920
 HEAP32[$2 + 4 >> 2] = 0; //@line 48920
 HEAP32[$2 + 8 >> 2] = 0; //@line 48920
 $19 = HEAP8[$$pre$phi46Z2D >> 0] | 0; //@line 48921
 $20 = $19 << 24 >> 24 < 0; //@line 48922
 $24 = $20 ? HEAP32[$3 + 4 >> 2] | 0 : $19 & 255; //@line 48926
 $26 = $20 ? HEAP32[$3 >> 2] | 0 : $3; //@line 48928
 $27 = $24 + 1 | 0; //@line 48929
 if ($27 >>> 0 > 4294967279) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($2); //@line 48932
 }
 if ($27 >>> 0 < 11) {
  $37 = $2 + 11 | 0; //@line 48938
  HEAP8[$37 >> 0] = $24; //@line 48939
  if (!$24) {
   $$0$i8$i = $2; //@line 48942
   $$pre$phi50Z2D = $37; //@line 48942
  } else {
   $$0$i7$i = $2; //@line 48944
   $$pre49$pre$phiZZ2D = $37; //@line 48944
   label = 13; //@line 48945
  }
 } else {
  $31 = $24 + 17 & -16; //@line 48949
  $32 = __Znwj($31) | 0; //@line 48950
  HEAP32[$2 >> 2] = $32; //@line 48951
  HEAP32[$2 + 8 >> 2] = $31 | -2147483648; //@line 48954
  HEAP32[$2 + 4 >> 2] = $24; //@line 48956
  $$0$i7$i = $32; //@line 48958
  $$pre49$pre$phiZZ2D = $2 + 11 | 0; //@line 48958
  label = 13; //@line 48959
 }
 if ((label | 0) == 13) {
  _memcpy($$0$i7$i | 0, $26 | 0, $24 | 0) | 0; //@line 48962
  $$0$i8$i = $$0$i7$i; //@line 48963
  $$pre$phi50Z2D = $$pre49$pre$phiZZ2D; //@line 48963
 }
 HEAP8[$$0$i8$i + $24 >> 0] = 0; //@line 48966
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc($2, 47); //@line 48967
 HEAP32[$4 >> 2] = 0; //@line 48968
 HEAP32[$4 + 4 >> 2] = 0; //@line 48968
 HEAP32[$4 + 8 >> 2] = 0; //@line 48968
 $40 = $4 + 11 | 0; //@line 48969
 HEAP8[$40 >> 0] = 5; //@line 48970
 HEAP8[$4 >> 0] = HEAP8[105322] | 0; //@line 48971
 HEAP8[$4 + 1 >> 0] = HEAP8[105323] | 0; //@line 48971
 HEAP8[$4 + 2 >> 0] = HEAP8[105324] | 0; //@line 48971
 HEAP8[$4 + 3 >> 0] = HEAP8[105325] | 0; //@line 48971
 HEAP8[$4 + 4 >> 0] = HEAP8[105326] | 0; //@line 48971
 HEAP8[$4 + 5 >> 0] = 0; //@line 48973
 HEAP32[$1 >> 2] = 0; //@line 48974
 HEAP32[$1 + 4 >> 2] = 0; //@line 48974
 HEAP32[$1 + 8 >> 2] = 0; //@line 48974
 $42 = HEAP8[$$pre$phi50Z2D >> 0] | 0; //@line 48975
 $43 = $42 << 24 >> 24 < 0; //@line 48976
 $47 = $43 ? HEAP32[$2 + 4 >> 2] | 0 : $42 & 255; //@line 48980
 $49 = $43 ? HEAP32[$2 >> 2] | 0 : $2; //@line 48982
 $50 = $47 + 5 | 0; //@line 48983
 if ($50 >>> 0 > 4294967279) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($1); //@line 48986
 }
 if ($50 >>> 0 < 11) {
  HEAP8[$1 + 11 >> 0] = $47; //@line 48993
  if (!$47) {
   $$0$i$i56 = $1; //@line 48996
  } else {
   $$0$i$i55 = $1; //@line 48998
   label = 19; //@line 48999
  }
 } else {
  $54 = $47 + 21 & -16; //@line 49003
  $55 = __Znwj($54) | 0; //@line 49004
  HEAP32[$1 >> 2] = $55; //@line 49005
  HEAP32[$1 + 8 >> 2] = $54 | -2147483648; //@line 49008
  HEAP32[$1 + 4 >> 2] = $47; //@line 49010
  $$0$i$i55 = $55; //@line 49011
  label = 19; //@line 49012
 }
 if ((label | 0) == 19) {
  _memcpy($$0$i$i55 | 0, $49 | 0, $47 | 0) | 0; //@line 49015
  $$0$i$i56 = $$0$i$i55; //@line 49016
 }
 HEAP8[$$0$i$i56 + $47 >> 0] = 0; //@line 49019
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($1, $4, 5) | 0; //@line 49020
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(123560, $1) | 0; //@line 49021
 if ((HEAP8[$1 + 11 >> 0] | 0) < 0) {
  __ZdlPv(HEAP32[$1 >> 2] | 0); //@line 49027
 }
 if ((HEAP8[$40 >> 0] | 0) < 0) {
  __ZdlPv(HEAP32[$4 >> 2] | 0); //@line 49033
 }
 if ((HEAP8[$$pre$phi50Z2D >> 0] | 0) < 0) {
  __ZdlPv(HEAP32[$2 >> 2] | 0); //@line 49039
 }
 if ((HEAP8[$$pre$phi46Z2D >> 0] | 0) < 0) {
  __ZdlPv(HEAP32[$3 >> 2] | 0); //@line 49045
 }
 $80 = _fopen((HEAP8[123571] | 0) < 0 ? HEAP32[30890] | 0 : 123560, 105328) | 0; //@line 49051
 if (!$80) {
  HEAP32[$vararg_buffer >> 2] = (HEAP8[123571] | 0) < 0 ? HEAP32[30890] | 0 : 123560; //@line 49058
  _printf(105330, $vararg_buffer) | 0; //@line 49059
  _exit(1); //@line 49060
 }
 __Z19LoadPrefsFromStreamP8_IO_FILE($80); //@line 49063
 _fclose($80) | 0; //@line 49064
 STACKTOP = sp; //@line 49065
 return;
}
function __Z19m68k_do_specialtiesv() {
 var $$0 = 0, $$0$i$i = 0, $$0$i15$i = 0, $0 = 0, $11 = 0, $14 = 0, $143 = 0, $150 = 0, $173 = 0, $177 = 0, $184 = 0, $186 = 0, $189 = 0, $191 = 0, $20 = 0, $22 = 0, $24 = 0, $34 = 0, $36 = 0, $40 = 0, $44 = 0, $5 = 0, $8 = 0, $91 = 0, $98 = 0, dest = 0, label = 0, src = 0, stop = 0;
 $0 = HEAP32[162771] | 0; //@line 52234
 if (!($0 & 16)) {
  $5 = $0; //@line 52238
 } else {
  __Z9Exceptionij(9, HEAP32[162821] | 0); //@line 52241
  $5 = HEAP32[162771] | 0; //@line 52243
 }
 L4 : do {
  if (!($5 & 1)) {
   $24 = $5; //@line 52249
  } else {
   $8 = $5; //@line 52251
   L5 : while (1) {
    do {
     if (!($8 & 34)) {
      $11 = $8; //@line 52257
     } else {
      HEAP32[162771] = $8 & -35; //@line 52260
      $14 = __Z6intlevv() | 0; //@line 52261
      if (!(($14 | 0) != -1 & ($14 | 0) > (HEAP32[162772] | 0))) {
       $11 = HEAP32[162771] | 0; //@line 52268
       break;
      }
      if ($14 >>> 0 >= 8) {
       break L5;
      }
      dest = 651124; //@line 52275
      src = 651008; //@line 52275
      stop = dest + 116 | 0; //@line 52275
      do {
       HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 52275
       dest = dest + 4 | 0; //@line 52275
       src = src + 4 | 0; //@line 52275
      } while ((dest | 0) < (stop | 0));
      HEAP32[162810] = $14; //@line 52276
      __Z9Exceptionij($14 + 24 | 0, 0); //@line 52278
      HEAP32[162772] = $14; //@line 52279
      $20 = HEAP32[162771] | 0; //@line 52280
      HEAP8[651123] = 0; //@line 52281
      $22 = $20 & -4 | 2; //@line 52283
      HEAP32[162771] = $22; //@line 52284
      $11 = $22; //@line 52285
     }
    } while (0);
    if (!($11 & 1)) {
     $24 = $11; //@line 52291
     break L4;
    } else {
     $8 = $11; //@line 52294
    }
   }
   ___assert_fail(105505, 105523, 817, 105547); //@line 52297
  }
 } while (0);
 L16 : do {
  if ($24 & 8 | 0) {
   if (!((HEAP8[651119] | 0) != 0 & (HEAP32[30880] | 0) > 1)) {
    if (!(HEAP8[651118] | 0)) {
     break;
    }
    HEAP32[162821] = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0); //@line 52321
    HEAP32[162771] = $24 & -25 | 16; //@line 52324
    break;
   }
   $34 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 52331
   $36 = 123608 + ($34 >>> 16 << 2) | 0; //@line 52333
   $40 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$36 >> 2] | 0) + 24 >> 2] & 127]($34) | 0; //@line 52337
   HEAP32[162770] = $40; //@line 52338
   HEAP32[162769] = $40; //@line 52339
   HEAP32[162768] = $34; //@line 52340
   $44 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$36 >> 2] | 0) + 4 >> 2] & 127]($34) | 0; //@line 52344
   L22 : do {
    switch (($44 & 65535) << 16 >> 16) {
    case 20086:
    case 20087:
    case 20085:
    case 20084:
    case 20082:
     {
      break;
     }
    default:
     {
      switch (($44 & 65472) << 16 >> 16) {
      case 20160:
      case 20096:
       {
        break L22;
        break;
       }
      default:
       {}
      }
      if (($44 & 65280 | 0) != 24832) {
       L26 : do {
        if (($44 & 61440 | 0) == 24576) {
         do {
          switch ($44 >>> 8 & 15) {
          case 0:
           {
            break L22;
            break;
           }
          case 15:
           {
            if (!(HEAP32[96442] | 0)) {
             $98 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0); //@line 52385
            } else {
             $98 = 1; //@line 52387
            }
            $$0$i15$i = $98 & 1; //@line 52390
            break;
           }
          case 2:
           {
            $$0$i15$i = (HEAP32[96442] | HEAP32[96441] | 0) == 0 & 1; //@line 52399
            break;
           }
          case 3:
           {
            $$0$i15$i = (HEAP32[96442] | HEAP32[96441] | 0) != 0 & 1; //@line 52408
            break;
           }
          case 4:
           {
            $$0$i15$i = (HEAP32[96441] | 0) == 0 & 1; //@line 52415
            break;
           }
          case 5:
           {
            $$0$i15$i = HEAP32[96441] | 0; //@line 52420
            break;
           }
          case 6:
           {
            $$0$i15$i = (HEAP32[96442] | 0) == 0 & 1; //@line 52427
            break;
           }
          case 7:
           {
            $$0$i15$i = HEAP32[96442] | 0; //@line 52432
            break;
           }
          case 8:
           {
            $$0$i15$i = (HEAP32[96444] | 0) == 0 & 1; //@line 52439
            break;
           }
          case 9:
           {
            $$0$i15$i = HEAP32[96444] | 0; //@line 52444
            break;
           }
          case 10:
           {
            $$0$i15$i = (HEAP32[96443] | 0) == 0 & 1; //@line 52451
            break;
           }
          case 11:
           {
            $$0$i15$i = HEAP32[96443] | 0; //@line 52456
            break;
           }
          case 12:
           {
            $$0$i15$i = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) & 1; //@line 52464
            break;
           }
          case 13:
           {
            $$0$i15$i = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) & 1; //@line 52472
            break;
           }
          case 14:
           {
            if (!(HEAP32[96442] | 0)) {
             $91 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0); //@line 52482
            } else {
             $91 = 0; //@line 52484
            }
            $$0$i15$i = $91 & 1; //@line 52487
            break;
           }
          default:
           {
            break L26;
           }
          }
         } while (0);
         if ($$0$i15$i | 0) {
          break L22;
         }
        }
       } while (0);
       if (($44 & 61680 | 0) != 20560) {
        break L16;
       }
       do {
        switch ($44 >>> 8 & 15) {
        case 0:
         {
          break L16;
          break;
         }
        case 15:
         {
          if (!(HEAP32[96442] | 0)) {
           $150 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0); //@line 52522
          } else {
           $150 = 1; //@line 52524
          }
          $$0$i$i = $150 & 1; //@line 52527
          label = 57; //@line 52528
          break;
         }
        case 2:
         {
          $$0$i$i = (HEAP32[96442] | HEAP32[96441] | 0) == 0 & 1; //@line 52537
          label = 57; //@line 52538
          break;
         }
        case 3:
         {
          $$0$i$i = (HEAP32[96442] | HEAP32[96441] | 0) != 0 & 1; //@line 52547
          label = 57; //@line 52548
          break;
         }
        case 4:
         {
          $$0$i$i = (HEAP32[96441] | 0) == 0 & 1; //@line 52555
          label = 57; //@line 52556
          break;
         }
        case 5:
         {
          $$0$i$i = HEAP32[96441] | 0; //@line 52561
          label = 57; //@line 52562
          break;
         }
        case 6:
         {
          $$0$i$i = (HEAP32[96442] | 0) == 0 & 1; //@line 52569
          label = 57; //@line 52570
          break;
         }
        case 7:
         {
          $$0$i$i = HEAP32[96442] | 0; //@line 52575
          label = 57; //@line 52576
          break;
         }
        case 8:
         {
          $$0$i$i = (HEAP32[96444] | 0) == 0 & 1; //@line 52583
          label = 57; //@line 52584
          break;
         }
        case 9:
         {
          $$0$i$i = HEAP32[96444] | 0; //@line 52589
          label = 57; //@line 52590
          break;
         }
        case 10:
         {
          $$0$i$i = (HEAP32[96443] | 0) == 0 & 1; //@line 52597
          label = 57; //@line 52598
          break;
         }
        case 11:
         {
          $$0$i$i = HEAP32[96443] | 0; //@line 52603
          label = 57; //@line 52604
          break;
         }
        case 12:
         {
          $$0$i$i = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) & 1; //@line 52612
          label = 57; //@line 52613
          break;
         }
        case 13:
         {
          $$0$i$i = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) & 1; //@line 52621
          label = 57; //@line 52622
          break;
         }
        case 14:
         {
          if (!(HEAP32[96442] | 0)) {
           $143 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0); //@line 52632
          } else {
           $143 = 0; //@line 52634
          }
          $$0$i$i = $143 & 1; //@line 52637
          label = 57; //@line 52638
          break;
         }
        default:
         {}
        }
       } while (0);
       if ((label | 0) == 57) {
        if ($$0$i$i | 0) {
         break L16;
        }
       }
       if (!(HEAP32[651008 + (($44 & 7) << 2) >> 2] & 65535)) {
        break L16;
       }
      }
     }
    }
   } while (0);
   HEAP32[162821] = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0); //@line 52668
   HEAP32[162771] = HEAP32[162771] & -25 | 16; //@line 52672
  }
 } while (0);
 $173 = HEAP32[162771] | 0; //@line 52675
 do {
  if (!($173 & 32)) {
   $186 = $173; //@line 52680
  } else {
   HEAP32[162771] = $173 & -33; //@line 52683
   $177 = __Z6intlevv() | 0; //@line 52684
   if (!(($177 | 0) != -1 & ($177 | 0) > (HEAP32[162772] | 0))) {
    $186 = HEAP32[162771] | 0; //@line 52691
    break;
   }
   if ($177 >>> 0 < 8) {
    dest = 651124; //@line 52696
    src = 651008; //@line 52696
    stop = dest + 116 | 0; //@line 52696
    do {
     HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 52696
     dest = dest + 4 | 0; //@line 52696
     src = src + 4 | 0; //@line 52696
    } while ((dest | 0) < (stop | 0));
    HEAP32[162810] = $177; //@line 52697
    __Z9Exceptionij($177 + 24 | 0, 0); //@line 52699
    HEAP32[162772] = $177; //@line 52700
    $184 = HEAP32[162771] | 2; //@line 52702
    HEAP32[162771] = $184; //@line 52703
    HEAP8[651123] = 0; //@line 52704
    $186 = $184; //@line 52705
    break;
   } else {
    ___assert_fail(105505, 105523, 817, 105547); //@line 52708
   }
  }
 } while (0);
 if (!($186 & 2)) {
  $191 = $186; //@line 52716
 } else {
  $189 = $186 & -35 | 32; //@line 52719
  HEAP32[162771] = $189; //@line 52720
  $191 = $189; //@line 52721
 }
 if (!($191 & 4)) {
  $$0 = 0; //@line 52726
  return $$0 | 0; //@line 52727
 }
 HEAP32[162771] = $191 & -5; //@line 52730
 $$0 = 1; //@line 52731
 return $$0 | 0; //@line 52732
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 $rem = $rem | 0;
 var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $_0$0 = 0, $_0$1 = 0, $q_sroa_1_1198$looptemp = 0;
 $n_sroa_0_0_extract_trunc = $a$0; //@line 4171
 $n_sroa_1_4_extract_shift$0 = $a$1; //@line 4172
 $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0; //@line 4173
 $d_sroa_0_0_extract_trunc = $b$0; //@line 4174
 $d_sroa_1_4_extract_shift$0 = $b$1; //@line 4175
 $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0; //@line 4176
 if (!$n_sroa_1_4_extract_trunc) {
  $4 = ($rem | 0) != 0; //@line 4178
  if (!$d_sroa_1_4_extract_trunc) {
   if ($4) {
    HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0); //@line 4181
    HEAP32[$rem + 4 >> 2] = 0; //@line 4182
   }
   $_0$1 = 0; //@line 4184
   $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0; //@line 4185
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4186
  } else {
   if (!$4) {
    $_0$1 = 0; //@line 4189
    $_0$0 = 0; //@line 4190
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4191
   }
   HEAP32[$rem >> 2] = $a$0 | 0; //@line 4193
   HEAP32[$rem + 4 >> 2] = $a$1 & 0; //@line 4194
   $_0$1 = 0; //@line 4195
   $_0$0 = 0; //@line 4196
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4197
  }
 }
 $17 = ($d_sroa_1_4_extract_trunc | 0) == 0; //@line 4200
 do {
  if (!$d_sroa_0_0_extract_trunc) {
   if ($17) {
    if ($rem | 0) {
     HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0); //@line 4205
     HEAP32[$rem + 4 >> 2] = 0; //@line 4206
    }
    $_0$1 = 0; //@line 4208
    $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0; //@line 4209
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4210
   }
   if (!$n_sroa_0_0_extract_trunc) {
    if ($rem | 0) {
     HEAP32[$rem >> 2] = 0; //@line 4214
     HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0); //@line 4215
    }
    $_0$1 = 0; //@line 4217
    $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0; //@line 4218
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4219
   }
   $37 = $d_sroa_1_4_extract_trunc - 1 | 0; //@line 4221
   if (!($37 & $d_sroa_1_4_extract_trunc)) {
    if ($rem | 0) {
     HEAP32[$rem >> 2] = $a$0 | 0; //@line 4224
     HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0; //@line 4225
    }
    $_0$1 = 0; //@line 4227
    $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0); //@line 4228
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4229
   }
   $51 = (Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0) - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 4232
   if ($51 >>> 0 <= 30) {
    $57 = $51 + 1 | 0; //@line 4234
    $58 = 31 - $51 | 0; //@line 4235
    $sr_1_ph = $57; //@line 4236
    $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0); //@line 4237
    $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0); //@line 4238
    $q_sroa_0_1_ph = 0; //@line 4239
    $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58; //@line 4240
    break;
   }
   if (!$rem) {
    $_0$1 = 0; //@line 4244
    $_0$0 = 0; //@line 4245
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4246
   }
   HEAP32[$rem >> 2] = $a$0 | 0; //@line 4248
   HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 4249
   $_0$1 = 0; //@line 4250
   $_0$0 = 0; //@line 4251
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4252
  } else {
   if (!$17) {
    $119 = (Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0) - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 4256
    if ($119 >>> 0 <= 31) {
     $125 = $119 + 1 | 0; //@line 4258
     $126 = 31 - $119 | 0; //@line 4259
     $130 = $119 - 31 >> 31; //@line 4260
     $sr_1_ph = $125; //@line 4261
     $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126; //@line 4262
     $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130; //@line 4263
     $q_sroa_0_1_ph = 0; //@line 4264
     $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126; //@line 4265
     break;
    }
    if (!$rem) {
     $_0$1 = 0; //@line 4269
     $_0$0 = 0; //@line 4270
     return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4271
    }
    HEAP32[$rem >> 2] = $a$0 | 0; //@line 4273
    HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 4274
    $_0$1 = 0; //@line 4275
    $_0$0 = 0; //@line 4276
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4277
   }
   $66 = $d_sroa_0_0_extract_trunc - 1 | 0; //@line 4279
   if ($66 & $d_sroa_0_0_extract_trunc | 0) {
    $88 = (Math_clz32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 4282
    $89 = 64 - $88 | 0; //@line 4283
    $91 = 32 - $88 | 0; //@line 4284
    $92 = $91 >> 31; //@line 4285
    $95 = $88 - 32 | 0; //@line 4286
    $105 = $95 >> 31; //@line 4287
    $sr_1_ph = $88; //@line 4288
    $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105; //@line 4289
    $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0); //@line 4290
    $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92; //@line 4291
    $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31; //@line 4292
    break;
   }
   if ($rem | 0) {
    HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc; //@line 4296
    HEAP32[$rem + 4 >> 2] = 0; //@line 4297
   }
   if (($d_sroa_0_0_extract_trunc | 0) == 1) {
    $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 4300
    $_0$0 = $a$0 | 0 | 0; //@line 4301
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4302
   } else {
    $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0; //@line 4304
    $_0$1 = $n_sroa_1_4_extract_trunc >>> ($78 >>> 0) | 0; //@line 4305
    $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0; //@line 4306
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4307
   }
  }
 } while (0);
 if (!$sr_1_ph) {
  $q_sroa_1_1_lcssa = $q_sroa_1_1_ph; //@line 4312
  $q_sroa_0_1_lcssa = $q_sroa_0_1_ph; //@line 4313
  $r_sroa_1_1_lcssa = $r_sroa_1_1_ph; //@line 4314
  $r_sroa_0_1_lcssa = $r_sroa_0_1_ph; //@line 4315
  $carry_0_lcssa$1 = 0; //@line 4316
  $carry_0_lcssa$0 = 0; //@line 4317
 } else {
  $d_sroa_0_0_insert_insert99$0 = $b$0 | 0 | 0; //@line 4319
  $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0; //@line 4320
  $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0 | 0, $d_sroa_0_0_insert_insert99$1 | 0, -1, -1) | 0; //@line 4321
  $137$1 = tempRet0; //@line 4322
  $q_sroa_1_1198 = $q_sroa_1_1_ph; //@line 4323
  $q_sroa_0_1199 = $q_sroa_0_1_ph; //@line 4324
  $r_sroa_1_1200 = $r_sroa_1_1_ph; //@line 4325
  $r_sroa_0_1201 = $r_sroa_0_1_ph; //@line 4326
  $sr_1202 = $sr_1_ph; //@line 4327
  $carry_0203 = 0; //@line 4328
  do {
   $q_sroa_1_1198$looptemp = $q_sroa_1_1198;
   $q_sroa_1_1198 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1; //@line 4330
   $q_sroa_0_1199 = $carry_0203 | $q_sroa_0_1199 << 1; //@line 4331
   $r_sroa_0_0_insert_insert42$0 = $r_sroa_0_1201 << 1 | $q_sroa_1_1198$looptemp >>> 31 | 0; //@line 4332
   $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0; //@line 4333
   _i64Subtract($137$0 | 0, $137$1 | 0, $r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0) | 0; //@line 4334
   $150$1 = tempRet0; //@line 4335
   $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1; //@line 4336
   $carry_0203 = $151$0 & 1; //@line 4337
   $r_sroa_0_1201 = _i64Subtract($r_sroa_0_0_insert_insert42$0 | 0, $r_sroa_0_0_insert_insert42$1 | 0, $151$0 & $d_sroa_0_0_insert_insert99$0 | 0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1 | 0) | 0; //@line 4339
   $r_sroa_1_1200 = tempRet0; //@line 4340
   $sr_1202 = $sr_1202 - 1 | 0; //@line 4341
  } while (($sr_1202 | 0) != 0);
  $q_sroa_1_1_lcssa = $q_sroa_1_1198; //@line 4353
  $q_sroa_0_1_lcssa = $q_sroa_0_1199; //@line 4354
  $r_sroa_1_1_lcssa = $r_sroa_1_1200; //@line 4355
  $r_sroa_0_1_lcssa = $r_sroa_0_1201; //@line 4356
  $carry_0_lcssa$1 = 0; //@line 4357
  $carry_0_lcssa$0 = $carry_0203; //@line 4358
 }
 $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa; //@line 4360
 $q_sroa_0_0_insert_ext75$1 = 0; //@line 4361
 if ($rem | 0) {
  HEAP32[$rem >> 2] = $r_sroa_0_1_lcssa; //@line 4364
  HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa; //@line 4365
 }
 $_0$1 = ($q_sroa_0_0_insert_ext75$0 | 0) >>> 31 | ($q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1) << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1; //@line 4367
 $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0; //@line 4368
 return (tempRet0 = $_0$1, $_0$0) | 0; //@line 4369
}
function __Z9Exceptionij($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $102 = 0, $109 = 0, $116 = 0, $123 = 0, $130 = 0, $137 = 0, $14 = 0, $145 = 0, $152 = 0, $164 = 0, $165 = 0, $172 = 0, $179 = 0, $18 = 0, $191 = 0, $199 = 0, $207 = 0, $216 = 0, $224 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $42 = 0, $48 = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $60 = 0, $67 = 0, $74 = 0, $81 = 0, $88 = 0, $95 = 0;
 $6 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 50496
 $14 = HEAP8[651120] | 0; //@line 50504
 $18 = HEAP8[651121] | 0; //@line 50508
 HEAP16[325558] = HEAP8[651119] << 14 | HEAP8[651118] << 15 | $14 << 24 >> 24 << 13 | $18 << 24 >> 24 << 12 | HEAP32[162772] << 8 | HEAP32[96445] << 4 | HEAP32[96443] << 3 | HEAP32[96442] << 2 | HEAP32[96444] << 1 | HEAP32[96441]; //@line 50530
 if (!($14 << 24 >> 24)) {
  HEAP32[162776] = HEAP32[162767]; //@line 50534
  $42 = HEAP32[30880] | 0; //@line 50535
  HEAP32[162767] = ($42 | 0) > 1 & $18 << 24 >> 24 != 0 ? HEAP32[162778] | 0 : HEAP32[162777] | 0; //@line 50542
  HEAP8[651120] = 1; //@line 50543
  $48 = $42; //@line 50544
 } else {
  $48 = HEAP32[30880] | 0; //@line 50547
 }
 $49 = ($0 | 0) == 3; //@line 50550
 $51 = ($0 | 1 | 0) == 3; //@line 50552
 L5 : do {
  if (($48 | 0) > 0) {
   $52 = HEAP32[162767] | 0; //@line 50555
   if ($51) {
    $53 = $52 + -2 | 0; //@line 50557
    HEAP32[162767] = $53; //@line 50558
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($53, 0); //@line 50564
    $60 = (HEAP32[162767] | 0) + -2 | 0; //@line 50566
    HEAP32[162767] = $60; //@line 50567
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($60 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($60, 0); //@line 50573
    $67 = (HEAP32[162767] | 0) + -2 | 0; //@line 50575
    HEAP32[162767] = $67; //@line 50576
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($67 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($67, 0); //@line 50582
    $74 = (HEAP32[162767] | 0) + -2 | 0; //@line 50584
    HEAP32[162767] = $74; //@line 50585
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($74, 0); //@line 50591
    $81 = (HEAP32[162767] | 0) + -2 | 0; //@line 50593
    HEAP32[162767] = $81; //@line 50594
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($81 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($81, 0); //@line 50600
    $88 = (HEAP32[162767] | 0) + -2 | 0; //@line 50602
    HEAP32[162767] = $88; //@line 50603
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($88 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($88, 0); //@line 50609
    $95 = (HEAP32[162767] | 0) + -2 | 0; //@line 50611
    HEAP32[162767] = $95; //@line 50612
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($95 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($95, 0); //@line 50618
    $102 = (HEAP32[162767] | 0) + -2 | 0; //@line 50620
    HEAP32[162767] = $102; //@line 50621
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($102 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($102, 0); //@line 50627
    $109 = (HEAP32[162767] | 0) + -2 | 0; //@line 50629
    HEAP32[162767] = $109; //@line 50630
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($109 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($109, 0); //@line 50636
    $116 = (HEAP32[162767] | 0) + -2 | 0; //@line 50638
    HEAP32[162767] = $116; //@line 50639
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($116 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($116, 0); //@line 50645
    $123 = (HEAP32[162767] | 0) + -2 | 0; //@line 50647
    HEAP32[162767] = $123; //@line 50648
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($123 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($123, 0); //@line 50654
    $130 = (HEAP32[162767] | 0) + -2 | 0; //@line 50656
    HEAP32[162767] = $130; //@line 50657
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($130 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($130, 0); //@line 50663
    $137 = (HEAP32[162767] | 0) + -2 | 0; //@line 50665
    HEAP32[162767] = $137; //@line 50666
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($137 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($137, ($0 << 2) + 40960 | 0); //@line 50674
    break;
   }
   switch ($0 | 0) {
   case 5:
   case 6:
   case 7:
   case 9:
    {
     $145 = $52 + -4 | 0; //@line 50679
     HEAP32[162767] = $145; //@line 50680
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($145 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($145, $1); //@line 50686
     $152 = (HEAP32[162767] | 0) + -2 | 0; //@line 50688
     HEAP32[162767] = $152; //@line 50689
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($152 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($152, ($0 << 2) + 8192 | 0); //@line 50697
     break L5;
     break;
    }
   default:
    {}
   }
   $164 = $52 + -2 | 0; //@line 50708
   HEAP32[162767] = $164; //@line 50709
   $165 = $0 << 2; //@line 50710
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($164 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($164, $165); //@line 50716
   if (($0 & -8 | 0) == 24 & $18 << 24 >> 24 != 0) {
    $172 = (HEAP32[162767] | 0) + -4 | 0; //@line 50719
    HEAP32[162767] = $172; //@line 50720
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($172 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($172, $6); //@line 50726
    $179 = (HEAP32[162767] | 0) + -2 | 0; //@line 50728
    HEAP32[162767] = $179; //@line 50729
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($179 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($179, HEAPU16[325558] | 0); //@line 50737
    HEAP16[325558] = HEAP16[325558] | 8192; //@line 50740
    HEAP32[162778] = HEAP32[162767]; //@line 50742
    $191 = (HEAP32[162777] | 0) + -2 | 0; //@line 50744
    HEAP32[162767] = $191; //@line 50745
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($191 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($191, $165 + 4096 | 0); //@line 50752
   }
  } else {
   if ($51) {
    $199 = (HEAP32[162767] | 0) + -12 | 0; //@line 50757
    HEAP32[162767] = $199; //@line 50758
    if ($49) {
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($199 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($199, HEAP32[96447] | 0); //@line 50766
     $207 = (HEAP32[162767] | 0) + 4 | 0; //@line 50768
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($207 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($207, HEAPU16[325963] | 0); //@line 50776
     $216 = (HEAP32[162767] | 0) + 8 | 0; //@line 50778
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($216 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($216, HEAP32[96446] | 0); //@line 50785
    }
    _puts(105494) | 0; //@line 50787
    $230 = HEAP32[162767] | 0; //@line 50788
    $231 = $230 + -2 | 0; //@line 50789
    HEAP32[162767] = $231; //@line 50790
    $232 = HEAP16[325558] | 0; //@line 50791
    $233 = $232 & 65535; //@line 50792
    $234 = $231 >>> 16; //@line 50793
    $235 = 123608 + ($234 << 2) | 0; //@line 50794
    $236 = HEAP32[$235 >> 2] | 0; //@line 50795
    $237 = $236 + 16 | 0; //@line 50796
    $238 = HEAP32[$237 >> 2] | 0; //@line 50797
    FUNCTION_TABLE_vii[$238 & 31]($231, $233); //@line 50798
    $239 = HEAP32[162773] | 0; //@line 50799
    $240 = $0 << 2; //@line 50800
    $241 = $239 + $240 | 0; //@line 50801
    $242 = $241 >>> 16; //@line 50802
    $243 = 123608 + ($242 << 2) | 0; //@line 50803
    $244 = HEAP32[$243 >> 2] | 0; //@line 50804
    $245 = HEAP32[$244 >> 2] | 0; //@line 50805
    $246 = FUNCTION_TABLE_ii[$245 & 127]($241) | 0; //@line 50806
    $247 = $246 >>> 16; //@line 50807
    $248 = 123608 + ($247 << 2) | 0; //@line 50808
    $249 = HEAP32[$248 >> 2] | 0; //@line 50809
    $250 = $249 + 24 | 0; //@line 50810
    $251 = HEAP32[$250 >> 2] | 0; //@line 50811
    $252 = FUNCTION_TABLE_ii[$251 & 127]($246) | 0; //@line 50812
    HEAP32[162770] = $252; //@line 50813
    HEAP32[162769] = $252; //@line 50814
    HEAP32[162768] = $246; //@line 50815
    HEAP8[651121] = 0; //@line 50816
    HEAP8[651119] = 0; //@line 50817
    HEAP8[651118] = 0; //@line 50818
    $253 = HEAP32[162771] | 0; //@line 50819
    $254 = $253 & -25; //@line 50820
    HEAP32[162771] = $254; //@line 50821
    return;
   }
  }
 } while (0);
 $224 = (HEAP32[162767] | 0) + -4 | 0; //@line 50827
 HEAP32[162767] = $224; //@line 50828
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($224 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($224, $6); //@line 50834
 $230 = HEAP32[162767] | 0; //@line 50835
 $231 = $230 + -2 | 0; //@line 50836
 HEAP32[162767] = $231; //@line 50837
 $232 = HEAP16[325558] | 0; //@line 50838
 $233 = $232 & 65535; //@line 50839
 $234 = $231 >>> 16; //@line 50840
 $235 = 123608 + ($234 << 2) | 0; //@line 50841
 $236 = HEAP32[$235 >> 2] | 0; //@line 50842
 $237 = $236 + 16 | 0; //@line 50843
 $238 = HEAP32[$237 >> 2] | 0; //@line 50844
 FUNCTION_TABLE_vii[$238 & 31]($231, $233); //@line 50845
 $239 = HEAP32[162773] | 0; //@line 50846
 $240 = $0 << 2; //@line 50847
 $241 = $239 + $240 | 0; //@line 50848
 $242 = $241 >>> 16; //@line 50849
 $243 = 123608 + ($242 << 2) | 0; //@line 50850
 $244 = HEAP32[$243 >> 2] | 0; //@line 50851
 $245 = HEAP32[$244 >> 2] | 0; //@line 50852
 $246 = FUNCTION_TABLE_ii[$245 & 127]($241) | 0; //@line 50853
 $247 = $246 >>> 16; //@line 50854
 $248 = 123608 + ($247 << 2) | 0; //@line 50855
 $249 = HEAP32[$248 >> 2] | 0; //@line 50856
 $250 = $249 + 24 | 0; //@line 50857
 $251 = HEAP32[$250 >> 2] | 0; //@line 50858
 $252 = FUNCTION_TABLE_ii[$251 & 127]($246) | 0; //@line 50859
 HEAP32[162770] = $252; //@line 50860
 HEAP32[162769] = $252; //@line 50861
 HEAP32[162768] = $246; //@line 50862
 HEAP8[651121] = 0; //@line 50863
 HEAP8[651119] = 0; //@line 50864
 HEAP8[651118] = 0; //@line 50865
 $253 = HEAP32[162771] | 0; //@line 50866
 $254 = $253 & -25; //@line 50867
 HEAP32[162771] = $254; //@line 50868
 return;
}
function __Z10DiskStatusjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$1 = 0, $$sroa$03$0$lcssa$i = 0, $$sroa$03$07$i = 0, $10 = 0, $104 = 0, $110 = 0, $116 = 0, $124 = 0, $126 = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $24 = 0, $29 = 0, $30 = 0, $40 = 0, $47 = 0, $48 = 0, $53 = 0, $54 = 0, $60 = 0, $66 = 0, $74 = 0, $8 = 0, $86 = 0, $9 = 0, $92 = 0, $98 = 0, $vararg_buffer = 0, dest = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 19218
 STACKTOP = STACKTOP + 16 | 0; //@line 19219
 $vararg_buffer = sp; //@line 19220
 $2 = $0 + 22 | 0; //@line 19221
 $8 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0; //@line 19227
 $9 = HEAP32[28490] | 0; //@line 19228
 $10 = HEAP32[28489] | 0; //@line 19229
 L1 : do {
  if (($10 | 0) == ($9 | 0)) {
   $$sroa$03$0$lcssa$i = $9; //@line 19233
  } else {
   $$sroa$03$07$i = $10; //@line 19235
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($8 | 0)) {
     $$sroa$03$0$lcssa$i = $$sroa$03$07$i; //@line 19240
     break L1;
    }
    $$sroa$03$07$i = $$sroa$03$07$i + 24 | 0; //@line 19243
    if (($$sroa$03$07$i | 0) == ($9 | 0)) {
     $$sroa$03$0$lcssa$i = $9; //@line 19246
     break;
    }
   }
  }
 } while (0);
 $16 = $0 + 26 | 0; //@line 19254
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 19260
 $23 = $22 & 65535; //@line 19261
 if (($23 | 0) != 43) {
  if (($$sroa$03$0$lcssa$i | 0) == (HEAP32[28490] | 0)) {
   $$1 = -56; //@line 19267
   STACKTOP = sp; //@line 19268
   return $$1 | 0; //@line 19268
  }
  switch (($22 & 65535) << 16 >> 16) {
  case 8:
   {
    $124 = $0 + 28 | 0; //@line 19273
    $126 = HEAP32[$$sroa$03$0$lcssa$i + 20 >> 2] | 0; //@line 19275
    dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($124 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($124) | 0; //@line 19288
    src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($126 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($126) | 0; //@line 19288
    stop = dest + 22 | 0; //@line 19288
    do {
     HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 19288
     dest = dest + 1 | 0; //@line 19288
     src = src + 1 | 0; //@line 19288
    } while ((dest | 0) < (stop | 0));
    $$1 = 0; //@line 19289
    STACKTOP = sp; //@line 19290
    return $$1 | 0; //@line 19290
   }
  case 44:
   {
    _puts(94569) | 0; //@line 19294
    $$1 = -18; //@line 19295
    STACKTOP = sp; //@line 19296
    return $$1 | 0; //@line 19296
   }
  case 45:
   {
    _puts(94640) | 0; //@line 19300
    $$1 = -18; //@line 19301
    STACKTOP = sp; //@line 19302
    return $$1 | 0; //@line 19302
   }
  case 46:
   {
    _puts(94717) | 0; //@line 19306
    $$1 = -18; //@line 19307
    STACKTOP = sp; //@line 19308
    return $$1 | 0; //@line 19308
   }
  case 70:
   {
    _puts(94786) | 0; //@line 19312
    $$1 = -18; //@line 19313
    STACKTOP = sp; //@line 19314
    return $$1 | 0; //@line 19314
   }
  default:
   {
    HEAP32[$vararg_buffer >> 2] = $23; //@line 19318
    _printf(94850, $vararg_buffer) | 0; //@line 19319
    $$1 = -18; //@line 19320
    STACKTOP = sp; //@line 19321
    return $$1 | 0; //@line 19321
   }
  }
 }
 $24 = $0 + 28 | 0; //@line 19325
 $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($24 >>> 16 << 2) >> 2] >> 2] & 127]($24) | 0; //@line 19330
 if (($29 | 0) >= 1886745191) {
  if (($29 | 0) < 1986359923) {
   if (($29 | 0) < 1937337955) {
    switch ($29 | 0) {
    case 1886745191:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 19342
      STACKTOP = sp; //@line 19343
      return $$1 | 0; //@line 19343
     }
    }
    $98 = $0 + 32 | 0; //@line 19346
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($98 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($98, 0); //@line 19352
    $$1 = 0; //@line 19353
    STACKTOP = sp; //@line 19354
    return $$1 | 0; //@line 19354
   } else {
    switch ($29 | 0) {
    case 1937337955:
     {
      break;
     }
    default:
     {
      $$1 = -18; //@line 19361
      STACKTOP = sp; //@line 19362
      return $$1 | 0; //@line 19362
     }
    }
    $66 = $0 + 32 | 0; //@line 19365
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($66 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($66, 16777216); //@line 19371
    $$1 = 0; //@line 19372
    STACKTOP = sp; //@line 19373
    return $$1 | 0; //@line 19373
   }
  }
  if (($29 | 0) < 1986883440) {
   switch ($29 | 0) {
   case 1986359923:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19383
     STACKTOP = sp; //@line 19384
     return $$1 | 0; //@line 19384
    }
   }
   $30 = $0 + 32 | 0; //@line 19387
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, 16809984); //@line 19393
   $$1 = 0; //@line 19394
   STACKTOP = sp; //@line 19395
   return $$1 | 0; //@line 19395
  }
  if (($29 | 0) < 2003395685) {
   switch ($29 | 0) {
   case 1986883440:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19404
     STACKTOP = sp; //@line 19405
     return $$1 | 0; //@line 19405
    }
   }
   $116 = $0 + 32 | 0; //@line 19408
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($116 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($116, 0); //@line 19414
   $$1 = 0; //@line 19415
   STACKTOP = sp; //@line 19416
   return $$1 | 0; //@line 19416
  } else {
   switch ($29 | 0) {
   case 2003395685:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19423
     STACKTOP = sp; //@line 19424
     return $$1 | 0; //@line 19424
    }
   }
   $92 = $0 + 32 | 0; //@line 19427
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($92 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($92, 256); //@line 19433
   $$1 = 0; //@line 19434
   STACKTOP = sp; //@line 19435
   return $$1 | 0; //@line 19435
  }
 }
 if (($29 | 0) >= 1701471587) {
  if (($29 | 0) < 1718383987) {
   switch ($29 | 0) {
   case 1701471587:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19447
     STACKTOP = sp; //@line 19448
     return $$1 | 0; //@line 19448
    }
   }
   $104 = $0 + 32 | 0; //@line 19451
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($104 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($104, 196611); //@line 19457
   $$1 = 0; //@line 19458
   STACKTOP = sp; //@line 19459
   return $$1 | 0; //@line 19459
  }
  if (($29 | 0) < 1768846438) {
   switch ($29 | 0) {
   case 1718383987:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19468
     STACKTOP = sp; //@line 19469
     return $$1 | 0; //@line 19469
    }
   }
   $110 = $0 + 32 | 0; //@line 19472
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($110 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($110, 0); //@line 19478
   $$1 = 0; //@line 19479
   STACKTOP = sp; //@line 19480
   return $$1 | 0; //@line 19480
  } else {
   switch ($29 | 0) {
   case 1768846438:
    {
     break;
    }
   default:
    {
     $$1 = -18; //@line 19487
     STACKTOP = sp; //@line 19488
     return $$1 | 0; //@line 19488
    }
   }
   $60 = $0 + 32 | 0; //@line 19491
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($60 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($60, 1650553705); //@line 19497
   $$1 = 0; //@line 19498
   STACKTOP = sp; //@line 19499
   return $$1 | 0; //@line 19499
  }
 }
 if (($29 | 0) < 1684371060) {
  switch ($29 | 0) {
  case 1651470196:
   {
    break;
   }
  default:
   {
    $$1 = -18; //@line 19509
    STACKTOP = sp; //@line 19510
    return $$1 | 0; //@line 19510
   }
  }
  $74 = $0 + 32 | 0; //@line 19515
  if (($$sroa$03$0$lcssa$i | 0) == (HEAP32[28490] | 0)) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($74, 0); //@line 19522
  } else {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($74, HEAP32[$$sroa$03$0$lcssa$i >> 2] | 0); //@line 19530
  }
  $86 = $0 + 34 | 0; //@line 19532
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($86 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($86, 65473); //@line 19538
  $$1 = 0; //@line 19539
  STACKTOP = sp; //@line 19540
  return $$1 | 0; //@line 19540
 }
 switch ($29 | 0) {
 case 1684371060:
  {
   break;
  }
 default:
  {
   $$1 = -18; //@line 19547
   STACKTOP = sp; //@line 19548
   return $$1 | 0; //@line 19548
  }
 }
 if (($$sroa$03$0$lcssa$i | 0) == (HEAP32[28490] | 0)) {
  $54 = $0 + 32 | 0; //@line 19554
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($54 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($54, 1684632427); //@line 19560
  $$1 = 0; //@line 19561
  STACKTOP = sp; //@line 19562
  return $$1 | 0; //@line 19562
 }
 $40 = (HEAP32[$$sroa$03$0$lcssa$i + 20 >> 2] | 0) + 3 | 0; //@line 19566
 $47 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($40) | 0) == 8; //@line 19573
 $48 = $0 + 32 | 0; //@line 19574
 $53 = HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 12 >> 2] | 0; //@line 19579
 if ($47) {
  FUNCTION_TABLE_vii[$53 & 31]($48, 1684632427); //@line 19581
  $$1 = 0; //@line 19582
  STACKTOP = sp; //@line 19583
  return $$1 | 0; //@line 19583
 } else {
  FUNCTION_TABLE_vii[$53 & 31]($48, 1919185771); //@line 19585
  $$1 = 0; //@line 19586
  STACKTOP = sp; //@line 19587
  return $$1 | 0; //@line 19587
 }
 return 0; //@line 19589
}
function __ZL7fs_openjjjb($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0$i48 = 0, $$042 = 0, $$043 = 0, $$05$i = 0, $$06$i = 0, $$1 = 0, $$2 = 0, $$pn$i = 0, $10 = 0, $102 = 0, $11 = 0, $110 = 0, $112 = 0, $117 = 0, $123 = 0, $129 = 0, $137 = 0, $143 = 0, $145 = 0, $148 = 0, $149 = 0, $20 = 0, $28 = 0, $38 = 0, $4 = 0, $43 = 0, $48 = 0, $5 = 0, $54 = 0, $6 = 0, $62 = 0, $7 = 0, $74 = 0, $76 = 0, $82 = 0, $90 = 0, $96 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 34270
 STACKTOP = STACKTOP + 160 | 0; //@line 34271
 $vararg_buffer = sp; //@line 34272
 $4 = sp + 84 | 0; //@line 34273
 $5 = sp + 80 | 0; //@line 34274
 $6 = sp + 4 | 0; //@line 34275
 $7 = __ZL17get_item_and_pathjjRP6FSItemb($0, $1, $5) | 0; //@line 34276
 if ($7 << 16 >> 16) {
  $$2 = $7; //@line 34279
  STACKTOP = sp; //@line 34280
  return $$2 | 0; //@line 34280
 }
 $10 = (_access(657423, 2) | 0) == 0; //@line 34283
 $11 = $0 + 27 | 0; //@line 34284
 switch (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($11) | 0) {
 case 0:
  {
   $$043 = $10 ? 2 : 0; //@line 34294
   break;
  }
 case 1:
  {
   $$043 = 0; //@line 34298
   break;
  }
 case 2:
  {
   $$043 = 1; //@line 34302
   break;
  }
 default:
  {
   $$043 = 2; //@line 34306
  }
 }
 L9 : do {
  if ($3) {
   if (!(_access(657423, 0) | 0)) {
    $20 = __Z10open_rforkPKci(657423, $$043) | 0; //@line 34314
    if (($20 | 0) <= -1) {
     HEAP32[$6 + 36 >> 2] = 0; //@line 34318
     HEAP32[$6 + 12 >> 2] = 0; //@line 34320
     $$042 = $20; //@line 34321
     label = 43; //@line 34322
     break;
    }
    if ((_fstat($20, $6) | 0) < 0) {
     _close($20) | 0; //@line 34328
     switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
     case 0:
      {
       $$1 = 0; //@line 34333
       break L9;
       break;
      }
     case 21:
     case 2:
      {
       $$1 = -43; //@line 34338
       break L9;
       break;
      }
     case 1:
     case 13:
      {
       $$1 = -54; //@line 34343
       break L9;
       break;
      }
     case 17:
      {
       $$1 = -48; //@line 34348
       break L9;
       break;
      }
     case 39:
     case 16:
      {
       $$1 = -47; //@line 34353
       break L9;
       break;
      }
     case 28:
      {
       $$1 = -34; //@line 34358
       break L9;
       break;
      }
     case 30:
      {
       $$1 = -44; //@line 34363
       break L9;
       break;
      }
     case 24:
      {
       $$1 = -42; //@line 34368
       break L9;
       break;
      }
     case 12:
      {
       $$1 = -108; //@line 34373
       break L9;
       break;
      }
     default:
      {
       $$1 = -36; //@line 34378
       break L9;
      }
     }
    } else {
     $$042 = $20; //@line 34383
     label = 43; //@line 34384
    }
   } else {
    $$1 = -43; //@line 34387
   }
  } else {
   $28 = _open(657423, $$043, $vararg_buffer) | 0; //@line 34390
   if (($28 | 0) < 0) {
    switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
    case 0:
     {
      $$1 = 0; //@line 34397
      break L9;
      break;
     }
    case 21:
    case 2:
     {
      $$1 = -43; //@line 34402
      break L9;
      break;
     }
    case 1:
    case 13:
     {
      $$1 = -54; //@line 34407
      break L9;
      break;
     }
    case 17:
     {
      $$1 = -48; //@line 34412
      break L9;
      break;
     }
    case 39:
    case 16:
     {
      $$1 = -47; //@line 34417
      break L9;
      break;
     }
    case 28:
     {
      $$1 = -34; //@line 34422
      break L9;
      break;
     }
    case 30:
     {
      $$1 = -44; //@line 34427
      break L9;
      break;
     }
    case 24:
     {
      $$1 = -42; //@line 34432
      break L9;
      break;
     }
    case 12:
     {
      $$1 = -108; //@line 34437
      break L9;
      break;
     }
    default:
     {
      $$1 = -36; //@line 34442
      break L9;
     }
    }
   }
   if ((_fstat($28, $6) | 0) < 0) {
    _close($28) | 0; //@line 34450
    switch (HEAP32[(___errno_location() | 0) >> 2] | 0) {
    case 0:
     {
      $$1 = 0; //@line 34455
      break L9;
      break;
     }
    case 21:
    case 2:
     {
      $$1 = -43; //@line 34460
      break L9;
      break;
     }
    case 1:
    case 13:
     {
      $$1 = -54; //@line 34465
      break L9;
      break;
     }
    case 17:
     {
      $$1 = -48; //@line 34470
      break L9;
      break;
     }
    case 39:
    case 16:
     {
      $$1 = -47; //@line 34475
      break L9;
      break;
     }
    case 28:
     {
      $$1 = -34; //@line 34480
      break L9;
      break;
     }
    case 30:
     {
      $$1 = -44; //@line 34485
      break L9;
      break;
     }
    case 24:
     {
      $$1 = -42; //@line 34490
      break L9;
      break;
     }
    case 12:
     {
      $$1 = -108; //@line 34495
      break L9;
      break;
     }
    default:
     {
      $$1 = -36; //@line 34500
      break L9;
     }
    }
   } else {
    $$042 = $28; //@line 34505
    label = 43; //@line 34506
   }
  }
 } while (0);
 L51 : do {
  if ((label | 0) == 43) {
   HEAP32[$4 + 32 >> 2] = $0 + 24; //@line 34514
   $38 = HEAP32[30848] | 0; //@line 34515
   HEAP32[$4 + 36 >> 2] = $38 + 306; //@line 34518
   _Execute68k($38 + 710 | 0, $4); //@line 34520
   $43 = (HEAP32[30848] | 0) + 306 | 0; //@line 34522
   $48 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($43 >>> 16 << 2) >> 2] >> 2] & 127]($43) | 0; //@line 34527
   if (HEAP32[$4 >> 2] & 65535 | 0) {
    _close($$042) | 0; //@line 34532
    $$1 = HEAP32[$4 >> 2] & 65535; //@line 34535
    break;
   }
   $54 = HEAP32[$5 >> 2] | 0; //@line 34538
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($48, HEAP32[$54 + 4 >> 2] | 0); //@line 34546
   $62 = $48 + 4 | 0; //@line 34547
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($62 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($62, ($10 ? 0 : 32) | ($3 ? 2 : 0) | ($$043 + -1 | 0) >>> 0 < 2); //@line 34560
   $74 = $48 + 8 | 0; //@line 34561
   $76 = HEAP32[$6 + 36 >> 2] | 0; //@line 34563
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($74, $76); //@line 34569
   $82 = $48 + 12 | 0; //@line 34570
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($82, ($76 | 16383) + 1 | 0); //@line 34578
   $90 = $48 + 16 | 0; //@line 34579
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($90 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($90, 0); //@line 34585
   $96 = $48 + 20 | 0; //@line 34586
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($96 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($96, $2); //@line 34592
   $102 = $48 + 30 | 0; //@line 34593
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($102 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($102, 16384); //@line 34599
   __Z9get_finfoPKcjjb(657423, (HEAP32[30848] | 0) + 238 | 0, 0, 0); //@line 34602
   $110 = $48 + 50 | 0; //@line 34603
   $112 = (HEAP32[30848] | 0) + 238 | 0; //@line 34605
   $117 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($112 >>> 16 << 2) >> 2] >> 2] & 127]($112) | 0; //@line 34610
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($110 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($110, $117); //@line 34616
   $123 = $48 + 54 | 0; //@line 34617
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($123 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($123, $$042); //@line 34623
   $129 = $48 + 58 | 0; //@line 34624
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($129 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($129, HEAP32[$54 + 8 >> 2] | 0); //@line 34632
   $137 = $48 + 62 | 0; //@line 34633
   $143 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($137 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($137) | 0; //@line 34639
   $145 = (HEAP32[$5 >> 2] | 0) + 20 | 0; //@line 34641
   HEAP8[$143 >> 0] = _strlen($145) | 0; //@line 34644
   $$05$i = $145; //@line 34645
   $$pn$i = $143; //@line 34645
   while (1) {
    $$06$i = $$pn$i + 1 | 0; //@line 34647
    $148 = $$05$i + 1 | 0; //@line 34648
    $149 = HEAP8[$$05$i >> 0] | 0; //@line 34649
    switch ($149 << 24 >> 24) {
    case 0:
     {
      $$1 = 0; //@line 34652
      break L51;
      break;
     }
    case 58:
     {
      $$0$i48 = 47; //@line 34657
      break;
     }
    default:
     {
      $$0$i48 = $149; //@line 34661
     }
    }
    HEAP8[$$06$i >> 0] = $$0$i48; //@line 34664
    $$05$i = $148; //@line 34665
    $$pn$i = $$06$i; //@line 34665
   }
  }
 } while (0);
 $$2 = $$1; //@line 34669
 STACKTOP = sp; //@line 34670
 return $$2 | 0; //@line 34670
}
function _try_realloc_chunk($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$1272 = 0, $$1275 = 0, $$2 = 0, $$3 = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = 0, $102 = 0, $105 = 0, $107 = 0, $110 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $119 = 0, $120 = 0, $122 = 0, $123 = 0, $128 = 0, $129 = 0, $142 = 0, $145 = 0, $146 = 0, $152 = 0, $159 = 0, $163 = 0, $166 = 0, $172 = 0, $2 = 0, $22 = 0, $24 = 0, $3 = 0, $31 = 0, $37 = 0, $39 = 0, $4 = 0, $40 = 0, $49 = 0, $5 = 0, $51 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $60 = 0, $66 = 0, $7 = 0, $72 = 0, $74 = 0, $75 = 0, $78 = 0, $80 = 0, $82 = 0, $95 = 0, $storemerge = 0, $storemerge1 = 0;
 $2 = $0 + 4 | 0; //@line 53398
 $3 = HEAP32[$2 >> 2] | 0; //@line 53399
 $4 = $3 & -8; //@line 53400
 $5 = $0 + $4 | 0; //@line 53401
 $6 = HEAP32[162839] | 0; //@line 53402
 $7 = $3 & 3; //@line 53403
 if (!(($7 | 0) != 1 & $0 >>> 0 >= $6 >>> 0 & $0 >>> 0 < $5 >>> 0)) {
  _abort(); //@line 53410
 }
 $10 = HEAP32[$5 + 4 >> 2] | 0; //@line 53414
 if (!($10 & 1)) {
  _abort(); //@line 53418
 }
 if (!$7) {
  if ($1 >>> 0 < 256) {
   $$2 = 0; //@line 53425
   return $$2 | 0; //@line 53426
  }
  if ($4 >>> 0 >= ($1 + 4 | 0) >>> 0) {
   if (($4 - $1 | 0) >>> 0 <= HEAP32[162955] << 1 >>> 0) {
    $$2 = $0; //@line 53436
    return $$2 | 0; //@line 53437
   }
  }
  $$2 = 0; //@line 53440
  return $$2 | 0; //@line 53441
 }
 if ($4 >>> 0 >= $1 >>> 0) {
  $22 = $4 - $1 | 0; //@line 53445
  if ($22 >>> 0 <= 15) {
   $$2 = $0; //@line 53448
   return $$2 | 0; //@line 53449
  }
  $24 = $0 + $1 | 0; //@line 53451
  HEAP32[$2 >> 2] = $3 & 1 | $1 | 2; //@line 53455
  HEAP32[$24 + 4 >> 2] = $22 | 3; //@line 53458
  $31 = $24 + $22 + 4 | 0; //@line 53460
  HEAP32[$31 >> 2] = HEAP32[$31 >> 2] | 1; //@line 53463
  _dispose_chunk($24, $22); //@line 53464
  $$2 = $0; //@line 53465
  return $$2 | 0; //@line 53466
 }
 if (($5 | 0) == (HEAP32[162841] | 0)) {
  $37 = (HEAP32[162838] | 0) + $4 | 0; //@line 53472
  $39 = $37 - $1 | 0; //@line 53474
  $40 = $0 + $1 | 0; //@line 53475
  if ($37 >>> 0 <= $1 >>> 0) {
   $$2 = 0; //@line 53477
   return $$2 | 0; //@line 53478
  }
  HEAP32[$2 >> 2] = $3 & 1 | $1 | 2; //@line 53485
  HEAP32[$40 + 4 >> 2] = $39 | 1; //@line 53486
  HEAP32[162841] = $40; //@line 53487
  HEAP32[162838] = $39; //@line 53488
  $$2 = $0; //@line 53489
  return $$2 | 0; //@line 53490
 }
 if (($5 | 0) == (HEAP32[162840] | 0)) {
  $49 = (HEAP32[162837] | 0) + $4 | 0; //@line 53496
  if ($49 >>> 0 < $1 >>> 0) {
   $$2 = 0; //@line 53499
   return $$2 | 0; //@line 53500
  }
  $51 = $49 - $1 | 0; //@line 53502
  $53 = $3 & 1; //@line 53504
  if ($51 >>> 0 > 15) {
   $54 = $0 + $1 | 0; //@line 53506
   $55 = $54 + $51 | 0; //@line 53507
   HEAP32[$2 >> 2] = $53 | $1 | 2; //@line 53510
   HEAP32[$54 + 4 >> 2] = $51 | 1; //@line 53513
   HEAP32[$55 >> 2] = $51; //@line 53514
   $60 = $55 + 4 | 0; //@line 53515
   HEAP32[$60 >> 2] = HEAP32[$60 >> 2] & -2; //@line 53518
   $storemerge = $54; //@line 53519
   $storemerge1 = $51; //@line 53519
  } else {
   HEAP32[$2 >> 2] = $53 | $49 | 2; //@line 53523
   $66 = $0 + $49 + 4 | 0; //@line 53525
   HEAP32[$66 >> 2] = HEAP32[$66 >> 2] | 1; //@line 53528
   $storemerge = 0; //@line 53529
   $storemerge1 = 0; //@line 53529
  }
  HEAP32[162837] = $storemerge1; //@line 53531
  HEAP32[162840] = $storemerge; //@line 53532
  $$2 = $0; //@line 53533
  return $$2 | 0; //@line 53534
 }
 if ($10 & 2 | 0) {
  $$2 = 0; //@line 53539
  return $$2 | 0; //@line 53540
 }
 $72 = ($10 & -8) + $4 | 0; //@line 53543
 if ($72 >>> 0 < $1 >>> 0) {
  $$2 = 0; //@line 53546
  return $$2 | 0; //@line 53547
 }
 $74 = $72 - $1 | 0; //@line 53549
 $75 = $10 >>> 3; //@line 53550
 L49 : do {
  if ($10 >>> 0 < 256) {
   $78 = HEAP32[$5 + 8 >> 2] | 0; //@line 53555
   $80 = HEAP32[$5 + 12 >> 2] | 0; //@line 53557
   $82 = 651380 + ($75 << 1 << 2) | 0; //@line 53559
   if (($78 | 0) != ($82 | 0)) {
    if ($78 >>> 0 < $6 >>> 0) {
     _abort(); //@line 53564
    }
    if ((HEAP32[$78 + 12 >> 2] | 0) != ($5 | 0)) {
     _abort(); //@line 53571
    }
   }
   if (($80 | 0) == ($78 | 0)) {
    HEAP32[162835] = HEAP32[162835] & ~(1 << $75); //@line 53581
    break;
   }
   if (($80 | 0) == ($82 | 0)) {
    $$pre$phiZ2D = $80 + 8 | 0; //@line 53587
   } else {
    if ($80 >>> 0 < $6 >>> 0) {
     _abort(); //@line 53591
    }
    $95 = $80 + 8 | 0; //@line 53594
    if ((HEAP32[$95 >> 2] | 0) == ($5 | 0)) {
     $$pre$phiZ2D = $95; //@line 53598
    } else {
     _abort(); //@line 53600
    }
   }
   HEAP32[$78 + 12 >> 2] = $80; //@line 53605
   HEAP32[$$pre$phiZ2D >> 2] = $78; //@line 53606
  } else {
   $100 = HEAP32[$5 + 24 >> 2] | 0; //@line 53609
   $102 = HEAP32[$5 + 12 >> 2] | 0; //@line 53611
   do {
    if (($102 | 0) == ($5 | 0)) {
     $113 = $5 + 16 | 0; //@line 53615
     $114 = $113 + 4 | 0; //@line 53616
     $115 = HEAP32[$114 >> 2] | 0; //@line 53617
     if (!$115) {
      $117 = HEAP32[$113 >> 2] | 0; //@line 53620
      if (!$117) {
       $$3 = 0; //@line 53623
       break;
      } else {
       $$1272 = $117; //@line 53626
       $$1275 = $113; //@line 53626
      }
     } else {
      $$1272 = $115; //@line 53629
      $$1275 = $114; //@line 53629
     }
     while (1) {
      $119 = $$1272 + 20 | 0; //@line 53632
      $120 = HEAP32[$119 >> 2] | 0; //@line 53633
      if ($120 | 0) {
       $$1272 = $120; //@line 53636
       $$1275 = $119; //@line 53636
       continue;
      }
      $122 = $$1272 + 16 | 0; //@line 53639
      $123 = HEAP32[$122 >> 2] | 0; //@line 53640
      if (!$123) {
       break;
      } else {
       $$1272 = $123; //@line 53645
       $$1275 = $122; //@line 53645
      }
     }
     if ($$1275 >>> 0 < $6 >>> 0) {
      _abort(); //@line 53650
     } else {
      HEAP32[$$1275 >> 2] = 0; //@line 53653
      $$3 = $$1272; //@line 53654
      break;
     }
    } else {
     $105 = HEAP32[$5 + 8 >> 2] | 0; //@line 53659
     if ($105 >>> 0 < $6 >>> 0) {
      _abort(); //@line 53662
     }
     $107 = $105 + 12 | 0; //@line 53665
     if ((HEAP32[$107 >> 2] | 0) != ($5 | 0)) {
      _abort(); //@line 53669
     }
     $110 = $102 + 8 | 0; //@line 53672
     if ((HEAP32[$110 >> 2] | 0) == ($5 | 0)) {
      HEAP32[$107 >> 2] = $102; //@line 53676
      HEAP32[$110 >> 2] = $105; //@line 53677
      $$3 = $102; //@line 53678
      break;
     } else {
      _abort(); //@line 53681
     }
    }
   } while (0);
   if ($100 | 0) {
    $128 = HEAP32[$5 + 28 >> 2] | 0; //@line 53689
    $129 = 651644 + ($128 << 2) | 0; //@line 53690
    do {
     if (($5 | 0) == (HEAP32[$129 >> 2] | 0)) {
      HEAP32[$129 >> 2] = $$3; //@line 53695
      if (!$$3) {
       HEAP32[162836] = HEAP32[162836] & ~(1 << $128); //@line 53702
       break L49;
      }
     } else {
      if ($100 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
       _abort(); //@line 53709
      } else {
       HEAP32[$100 + 16 + (((HEAP32[$100 + 16 >> 2] | 0) != ($5 | 0) & 1) << 2) >> 2] = $$3; //@line 53717
       if (!$$3) {
        break L49;
       } else {
        break;
       }
      }
     }
    } while (0);
    $142 = HEAP32[162839] | 0; //@line 53727
    if ($$3 >>> 0 < $142 >>> 0) {
     _abort(); //@line 53730
    }
    HEAP32[$$3 + 24 >> 2] = $100; //@line 53734
    $145 = $5 + 16 | 0; //@line 53735
    $146 = HEAP32[$145 >> 2] | 0; //@line 53736
    do {
     if ($146 | 0) {
      if ($146 >>> 0 < $142 >>> 0) {
       _abort(); //@line 53742
      } else {
       HEAP32[$$3 + 16 >> 2] = $146; //@line 53746
       HEAP32[$146 + 24 >> 2] = $$3; //@line 53748
       break;
      }
     }
    } while (0);
    $152 = HEAP32[$145 + 4 >> 2] | 0; //@line 53754
    if ($152 | 0) {
     if ($152 >>> 0 < (HEAP32[162839] | 0) >>> 0) {
      _abort(); //@line 53760
     } else {
      HEAP32[$$3 + 20 >> 2] = $152; //@line 53764
      HEAP32[$152 + 24 >> 2] = $$3; //@line 53766
      break;
     }
    }
   }
  }
 } while (0);
 $159 = $3 & 1; //@line 53774
 if ($74 >>> 0 < 16) {
  HEAP32[$2 >> 2] = $72 | $159 | 2; //@line 53778
  $163 = $0 + $72 + 4 | 0; //@line 53780
  HEAP32[$163 >> 2] = HEAP32[$163 >> 2] | 1; //@line 53783
  $$2 = $0; //@line 53784
  return $$2 | 0; //@line 53785
 } else {
  $166 = $0 + $1 | 0; //@line 53787
  HEAP32[$2 >> 2] = $159 | $1 | 2; //@line 53790
  HEAP32[$166 + 4 >> 2] = $74 | 3; //@line 53793
  $172 = $166 + $74 + 4 | 0; //@line 53795
  HEAP32[$172 >> 2] = HEAP32[$172 >> 2] | 1; //@line 53798
  _dispose_chunk($166, $74); //@line 53799
  $$2 = $0; //@line 53800
  return $$2 | 0; //@line 53801
 }
 return 0; //@line 53803
}
function ___floatscan($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$0105$ph = 0, $$0106$ph = 0, $$0107$lcssa = 0, $$0107127 = 0, $$0113 = 0, $$0114 = 0.0, $$1$lcssa = 0, $$1108 = 0, $$1128 = 0, $$2 = 0, $$2109125 = 0, $$3110 = 0, $$3126 = 0, $$4 = 0, $$4111 = 0, $$5 = 0, $$6 = 0, $$in = 0, $102 = 0, $118 = 0, $12 = 0, $126 = 0, $18 = 0, $19 = 0, $3 = 0, $32 = 0, $39 = 0, $4 = 0, $42 = 0, $45 = 0, $5 = 0, $63 = 0, $70 = 0, $72 = 0, $80 = 0, $85 = 0, $93 = 0, label = 0;
 switch ($1 | 0) {
 case 0:
  {
   $$0105$ph = -149; //@line 59630
   $$0106$ph = 24; //@line 59630
   label = 4; //@line 59631
   break;
  }
 case 1:
  {
   $$0105$ph = -1074; //@line 59635
   $$0106$ph = 53; //@line 59635
   label = 4; //@line 59636
   break;
  }
 case 2:
  {
   $$0105$ph = -1074; //@line 59640
   $$0106$ph = 53; //@line 59640
   label = 4; //@line 59641
   break;
  }
 default:
  {
   $$0114 = 0.0; //@line 59645
  }
 }
 L4 : do {
  if ((label | 0) == 4) {
   $3 = $0 + 4 | 0; //@line 59650
   $4 = $0 + 100 | 0; //@line 59651
   do {
    $5 = HEAP32[$3 >> 2] | 0; //@line 59653
    if ($5 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
     HEAP32[$3 >> 2] = $5 + 1; //@line 59658
     $12 = HEAPU8[$5 >> 0] | 0; //@line 59661
    } else {
     $12 = ___shgetc($0) | 0; //@line 59664
    }
   } while ((_isspace($12) | 0) != 0);
   L13 : do {
    switch ($12 | 0) {
    case 43:
    case 45:
     {
      $18 = 1 - ((($12 | 0) == 45 & 1) << 1) | 0; //@line 59678
      $19 = HEAP32[$3 >> 2] | 0; //@line 59679
      if ($19 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
       HEAP32[$3 >> 2] = $19 + 1; //@line 59684
       $$0 = HEAPU8[$19 >> 0] | 0; //@line 59687
       $$0113 = $18; //@line 59687
       break L13;
      } else {
       $$0 = ___shgetc($0) | 0; //@line 59691
       $$0113 = $18; //@line 59691
       break L13;
      }
      break;
     }
    default:
     {
      $$0 = $12; //@line 59697
      $$0113 = 1; //@line 59697
     }
    }
   } while (0);
   $$0107127 = 0; //@line 59701
   $$1128 = $$0; //@line 59701
   while (1) {
    if (($$1128 | 32 | 0) != (HEAP8[112499 + $$0107127 >> 0] | 0)) {
     $$0107$lcssa = $$0107127; //@line 59709
     $$1$lcssa = $$1128; //@line 59709
     break;
    }
    do {
     if ($$0107127 >>> 0 < 7) {
      $32 = HEAP32[$3 >> 2] | 0; //@line 59715
      if ($32 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
       HEAP32[$3 >> 2] = $32 + 1; //@line 59720
       $$2 = HEAPU8[$32 >> 0] | 0; //@line 59723
       break;
      } else {
       $$2 = ___shgetc($0) | 0; //@line 59727
       break;
      }
     } else {
      $$2 = $$1128; //@line 59731
     }
    } while (0);
    $39 = $$0107127 + 1 | 0; //@line 59734
    if ($39 >>> 0 < 8) {
     $$0107127 = $39; //@line 59737
     $$1128 = $$2; //@line 59737
    } else {
     $$0107$lcssa = $39; //@line 59739
     $$1$lcssa = $$2; //@line 59739
     break;
    }
   }
   L29 : do {
    switch ($$0107$lcssa | 0) {
    case 8:
     {
      break;
     }
    case 3:
     {
      label = 23; //@line 59749
      break;
     }
    default:
     {
      $42 = ($2 | 0) != 0; //@line 59754
      if ($42 & $$0107$lcssa >>> 0 > 3) {
       if (($$0107$lcssa | 0) == 8) {
        break L29;
       } else {
        label = 23; //@line 59761
        break L29;
       }
      }
      L34 : do {
       if (!$$0107$lcssa) {
        $$2109125 = 0; //@line 59768
        $$3126 = $$1$lcssa; //@line 59768
        while (1) {
         if (($$3126 | 32 | 0) != (HEAP8[112508 + $$2109125 >> 0] | 0)) {
          $$3110 = $$2109125; //@line 59776
          $$5 = $$3126; //@line 59776
          break L34;
         }
         do {
          if ($$2109125 >>> 0 < 2) {
           $63 = HEAP32[$3 >> 2] | 0; //@line 59782
           if ($63 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
            HEAP32[$3 >> 2] = $63 + 1; //@line 59787
            $$4 = HEAPU8[$63 >> 0] | 0; //@line 59790
            break;
           } else {
            $$4 = ___shgetc($0) | 0; //@line 59794
            break;
           }
          } else {
           $$4 = $$3126; //@line 59798
          }
         } while (0);
         $70 = $$2109125 + 1 | 0; //@line 59801
         if ($70 >>> 0 < 3) {
          $$2109125 = $70; //@line 59804
          $$3126 = $$4; //@line 59804
         } else {
          $$3110 = $70; //@line 59806
          $$5 = $$4; //@line 59806
          break;
         }
        }
       } else {
        $$3110 = $$0107$lcssa; //@line 59811
        $$5 = $$1$lcssa; //@line 59811
       }
      } while (0);
      switch ($$3110 | 0) {
      case 3:
       {
        $72 = HEAP32[$3 >> 2] | 0; //@line 59816
        if ($72 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
         HEAP32[$3 >> 2] = $72 + 1; //@line 59821
         $80 = HEAPU8[$72 >> 0] | 0; //@line 59824
        } else {
         $80 = ___shgetc($0) | 0; //@line 59827
        }
        if (($80 | 0) == 40) {
         $$4111 = 1; //@line 59831
        } else {
         if (!(HEAP32[$4 >> 2] | 0)) {
          $$0114 = nan; //@line 59836
          break L4;
         }
         HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59841
         $$0114 = nan; //@line 59842
         break L4;
        }
        while (1) {
         $85 = HEAP32[$3 >> 2] | 0; //@line 59846
         if ($85 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
          HEAP32[$3 >> 2] = $85 + 1; //@line 59851
          $93 = HEAPU8[$85 >> 0] | 0; //@line 59854
         } else {
          $93 = ___shgetc($0) | 0; //@line 59857
         }
         if (!(($93 + -48 | 0) >>> 0 < 10 | ($93 + -65 | 0) >>> 0 < 26)) {
          if (!(($93 | 0) == 95 | ($93 + -97 | 0) >>> 0 < 26)) {
           break;
          }
         }
         $$4111 = $$4111 + 1 | 0; //@line 59874
        }
        if (($93 | 0) == 41) {
         $$0114 = nan; //@line 59878
         break L4;
        }
        $102 = (HEAP32[$4 >> 2] | 0) == 0; //@line 59882
        if (!$102) {
         HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59886
        }
        if (!$42) {
         HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 59890
         ___shlim($0, 0); //@line 59891
         $$0114 = 0.0; //@line 59892
         break L4;
        }
        if (!$$4111) {
         $$0114 = nan; //@line 59897
         break L4;
        } else {
         $$in = $$4111; //@line 59900
        }
        while (1) {
         $$in = $$in + -1 | 0; //@line 59903
         if (!$102) {
          HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59907
         }
         if (!$$in) {
          $$0114 = nan; //@line 59911
          break L4;
         }
        }
        break;
       }
      case 0:
       {
        if (($$5 | 0) == 48) {
         $118 = HEAP32[$3 >> 2] | 0; //@line 59922
         if ($118 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
          HEAP32[$3 >> 2] = $118 + 1; //@line 59927
          $126 = HEAPU8[$118 >> 0] | 0; //@line 59930
         } else {
          $126 = ___shgetc($0) | 0; //@line 59933
         }
         if (($126 | 32 | 0) == 120) {
          $$0114 = +_hexfloat($0, $$0106$ph, $$0105$ph, $$0113, $2); //@line 59939
          break L4;
         }
         if (!(HEAP32[$4 >> 2] | 0)) {
          $$6 = 48; //@line 59945
         } else {
          HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59949
          $$6 = 48; //@line 59950
         }
        } else {
         $$6 = $$5; //@line 59953
        }
        $$0114 = +_decfloat($0, $$6, $$0106$ph, $$0105$ph, $$0113, $2); //@line 59956
        break L4;
        break;
       }
      default:
       {
        if (HEAP32[$4 >> 2] | 0) {
         HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59966
        }
        HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 59969
        ___shlim($0, 0); //@line 59970
        $$0114 = 0.0; //@line 59971
        break L4;
       }
      }
     }
    }
   } while (0);
   if ((label | 0) == 23) {
    $45 = (HEAP32[$4 >> 2] | 0) == 0; //@line 59980
    if (!$45) {
     HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59984
    }
    if (($2 | 0) != 0 & $$0107$lcssa >>> 0 > 3) {
     $$1108 = $$0107$lcssa; //@line 59990
     do {
      if (!$45) {
       HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 59995
      }
      $$1108 = $$1108 + -1 | 0; //@line 59997
     } while ($$1108 >>> 0 > 3);
    }
   }
   $$0114 = +($$0113 | 0) * inf; //@line 60010
  }
 } while (0);
 return +$$0114;
}
function _do_merges() {
 var $$$i = 0, $$01012 = 0, $$014 = 0, $$05976$i = 0, $$05976$i$us = 0, $$06077$i = 0, $$062$i = 0, $$064$i = 0, $$1 = 0, $$1$i = 0, $$165$i = 0, $$hi = 0, $$hi1 = 0, $$hi16 = 0, $$hi18 = 0, $$hi7 = 0, $$hi9 = 0, $$lo = 0, $$lo15 = 0, $$lo6 = 0, $$phitmp67$i = 0, $$pre$phiZ2D = 0, $0 = 0, $101 = 0, $109 = 0, $11 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $14 = 0, $17 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $28 = 0, $32 = 0, $33 = 0, $34 = 0, $37 = 0, $4 = 0, $40 = 0, $41 = 0, $43 = 0, $49 = 0, $57 = 0, $58 = 0, $67 = 0, $74 = 0, $75 = 0, $77 = 0, $83 = 0, $9 = 0, $91 = 0, $92 = 0, label = 0;
 HEAP32[162824] = 0; //@line 54905
 $0 = HEAP32[162823] | 0; //@line 54906
 $$01012 = 0; //@line 54907
 $$014 = 0; //@line 54907
 $118 = 0; //@line 54907
 L1 : while (1) {
  if ((HEAP32[$0 + ($$01012 << 4) >> 2] | 0) == -1) {
   $4 = $0 + ($$01012 << 4) + 9 | 0; //@line 54913
   $$lo = HEAPU8[$4 >> 0] | HEAPU8[$4 + 1 >> 0] << 8 | HEAPU8[$4 + 2 >> 0] << 16 | HEAPU8[$4 + 3 >> 0] << 24; //@line 54914
   $$hi = $4 + 4 | 0; //@line 54915
   $$hi1 = (HEAPU8[$$hi >> 0] | HEAPU8[$$hi + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi + 2 >> 0] << 16; //@line 54922
   if (($$lo & 16711680 | 0) == 0 & 0 == 0) {
    $$1 = $$014; //@line 54928
    $119 = $118; //@line 54928
   } else {
    $9 = $$014 + 1 | 0; //@line 54930
    $11 = HEAP8[$0 + ($$01012 << 4) + 7 >> 0] | 0; //@line 54932
    if ($11 << 24 >> 24 == -1) {
     $$1$i = 1; //@line 54935
     $$165$i = -1; //@line 54935
     $$pre$phiZ2D = -1; //@line 54935
    } else {
     $14 = _bitshift64Lshr($$lo | 0, $$hi1 & 16777215 | 0, 37) | 0; //@line 54938
     switch ($14 & 7) {
     case 4:
     case 3:
     case 0:
      {
       $$062$i = 8; //@line 54944
       $$064$i = 7; //@line 54944
       break;
      }
     case 1:
      {
       $$062$i = 256; //@line 54948
       $$064$i = 255; //@line 54948
       break;
      }
     case 2:
      {
       $$062$i = 16; //@line 54952
       $$064$i = 15; //@line 54952
       break;
      }
     case 5:
      {
       $$062$i = 64; //@line 54956
       $$064$i = 63; //@line 54956
       break;
      }
     case 6:
      {
       $$062$i = 256; //@line 54960
       $$064$i = 255; //@line 54960
       break;
      }
     case 7:
      {
       $$062$i = 4; //@line 54964
       $$064$i = 3; //@line 54964
       break;
      }
     default:
      {
       label = 11; //@line 54968
       break L1;
      }
     }
     $17 = $11 << 24 >> 24; //@line 54972
     $$1$i = $$062$i; //@line 54976
     $$165$i = ($$064$i << $17 | -65536) ^ 65535; //@line 54976
     $$pre$phiZ2D = $17; //@line 54976
    }
    $20 = HEAP8[$0 + ($$01012 << 4) + 6 >> 0] | 0; //@line 54979
    $21 = $20 << 24 >> 24 == -1; //@line 54980
    $22 = $20 << 24 >> 24; //@line 54981
    $$phitmp67$i = $21 ? 65535 : 7 << $22 ^ 65535; //@line 54984
    $$$i = $21 ? 1 : 8; //@line 54985
    $24 = $$165$i & $$01012; //@line 54986
    $26 = _bitshift64Lshr($$lo | 0, $$hi1 & 16777215 | 0, 45) | 0; //@line 54988
    $28 = $26 & 1; //@line 54990
    $32 = 0 == 0 & ($$hi1 & 16384 | 0) == 0; //@line 54994
    $33 = ($28 | 0) == 0; //@line 54995
    $34 = ($28 | 0) == 0; //@line 54996
    $$06077$i = 0; //@line 54997
    $120 = $118; //@line 54997
    while (1) {
     $37 = ($$06077$i << $$pre$phiZ2D | $24) & $$phitmp67$i; //@line 55001
     if ($32) {
      $$05976$i$us = 0; //@line 55003
      $58 = $120; //@line 55003
      while (1) {
       $40 = ($$05976$i$us << $22 | $37) & 65535; //@line 55007
       $41 = $0 + ($40 << 4) + 9 | 0; //@line 55008
       $$lo6 = HEAPU8[$41 >> 0] | HEAPU8[$41 + 1 >> 0] << 8 | HEAPU8[$41 + 2 >> 0] << 16 | HEAPU8[$41 + 3 >> 0] << 24; //@line 55009
       $$hi7 = $41 + 4 | 0; //@line 55010
       $$hi9 = (HEAPU8[$$hi7 >> 0] | HEAPU8[$$hi7 + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi7 + 2 >> 0] << 16; //@line 55017
       $43 = $$hi9 ^ $$hi1; //@line 55019
       do {
        if ((($$lo6 ^ $$lo) & -1057030144 | 0) == 0 & 0 == 0) {
         $49 = _bitshift64Lshr($$lo6 | 0, $$hi9 & 16777215 | 0, 45) | 0; //@line 55027
         if (0 == 0 & ($43 & 16384 | 0) == 0 & ($49 & 1 | 0) == ($28 | 0)) {
          if (!$33) {
           if (!(0 == 0 & ($43 & 255 | 0) == 0 & $11 << 24 >> 24 == (HEAP8[$0 + ($40 << 4) + 7 >> 0] | 0))) {
            $67 = $58 + 1 | 0; //@line 55047
            HEAP32[162824] = $67; //@line 55048
            $121 = $67; //@line 55049
            break;
           }
          }
          if (($40 | 0) == ($$01012 | 0)) {
           $121 = $58; //@line 55055
          } else {
           HEAP32[$0 + ($40 << 4) >> 2] = $$01012; //@line 55058
           $121 = $58; //@line 55059
          }
         } else {
          label = 17; //@line 55062
         }
        } else {
         label = 17; //@line 55065
        }
       } while (0);
       if ((label | 0) == 17) {
        label = 0; //@line 55069
        $57 = $58 + 1 | 0; //@line 55070
        HEAP32[162824] = $57; //@line 55071
        $121 = $57; //@line 55072
       }
       $$05976$i$us = $$05976$i$us + 1 | 0; //@line 55074
       if (($$05976$i$us | 0) >= ($$$i | 0)) {
        $122 = $121; //@line 55079
        break;
       } else {
        $58 = $121; //@line 55077
       }
      }
     } else {
      $$05976$i = 0; //@line 55084
      $92 = $120; //@line 55084
      while (1) {
       $74 = ($$05976$i << $22 | $37) & 65535; //@line 55088
       $75 = $0 + ($74 << 4) + 9 | 0; //@line 55089
       $$lo15 = HEAPU8[$75 >> 0] | HEAPU8[$75 + 1 >> 0] << 8 | HEAPU8[$75 + 2 >> 0] << 16 | HEAPU8[$75 + 3 >> 0] << 24; //@line 55090
       $$hi16 = $75 + 4 | 0; //@line 55091
       $$hi18 = (HEAPU8[$$hi16 >> 0] | HEAPU8[$$hi16 + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi16 + 2 >> 0] << 16; //@line 55098
       $77 = $$hi18 ^ $$hi1; //@line 55100
       do {
        if ((($$lo15 ^ $$lo) & -1057030144 | 0) == 0 & 0 == 0) {
         $83 = _bitshift64Lshr($$lo15 | 0, $$hi18 & 16777215 | 0, 45) | 0; //@line 55108
         if (0 == 0 & ($77 & 16384 | 0) == 0 & ($83 & 1 | 0) == ($28 | 0)) {
          if (!$34) {
           if (!(0 == 0 & ($77 & 255 | 0) == 0 & $11 << 24 >> 24 == (HEAP8[$0 + ($74 << 4) + 7 >> 0] | 0))) {
            $101 = $92 + 1 | 0; //@line 55128
            HEAP32[162824] = $101; //@line 55129
            $123 = $101; //@line 55130
            break;
           }
          }
          if (!(0 == 0 & ($77 & 7936 | 0) == 0 & $20 << 24 >> 24 == (HEAP8[$0 + ($74 << 4) + 6 >> 0] | 0))) {
           $109 = $92 + 1 | 0; //@line 55143
           HEAP32[162824] = $109; //@line 55144
           $123 = $109; //@line 55145
           break;
          }
          if (($74 | 0) == ($$01012 | 0)) {
           $123 = $92; //@line 55150
          } else {
           HEAP32[$0 + ($74 << 4) >> 2] = $$01012; //@line 55153
           $123 = $92; //@line 55154
          }
         } else {
          label = 26; //@line 55157
         }
        } else {
         label = 26; //@line 55160
        }
       } while (0);
       if ((label | 0) == 26) {
        label = 0; //@line 55164
        $91 = $92 + 1 | 0; //@line 55165
        HEAP32[162824] = $91; //@line 55166
        $123 = $91; //@line 55167
       }
       $$05976$i = $$05976$i + 1 | 0; //@line 55169
       if (($$05976$i | 0) >= ($$$i | 0)) {
        $122 = $123; //@line 55174
        break;
       } else {
        $92 = $123; //@line 55172
       }
      }
     }
     $$06077$i = $$06077$i + 1 | 0; //@line 55179
     if (($$06077$i | 0) >= ($$1$i | 0)) {
      $$1 = $9; //@line 55184
      $119 = $122; //@line 55184
      break;
     } else {
      $120 = $122; //@line 55182
     }
    }
   }
  } else {
   $$1 = $$014; //@line 55190
   $119 = $118; //@line 55190
  }
  $$01012 = $$01012 + 1 | 0; //@line 55192
  if (($$01012 | 0) >= 65536) {
   label = 37; //@line 55197
   break;
  } else {
   $$014 = $$1; //@line 55195
   $118 = $119; //@line 55195
  }
 }
 if ((label | 0) == 11) {} else if ((label | 0) == 37) {
  HEAP32[162822] = $$1; //@line 55205
  return;
 }
}
function __Z11SonyControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$1 = 0, $$122$sink = 0, $$sroa$03$07$i = 0, $$sroa$03$09$i = 0, $10 = 0, $103 = 0, $112 = 0, $117 = 0, $120 = 0, $131 = 0, $136 = 0, $142 = 0, $146 = 0, $17 = 0, $18 = 0, $2 = 0, $20 = 0, $21 = 0, $27 = 0, $29 = 0, $3 = 0, $34 = 0, $38 = 0, $44 = 0, $45 = 0, $46 = 0, $50 = 0, $55 = 0, $62 = 0, $68 = 0, $78 = 0, $79 = 0, $81 = 0, $9 = 0, $90 = 0, $96 = 0, $trunc = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 17603
 STACKTOP = STACKTOP + 80 | 0; //@line 17604
 $vararg_buffer = sp; //@line 17605
 $2 = sp + 4 | 0; //@line 17606
 $3 = $0 + 26 | 0; //@line 17607
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 17613
 $10 = $9 & 65535; //@line 17614
 $trunc = $9 & 65535; //@line 17615
 switch ($trunc << 16 >> 16) {
 case 1:
  {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, -1); //@line 17621
   $$1 = -1; //@line 17622
   STACKTOP = sp; //@line 17623
   return $$1 | 0; //@line 17623
  }
 case 9:
  {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, 0); //@line 17630
   $$1 = 0; //@line 17631
   STACKTOP = sp; //@line 17632
   return $$1 | 0; //@line 17632
  }
 case 65:
  {
   $17 = HEAP32[28486] | 0; //@line 17636
   $18 = HEAP32[28485] | 0; //@line 17637
   if (($18 | 0) != ($17 | 0)) {
    $20 = $2 + 32 | 0; //@line 17640
    $$sroa$03$09$i = $18; //@line 17641
    do {
     $21 = $$sroa$03$09$i + 8 | 0; //@line 17643
     if (HEAP8[$21 >> 0] | 0) {
      HEAP32[$2 >> 2] = HEAP32[$$sroa$03$09$i >> 2]; //@line 17648
      HEAP32[$20 >> 2] = 7; //@line 17649
      _Execute68kTrap(-24529, $2); //@line 17650
      HEAP8[$21 >> 0] = 0; //@line 17651
     }
     $$sroa$03$09$i = $$sroa$03$09$i + 16 | 0; //@line 17653
    } while (($$sroa$03$09$i | 0) != ($17 | 0));
   }
   __Z17PatchAfterStartupv(); //@line 17662
   $27 = $1 + 4 | 0; //@line 17663
   $29 = 123608 + ($27 >>> 16 << 2) | 0; //@line 17665
   $34 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0) & -8193; //@line 17670
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $34); //@line 17674
   HEAP8[657352] = 1; //@line 17675
   $$1 = 0; //@line 17676
   STACKTOP = sp; //@line 17677
   return $$1 | 0; //@line 17677
  }
 default:
  {
   $38 = $0 + 22 | 0; //@line 17681
   $44 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($38 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($38) | 0; //@line 17687
   $45 = HEAP32[28486] | 0; //@line 17688
   $46 = HEAP32[28485] | 0; //@line 17689
   L3 : do {
    if (($46 | 0) == ($45 | 0)) {
     $$122$sink = -56; //@line 17693
    } else {
     $$sroa$03$07$i = $46; //@line 17695
     while (1) {
      if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($44 | 0)) {
       break;
      }
      $50 = $$sroa$03$07$i + 16 | 0; //@line 17702
      if (($50 | 0) == ($45 | 0)) {
       $$122$sink = -56; //@line 17705
       break L3;
      } else {
       $$sroa$03$07$i = $50; //@line 17708
      }
     }
     if (($$sroa$03$07$i | 0) == ($45 | 0)) {
      $$122$sink = -56; //@line 17713
     } else {
      L9 : do {
       if ($trunc << 16 >> 16 < 21) {
        switch ($trunc << 16 >> 16) {
        case 8:
         {
          $$122$sink = 0; //@line 17720
          break L3;
          break;
         }
        case 5:
         {
          $55 = (HEAP32[$$sroa$03$07$i + 12 >> 2] | 0) + 3 | 0; //@line 17727
          $62 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) == 0; //@line 17734
          $$122$sink = $62 ? -65 : 0; //@line 17736
          break L3;
          break;
         }
        case 6:
         {
          if (HEAP8[$$sroa$03$07$i + 9 >> 0] | 0) {
           $$122$sink = -44; //@line 17745
           break L3;
          }
          $68 = (HEAP32[$$sroa$03$07$i + 12 >> 2] | 0) + 3 | 0; //@line 17750
          if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($68 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($68) | 0)) {
           $$122$sink = -65; //@line 17759
           break L3;
          }
          $78 = __Z9SysFormatPv(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0) | 0; //@line 17764
          $$122$sink = $78 ? 0 : -20; //@line 17766
          break L3;
          break;
         }
        case 7:
         {
          $79 = $$sroa$03$07$i + 12 | 0; //@line 17771
          $81 = (HEAP32[$79 >> 2] | 0) + 3 | 0; //@line 17773
          if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($81 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($81) | 0)) {
           $$122$sink = 0; //@line 17782
           break L3;
          }
          $90 = (HEAP32[$79 >> 2] | 0) + 3 | 0; //@line 17786
          FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($90 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($90, 0); //@line 17792
          $$122$sink = 0; //@line 17793
          break L3;
          break;
         }
        default:
         {
          break L9;
         }
        }
       } else {
        if ($trunc << 16 >> 16 < 23) {
         switch ($trunc << 16 >> 16) {
         case 21:
          {
           $96 = $0 + 28 | 0; //@line 17806
           FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($96 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($96, HEAP32[28484] | 0); //@line 17813
           $$122$sink = 0; //@line 17814
           break L3;
           break;
          }
         case 22:
          {
           $103 = $0 + 28 | 0; //@line 17819
           FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($103 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($103, HEAP32[28483] | 0); //@line 17826
           $$122$sink = 0; //@line 17827
           break L3;
           break;
          }
         default:
          {
           break L9;
          }
         }
        }
        if ($trunc << 16 >> 16 < 21315) {
         switch ($trunc << 16 >> 16) {
         case 23:
          {
           break;
          }
         default:
          {
           break L9;
          }
         }
         $112 = $0 + 28 | 0; //@line 17848
         $117 = HEAP32[(HEAP32[123608 + ($112 >>> 16 << 2) >> 2] | 0) + 12 >> 2] | 0; //@line 17853
         if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == 1) {
          FUNCTION_TABLE_vii[$117 & 31]($112, 4); //@line 17855
          $$122$sink = 0; //@line 17856
          break L3;
         } else {
          FUNCTION_TABLE_vii[$117 & 31]($112, 260); //@line 17859
          $$122$sink = 0; //@line 17860
          break L3;
         }
        } else {
         switch ($trunc << 16 >> 16) {
         case 21315:
          {
           break;
          }
         default:
          {
           break L9;
          }
         }
         $120 = (HEAP32[$$sroa$03$07$i + 12 >> 2] | 0) + 3 | 0; //@line 17874
         if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($120 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($120) | 0)) {
          $$122$sink = -65; //@line 17883
          break L3;
         }
         if (HEAP8[$$sroa$03$07$i + 9 >> 0] | 0) {
          $$122$sink = -44; //@line 17890
          break L3;
         }
         $131 = $0 + 30 | 0; //@line 17893
         $136 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($131 >>> 16 << 2) >> 2] >> 2] & 127]($131) | 0; //@line 17898
         $142 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($136 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($136) | 0; //@line 17904
         $146 = (__Z9Sys_writePvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $142, 0, 1474560) | 0) == 1474560; //@line 17908
         $$122$sink = $146 ? 0 : -20; //@line 17910
         break L3;
        }
       }
      } while (0);
      HEAP32[$vararg_buffer >> 2] = $10; //@line 17915
      _printf(94205, $vararg_buffer) | 0; //@line 17916
      $$122$sink = -17; //@line 17917
     }
    }
   } while (0);
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, $$122$sink << 16 >> 16); //@line 17925
   $$1 = $$122$sink; //@line 17926
   STACKTOP = sp; //@line 17927
   return $$1 | 0; //@line 17927
  }
 }
 return 0; //@line 17930
}
function _fmod($0, $1) {
 $0 = +$0;
 $1 = +$1;
 var $$070 = 0.0, $$071$lcssa = 0, $$07194 = 0, $$073$lcssa = 0, $$073100 = 0, $$172$ph = 0, $$174 = 0, $$275$lcssa = 0, $$27586 = 0, $$376$lcssa = 0, $$37683 = 0, $$lcssa = 0, $101 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $110 = 0, $111 = 0, $116 = 0, $118 = 0, $12 = 0, $120 = 0, $123 = 0, $125 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $150 = 0, $153 = 0, $154 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $160 = 0, $18 = 0, $2 = 0, $20 = 0, $27 = 0.0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $41 = 0, $42 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $59 = 0, $6 = 0, $64 = 0, $65 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $82 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $97 = 0, $99 = 0, label = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 61568
 $2 = HEAP32[tempDoublePtr >> 2] | 0; //@line 61568
 $3 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 61569
 HEAPF64[tempDoublePtr >> 3] = $1; //@line 61570
 $4 = HEAP32[tempDoublePtr >> 2] | 0; //@line 61570
 $5 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 61571
 $6 = _bitshift64Lshr($2 | 0, $3 | 0, 52) | 0; //@line 61572
 $8 = $6 & 2047; //@line 61574
 $9 = _bitshift64Lshr($4 | 0, $5 | 0, 52) | 0; //@line 61575
 $11 = $9 & 2047; //@line 61577
 $12 = $3 & -2147483648; //@line 61578
 $13 = _bitshift64Shl($4 | 0, $5 | 0, 1) | 0; //@line 61579
 $14 = tempRet0; //@line 61580
 L1 : do {
  if (($13 | 0) == 0 & ($14 | 0) == 0) {
   label = 3; //@line 61586
  } else {
   $18 = ___DOUBLE_BITS_272($1) | 0; //@line 61588
   $20 = tempRet0 & 2147483647; //@line 61590
   if (($8 | 0) == 2047 | ($20 >>> 0 > 2146435072 | ($20 | 0) == 2146435072 & $18 >>> 0 > 0)) {
    label = 3; //@line 61599
   } else {
    $29 = _bitshift64Shl($2 | 0, $3 | 0, 1) | 0; //@line 61601
    $30 = tempRet0; //@line 61602
    if (!($30 >>> 0 > $14 >>> 0 | ($30 | 0) == ($14 | 0) & $29 >>> 0 > $13 >>> 0)) {
     return +(($29 | 0) == ($13 | 0) & ($30 | 0) == ($14 | 0) ? $0 * 0.0 : $0);
    }
    if (!$8) {
     $41 = _bitshift64Shl($2 | 0, $3 | 0, 12) | 0; //@line 61618
     $42 = tempRet0; //@line 61619
     if (($42 | 0) > -1 | ($42 | 0) == -1 & $41 >>> 0 > 4294967295) {
      $$073100 = 0; //@line 61626
      $49 = $41; //@line 61626
      $50 = $42; //@line 61626
      while (1) {
       $48 = $$073100 + -1 | 0; //@line 61628
       $49 = _bitshift64Shl($49 | 0, $50 | 0, 1) | 0; //@line 61629
       $50 = tempRet0; //@line 61630
       if (!(($50 | 0) > -1 | ($50 | 0) == -1 & $49 >>> 0 > 4294967295)) {
        $$073$lcssa = $48; //@line 61639
        break;
       } else {
        $$073100 = $48; //@line 61637
       }
      }
     } else {
      $$073$lcssa = 0; //@line 61644
     }
     $59 = _bitshift64Shl($2 | 0, $3 | 0, 1 - $$073$lcssa | 0) | 0; //@line 61647
     $$174 = $$073$lcssa; //@line 61649
     $87 = $59; //@line 61649
     $88 = tempRet0; //@line 61649
    } else {
     $$174 = $8; //@line 61653
     $87 = $2; //@line 61653
     $88 = $3 & 1048575 | 1048576; //@line 61653
    }
    if (!$11) {
     $64 = _bitshift64Shl($4 | 0, $5 | 0, 12) | 0; //@line 61657
     $65 = tempRet0; //@line 61658
     if (($65 | 0) > -1 | ($65 | 0) == -1 & $64 >>> 0 > 4294967295) {
      $$07194 = 0; //@line 61665
      $72 = $64; //@line 61665
      $73 = $65; //@line 61665
      while (1) {
       $71 = $$07194 + -1 | 0; //@line 61667
       $72 = _bitshift64Shl($72 | 0, $73 | 0, 1) | 0; //@line 61668
       $73 = tempRet0; //@line 61669
       if (!(($73 | 0) > -1 | ($73 | 0) == -1 & $72 >>> 0 > 4294967295)) {
        $$071$lcssa = $71; //@line 61678
        break;
       } else {
        $$07194 = $71; //@line 61676
       }
      }
     } else {
      $$071$lcssa = 0; //@line 61683
     }
     $82 = _bitshift64Shl($4 | 0, $5 | 0, 1 - $$071$lcssa | 0) | 0; //@line 61686
     $$172$ph = $$071$lcssa; //@line 61688
     $89 = $82; //@line 61688
     $90 = tempRet0; //@line 61688
    } else {
     $$172$ph = $11; //@line 61692
     $89 = $4; //@line 61692
     $90 = $5 & 1048575 | 1048576; //@line 61692
    }
    $91 = _i64Subtract($87 | 0, $88 | 0, $89 | 0, $90 | 0) | 0; //@line 61695
    $92 = tempRet0; //@line 61696
    $97 = ($92 | 0) > -1 | ($92 | 0) == -1 & $91 >>> 0 > 4294967295; //@line 61701
    L23 : do {
     if (($$174 | 0) > ($$172$ph | 0)) {
      $$27586 = $$174; //@line 61704
      $101 = $92; //@line 61704
      $156 = $97; //@line 61704
      $157 = $87; //@line 61704
      $158 = $88; //@line 61704
      $99 = $91; //@line 61704
      while (1) {
       if ($156) {
        if (($99 | 0) == 0 & ($101 | 0) == 0) {
         break;
        } else {
         $104 = $99; //@line 61713
         $105 = $101; //@line 61713
        }
       } else {
        $104 = $157; //@line 61716
        $105 = $158; //@line 61716
       }
       $106 = _bitshift64Shl($104 | 0, $105 | 0, 1) | 0; //@line 61718
       $107 = tempRet0; //@line 61719
       $108 = $$27586 + -1 | 0; //@line 61720
       $110 = _i64Subtract($106 | 0, $107 | 0, $89 | 0, $90 | 0) | 0; //@line 61722
       $111 = tempRet0; //@line 61723
       $116 = ($111 | 0) > -1 | ($111 | 0) == -1 & $110 >>> 0 > 4294967295; //@line 61728
       if (($108 | 0) > ($$172$ph | 0)) {
        $$27586 = $108; //@line 61730
        $101 = $111; //@line 61730
        $156 = $116; //@line 61730
        $157 = $106; //@line 61730
        $158 = $107; //@line 61730
        $99 = $110; //@line 61730
       } else {
        $$275$lcssa = $108; //@line 61732
        $$lcssa = $116; //@line 61732
        $118 = $110; //@line 61732
        $120 = $111; //@line 61732
        $159 = $106; //@line 61732
        $160 = $107; //@line 61732
        break L23;
       }
      }
      $$070 = $0 * 0.0; //@line 61737
      break L1;
     } else {
      $$275$lcssa = $$174; //@line 61740
      $$lcssa = $97; //@line 61740
      $118 = $91; //@line 61740
      $120 = $92; //@line 61740
      $159 = $87; //@line 61740
      $160 = $88; //@line 61740
     }
    } while (0);
    if ($$lcssa) {
     if (($118 | 0) == 0 & ($120 | 0) == 0) {
      $$070 = $0 * 0.0; //@line 61749
      break;
     } else {
      $123 = $120; //@line 61752
      $125 = $118; //@line 61752
     }
    } else {
     $123 = $160; //@line 61755
     $125 = $159; //@line 61755
    }
    if ($123 >>> 0 < 1048576 | ($123 | 0) == 1048576 & $125 >>> 0 < 0) {
     $$37683 = $$275$lcssa; //@line 61763
     $130 = $125; //@line 61763
     $131 = $123; //@line 61763
     while (1) {
      $132 = _bitshift64Shl($130 | 0, $131 | 0, 1) | 0; //@line 61765
      $133 = tempRet0; //@line 61766
      $134 = $$37683 + -1 | 0; //@line 61767
      if ($133 >>> 0 < 1048576 | ($133 | 0) == 1048576 & $132 >>> 0 < 0) {
       $$37683 = $134; //@line 61774
       $130 = $132; //@line 61774
       $131 = $133; //@line 61774
      } else {
       $$376$lcssa = $134; //@line 61776
       $141 = $132; //@line 61776
       $142 = $133; //@line 61776
       break;
      }
     }
    } else {
     $$376$lcssa = $$275$lcssa; //@line 61781
     $141 = $125; //@line 61781
     $142 = $123; //@line 61781
    }
    if (($$376$lcssa | 0) > 0) {
     $143 = _i64Add($141 | 0, $142 | 0, 0, -1048576) | 0; //@line 61785
     $144 = tempRet0; //@line 61786
     $145 = _bitshift64Shl($$376$lcssa | 0, 0, 52) | 0; //@line 61787
     $153 = $144 | tempRet0; //@line 61791
     $154 = $143 | $145; //@line 61791
    } else {
     $150 = _bitshift64Lshr($141 | 0, $142 | 0, 1 - $$376$lcssa | 0) | 0; //@line 61794
     $153 = tempRet0; //@line 61796
     $154 = $150; //@line 61796
    }
    HEAP32[tempDoublePtr >> 2] = $154; //@line 61799
    HEAP32[tempDoublePtr + 4 >> 2] = $153 | $12; //@line 61799
    $$070 = +HEAPF64[tempDoublePtr >> 3]; //@line 61800
   }
  }
 } while (0);
 if ((label | 0) == 3) {
  $27 = $0 * $1; //@line 61805
  $$070 = $27 / $27; //@line 61807
 }
 return +$$070;
}
function __ZN8tinyxml27XMLNode9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$0$lcssa$i = 0, $$019$lcssa$i = 0, $$019$lcssa$i3233 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $$026 = 0, $$030 = 0, $$1 = 0, $$228 = 0, $$3 = 0, $$sink43 = 0, $10 = 0, $105 = 0, $106 = 0, $112 = 0, $119 = 0, $15 = 0, $17 = 0, $22 = 0, $25 = 0, $3 = 0, $32 = 0, $33 = 0, $4 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $54 = 0, $6 = 0, $63 = 0, $7 = 0, $70 = 0, $71 = 0, $73 = 0, $75 = 0, $77 = 0, $8 = 0, $80 = 0, $83 = 0, $84 = 0, $89 = 0, $9 = 0, $93 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 36191
 STACKTOP = STACKTOP + 16 | 0; //@line 36192
 $3 = sp + 12 | 0; //@line 36193
 $4 = sp; //@line 36194
 $5 = $0 + 4 | 0; //@line 36195
 $6 = $4 + 4 | 0; //@line 36196
 $7 = $4 + 8 | 0; //@line 36197
 $8 = $0 + 28 | 0; //@line 36198
 $9 = $0 + 24 | 0; //@line 36199
 $10 = ($2 | 0) == 0; //@line 36200
 $$0 = 0; //@line 36201
 $$026 = $1; //@line 36201
 L1 : while (1) {
  if (!$$026) {
   $$3 = 0; //@line 36205
   label = 32; //@line 36206
   break;
  }
  if (!(HEAP8[$$026 >> 0] | 0)) {
   $$3 = 0; //@line 36212
   label = 32; //@line 36213
   break;
  }
  HEAP32[$3 >> 2] = 0; //@line 36216
  $15 = __ZN8tinyxml211XMLDocument8IdentifyEPcPPNS_7XMLNodeE(HEAP32[$5 >> 2] | 0, $$026, $3) | 0; //@line 36218
  $17 = HEAP32[$3 >> 2] | 0; //@line 36220
  if (($15 | 0) == 0 | ($17 | 0) == 0) {
   label = 5; //@line 36224
   break;
  }
  HEAP32[$4 >> 2] = 0; //@line 36227
  HEAP32[$6 >> 2] = 0; //@line 36228
  HEAP32[$7 >> 2] = 0; //@line 36229
  $22 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[$17 >> 2] | 0) + 60 >> 2] & 15]($17, $15, $4) | 0; //@line 36233
  L6 : do {
   if (!$22) {
    $25 = HEAP32[$17 + 40 >> 2] | 0; //@line 36238
    FUNCTION_TABLE_vi[HEAP32[(HEAP32[$17 >> 2] | 0) + 64 >> 2] & 4095]($17); //@line 36242
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($25, $17); //@line 36246
    HEAP32[$3 >> 2] = 0; //@line 36247
    $32 = HEAP32[$5 >> 2] | 0; //@line 36248
    $33 = $32 + 48 | 0; //@line 36249
    if (!(HEAP32[$33 >> 2] | 0)) {
     HEAP32[$33 >> 2] = 17; //@line 36253
     HEAP32[$32 + 56 >> 2] = 0; //@line 36255
     HEAP32[$32 + 60 >> 2] = 0; //@line 36257
     $$030 = 3; //@line 36258
     $$1 = $$0; //@line 36258
     $$228 = 0; //@line 36258
    } else {
     $$030 = 3; //@line 36260
     $$1 = $$0; //@line 36260
     $$228 = 0; //@line 36260
    }
   } else {
    if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$17 >> 2] >> 2] & 127]($17) | 0) {
     if ((HEAP32[(FUNCTION_TABLE_ii[HEAP32[HEAP32[$17 >> 2] >> 2] & 127]($17) | 0) + 44 >> 2] | 0) == 2) {
      if (!$10) {
       $48 = $17 + 12 | 0; //@line 36276
       HEAP32[$2 >> 2] = HEAP32[$48 >> 2]; //@line 36277
       HEAP32[$2 + 4 >> 2] = HEAP32[$48 + 4 >> 2]; //@line 36277
       HEAP32[$2 + 8 >> 2] = HEAP32[$48 + 8 >> 2]; //@line 36277
      }
      $49 = $17 + 40 | 0; //@line 36279
      $50 = HEAP32[$49 >> 2] | 0; //@line 36280
      FUNCTION_TABLE_vi[HEAP32[(HEAP32[$50 >> 2] | 0) + 20 >> 2] & 4095]($50); //@line 36284
      $54 = HEAP32[$49 >> 2] | 0; //@line 36285
      FUNCTION_TABLE_vi[HEAP32[(HEAP32[$17 >> 2] | 0) + 64 >> 2] & 4095]($17); //@line 36289
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$54 >> 2] | 0) + 16 >> 2] & 31]($54, $17); //@line 36293
      $$030 = 1; //@line 36294
      $$1 = $22; //@line 36294
      $$228 = $22; //@line 36294
      break;
     }
    }
    $63 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$17 >> 2] >> 2] & 127]($17) | 0; //@line 36300
    L17 : do {
     if ($63 | 0) {
      $70 = (HEAP32[$63 + 44 >> 2] | 0) == 0; //@line 36309
      do {
       if ((HEAP32[$6 >> 2] | 0) == (HEAP32[$7 >> 2] | 0)) {
        if (!$70) {
         break L17;
        }
       } else {
        if ($70) {
         $71 = __ZN8tinyxml27StrPair6GetStrEv($4) | 0; //@line 36317
         $73 = __ZN8tinyxml27StrPair6GetStrEv($17 + 12 | 0) | 0; //@line 36319
         if (($71 | 0) == ($73 | 0)) {
          break L17;
         }
         $75 = HEAP8[$71 >> 0] | 0; //@line 36324
         if (!($75 << 24 >> 24)) {
          $$019$lcssa$i3233 = $73; //@line 36327
         } else {
          $$01923$i = $73; //@line 36329
          $$02022$i = $71; //@line 36329
          $$024$i = 0; //@line 36329
          $80 = $75; //@line 36329
          while (1) {
           $77 = HEAP8[$$01923$i >> 0] | 0; //@line 36331
           if (!(($$024$i | 0) != 2147483647 & ($77 << 24 >> 24 ? $80 << 24 >> 24 == $77 << 24 >> 24 : 0))) {
            $$0$lcssa$i = $$024$i; //@line 36338
            $$019$lcssa$i = $$01923$i; //@line 36338
            $89 = $80; //@line 36338
            break;
           }
           $$02022$i = $$02022$i + 1 | 0; //@line 36341
           $83 = $$01923$i + 1 | 0; //@line 36342
           $84 = $$024$i + 1 | 0; //@line 36343
           $80 = HEAP8[$$02022$i >> 0] | 0; //@line 36344
           if (!($80 << 24 >> 24)) {
            $$0$lcssa$i = $84; //@line 36347
            $$019$lcssa$i = $83; //@line 36347
            $89 = 0; //@line 36347
            break;
           } else {
            $$01923$i = $83; //@line 36350
            $$024$i = $84; //@line 36350
           }
          }
          if (($$0$lcssa$i | 0) == 2147483647) {
           break L17;
          }
          if (!($89 << 24 >> 24)) {
           $$019$lcssa$i3233 = $$019$lcssa$i; //@line 36359
          } else {
           break;
          }
         }
         if (!(HEAP8[$$019$lcssa$i3233 >> 0] | 0)) {
          break L17;
         }
        }
       }
      } while (0);
      $$sink43 = HEAP32[$5 >> 2] | 0; //@line 36372
      $93 = __ZN8tinyxml27StrPair6GetStrEv($17 + 12 | 0) | 0; //@line 36374
      HEAP32[$$sink43 + 48 >> 2] = 16; //@line 36376
      HEAP32[$$sink43 + 56 >> 2] = $93; //@line 36378
      HEAP32[$$sink43 + 60 >> 2] = 0; //@line 36380
      $98 = HEAP32[$17 + 40 >> 2] | 0; //@line 36382
      FUNCTION_TABLE_vi[HEAP32[(HEAP32[$17 >> 2] | 0) + 64 >> 2] & 4095]($17); //@line 36386
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$98 >> 2] | 0) + 16 >> 2] & 31]($98, $17); //@line 36390
      HEAP32[$3 >> 2] = 0; //@line 36391
      $$030 = 0; //@line 36392
      $$1 = $$0; //@line 36392
      $$228 = 0; //@line 36392
      break L6;
     }
    } while (0);
    $105 = HEAP32[$8 >> 2] | 0; //@line 36396
    $106 = ($105 | 0) == 0; //@line 36397
    HEAP32[($106 ? $8 : $105 + 36 | 0) >> 2] = $17; //@line 36401
    HEAP32[($106 ? $9 : $8) >> 2] = $17; //@line 36402
    HEAP32[$17 + 32 >> 2] = $105; //@line 36404
    HEAP32[$17 + 36 >> 2] = 0; //@line 36406
    HEAP32[$17 + 8 >> 2] = $0; //@line 36408
    $112 = HEAP32[$17 + 40 >> 2] | 0; //@line 36410
    FUNCTION_TABLE_vi[HEAP32[(HEAP32[$112 >> 2] | 0) + 20 >> 2] & 4095]($112); //@line 36414
    $$030 = 0; //@line 36415
    $$1 = $$0; //@line 36415
    $$228 = $22; //@line 36415
   }
  } while (0);
  if (HEAP32[$4 >> 2] & 512 | 0) {
   $119 = HEAP32[$6 >> 2] | 0; //@line 36422
   if ($119 | 0) {
    __ZdaPv($119); //@line 36425
   }
  }
  switch ($$030 & 3) {
  case 0:
   {
    $$0 = $$1; //@line 36431
    $$026 = $$228; //@line 36431
    break;
   }
  case 1:
   {
    label = 31; //@line 36435
    break L1;
    break;
   }
  case 3:
   {
    $$3 = 0; //@line 36440
    label = 32; //@line 36441
    break L1;
    break;
   }
  default:
   {
    label = 33; //@line 36446
    break L1;
   }
  }
 }
 if ((label | 0) == 5) {
  $$3 = 0; //@line 36452
  STACKTOP = sp; //@line 36453
  return $$3 | 0; //@line 36453
 } else if ((label | 0) == 31) {
  $$3 = $$1; //@line 36456
  STACKTOP = sp; //@line 36457
  return $$3 | 0; //@line 36457
 } else if ((label | 0) == 32) {
  STACKTOP = sp; //@line 36460
  return $$3 | 0; //@line 36460
 } else if ((label | 0) == 33) {}
 return 0; //@line 36465
}
function __Z12ADBInterruptv() {
 var $$pre101 = 0, $0 = 0, $10 = 0, $11 = 0, $12 = 0, $121 = 0, $13 = 0, $137 = 0, $138 = 0, $14 = 0, $145 = 0, $15 = 0, $152 = 0, $159 = 0, $16 = 0, $166 = 0, $178 = 0, $180 = 0, $192 = 0, $195 = 0, $197 = 0, $198 = 0, $200 = 0, $201 = 0, $203 = 0, $204 = 0, $205 = 0, $207 = 0, $208 = 0, $209 = 0, $211 = 0, $212 = 0, $244 = 0, $3 = 0, $33 = 0, $34 = 0, $4 = 0, $43 = 0, $5 = 0, $52 = 0, $6 = 0, $65 = 0, $74 = 0, $88 = 0, $9 = 0, $90 = 0, sp = 0;
 sp = STACKTOP; //@line 14214
 STACKTOP = STACKTOP + 80 | 0; //@line 14215
 $0 = sp; //@line 14216
 $3 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3320) | 0; //@line 14219
 switch ($3 | 0) {
 case 0:
 case -1:
  {
   STACKTOP = sp; //@line 14222
   return;
  }
 default:
  {}
 }
 $4 = $3 + 355 | 0; //@line 14228
 $5 = HEAP32[28469] | 0; //@line 14229
 $6 = HEAP32[28470] | 0; //@line 14230
 if (HEAP8[657321] | 0) {
  HEAP32[28470] = 0; //@line 14234
  HEAP32[28469] = 0; //@line 14235
 }
 $9 = HEAP8[657322] | 0; //@line 14237
 $10 = $9 << 24 >> 24 != 0; //@line 14238
 $11 = HEAP8[657323] | 0; //@line 14239
 $12 = $11 << 24 >> 24 != 0; //@line 14240
 $13 = HEAP8[657324] | 0; //@line 14241
 $14 = $13 << 24 >> 24 != 0; //@line 14242
 $15 = $3 + 4 | 0; //@line 14243
 $16 = $3 + 16 | 0; //@line 14244
 if (!(HEAP8[657321] | 0)) {
  if (!(($5 | 0) == (HEAP32[28472] | 0) & ($6 | 0) == (HEAP32[28473] | 0))) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](2090, $5); //@line 14257
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](2088, $6); //@line 14261
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](2094, $5); //@line 14265
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](2092, $6); //@line 14269
   $121 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[30902] | 0) + 8 >> 2] & 127](2255) | 0; //@line 14273
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 20 >> 2] & 31](2254, $121); //@line 14277
   HEAP32[28472] = $5; //@line 14278
   HEAP32[28473] = $6; //@line 14279
  }
  if (!(($9 << 24 >> 24 == (HEAP8[657341] | 0) ? $11 << 24 >> 24 == (HEAP8[657342] | 0) : 0) & $13 << 24 >> 24 == (HEAP8[657343] | 0))) {
   $137 = HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 20 >> 2] | 0; //@line 14296
   if ((HEAP8[93413] | 0) == 4) {
    FUNCTION_TABLE_vii[$137 & 31]($4, 3); //@line 14298
    $138 = $3 + 356 | 0; //@line 14299
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($138 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($138, $10 ? 0 : 128); //@line 14306
    $145 = $3 + 357 | 0; //@line 14307
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($145 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($145, $12 ? 0 : 128); //@line 14314
    $152 = $3 + 358 | 0; //@line 14315
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($152 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($152, $14 ? 8 : 136); //@line 14322
   } else {
    FUNCTION_TABLE_vii[$137 & 31]($4, 2); //@line 14324
    $159 = $3 + 356 | 0; //@line 14325
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($159 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($159, $10 ? 0 : 128); //@line 14332
    $166 = $3 + 357 | 0; //@line 14333
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($166 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($166, $12 ? 0 : 128); //@line 14340
   }
   HEAP32[$0 + 32 >> 2] = $4; //@line 14343
   $178 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 14348
   HEAP32[$0 + 36 >> 2] = $178; //@line 14350
   $180 = $3 + 20 | 0; //@line 14351
   HEAP32[$0 + 40 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($180 >>> 16 << 2) >> 2] >> 2] & 127]($180) | 0; //@line 14358
   HEAP32[$0 + 44 >> 2] = $3; //@line 14360
   HEAP32[$0 >> 2] = HEAPU8[93412] << 4 | 12; //@line 14365
   _Execute68k($178, $0); //@line 14366
   HEAP8[657341] = $9; //@line 14367
   HEAP8[657342] = $11; //@line 14368
   HEAP8[657343] = $13; //@line 14369
  }
 } else {
  if (!((($6 | $5 | 0) == 0 ? $9 << 24 >> 24 == (HEAP8[657341] | 0) : 0) & $11 << 24 >> 24 == (HEAP8[657342] | 0) & $13 << 24 >> 24 == (HEAP8[657343] | 0))) {
   $33 = HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 20 >> 2] | 0; //@line 14390
   if ((HEAP8[93413] | 0) == 4) {
    FUNCTION_TABLE_vii[$33 & 31]($4, 3); //@line 14392
    $34 = $3 + 356 | 0; //@line 14393
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, ($10 ? 0 : 128) | $6 & 127); //@line 14402
    $43 = $3 + 357 | 0; //@line 14403
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($43 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($43, ($12 ? 0 : 128) | $5 & 127); //@line 14412
    $52 = $3 + 358 | 0; //@line 14413
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($52 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($52, $6 >>> 3 & 112 | $5 >>> 7 & 7 | ($14 ? 8 : 136)); //@line 14426
   } else {
    FUNCTION_TABLE_vii[$33 & 31]($4, 2); //@line 14428
    $65 = $3 + 356 | 0; //@line 14429
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($65 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($65, ($10 ? 0 : 128) | $6 & 127); //@line 14438
    $74 = $3 + 357 | 0; //@line 14439
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($74 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($74, ($12 ? 0 : 128) | $5 & 127); //@line 14448
   }
   HEAP32[$0 + 32 >> 2] = $4; //@line 14451
   $88 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 14456
   HEAP32[$0 + 36 >> 2] = $88; //@line 14458
   $90 = $3 + 20 | 0; //@line 14459
   HEAP32[$0 + 40 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($90 >>> 16 << 2) >> 2] >> 2] & 127]($90) | 0; //@line 14466
   HEAP32[$0 + 44 >> 2] = $3; //@line 14468
   HEAP32[$0 >> 2] = HEAPU8[93412] << 4 | 12; //@line 14473
   _Execute68k($88, $0); //@line 14474
   HEAP8[657341] = $9; //@line 14475
   HEAP8[657342] = $11; //@line 14476
   HEAP8[657343] = $13; //@line 14477
  }
 }
 $192 = HEAP32[28474] | 0; //@line 14480
 $$pre101 = 123608 + ($4 >>> 16 << 2) | 0; //@line 14484
 if (($192 | 0) != (HEAP32[28471] | 0)) {
  $195 = $3 + 356 | 0; //@line 14486
  $197 = 123608 + ($195 >>> 16 << 2) | 0; //@line 14488
  $198 = $3 + 357 | 0; //@line 14489
  $200 = 123608 + ($198 >>> 16 << 2) | 0; //@line 14491
  $201 = $0 + 32 | 0; //@line 14492
  $203 = 123608 + ($15 >>> 16 << 2) | 0; //@line 14494
  $204 = $0 + 36 | 0; //@line 14495
  $205 = $3 + 8 | 0; //@line 14496
  $207 = 123608 + ($205 >>> 16 << 2) | 0; //@line 14498
  $208 = $0 + 40 | 0; //@line 14499
  $209 = $0 + 44 | 0; //@line 14500
  $211 = $192; //@line 14501
  do {
   $212 = HEAP8[657325 + $211 >> 0] | 0; //@line 14504
   HEAP32[28474] = $211 + 1 & 15; //@line 14507
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$$pre101 >> 2] | 0) + 20 >> 2] & 31]($4, 2); //@line 14511
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$197 >> 2] | 0) + 20 >> 2] & 31]($195, $212 & 255); //@line 14516
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$200 >> 2] | 0) + 20 >> 2] & 31]($198, $212 << 24 >> 24 == 127 ? 127 : 255); //@line 14522
   HEAP32[$201 >> 2] = $4; //@line 14523
   HEAP32[$204 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[$203 >> 2] >> 2] & 127]($15) | 0; //@line 14527
   HEAP32[$208 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[$207 >> 2] >> 2] & 127]($205) | 0; //@line 14531
   HEAP32[$209 >> 2] = $3; //@line 14532
   HEAP32[$0 >> 2] = HEAPU8[93415] << 4 | 12; //@line 14537
   _Execute68k(HEAP32[$204 >> 2] | 0, $0); //@line 14539
   $211 = HEAP32[28474] | 0; //@line 14540
  } while (($211 | 0) != (HEAP32[28471] | 0));
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$$pre101 >> 2] | 0) + 12 >> 2] & 31]($4, 0); //@line 14553
 $244 = $3 + 359 | 0; //@line 14554
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($244 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($244, 0); //@line 14560
 STACKTOP = sp; //@line 14561
 return;
}
function __Z11DiskControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$1 = 0, $$sroa$03$012$i = 0, $$sroa$03$07$i = 0, $10 = 0, $106 = 0, $11 = 0, $112 = 0, $12 = 0, $121 = 0, $128 = 0, $129 = 0, $134 = 0, $137 = 0, $14 = 0, $145 = 0, $17 = 0, $2 = 0, $25 = 0, $29 = 0, $3 = 0, $35 = 0, $37 = 0, $42 = 0, $46 = 0, $52 = 0, $53 = 0, $54 = 0, $58 = 0, $63 = 0, $70 = 0, $76 = 0, $83 = 0, $84 = 0, $86 = 0, $9 = 0, $97 = 0, $trunc = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 18919
 STACKTOP = STACKTOP + 80 | 0; //@line 18920
 $vararg_buffer = sp; //@line 18921
 $2 = sp + 4 | 0; //@line 18922
 $3 = $0 + 26 | 0; //@line 18923
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 18929
 $10 = $9 & 65535; //@line 18930
 $trunc = $9 & 65535; //@line 18931
 switch ($trunc << 16 >> 16) {
 case 65:
  {
   $11 = HEAP32[28490] | 0; //@line 18934
   $12 = HEAP32[28489] | 0; //@line 18935
   if (($12 | 0) != ($11 | 0)) {
    $14 = $2 + 32 | 0; //@line 18938
    $$sroa$03$012$i = $12; //@line 18939
    do {
     $17 = (HEAP32[$$sroa$03$012$i + 20 >> 2] | 0) + 3 | 0; //@line 18943
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0)) {
      $25 = $$sroa$03$012$i + 4 | 0; //@line 18952
      if (__Z17SysIsDiskInsertedPv(HEAP32[$25 >> 2] | 0) | 0) {
       __Z15DiskMountVolumePv(HEAP32[$25 >> 2] | 0) | 0; //@line 18957
      }
     }
     $29 = $$sroa$03$012$i + 16 | 0; //@line 18960
     if (HEAP8[$29 >> 0] | 0) {
      HEAP32[$2 >> 2] = HEAP32[$$sroa$03$012$i >> 2]; //@line 18965
      HEAP32[$14 >> 2] = 7; //@line 18966
      _Execute68kTrap(-24529, $2); //@line 18967
      HEAP8[$29 >> 0] = 0; //@line 18968
     }
     $$sroa$03$012$i = $$sroa$03$012$i + 24 | 0; //@line 18970
    } while (($$sroa$03$012$i | 0) != ($11 | 0));
   }
   $35 = $1 + 4 | 0; //@line 18979
   $37 = 123608 + ($35 >>> 16 << 2) | 0; //@line 18981
   $42 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$37 >> 2] | 0) + 4 >> 2] & 127]($35) | 0) & -8193; //@line 18986
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$37 >> 2] | 0) + 16 >> 2] & 31]($35, $42); //@line 18990
   HEAP8[657353] = 1; //@line 18991
   $$1 = 0; //@line 18992
   STACKTOP = sp; //@line 18993
   return $$1 | 0; //@line 18993
  }
 case 1:
  {
   $$1 = 0; //@line 18997
   STACKTOP = sp; //@line 18998
   return $$1 | 0; //@line 18998
  }
 default:
  {
   $46 = $0 + 22 | 0; //@line 19002
   $52 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($46) | 0; //@line 19008
   $53 = HEAP32[28490] | 0; //@line 19009
   $54 = HEAP32[28489] | 0; //@line 19010
   if (($54 | 0) == ($53 | 0)) {
    $$1 = -56; //@line 19013
    STACKTOP = sp; //@line 19014
    return $$1 | 0; //@line 19014
   } else {
    $$sroa$03$07$i = $54; //@line 19016
   }
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($52 | 0)) {
     break;
    }
    $58 = $$sroa$03$07$i + 24 | 0; //@line 19024
    if (($58 | 0) == ($53 | 0)) {
     $$1 = -56; //@line 19027
     label = 30; //@line 19028
     break;
    } else {
     $$sroa$03$07$i = $58; //@line 19031
    }
   }
   if ((label | 0) == 30) {
    STACKTOP = sp; //@line 19035
    return $$1 | 0; //@line 19035
   }
   if (($$sroa$03$07$i | 0) == ($53 | 0)) {
    $$1 = -56; //@line 19039
    STACKTOP = sp; //@line 19040
    return $$1 | 0; //@line 19040
   }
   switch ($trunc << 16 >> 16) {
   case 5:
    {
     $63 = (HEAP32[$$sroa$03$07$i + 20 >> 2] | 0) + 3 | 0; //@line 19046
     $70 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($63 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($63) | 0) == 0; //@line 19053
     $$1 = $70 ? -65 : 0; //@line 19055
     STACKTOP = sp; //@line 19056
     return $$1 | 0; //@line 19056
    }
   case 6:
    {
     if (HEAP8[$$sroa$03$07$i + 17 >> 0] | 0) {
      $$1 = -44; //@line 19064
      STACKTOP = sp; //@line 19065
      return $$1 | 0; //@line 19065
     }
     $76 = (HEAP32[$$sroa$03$07$i + 20 >> 2] | 0) + 3 | 0; //@line 19069
     $83 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($76 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($76) | 0) == 0; //@line 19076
     $$1 = $83 ? -65 : 0; //@line 19078
     STACKTOP = sp; //@line 19079
     return $$1 | 0; //@line 19079
    }
   case 7:
    {
     $84 = $$sroa$03$07$i + 20 | 0; //@line 19083
     $86 = (HEAP32[$84 >> 2] | 0) + 3 | 0; //@line 19085
     if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($86 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($86) | 0) == 8) {
      HEAP32[$2 >> 2] = HEAP32[$$sroa$03$07$i >> 2]; //@line 19095
      HEAP32[$2 + 32 >> 2] = 7; //@line 19097
      _Execute68kTrap(-24529, $2); //@line 19098
      $$1 = 0; //@line 19099
      STACKTOP = sp; //@line 19100
      return $$1 | 0; //@line 19100
     }
     $97 = (HEAP32[$84 >> 2] | 0) + 3 | 0; //@line 19103
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($97 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($97) | 0)) {
      $$1 = 0; //@line 19112
      STACKTOP = sp; //@line 19113
      return $$1 | 0; //@line 19113
     }
     $106 = (HEAP32[$84 >> 2] | 0) + 3 | 0; //@line 19116
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($106 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($106, 0); //@line 19122
     $$1 = 0; //@line 19123
     STACKTOP = sp; //@line 19124
     return $$1 | 0; //@line 19124
    }
   case 22:
   case 21:
    {
     $112 = $0 + 28 | 0; //@line 19128
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($112 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($112, HEAP32[28488] | 0); //@line 19135
     $$1 = 0; //@line 19136
     STACKTOP = sp; //@line 19137
     return $$1 | 0; //@line 19137
    }
   case 23:
    {
     $121 = (HEAP32[$$sroa$03$07$i + 20 >> 2] | 0) + 3 | 0; //@line 19143
     $128 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($121 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($121) | 0) == 8; //@line 19150
     $129 = $0 + 28 | 0; //@line 19151
     $134 = HEAP32[(HEAP32[123608 + ($129 >>> 16 << 2) >> 2] | 0) + 12 >> 2] | 0; //@line 19156
     if ($128) {
      FUNCTION_TABLE_vii[$134 & 31]($129, 1537); //@line 19158
      $$1 = 0; //@line 19159
      STACKTOP = sp; //@line 19160
      return $$1 | 0; //@line 19160
     } else {
      FUNCTION_TABLE_vii[$134 & 31]($129, 513); //@line 19162
      $$1 = 0; //@line 19163
      STACKTOP = sp; //@line 19164
      return $$1 | 0; //@line 19164
     }
     break;
    }
   case 24:
    {
     $137 = (HEAP32[$$sroa$03$07$i + 20 >> 2] | 0) + 3 | 0; //@line 19171
     if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($137 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($137) | 0)) {
      $$1 = -65; //@line 19180
      STACKTOP = sp; //@line 19181
      return $$1 | 0; //@line 19181
     }
     $145 = $0 + 28 | 0; //@line 19183
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($145 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($145, HEAP32[$$sroa$03$07$i + 12 >> 2] | 0); //@line 19191
     $$1 = 0; //@line 19192
     STACKTOP = sp; //@line 19193
     return $$1 | 0; //@line 19193
    }
   default:
    {
     HEAP32[$vararg_buffer >> 2] = $10; //@line 19197
     _printf(94535, $vararg_buffer) | 0; //@line 19198
     $$1 = -17; //@line 19199
     STACKTOP = sp; //@line 19200
     return $$1 | 0; //@line 19200
    }
   }
  }
 }
 return 0; //@line 19205
}
function __Z12VideoRefreshv() {
 var $$0$i$i$i = 0, $10 = 0, $13 = 0, $19 = 0, $20 = 0, $26 = 0, $4 = 0, $9 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 46095
 STACKTOP = STACKTOP + 16 | 0; //@line 46096
 $vararg_buffer = sp; //@line 46097
 if (!(HEAP8[659472] | 0)) {
  STACKTOP = sp; //@line 46101
  return;
 }
 if (_emscripten_asm_const_i(2) | 0) {
  $4 = _emscripten_asm_const_i(3) | 0; //@line 46106
  do {
   if (($4 | 0) > -1) {
    if (!$4) {
     __Z10ADBMouseUpi(0); //@line 46112
     break;
    } else {
     __Z12ADBMouseDowni(0); //@line 46115
     break;
    }
   }
  } while (0);
  if (_emscripten_asm_const_i(4) | 0) {
   $9 = _emscripten_asm_const_i(5) | 0; //@line 46123
   $10 = _emscripten_asm_const_i(6) | 0; //@line 46124
   if (($9 | 0) > 0 & ($10 | 0) > 0) {
    $13 = HEAP32[30855] | 0; //@line 46129
    FUNCTION_TABLE_viii[HEAP32[(HEAP32[$13 >> 2] | 0) + 24 >> 2] & 7]($13, $9, $10); //@line 46133
   }
  }
  do {
   if (_emscripten_asm_const_i(7) | 0) {
    $19 = _emscripten_asm_const_i(8) | 0; //@line 46140
    $20 = _emscripten_asm_const_i(9) | 0; //@line 46141
    do {
     switch ($19 | 0) {
     case 65:
      {
       $$0$i$i$i = 0; //@line 46145
       break;
      }
     case 66:
      {
       $$0$i$i$i = 11; //@line 46149
       break;
      }
     case 67:
      {
       $$0$i$i$i = 8; //@line 46153
       break;
      }
     case 68:
      {
       $$0$i$i$i = 2; //@line 46157
       break;
      }
     case 69:
      {
       $$0$i$i$i = 14; //@line 46161
       break;
      }
     case 70:
      {
       $$0$i$i$i = 3; //@line 46165
       break;
      }
     case 71:
      {
       $$0$i$i$i = 5; //@line 46169
       break;
      }
     case 72:
      {
       $$0$i$i$i = 4; //@line 46173
       break;
      }
     case 73:
      {
       $$0$i$i$i = 34; //@line 46177
       break;
      }
     case 74:
      {
       $$0$i$i$i = 38; //@line 46181
       break;
      }
     case 75:
      {
       $$0$i$i$i = 40; //@line 46185
       break;
      }
     case 76:
      {
       $$0$i$i$i = 37; //@line 46189
       break;
      }
     case 77:
      {
       $$0$i$i$i = 46; //@line 46193
       break;
      }
     case 78:
      {
       $$0$i$i$i = 45; //@line 46197
       break;
      }
     case 79:
      {
       $$0$i$i$i = 31; //@line 46201
       break;
      }
     case 80:
      {
       $$0$i$i$i = 35; //@line 46205
       break;
      }
     case 81:
      {
       $$0$i$i$i = 12; //@line 46209
       break;
      }
     case 82:
      {
       $$0$i$i$i = 15; //@line 46213
       break;
      }
     case 83:
      {
       $$0$i$i$i = 1; //@line 46217
       break;
      }
     case 84:
      {
       $$0$i$i$i = 17; //@line 46221
       break;
      }
     case 85:
      {
       $$0$i$i$i = 32; //@line 46225
       break;
      }
     case 86:
      {
       $$0$i$i$i = 9; //@line 46229
       break;
      }
     case 87:
      {
       $$0$i$i$i = 13; //@line 46233
       break;
      }
     case 88:
      {
       $$0$i$i$i = 7; //@line 46237
       break;
      }
     case 89:
      {
       $$0$i$i$i = 16; //@line 46241
       break;
      }
     case 90:
      {
       $$0$i$i$i = 6; //@line 46245
       break;
      }
     case 49:
      {
       $$0$i$i$i = 18; //@line 46249
       break;
      }
     case 50:
      {
       $$0$i$i$i = 19; //@line 46253
       break;
      }
     case 51:
      {
       $$0$i$i$i = 20; //@line 46257
       break;
      }
     case 52:
      {
       $$0$i$i$i = 21; //@line 46261
       break;
      }
     case 53:
      {
       $$0$i$i$i = 23; //@line 46265
       break;
      }
     case 54:
      {
       $$0$i$i$i = 22; //@line 46269
       break;
      }
     case 55:
      {
       $$0$i$i$i = 26; //@line 46273
       break;
      }
     case 56:
      {
       $$0$i$i$i = 28; //@line 46277
       break;
      }
     case 57:
      {
       $$0$i$i$i = 25; //@line 46281
       break;
      }
     case 48:
      {
       $$0$i$i$i = 29; //@line 46285
       break;
      }
     case 192:
      {
       $$0$i$i$i = 10; //@line 46289
       break;
      }
     case 189:
      {
       $$0$i$i$i = 27; //@line 46293
       break;
      }
     case 187:
      {
       $$0$i$i$i = 24; //@line 46297
       break;
      }
     case 219:
      {
       $$0$i$i$i = 33; //@line 46301
       break;
      }
     case 221:
      {
       $$0$i$i$i = 30; //@line 46305
       break;
      }
     case 220:
      {
       $$0$i$i$i = 42; //@line 46309
       break;
      }
     case 186:
      {
       $$0$i$i$i = 41; //@line 46313
       break;
      }
     case 222:
      {
       $$0$i$i$i = 39; //@line 46317
       break;
      }
     case 188:
      {
       $$0$i$i$i = 43; //@line 46321
       break;
      }
     case 190:
      {
       $$0$i$i$i = 47; //@line 46325
       break;
      }
     case 191:
      {
       $$0$i$i$i = 44; //@line 46329
       break;
      }
     case 9:
      {
       $$0$i$i$i = 48; //@line 46333
       break;
      }
     case 13:
      {
       $$0$i$i$i = 36; //@line 46337
       break;
      }
     case 32:
      {
       $$0$i$i$i = 49; //@line 46341
       break;
      }
     case 8:
      {
       $$0$i$i$i = 51; //@line 46345
       break;
      }
     case 17:
      {
       $$0$i$i$i = 54; //@line 46349
       break;
      }
     case 16:
      {
       $$0$i$i$i = 56; //@line 46353
       break;
      }
     case 18:
      {
       $$0$i$i$i = 58; //@line 46357
       break;
      }
     case 91:
      {
       $$0$i$i$i = 55; //@line 46361
       break;
      }
     case 93:
      {
       $$0$i$i$i = 55; //@line 46365
       break;
      }
     case 38:
      {
       $$0$i$i$i = 62; //@line 46369
       break;
      }
     case 40:
      {
       $$0$i$i$i = 61; //@line 46373
       break;
      }
     case 37:
      {
       $$0$i$i$i = 59; //@line 46377
       break;
      }
     case 39:
      {
       $$0$i$i$i = 60; //@line 46381
       break;
      }
     case 27:
      {
       $$0$i$i$i = 53; //@line 46385
       break;
      }
     default:
      {
       HEAP32[$vararg_buffer >> 2] = $19; //@line 46389
       _printf(103744, $vararg_buffer) | 0; //@line 46390
       $$0$i$i$i = -1; //@line 46391
      }
     }
    } while (0);
    if (!$20) {
     __Z8ADBKeyUpi($$0$i$i$i); //@line 46397
     break;
    } else {
     __Z10ADBKeyDowni($$0$i$i$i); //@line 46400
     break;
    }
   }
  } while (0);
  _emscripten_asm_const_i(10) | 0; //@line 46405
 }
 FUNCTION_TABLE_v[HEAP32[30857] & 3](); //@line 46408
 _SDL_mutexP(0) | 0; //@line 46409
 if (HEAP8[659471] | 0) {
  HEAP8[659471] = 0; //@line 46413
  $26 = HEAP32[30855] | 0; //@line 46414
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$26 >> 2] | 0) + 8 >> 2] & 4095]($26); //@line 46418
 }
 _SDL_mutexV(0) | 0; //@line 46420
 STACKTOP = sp; //@line 46421
 return;
}
function __ZN8tinyxml210XMLElement15ParseAttributesEPc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i$i = 0, $$0$lcssa$i$i$i = 0, $$0$lcssa$i467375 = 0, $$010$i$i = 0, $$011$i$i = 0, $$019$lcssa$i$i$i = 0, $$019$lcssa$i89$i$i = 0, $$01923$i$i$i = 0, $$02022$i$i$i = 0, $$024$i$i$i = 0, $$03$i = 0, $$04158 = 0, $$04457 = 0, $$2 = 0, $$lcssa63 = 0, $11 = 0, $12 = 0, $16 = 0, $18 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $38 = 0, $4 = 0, $40 = 0, $43 = 0, $45 = 0, $47 = 0, $5 = 0, $50 = 0, $53 = 0, $54 = 0, $59 = 0, $68 = 0, $76 = 0, $8 = 0, $86 = 0, label = 0;
 if (!$1) {
  $$2 = 0; //@line 38437
  return $$2 | 0; //@line 38438
 }
 $3 = $0 + 4 | 0; //@line 38440
 $4 = $0 + 48 | 0; //@line 38441
 $$04158 = $1; //@line 38442
 $$04457 = 0; //@line 38442
 L4 : while (1) {
  $5 = HEAP8[$$04158 >> 0] | 0; //@line 38444
  L6 : do {
   if ($5 << 24 >> 24 > -1) {
    $$03$i = $$04158; //@line 38448
    $8 = $5; //@line 38448
    while (1) {
     if (!(_isspace($8 & 255) | 0)) {
      break;
     }
     $11 = $$03$i + 1 | 0; //@line 38456
     $12 = HEAP8[$11 >> 0] | 0; //@line 38457
     if ($12 << 24 >> 24 > -1) {
      $$03$i = $11; //@line 38460
      $8 = $12; //@line 38460
     } else {
      $$0$lcssa$i467375 = $11; //@line 38462
      break L6;
     }
    }
    if (($$03$i | 0) == 0 | $8 << 24 >> 24 == 0) {
     label = 7; //@line 38470
     break L4;
    }
    if (!(_isalpha($8 & 255) | 0)) {
     switch ($8 << 24 >> 24) {
     case 47:
      {
       label = 26; //@line 38479
       break L4;
       break;
      }
     case 62:
      {
       label = 28; //@line 38484
       break L4;
       break;
      }
     case 58:
     case 95:
      {
       $$0$lcssa$i467375 = $$03$i; //@line 38489
       break;
      }
     default:
      {
       break L4;
      }
     }
    } else {
     $$0$lcssa$i467375 = $$03$i; //@line 38497
    }
   } else {
    $$0$lcssa$i467375 = $$04158; //@line 38500
   }
  } while (0);
  $26 = __ZN8tinyxml28MemPoolTILi36EE5AllocEv((HEAP32[$3 >> 2] | 0) + 144 | 0) | 0; //@line 38505
  HEAP32[$26 >> 2] = 2144; //@line 38506
  $27 = $26 + 4 | 0; //@line 38507
  HEAP32[$27 >> 2] = 0; //@line 38508
  HEAP32[$27 + 4 >> 2] = 0; //@line 38508
  HEAP32[$27 + 8 >> 2] = 0; //@line 38508
  HEAP32[$27 + 12 >> 2] = 0; //@line 38508
  HEAP32[$27 + 16 >> 2] = 0; //@line 38508
  HEAP32[$27 + 20 >> 2] = 0; //@line 38508
  HEAP32[$27 + 24 >> 2] = 0; //@line 38508
  $29 = (HEAP32[$3 >> 2] | 0) + 144 | 0; //@line 38510
  $30 = $26 + 32 | 0; //@line 38511
  HEAP32[$30 >> 2] = $29; //@line 38512
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$29 >> 2] | 0) + 20 >> 2] & 4095]($29); //@line 38516
  $38 = __ZN8tinyxml212XMLAttribute9ParseDeepEPcb($26, $$0$lcssa$i467375, (HEAP8[(HEAP32[$3 >> 2] | 0) + 45 >> 0] | 0) != 0) | 0; //@line 38521
  if (!$38) {
   $$lcssa63 = 0; //@line 38524
   label = 22; //@line 38525
   break;
  }
  $40 = __ZN8tinyxml27StrPair6GetStrEv($27) | 0; //@line 38528
  $$010$i$i = HEAP32[$4 >> 2] | 0; //@line 38529
  L15 : do {
   if ($$010$i$i | 0) {
    $$011$i$i = $$010$i$i; //@line 38533
    while (1) {
     $43 = __ZN8tinyxml27StrPair6GetStrEv($$011$i$i + 4 | 0) | 0; //@line 38536
     if (($43 | 0) == ($40 | 0)) {
      break;
     }
     $45 = HEAP8[$43 >> 0] | 0; //@line 38541
     if (!($45 << 24 >> 24)) {
      $$019$lcssa$i89$i$i = $40; //@line 38544
      label = 18; //@line 38545
     } else {
      $$01923$i$i$i = $40; //@line 38547
      $$02022$i$i$i = $43; //@line 38547
      $$024$i$i$i = 0; //@line 38547
      $50 = $45; //@line 38547
      while (1) {
       $47 = HEAP8[$$01923$i$i$i >> 0] | 0; //@line 38549
       if (!(($$024$i$i$i | 0) != 2147483647 & ($47 << 24 >> 24 ? $50 << 24 >> 24 == $47 << 24 >> 24 : 0))) {
        $$0$lcssa$i$i$i = $$024$i$i$i; //@line 38556
        $$019$lcssa$i$i$i = $$01923$i$i$i; //@line 38556
        $59 = $50; //@line 38556
        break;
       }
       $$02022$i$i$i = $$02022$i$i$i + 1 | 0; //@line 38559
       $53 = $$01923$i$i$i + 1 | 0; //@line 38560
       $54 = $$024$i$i$i + 1 | 0; //@line 38561
       $50 = HEAP8[$$02022$i$i$i >> 0] | 0; //@line 38562
       if (!($50 << 24 >> 24)) {
        $$0$lcssa$i$i$i = $54; //@line 38565
        $$019$lcssa$i$i$i = $53; //@line 38565
        $59 = 0; //@line 38565
        break;
       } else {
        $$01923$i$i$i = $53; //@line 38568
        $$024$i$i$i = $54; //@line 38568
       }
      }
      if (($$0$lcssa$i$i$i | 0) == 2147483647) {
       label = 20; //@line 38573
       break;
      }
      if (!($59 << 24 >> 24)) {
       $$019$lcssa$i89$i$i = $$019$lcssa$i$i$i; //@line 38578
       label = 18; //@line 38579
      }
     }
     if ((label | 0) == 18) {
      label = 0; //@line 38583
      if (!(HEAP8[$$019$lcssa$i89$i$i >> 0] | 0)) {
       label = 20; //@line 38587
       break;
      }
     }
     $$0$i$i = HEAP32[$$011$i$i + 28 >> 2] | 0; //@line 38592
     if (!$$0$i$i) {
      break L15;
     } else {
      $$011$i$i = $$0$i$i; //@line 38597
     }
    }
    if ((label | 0) == 20) {
     label = 0; //@line 38601
     if (!$$011$i$i) {
      break;
     }
    }
    if (__ZN8tinyxml27StrPair6GetStrEv($$011$i$i + 16 | 0) | 0) {
     $$lcssa63 = $38; //@line 38611
     label = 22; //@line 38612
     break L4;
    }
   }
  } while (0);
  HEAP32[($$04457 | 0 ? $$04457 + 28 | 0 : $4) >> 2] = $26; //@line 38620
  $$04158 = $38; //@line 38621
  $$04457 = $26; //@line 38621
 }
 if ((label | 0) == 7) {
  $16 = HEAP32[$3 >> 2] | 0; //@line 38624
  $18 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 38626
  HEAP32[$16 + 48 >> 2] = 7; //@line 38628
  HEAP32[$16 + 56 >> 2] = $1; //@line 38630
  HEAP32[$16 + 60 >> 2] = $18; //@line 38632
  $$2 = 0; //@line 38633
  return $$2 | 0; //@line 38634
 } else if ((label | 0) == 22) {
  if ($26 | 0) {
   $68 = HEAP32[$30 >> 2] | 0; //@line 38639
   FUNCTION_TABLE_vi[HEAP32[HEAP32[$26 >> 2] >> 2] & 4095]($26); //@line 38642
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$68 >> 2] | 0) + 16 >> 2] & 31]($68, $26); //@line 38646
  }
  $76 = HEAP32[$3 >> 2] | 0; //@line 38648
  HEAP32[$76 + 48 >> 2] = 8; //@line 38650
  HEAP32[$76 + 56 >> 2] = $1; //@line 38652
  HEAP32[$76 + 60 >> 2] = $$lcssa63; //@line 38654
  $$2 = 0; //@line 38655
  return $$2 | 0; //@line 38656
 } else if ((label | 0) == 26) {
  if ((HEAP8[$$03$i + 1 >> 0] | 0) == 62) {
   HEAP32[$0 + 44 >> 2] = 1; //@line 38664
   $$2 = $$03$i + 2 | 0; //@line 38666
   return $$2 | 0; //@line 38667
  }
 } else if ((label | 0) == 28) {
  $$2 = $$03$i + 1 | 0; //@line 38672
  return $$2 | 0; //@line 38673
 }
 $86 = HEAP32[$3 >> 2] | 0; //@line 38675
 HEAP32[$86 + 48 >> 2] = 7; //@line 38677
 HEAP32[$86 + 56 >> 2] = $1; //@line 38679
 HEAP32[$86 + 60 >> 2] = $$03$i; //@line 38681
 $$2 = 0; //@line 38682
 return $$2 | 0; //@line 38683
}
function __ZN12monitor_descC2ERKNSt3__26vectorI10video_modeNS0_9allocatorIS2_EEEE11video_depthj($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0$i = 0, $$0$i$1 = 0, $$0$i$2 = 0, $$0$i$3 = 0, $$0$i$4 = 0, $$1 = 0, $$1$1 = 0, $$1$2 = 0, $$1$3 = 0, $$1$4 = 0, $$ph = 0, $$sroa$0$0$$sroa_idx = 0, $$sroa$03$07$i = 0, $$sroa$03$07$i$1 = 0, $$sroa$03$07$i$2 = 0, $$sroa$03$07$i$3 = 0, $$sroa$03$07$i$4 = 0, $$sroa$03$07$i$5 = 0, $$sroa$04$0$lcssa$i = 0, $$sroa$04$09$i = 0, $10 = 0, $11 = 0, $14 = 0, $17 = 0, $20 = 0, $22 = 0, $26 = 0, $27 = 0, $39 = 0, $4 = 0, $42 = 0, $49 = 0, $5 = 0, $7 = 0, $83 = 0, label = 0;
 HEAP32[$0 >> 2] = 1492; //@line 23197
 $4 = $0 + 4 | 0; //@line 23198
 HEAP32[$4 >> 2] = 0; //@line 23199
 $5 = $0 + 8 | 0; //@line 23200
 HEAP32[$5 >> 2] = 0; //@line 23201
 HEAP32[$0 + 12 >> 2] = 0; //@line 23203
 $7 = $1 + 4 | 0; //@line 23204
 $10 = (HEAP32[$7 >> 2] | 0) - (HEAP32[$1 >> 2] | 0) | 0; //@line 23207
 $11 = ($10 | 0) / 24 | 0; //@line 23208
 L1 : do {
  if (!$10) {
   $$ph = 0; //@line 23212
   label = 5; //@line 23213
  } else {
   if ($11 >>> 0 > 178956970) {
    __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($4); //@line 23217
   }
   $14 = __Znwj($10) | 0; //@line 23220
   HEAP32[$5 >> 2] = $14; //@line 23221
   HEAP32[$4 >> 2] = $14; //@line 23222
   HEAP32[$0 + 12 >> 2] = $14 + ($11 * 24 | 0); //@line 23225
   $17 = HEAP32[$1 >> 2] | 0; //@line 23226
   $20 = (HEAP32[$7 >> 2] | 0) - $17 | 0; //@line 23229
   if (($20 | 0) > 0) {
    _memcpy($14 | 0, $17 | 0, $20 | 0) | 0; //@line 23233
    $26 = $14 + ((($20 >>> 0) / 24 | 0) * 24 | 0) | 0; //@line 23234
    HEAP32[$5 >> 2] = $26; //@line 23235
    $27 = HEAP8[96304] | 0; //@line 23236
    HEAP8[96304] = $27 + 1 << 24 >> 24; //@line 23238
    HEAP8[$0 + 24 >> 0] = $27; //@line 23240
    if (($14 | 0) == ($26 | 0)) {
     $$0$i = 0; //@line 23243
     $42 = $26; //@line 23243
     $49 = $14; //@line 23243
    } else {
     $$sroa$03$07$i = $14; //@line 23245
     while (1) {
      if (!(HEAP32[$$sroa$03$07$i + 12 >> 2] | 0)) {
       $$0$i = 1; //@line 23252
       $42 = $26; //@line 23252
       $49 = $14; //@line 23252
       break L1;
      }
      $$sroa$03$07$i = $$sroa$03$07$i + 24 | 0; //@line 23250
      if (($$sroa$03$07$i | 0) == ($26 | 0)) {
       $$0$i = 0; //@line 23257
       $42 = $26; //@line 23257
       $49 = $14; //@line 23257
       break;
      }
     }
    }
   } else {
    $$ph = $14; //@line 23265
    label = 5; //@line 23266
   }
  }
 } while (0);
 if ((label | 0) == 5) {
  $22 = HEAP8[96304] | 0; //@line 23271
  HEAP8[96304] = $22 + 1 << 24 >> 24; //@line 23273
  HEAP8[$0 + 24 >> 0] = $22; //@line 23275
  $$0$i = 0; //@line 23276
  $42 = $$ph; //@line 23276
  $49 = $$ph; //@line 23276
 }
 $$1 = $$0$i ? 129 : 128; //@line 23278
 HEAP16[$0 + 824 >> 1] = $$0$i ? 128 : 0; //@line 23281
 L13 : do {
  if (($49 | 0) == ($42 | 0)) {
   $$0$i$1 = 0; //@line 23285
  } else {
   $$sroa$03$07$i$1 = $49; //@line 23287
   while (1) {
    if ((HEAP32[$$sroa$03$07$i$1 + 12 >> 2] | 0) == 1) {
     $$0$i$1 = 1; //@line 23294
     break L13;
    }
    $$sroa$03$07$i$1 = $$sroa$03$07$i$1 + 24 | 0; //@line 23292
    if (($$sroa$03$07$i$1 | 0) == ($42 | 0)) {
     $$0$i$1 = 0; //@line 23299
     break;
    }
   }
  }
 } while (0);
 $$1$1 = ($$0$i$1 & 1) + $$1 << 16 >> 16; //@line 23308
 HEAP16[$0 + 826 >> 1] = $$0$i$1 ? $$1 : 0; //@line 23311
 L18 : do {
  if (($49 | 0) == ($42 | 0)) {
   $$0$i$2 = 0; //@line 23315
  } else {
   $$sroa$03$07$i$2 = $49; //@line 23317
   while (1) {
    if ((HEAP32[$$sroa$03$07$i$2 + 12 >> 2] | 0) == 2) {
     $$0$i$2 = 1; //@line 23324
     break L18;
    }
    $$sroa$03$07$i$2 = $$sroa$03$07$i$2 + 24 | 0; //@line 23322
    if (($$sroa$03$07$i$2 | 0) == ($42 | 0)) {
     $$0$i$2 = 0; //@line 23329
     break;
    }
   }
  }
 } while (0);
 $$1$2 = ($$0$i$2 & 1) + $$1$1 << 16 >> 16; //@line 23338
 HEAP16[$0 + 828 >> 1] = $$0$i$2 ? $$1$1 : 0; //@line 23341
 L23 : do {
  if (($49 | 0) == ($42 | 0)) {
   $$0$i$3 = 0; //@line 23345
  } else {
   $$sroa$03$07$i$3 = $49; //@line 23347
   while (1) {
    if ((HEAP32[$$sroa$03$07$i$3 + 12 >> 2] | 0) == 3) {
     $$0$i$3 = 1; //@line 23354
     break L23;
    }
    $$sroa$03$07$i$3 = $$sroa$03$07$i$3 + 24 | 0; //@line 23352
    if (($$sroa$03$07$i$3 | 0) == ($42 | 0)) {
     $$0$i$3 = 0; //@line 23359
     break;
    }
   }
  }
 } while (0);
 $$1$3 = ($$0$i$3 & 1) + $$1$2 << 16 >> 16; //@line 23368
 HEAP16[$0 + 830 >> 1] = $$0$i$3 ? $$1$2 : 0; //@line 23371
 L28 : do {
  if (($49 | 0) == ($42 | 0)) {
   $$0$i$4 = 0; //@line 23375
  } else {
   $$sroa$03$07$i$4 = $49; //@line 23377
   while (1) {
    if ((HEAP32[$$sroa$03$07$i$4 + 12 >> 2] | 0) == 4) {
     $$0$i$4 = 1; //@line 23384
     break L28;
    }
    $$sroa$03$07$i$4 = $$sroa$03$07$i$4 + 24 | 0; //@line 23382
    if (($$sroa$03$07$i$4 | 0) == ($42 | 0)) {
     $$0$i$4 = 0; //@line 23389
     break;
    }
   }
  }
 } while (0);
 $$1$4 = ($$0$i$4 & 1) + $$1$3 << 16 >> 16; //@line 23398
 HEAP16[$0 + 832 >> 1] = $$0$i$4 ? $$1$3 : 0; //@line 23401
 L33 : do {
  if (($49 | 0) == ($42 | 0)) {
   $83 = 0; //@line 23405
  } else {
   $$sroa$03$07$i$5 = $49; //@line 23407
   while (1) {
    if ((HEAP32[$$sroa$03$07$i$5 + 12 >> 2] | 0) == 5) {
     $83 = $$1$4; //@line 23414
     break L33;
    }
    $$sroa$03$07$i$5 = $$sroa$03$07$i$5 + 24 | 0; //@line 23412
    if (($$sroa$03$07$i$5 | 0) == ($42 | 0)) {
     $83 = 0; //@line 23419
     break;
    }
   }
  }
 } while (0);
 HEAP16[$0 + 834 >> 1] = $83; //@line 23428
 $39 = HEAP16[$0 + 824 + ($2 << 1) >> 1] | 0; //@line 23430
 if (($49 | 0) == ($42 | 0)) {
  $$sroa$04$0$lcssa$i = $49; //@line 23433
  $$sroa$0$0$$sroa_idx = $0 + 16 | 0; //@line 23434
  HEAP32[$$sroa$0$0$$sroa_idx >> 2] = $$sroa$04$0$lcssa$i; //@line 23435
  return;
 } else {
  $$sroa$04$09$i = $49; //@line 23438
 }
 while (1) {
  if ((HEAP32[$$sroa$04$09$i + 8 >> 2] | 0) == ($3 | 0)) {
   if ((HEAP16[$0 + 824 + (HEAP32[$$sroa$04$09$i + 12 >> 2] << 1) >> 1] | 0) == $39 << 16 >> 16) {
    $$sroa$04$0$lcssa$i = $$sroa$04$09$i; //@line 23451
    label = 10; //@line 23452
    break;
   }
  }
  $$sroa$04$09$i = $$sroa$04$09$i + 24 | 0; //@line 23456
  if (($$sroa$04$09$i | 0) == ($42 | 0)) {
   $$sroa$04$0$lcssa$i = $42; //@line 23459
   label = 10; //@line 23460
   break;
  }
 }
 if ((label | 0) == 10) {
  $$sroa$0$0$$sroa_idx = $0 + 16 | 0; //@line 23467
  HEAP32[$$sroa$0$0$$sroa_idx >> 2] = $$sroa$04$0$lcssa$i; //@line 23468
  return;
 }
}
function __ZN12monitor_desc11switch_modeENSt3__211__wrap_iterIPK10video_modeEEjj($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $106 = 0, $113 = 0, $124 = 0, $131 = 0, $136 = 0, $138 = 0, $139 = 0, $14 = 0, $151 = 0, $175 = 0, $179 = 0, $185 = 0, $192 = 0, $212 = 0, $218 = 0, $22 = 0, $223 = 0, $228 = 0, $23 = 0, $25 = 0, $26 = 0, $32 = 0, $39 = 0, $4 = 0, $40 = 0, $42 = 0, $46 = 0, $5 = 0, $53 = 0, $60 = 0, $65 = 0, $67 = 0, $74 = 0, $79 = 0, $81 = 0, $82 = 0, $scevgep$i = 0, sp = 0;
 sp = STACKTOP; //@line 24053
 STACKTOP = STACKTOP + 80 | 0; //@line 24054
 $4 = sp; //@line 24055
 $5 = HEAP32[$1 >> 2] | 0; //@line 24056
 $scevgep$i = $0 + 25 | 0; //@line 24057
 _memset($scevgep$i | 0, 127, 768) | 0; //@line 24058
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[$0 >> 2] | 0) + 12 >> 2] & 7]($0, $scevgep$i, 256); //@line 24062
 HEAP32[$0 + 16 >> 2] = $5; //@line 24065
 FUNCTION_TABLE_vi[HEAP32[(HEAP32[$0 >> 2] | 0) + 8 >> 2] & 4095]($0); //@line 24069
 $14 = $5 + 12 | 0; //@line 24070
 HEAP16[$0 + 804 >> 1] = HEAP16[$0 + 824 + (HEAP32[$14 >> 2] << 1) >> 1] | 0; //@line 24075
 HEAP32[$0 + 808 >> 2] = HEAP32[$5 + 8 >> 2]; //@line 24079
 $22 = $0 + 820 | 0; //@line 24080
 $23 = HEAP32[$22 >> 2] | 0; //@line 24081
 HEAP32[$4 + 32 >> 2] = $23; //@line 24083
 $25 = $23 + 49 | 0; //@line 24084
 $26 = $3 + 40 | 0; //@line 24085
 $32 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($26) | 0; //@line 24091
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $32); //@line 24097
 $39 = (HEAP32[$22 >> 2] | 0) + 50 | 0; //@line 24099
 $40 = $3 + 41 | 0; //@line 24100
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 24102
 $46 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0; //@line 24106
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($39, $46); //@line 24112
 $53 = (HEAP32[$22 >> 2] | 0) + 51 | 0; //@line 24114
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($53, 0); //@line 24120
 HEAP32[$4 >> 2] = 22; //@line 24121
 _Execute68kTrap(-24466, $4); //@line 24122
 $60 = (HEAP32[$22 >> 2] | 0) + 4 | 0; //@line 24124
 $65 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($60 >>> 16 << 2) >> 2] >> 2] & 127]($60) | 0; //@line 24129
 $67 = (HEAP32[$22 >> 2] | 0) + 50 | 0; //@line 24131
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($67 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($67, 10); //@line 24137
 HEAP32[$4 >> 2] = 6; //@line 24138
 _Execute68kTrap(-24466, $4); //@line 24139
 $74 = (HEAP32[$22 >> 2] | 0) + 4 | 0; //@line 24141
 $79 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($74 >>> 16 << 2) >> 2] >> 2] & 127]($74) | 0; //@line 24146
 $81 = $79 - (HEAP32[30896] | 0) | 0; //@line 24148
 $82 = $0 + 20 | 0; //@line 24149
 HEAP8[(HEAP32[30897] | 0) + $81 >> 0] = (HEAP32[$82 >> 2] | 0) >>> 24; //@line 24155
 HEAP8[(HEAP32[30897] | 0) + ($81 + 1) >> 0] = (HEAP32[$82 >> 2] | 0) >>> 16; //@line 24162
 HEAP8[(HEAP32[30897] | 0) + ($81 + 2) >> 0] = (HEAP32[$82 >> 2] | 0) >>> 8; //@line 24169
 HEAP8[(HEAP32[30897] | 0) + ($81 + 3) >> 0] = HEAP32[$82 >> 2]; //@line 24175
 $106 = (HEAP32[$22 >> 2] | 0) + 4 | 0; //@line 24177
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($106 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($106, $65); //@line 24183
 $113 = (HEAP32[$22 >> 2] | 0) + 50 | 0; //@line 24185
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($113 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($113, HEAPU16[$0 + 824 + (HEAP32[$14 >> 2] << 1) >> 1] | 0); //@line 24195
 HEAP32[$4 >> 2] = 6; //@line 24196
 _Execute68kTrap(-24466, $4); //@line 24197
 $124 = (HEAP32[$22 >> 2] | 0) + 50 | 0; //@line 24199
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($124 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($124, 1); //@line 24205
 HEAP32[$4 >> 2] = 6; //@line 24206
 _Execute68kTrap(-24466, $4); //@line 24207
 $131 = (HEAP32[$22 >> 2] | 0) + 4 | 0; //@line 24209
 $136 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($131 >>> 16 << 2) >> 2] >> 2] & 127]($131) | 0; //@line 24214
 $138 = $136 - (HEAP32[30896] | 0) | 0; //@line 24216
 $139 = $5 + 16 | 0; //@line 24217
 HEAP8[(HEAP32[30897] | 0) + ($138 + 8) >> 0] = (HEAP32[$139 >> 2] | 0) >>> 8; //@line 24224
 HEAP8[(HEAP32[30897] | 0) + ($138 + 9) >> 0] = HEAP32[$139 >> 2]; //@line 24230
 $151 = $5 + 4 | 0; //@line 24231
 HEAP8[(HEAP32[30897] | 0) + ($138 + 14) >> 0] = (HEAP32[$151 >> 2] | 0) >>> 8; //@line 24238
 HEAP8[(HEAP32[30897] | 0) + ($138 + 15) >> 0] = HEAP32[$151 >> 2]; //@line 24244
 HEAP8[(HEAP32[30897] | 0) + ($138 + 16) >> 0] = (HEAP32[$5 >> 2] | 0) >>> 8; //@line 24251
 HEAP8[(HEAP32[30897] | 0) + ($138 + 17) >> 0] = HEAP32[$5 >> 2]; //@line 24257
 __Z15ChecksumSlotROMv(); //@line 24258
 $175 = (HEAP32[$22 >> 2] | 0) + 50 | 0; //@line 24260
 $179 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0; //@line 24264
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($175 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($175, $179); //@line 24270
 HEAP32[$4 >> 2] = 43; //@line 24271
 _Execute68kTrap(-24466, $4); //@line 24272
 $185 = $3 + 42 | 0; //@line 24273
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($185 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($185, HEAP32[$82 >> 2] | 0); //@line 24280
 $192 = $2 + 8 | 0; //@line 24281
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($192 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($192, HEAP32[$82 >> 2] | 0); //@line 24288
 if (HEAP8[$0 + 795 >> 0] | 0) {
  STACKTOP = sp; //@line 24293
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](2084, HEAP32[$82 >> 2] | 0); //@line 24299
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](2200, HEAP32[$82 >> 2] | 0); //@line 24304
 $212 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](2212) | 0; //@line 24307
 if (($212 + 1 | 0) >>> 0 > 1) {
  $218 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($212 >>> 16 << 2) >> 2] >> 2] & 127]($212) | 0) + 22 | 0; //@line 24316
  $223 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($218 >>> 16 << 2) >> 2] >> 2] & 127]($218) | 0; //@line 24321
  $228 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($223 >>> 16 << 2) >> 2] >> 2] & 127]($223) | 0; //@line 24326
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($228 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($228, HEAP32[$82 >> 2] | 0); //@line 24333
 }
 FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3272) | 0; //@line 24337
 STACKTOP = sp; //@line 24338
 return;
}
function __Z13fpuop_restorej($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $17 = 0, $2 = 0, $20 = 0, $21 = 0, $26 = 0, $28 = 0, $29 = 0, $3 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $39 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $53 = 0, $54 = 0, $56 = 0, $57 = 0, $58 = 0, $62 = 0, $64 = 0, $trunc$clear = 0, $trunc27$clear = 0, $trunc28$clear = 0, $trunc29$clear = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 56068
 STACKTOP = STACKTOP + 16 | 0; //@line 56069
 $1 = sp; //@line 56070
 $2 = $0 & 56; //@line 56071
 $3 = ($2 | 0) == 32; //@line 56072
 if (!(__ZL9get_fp_adjPj($0, $1) | 0)) {
  $11 = (HEAP32[162768] | 0) + -2 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 56081
  $17 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($11) | 0; //@line 56087
  HEAP32[162770] = $17; //@line 56088
  HEAP32[162769] = $17; //@line 56089
  HEAP32[162768] = $11; //@line 56090
  __Z7op_illgj($0); //@line 56091
  STACKTOP = sp; //@line 56092
  return;
 }
 $20 = HEAP32[$1 >> 2] | 0; //@line 56096
 L5 : do {
  if ((HEAP32[30880] | 0) == 4) {
   if ($3) {
    $21 = $20 + -4 | 0; //@line 56100
    HEAP32[$1 >> 2] = $21; //@line 56101
    $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($21 >>> 16 << 2) >> 2] >> 2] & 127]($21) | 0; //@line 56106
    if ($26 >>> 0 <= 16777215) {
     $64 = $21; //@line 56109
     break;
    }
    $trunc29$clear = $26 & 16711680; //@line 56113
    if (($trunc29$clear | 0) < 6291456) {
     switch ($trunc29$clear | 0) {
     case 3145728:
      {
       break;
      }
     default:
      {
       $64 = $21; //@line 56121
       break L5;
      }
     }
     $28 = $20 + -48 | 0; //@line 56125
     HEAP32[$1 >> 2] = $28; //@line 56126
     $64 = $28; //@line 56127
     break;
    } else {
     switch ($trunc29$clear | 0) {
     case 6291456:
      {
       break;
      }
     default:
      {
       $64 = $21; //@line 56135
       break L5;
      }
     }
     $29 = $20 + -96 | 0; //@line 56139
     HEAP32[$1 >> 2] = $29; //@line 56140
     $64 = $29; //@line 56141
     break;
    }
   } else {
    $34 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 56149
    $35 = $20 + 4 | 0; //@line 56150
    HEAP32[$1 >> 2] = $35; //@line 56151
    if ($34 >>> 0 <= 16777215) {
     $62 = $35; //@line 56154
     label = 24; //@line 56155
     break;
    }
    $trunc28$clear = $34 & 16711680; //@line 56159
    if (($trunc28$clear | 0) < 6291456) {
     switch ($trunc28$clear | 0) {
     case 3145728:
      {
       break;
      }
     default:
      {
       $62 = $35; //@line 56167
       label = 24; //@line 56168
       break L5;
      }
     }
     $37 = $20 + 48 | 0; //@line 56172
     HEAP32[$1 >> 2] = $37; //@line 56173
     $62 = $37; //@line 56174
     label = 24; //@line 56175
     break;
    } else {
     switch ($trunc28$clear | 0) {
     case 6291456:
      {
       break;
      }
     default:
      {
       $62 = $35; //@line 56183
       label = 24; //@line 56184
       break L5;
      }
     }
     $38 = $20 + 96 | 0; //@line 56188
     HEAP32[$1 >> 2] = $38; //@line 56189
     $62 = $38; //@line 56190
     label = 24; //@line 56191
     break;
    }
   }
  } else {
   if ($3) {
    $39 = $20 + -4 | 0; //@line 56197
    HEAP32[$1 >> 2] = $39; //@line 56198
    $44 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($39 >>> 16 << 2) >> 2] >> 2] & 127]($39) | 0; //@line 56203
    if ($44 >>> 0 <= 16777215) {
     $64 = $39; //@line 56206
     break;
    }
    $trunc27$clear = $44 & 16711680; //@line 56210
    if (($trunc27$clear | 0) < 3670016) {
     switch ($trunc27$clear | 0) {
     case 1572864:
      {
       break;
      }
     default:
      {
       $64 = $39; //@line 56218
       break L5;
      }
     }
     $46 = $20 + -28 | 0; //@line 56222
     HEAP32[$1 >> 2] = $46; //@line 56223
     $64 = $46; //@line 56224
     break;
    }
    if (($trunc27$clear | 0) < 11796480) {
     switch ($trunc27$clear | 0) {
     case 3670016:
      {
       break;
      }
     default:
      {
       $64 = $39; //@line 56234
       break L5;
      }
     }
     $47 = $20 + -60 | 0; //@line 56238
     HEAP32[$1 >> 2] = $47; //@line 56239
     $64 = $47; //@line 56240
     break;
    } else {
     switch ($trunc27$clear | 0) {
     case 11796480:
      {
       break;
      }
     default:
      {
       $64 = $39; //@line 56248
       break L5;
      }
     }
     $48 = $20 + -184 | 0; //@line 56252
     HEAP32[$1 >> 2] = $48; //@line 56253
     $64 = $48; //@line 56254
     break;
    }
   } else {
    $53 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 56262
    $54 = $20 + 4 | 0; //@line 56263
    HEAP32[$1 >> 2] = $54; //@line 56264
    if ($53 >>> 0 <= 16777215) {
     $62 = $54; //@line 56267
     label = 24; //@line 56268
     break;
    }
    $trunc$clear = $53 & 16711680; //@line 56272
    if (($trunc$clear | 0) < 3670016) {
     switch ($trunc$clear | 0) {
     case 1572864:
      {
       break;
      }
     default:
      {
       $62 = $54; //@line 56280
       label = 24; //@line 56281
       break L5;
      }
     }
     $56 = $20 + 28 | 0; //@line 56285
     HEAP32[$1 >> 2] = $56; //@line 56286
     $62 = $56; //@line 56287
     label = 24; //@line 56288
     break;
    }
    if (($trunc$clear | 0) < 11796480) {
     switch ($trunc$clear | 0) {
     case 3670016:
      {
       break;
      }
     default:
      {
       $62 = $54; //@line 56298
       label = 24; //@line 56299
       break L5;
      }
     }
     $57 = $20 + 60 | 0; //@line 56303
     HEAP32[$1 >> 2] = $57; //@line 56304
     $62 = $57; //@line 56305
     label = 24; //@line 56306
     break;
    } else {
     switch ($trunc$clear | 0) {
     case 11796480:
      {
       break;
      }
     default:
      {
       $62 = $54; //@line 56314
       label = 24; //@line 56315
       break L5;
      }
     }
     $58 = $20 + 184 | 0; //@line 56319
     HEAP32[$1 >> 2] = $58; //@line 56320
     $62 = $58; //@line 56321
     label = 24; //@line 56322
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 24) {
  if (($2 | 0) == 24) {
   HEAP32[651040 + (($0 & 7) << 2) >> 2] = $62; //@line 56333
  }
  if ($3) {
   $64 = $62; //@line 56336
  } else {
   STACKTOP = sp; //@line 56338
   return;
  }
 }
 HEAP32[651040 + (($0 & 7) << 2) >> 2] = $64; //@line 56343
 STACKTOP = sp; //@line 56344
 return;
}
function __ZN8tinyxml27StrPair6GetStrEv($0) {
 $0 = $0 | 0;
 var $$04355 = 0, $$044$be = 0, $$044$lcssa = 0, $$04457 = 0, $$045$be = 0, $$04556 = 0, $$052 = 0, $$053$lcssa = 0, $$1$lcssa = 0, $$146 = 0, $$154 = 0, $$2 = 0, $$247 = 0, $$348 = 0, $$lcssa62 = 0, $$pre71 = 0, $1 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $20 = 0, $26 = 0, $36 = 0, $41 = 0, $46 = 0, $59 = 0, $6 = 0, $67 = 0, $68 = 0, $69 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 36981
 STACKTOP = STACKTOP + 16 | 0; //@line 36982
 $1 = sp + 4 | 0; //@line 36983
 $2 = sp; //@line 36984
 if (!(HEAP32[$0 >> 2] & 256)) {
  $68 = $0 + 4 | 0; //@line 36989
  $69 = HEAP32[$68 >> 2] | 0; //@line 36990
  STACKTOP = sp; //@line 36991
  return $69 | 0; //@line 36991
 }
 $6 = $0 + 8 | 0; //@line 36993
 HEAP8[HEAP32[$6 >> 2] >> 0] = 0; //@line 36995
 $9 = HEAP32[$0 >> 2] ^ 256; //@line 36997
 HEAP32[$0 >> 2] = $9; //@line 36998
 if (!$9) {
  $67 = 0; //@line 37001
 } else {
  $12 = HEAP32[$0 + 4 >> 2] | 0; //@line 37004
  L6 : do {
   if ($12 >>> 0 < (HEAP32[$6 >> 2] | 0) >>> 0) {
    $$04457 = $12; //@line 37009
    $$04556 = $12; //@line 37009
    $16 = $9; //@line 37009
    while (1) {
     $17 = ($16 & 2 | 0) != 0; //@line 37012
     $18 = HEAP8[$$04556 >> 0] | 0; //@line 37013
     do {
      if ($17 & $18 << 24 >> 24 == 13) {
       $20 = $$04556 + 1 | 0; //@line 37018
       $$146 = (HEAP8[$20 >> 0] | 0) == 10 ? $$04556 + 2 | 0 : $20; //@line 37022
       HEAP8[$$04457 >> 0] = 10; //@line 37024
       $$044$be = $$04457 + 1 | 0; //@line 37025
       $$045$be = $$146; //@line 37025
      } else {
       if ($17 & $18 << 24 >> 24 == 10) {
        $26 = $$04556 + 1 | 0; //@line 37030
        $$247 = (HEAP8[$26 >> 0] | 0) == 13 ? $$04556 + 2 | 0 : $26; //@line 37034
        HEAP8[$$04457 >> 0] = 10; //@line 37036
        $$044$be = $$04457 + 1 | 0; //@line 37037
        $$045$be = $$247; //@line 37037
        break;
       }
       if (!(($16 & 1 | 0) != 0 & $18 << 24 >> 24 == 38)) {
        HEAP8[$$04457 >> 0] = $18; //@line 37045
        $$044$be = $$04457 + 1 | 0; //@line 37048
        $$045$be = $$04556 + 1 | 0; //@line 37048
        break;
       }
       $36 = $$04556 + 1 | 0; //@line 37051
       if ((HEAP8[$36 >> 0] | 0) == 35) {
        dest = $1; //@line 37055
        stop = dest + 10 | 0; //@line 37055
        do {
         HEAP8[dest >> 0] = 0; //@line 37055
         dest = dest + 1 | 0; //@line 37055
        } while ((dest | 0) < (stop | 0));
        $41 = __ZN8tinyxml27XMLUtil15GetCharacterRefEPKcPcPi($$04556, $1, $2) | 0; //@line 37056
        if ((HEAP32[$2 >> 2] | 0) > 0) {
         $$04355 = 0; //@line 37060
         $$154 = $$04457; //@line 37060
         while (1) {
          $46 = $$154 + 1 | 0; //@line 37064
          HEAP8[$$154 >> 0] = HEAP8[$1 + $$04355 >> 0] | 0; //@line 37065
          $$04355 = $$04355 + 1 | 0; //@line 37066
          if (($$04355 | 0) >= (HEAP32[$2 >> 2] | 0)) {
           $$1$lcssa = $46; //@line 37072
           break;
          } else {
           $$154 = $46; //@line 37070
          }
         }
        } else {
         $$1$lcssa = $$04457; //@line 37077
        }
        $$044$be = $$1$lcssa; //@line 37079
        $$045$be = $41; //@line 37079
        break;
       }
       if (!(_strncmp($36, 97290, 4) | 0)) {
        if ((HEAP8[$$04556 + 5 >> 0] | 0) == 59) {
         $$053$lcssa = 0; //@line 37089
         $$lcssa62 = 6; //@line 37089
         label = 18; //@line 37090
        } else {
         label = 19; //@line 37092
        }
       } else {
        label = 19; //@line 37095
       }
       do {
        if ((label | 0) == 19) {
         label = 0; //@line 37099
         if (!(_strncmp($36, 97295, 3) | 0)) {
          if ((HEAP8[$$04556 + 4 >> 0] | 0) == 59) {
           $$053$lcssa = 1; //@line 37107
           $$lcssa62 = 5; //@line 37107
           label = 18; //@line 37108
           break;
          }
         }
         if (!(_strncmp($36, 97299, 4) | 0)) {
          if ((HEAP8[$$04556 + 5 >> 0] | 0) == 59) {
           $$053$lcssa = 2; //@line 37119
           $$lcssa62 = 6; //@line 37119
           label = 18; //@line 37120
           break;
          }
         }
         if (!(_strncmp($36, 97304, 2) | 0)) {
          if ((HEAP8[$$04556 + 3 >> 0] | 0) == 59) {
           $$053$lcssa = 3; //@line 37131
           $$lcssa62 = 4; //@line 37131
           label = 18; //@line 37132
           break;
          }
         }
         if (!(_strncmp($36, 97307, 2) | 0)) {
          if ((HEAP8[$$04556 + 3 >> 0] | 0) == 59) {
           $$053$lcssa = 4; //@line 37143
           $$lcssa62 = 4; //@line 37143
           label = 18; //@line 37144
          } else {
           $$052 = 5; //@line 37146
           $$2 = $$04457; //@line 37146
           $$348 = $$04556; //@line 37146
          }
         } else {
          $$052 = 5; //@line 37149
          $$2 = $$04457; //@line 37149
          $$348 = $$04556; //@line 37149
         }
        }
       } while (0);
       if ((label | 0) == 18) {
        label = 0; //@line 37154
        HEAP8[$$04457 >> 0] = HEAP8[1648 + ($$053$lcssa * 12 | 0) + 8 >> 0] | 0; //@line 37157
        $$052 = $$053$lcssa; //@line 37160
        $$2 = $$04457 + 1 | 0; //@line 37160
        $$348 = $$04556 + $$lcssa62 | 0; //@line 37160
       }
       $59 = ($$052 | 0) == 5; //@line 37162
       $$044$be = $59 ? $$2 + 1 | 0 : $$2; //@line 37167
       $$045$be = $59 ? $$348 + 1 | 0 : $$348; //@line 37167
      }
     } while (0);
     if ($$045$be >>> 0 >= (HEAP32[$6 >> 2] | 0) >>> 0) {
      $$044$lcssa = $$044$be; //@line 37173
      break L6;
     }
     $$04457 = $$044$be; //@line 37177
     $$04556 = $$045$be; //@line 37177
     $16 = HEAP32[$0 >> 2] | 0; //@line 37177
    }
   } else {
    $$044$lcssa = $12; //@line 37180
   }
  } while (0);
  HEAP8[$$044$lcssa >> 0] = 0; //@line 37183
  $$pre71 = HEAP32[$0 >> 2] | 0; //@line 37184
  if (!($$pre71 & 4)) {
   $67 = $$pre71; //@line 37188
  } else {
   __ZN8tinyxml27StrPair18CollapseWhitespaceEv($0); //@line 37190
   $67 = HEAP32[$0 >> 2] | 0; //@line 37192
  }
 }
 HEAP32[$0 >> 2] = $67 & 512; //@line 37196
 $68 = $0 + 4 | 0; //@line 37197
 $69 = HEAP32[$68 >> 2] | 0; //@line 37198
 STACKTOP = sp; //@line 37199
 return $69 | 0; //@line 37199
}
function __ZL10VModeParmsRK12monitor_desc11video_depth($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sink = 0, $$sink17 = 0, $$sink25 = 0, $$sink33 = 0, $106 = 0, $108 = 0, $109 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $23 = 0, $27 = 0, $3 = 0, $4 = 0, $42 = 0, $51 = 0, $90 = 0;
 $3 = HEAP32[$0 + 16 >> 2] | 0; //@line 10070
 $4 = HEAP32[28210] | 0; //@line 10071
 HEAP8[651929 + $4 >> 0] = 0; //@line 10074
 HEAP8[651929 + ($4 + 1) >> 0] = 0; //@line 10077
 HEAP8[651929 + ($4 + 2) >> 0] = 0; //@line 10080
 HEAP8[651929 + ($4 + 3) >> 0] = 50; //@line 10083
 HEAP8[651929 + ($4 + 4) >> 0] = 0; //@line 10086
 HEAP8[651929 + ($4 + 5) >> 0] = 0; //@line 10089
 HEAP8[651929 + ($4 + 6) >> 0] = 0; //@line 10092
 HEAP32[28210] = $4 + 8; //@line 10094
 HEAP8[651929 + ($4 + 7) >> 0] = 0; //@line 10096
 $23 = __ZNK12monitor_desc17get_bytes_per_rowE11video_depthj($0, $1, HEAP32[$3 + 8 >> 2] | 0) | 0; //@line 10099
 $27 = HEAP32[28210] | 0; //@line 10103
 HEAP8[651929 + $27 >> 0] = ($23 & 65535) >>> 8; //@line 10106
 HEAP8[651929 + ($27 + 1) >> 0] = $23; //@line 10110
 HEAP8[651929 + ($27 + 2) >> 0] = 0; //@line 10113
 HEAP8[651929 + ($27 + 3) >> 0] = 0; //@line 10116
 HEAP8[651929 + ($27 + 4) >> 0] = 0; //@line 10119
 HEAP8[651929 + ($27 + 5) >> 0] = 0; //@line 10122
 $42 = HEAP32[$3 + 4 >> 2] | 0; //@line 10124
 HEAP8[651929 + ($27 + 6) >> 0] = ($42 & 65535) >>> 8; //@line 10130
 HEAP8[651929 + ($27 + 7) >> 0] = $42; //@line 10134
 $51 = HEAP32[$3 >> 2] | 0; //@line 10135
 HEAP8[651929 + ($27 + 8) >> 0] = ($51 & 65535) >>> 8; //@line 10141
 HEAP8[651929 + ($27 + 9) >> 0] = $51; //@line 10145
 HEAP8[651929 + ($27 + 10) >> 0] = 0; //@line 10148
 HEAP8[651929 + ($27 + 11) >> 0] = 0; //@line 10151
 HEAP8[651929 + ($27 + 12) >> 0] = 0; //@line 10154
 HEAP8[651929 + ($27 + 13) >> 0] = 0; //@line 10157
 HEAP8[651929 + ($27 + 14) >> 0] = 0; //@line 10160
 HEAP8[651929 + ($27 + 15) >> 0] = 0; //@line 10163
 HEAP8[651929 + ($27 + 16) >> 0] = 0; //@line 10166
 HEAP8[651929 + ($27 + 17) >> 0] = 0; //@line 10169
 HEAP8[651929 + ($27 + 18) >> 0] = 0; //@line 10172
 HEAP8[651929 + ($27 + 19) >> 0] = 72; //@line 10175
 HEAP8[651929 + ($27 + 20) >> 0] = 0; //@line 10178
 HEAP8[651929 + ($27 + 21) >> 0] = 0; //@line 10181
 HEAP8[651929 + ($27 + 22) >> 0] = 0; //@line 10184
 HEAP8[651929 + ($27 + 23) >> 0] = 72; //@line 10187
 HEAP8[651929 + ($27 + 24) >> 0] = 0; //@line 10190
 $90 = $27 + 26 | 0; //@line 10191
 HEAP32[28210] = $90; //@line 10192
 HEAP8[651929 + ($27 + 25) >> 0] = 0; //@line 10194
 switch ($1 | 0) {
 case 0:
  {
   $$sink = 1; //@line 10197
   $$sink17 = 1; //@line 10197
   $$sink25 = 1; //@line 10197
   $$sink33 = 0; //@line 10197
   break;
  }
 case 1:
  {
   $$sink = 2; //@line 10201
   $$sink17 = 1; //@line 10201
   $$sink25 = 2; //@line 10201
   $$sink33 = 0; //@line 10201
   break;
  }
 case 2:
  {
   $$sink = 4; //@line 10205
   $$sink17 = 1; //@line 10205
   $$sink25 = 4; //@line 10205
   $$sink33 = 0; //@line 10205
   break;
  }
 case 3:
  {
   $$sink = 8; //@line 10209
   $$sink17 = 1; //@line 10209
   $$sink25 = 8; //@line 10209
   $$sink33 = 0; //@line 10209
   break;
  }
 case 4:
  {
   $$sink = 5; //@line 10213
   $$sink17 = 3; //@line 10213
   $$sink25 = 16; //@line 10213
   $$sink33 = 16; //@line 10213
   break;
  }
 case 5:
  {
   $$sink = 8; //@line 10217
   $$sink17 = 3; //@line 10217
   $$sink25 = 32; //@line 10217
   $$sink33 = 16; //@line 10217
   break;
  }
 default:
  {
   $109 = $90; //@line 10221
   $108 = $109 + 1 | 0; //@line 10222
   $110 = 651929 + $109 | 0; //@line 10223
   HEAP8[$110 >> 0] = 0; //@line 10224
   $111 = $109 + 2 | 0; //@line 10225
   $112 = 651929 + $108 | 0; //@line 10226
   HEAP8[$112 >> 0] = 0; //@line 10227
   $113 = $109 + 3 | 0; //@line 10228
   $114 = 651929 + $111 | 0; //@line 10229
   HEAP8[$114 >> 0] = 0; //@line 10230
   $115 = $109 + 4 | 0; //@line 10231
   $116 = 651929 + $113 | 0; //@line 10232
   HEAP8[$116 >> 0] = 0; //@line 10233
   $117 = $109 + 5 | 0; //@line 10234
   $118 = 651929 + $115 | 0; //@line 10235
   HEAP8[$118 >> 0] = 0; //@line 10236
   $119 = $109 + 6 | 0; //@line 10237
   $120 = 651929 + $117 | 0; //@line 10238
   HEAP8[$120 >> 0] = 0; //@line 10239
   $121 = $109 + 7 | 0; //@line 10240
   $122 = 651929 + $119 | 0; //@line 10241
   HEAP8[$122 >> 0] = 0; //@line 10242
   $123 = $109 + 8 | 0; //@line 10243
   HEAP32[28210] = $123; //@line 10244
   $124 = 651929 + $121 | 0; //@line 10245
   HEAP8[$124 >> 0] = 0; //@line 10246
   return $4 | 0; //@line 10247
  }
 }
 HEAP8[651929 + $90 >> 0] = 0; //@line 10252
 HEAP8[651929 + ($27 + 27) >> 0] = $$sink33; //@line 10255
 HEAP8[651929 + ($27 + 28) >> 0] = 0; //@line 10258
 HEAP8[651929 + ($27 + 29) >> 0] = $$sink25; //@line 10261
 HEAP8[651929 + ($27 + 30) >> 0] = 0; //@line 10264
 HEAP8[651929 + ($27 + 31) >> 0] = $$sink17; //@line 10267
 HEAP8[651929 + ($27 + 32) >> 0] = 0; //@line 10270
 $106 = $27 + 34 | 0; //@line 10271
 HEAP32[28210] = $106; //@line 10272
 HEAP8[651929 + ($27 + 33) >> 0] = $$sink; //@line 10274
 $109 = $106; //@line 10275
 $108 = $109 + 1 | 0; //@line 10276
 $110 = 651929 + $109 | 0; //@line 10277
 HEAP8[$110 >> 0] = 0; //@line 10278
 $111 = $109 + 2 | 0; //@line 10279
 $112 = 651929 + $108 | 0; //@line 10280
 HEAP8[$112 >> 0] = 0; //@line 10281
 $113 = $109 + 3 | 0; //@line 10282
 $114 = 651929 + $111 | 0; //@line 10283
 HEAP8[$114 >> 0] = 0; //@line 10284
 $115 = $109 + 4 | 0; //@line 10285
 $116 = 651929 + $113 | 0; //@line 10286
 HEAP8[$116 >> 0] = 0; //@line 10287
 $117 = $109 + 5 | 0; //@line 10288
 $118 = 651929 + $115 | 0; //@line 10289
 HEAP8[$118 >> 0] = 0; //@line 10290
 $119 = $109 + 6 | 0; //@line 10291
 $120 = 651929 + $117 | 0; //@line 10292
 HEAP8[$120 >> 0] = 0; //@line 10293
 $121 = $109 + 7 | 0; //@line 10294
 $122 = 651929 + $119 | 0; //@line 10295
 HEAP8[$122 >> 0] = 0; //@line 10296
 $123 = $109 + 8 | 0; //@line 10297
 HEAP32[28210] = $123; //@line 10298
 $124 = 651929 + $121 | 0; //@line 10299
 HEAP8[$124 >> 0] = 0; //@line 10300
 return $4 | 0; //@line 10301
}
function __ZN8tinyxml211XMLDocumentD2Ev($0) {
 $0 = $0 | 0;
 var $$04$i = 0, $$04$i13 = 0, $$04$i20 = 0, $$04$i6 = 0, $$lcssa$i = 0, $$lcssa$i10 = 0, $$lcssa$i17 = 0, $$lcssa$i3 = 0, $$pre$phi$iZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $12 = 0, $15 = 0, $18 = 0, $2 = 0, $22 = 0, $32 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $4 = 0, $44 = 0, $45 = 0, $49 = 0, $5 = 0, $51 = 0, $52 = 0, $54 = 0, $55 = 0, $6 = 0, $60 = 0, $61 = 0, $65 = 0, $67 = 0, $68 = 0, $7 = 0, $70 = 0, $71 = 0, $76 = 0, $77 = 0, $81 = 0, $83 = 0, $84 = 0, $86 = 0, $87 = 0, $92 = 0, $93 = 0, $97 = 0, $98 = 0, $99 = 0;
 HEAP32[$0 >> 2] = 2160; //@line 40181
 $1 = $0 + 24 | 0; //@line 40182
 $2 = HEAP32[$1 >> 2] | 0; //@line 40183
 if (!$2) {
  $$pre$phi$iZ2D = $0 + 28 | 0; //@line 40187
 } else {
  $4 = $0 + 28 | 0; //@line 40189
  $6 = $2; //@line 40190
  do {
   $5 = $6 + 36 | 0; //@line 40192
   $7 = HEAP32[$5 >> 2] | 0; //@line 40193
   HEAP32[$1 >> 2] = $7; //@line 40194
   $10 = $6 + 32 | 0; //@line 40197
   if ((HEAP32[$4 >> 2] | 0) == ($6 | 0)) {
    $12 = HEAP32[$10 >> 2] | 0; //@line 40200
    HEAP32[$4 >> 2] = $12; //@line 40201
    $15 = $12; //@line 40203
   } else {
    $15 = HEAP32[$10 >> 2] | 0; //@line 40206
   }
   if (!$15) {
    $18 = $7; //@line 40210
   } else {
    HEAP32[$15 + 36 >> 2] = $7; //@line 40213
    $18 = HEAP32[$5 >> 2] | 0; //@line 40215
   }
   if ($18 | 0) {
    HEAP32[$18 + 32 >> 2] = $15; //@line 40220
   }
   HEAP32[$6 + 8 >> 2] = 0; //@line 40223
   $22 = HEAP32[$6 + 40 >> 2] | 0; //@line 40225
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$6 >> 2] | 0) + 64 >> 2] & 4095]($6); //@line 40229
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$22 >> 2] | 0) + 16 >> 2] & 31]($22, $6); //@line 40233
   $6 = HEAP32[$1 >> 2] | 0; //@line 40234
  } while (($6 | 0) != 0);
  $$pre$phi$iZ2D = $4; //@line 40237
 }
 HEAP32[$$pre$phi$iZ2D >> 2] = 0; //@line 40244
 HEAP32[$1 >> 2] = 0; //@line 40245
 $32 = HEAP32[$0 + 64 >> 2] | 0; //@line 40247
 if ($32 | 0) {
  __ZdaPv($32); //@line 40250
 }
 HEAP32[$0 + 296 >> 2] = 2240; //@line 40253
 $35 = $0 + 348 | 0; //@line 40254
 $36 = HEAP32[$35 >> 2] | 0; //@line 40255
 $38 = $0 + 300 | 0; //@line 40257
 $39 = HEAP32[$38 >> 2] | 0; //@line 40258
 if (($36 | 0) > 0) {
  $$04$i = 0; //@line 40260
  $44 = $39; //@line 40260
  $98 = $36; //@line 40260
  while (1) {
   $45 = HEAP32[$44 + ($$04$i << 2) >> 2] | 0; //@line 40263
   if (!$45) {
    $49 = $98; //@line 40266
    $99 = $44; //@line 40266
   } else {
    __ZdlPv($45); //@line 40268
    $49 = HEAP32[$35 >> 2] | 0; //@line 40271
    $99 = HEAP32[$38 >> 2] | 0; //@line 40271
   }
   $$04$i = $$04$i + 1 | 0; //@line 40273
   if (($$04$i | 0) >= ($49 | 0)) {
    $$lcssa$i = $99; //@line 40278
    break;
   } else {
    $44 = $99; //@line 40276
    $98 = $49; //@line 40276
   }
  }
 } else {
  $$lcssa$i = $39; //@line 40283
 }
 if (!(($$lcssa$i | 0) == ($0 + 304 | 0) | ($$lcssa$i | 0) == 0)) {
  __ZdaPv($$lcssa$i); //@line 40290
 }
 HEAP32[$0 + 220 >> 2] = 2272; //@line 40293
 $51 = $0 + 272 | 0; //@line 40294
 $52 = HEAP32[$51 >> 2] | 0; //@line 40295
 $54 = $0 + 224 | 0; //@line 40297
 $55 = HEAP32[$54 >> 2] | 0; //@line 40298
 if (($52 | 0) > 0) {
  $$04$i6 = 0; //@line 40300
  $100 = $52; //@line 40300
  $60 = $55; //@line 40300
  while (1) {
   $61 = HEAP32[$60 + ($$04$i6 << 2) >> 2] | 0; //@line 40303
   if (!$61) {
    $101 = $60; //@line 40306
    $65 = $100; //@line 40306
   } else {
    __ZdlPv($61); //@line 40308
    $101 = HEAP32[$54 >> 2] | 0; //@line 40311
    $65 = HEAP32[$51 >> 2] | 0; //@line 40311
   }
   $$04$i6 = $$04$i6 + 1 | 0; //@line 40313
   if (($$04$i6 | 0) >= ($65 | 0)) {
    $$lcssa$i3 = $101; //@line 40318
    break;
   } else {
    $100 = $65; //@line 40316
    $60 = $101; //@line 40316
   }
  }
 } else {
  $$lcssa$i3 = $55; //@line 40323
 }
 if (!(($$lcssa$i3 | 0) == ($0 + 228 | 0) | ($$lcssa$i3 | 0) == 0)) {
  __ZdaPv($$lcssa$i3); //@line 40330
 }
 HEAP32[$0 + 144 >> 2] = 2304; //@line 40333
 $67 = $0 + 196 | 0; //@line 40334
 $68 = HEAP32[$67 >> 2] | 0; //@line 40335
 $70 = $0 + 148 | 0; //@line 40337
 $71 = HEAP32[$70 >> 2] | 0; //@line 40338
 if (($68 | 0) > 0) {
  $$04$i13 = 0; //@line 40340
  $102 = $68; //@line 40340
  $76 = $71; //@line 40340
  while (1) {
   $77 = HEAP32[$76 + ($$04$i13 << 2) >> 2] | 0; //@line 40343
   if (!$77) {
    $103 = $76; //@line 40346
    $81 = $102; //@line 40346
   } else {
    __ZdlPv($77); //@line 40348
    $103 = HEAP32[$70 >> 2] | 0; //@line 40351
    $81 = HEAP32[$67 >> 2] | 0; //@line 40351
   }
   $$04$i13 = $$04$i13 + 1 | 0; //@line 40353
   if (($$04$i13 | 0) >= ($81 | 0)) {
    $$lcssa$i10 = $103; //@line 40358
    break;
   } else {
    $102 = $81; //@line 40356
    $76 = $103; //@line 40356
   }
  }
 } else {
  $$lcssa$i10 = $71; //@line 40363
 }
 if (!(($$lcssa$i10 | 0) == ($0 + 152 | 0) | ($$lcssa$i10 | 0) == 0)) {
  __ZdaPv($$lcssa$i10); //@line 40370
 }
 HEAP32[$0 + 68 >> 2] = 2336; //@line 40373
 $83 = $0 + 120 | 0; //@line 40374
 $84 = HEAP32[$83 >> 2] | 0; //@line 40375
 $86 = $0 + 72 | 0; //@line 40377
 $87 = HEAP32[$86 >> 2] | 0; //@line 40378
 if (($84 | 0) > 0) {
  $$04$i20 = 0; //@line 40380
  $104 = $84; //@line 40380
  $92 = $87; //@line 40380
  while (1) {
   $93 = HEAP32[$92 + ($$04$i20 << 2) >> 2] | 0; //@line 40383
   if (!$93) {
    $105 = $92; //@line 40386
    $97 = $104; //@line 40386
   } else {
    __ZdlPv($93); //@line 40388
    $105 = HEAP32[$86 >> 2] | 0; //@line 40391
    $97 = HEAP32[$83 >> 2] | 0; //@line 40391
   }
   $$04$i20 = $$04$i20 + 1 | 0; //@line 40393
   if (($$04$i20 | 0) >= ($97 | 0)) {
    $$lcssa$i17 = $105; //@line 40398
    break;
   } else {
    $104 = $97; //@line 40396
    $92 = $105; //@line 40396
   }
  }
 } else {
  $$lcssa$i17 = $87; //@line 40403
 }
 if (($$lcssa$i17 | 0) == ($0 + 76 | 0) | ($$lcssa$i17 | 0) == 0) {
  __ZN8tinyxml27XMLNodeD2Ev($0); //@line 40410
  return;
 }
 __ZdaPv($$lcssa$i17); //@line 40413
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 40414
 return;
}
function __Z12extfs_renamePKcS0_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$0$i10 = 0, $$0$i8 = 0, $$0$i9 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $2 = 0, $23 = 0, $27 = 0, $3 = 0, $30 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $42 = 0, $46 = 0, $5 = 0, $50 = 0, $53 = 0, $54 = 0, $9 = 0, $endptr = 0, $endptr14 = 0, $endptr16 = 0, $endptr18 = 0, $endptr20 = 0, $endptr22 = 0, sp = 0;
 sp = STACKTOP; //@line 46846
 STACKTOP = STACKTOP + 3072 | 0; //@line 46847
 $2 = sp + 2048 | 0; //@line 46848
 $3 = sp + 1024 | 0; //@line 46849
 $4 = sp; //@line 46850
 HEAP8[$3 >> 0] = 0; //@line 46851
 $5 = _strrchr($0, 47) | 0; //@line 46852
 $$0$i = ($5 | 0) == 0 ? $0 : $5 + 1 | 0; //@line 46855
 $9 = $0; //@line 46857
 $10 = $$0$i - $9 | 0; //@line 46858
 _strncpy($3, $0, $10) | 0; //@line 46859
 HEAP8[$3 + $10 >> 0] = 0; //@line 46861
 $endptr = $3 + (_strlen($3) | 0) | 0; //@line 46863
 HEAP8[$endptr >> 0] = HEAP8[103798] | 0; //@line 46864
 HEAP8[$endptr + 1 >> 0] = HEAP8[103799] | 0; //@line 46864
 HEAP8[$endptr + 2 >> 0] = HEAP8[103800] | 0; //@line 46864
 HEAP8[$endptr + 3 >> 0] = HEAP8[103801] | 0; //@line 46864
 HEAP8[$endptr + 4 >> 0] = HEAP8[103802] | 0; //@line 46864
 HEAP8[$endptr + 5 >> 0] = HEAP8[103803] | 0; //@line 46864
 HEAP8[$endptr + 6 >> 0] = HEAP8[103804] | 0; //@line 46864
 _strncat($3, $$0$i, 1023) | 0; //@line 46865
 HEAP8[$4 >> 0] = 0; //@line 46866
 $12 = _strrchr($1, 47) | 0; //@line 46867
 $$0$i8 = ($12 | 0) == 0 ? $1 : $12 + 1 | 0; //@line 46870
 $16 = $1; //@line 46872
 $17 = $$0$i8 - $16 | 0; //@line 46873
 _strncpy($4, $1, $17) | 0; //@line 46874
 HEAP8[$4 + $17 >> 0] = 0; //@line 46876
 $endptr14 = $4 + (_strlen($4) | 0) | 0; //@line 46878
 HEAP8[$endptr14 >> 0] = HEAP8[103798] | 0; //@line 46879
 HEAP8[$endptr14 + 1 >> 0] = HEAP8[103799] | 0; //@line 46879
 HEAP8[$endptr14 + 2 >> 0] = HEAP8[103800] | 0; //@line 46879
 HEAP8[$endptr14 + 3 >> 0] = HEAP8[103801] | 0; //@line 46879
 HEAP8[$endptr14 + 4 >> 0] = HEAP8[103802] | 0; //@line 46879
 HEAP8[$endptr14 + 5 >> 0] = HEAP8[103803] | 0; //@line 46879
 HEAP8[$endptr14 + 6 >> 0] = HEAP8[103804] | 0; //@line 46879
 _strncat($4, $$0$i8, 1023) | 0; //@line 46880
 HEAP8[$2 >> 0] = 0; //@line 46881
 $19 = _strrchr($1, 47) | 0; //@line 46882
 $23 = (($19 | 0) == 0 ? $1 : $19 + 1 | 0) - $16 | 0; //@line 46887
 _strncpy($2, $1, $23) | 0; //@line 46888
 HEAP8[$2 + $23 >> 0] = 0; //@line 46890
 $endptr16 = $2 + (_strlen($2) | 0) | 0; //@line 46892
 HEAP8[$endptr16 >> 0] = HEAP8[103798] | 0; //@line 46893
 HEAP8[$endptr16 + 1 >> 0] = HEAP8[103799] | 0; //@line 46893
 HEAP8[$endptr16 + 2 >> 0] = HEAP8[103800] | 0; //@line 46893
 HEAP8[$endptr16 + 3 >> 0] = HEAP8[103801] | 0; //@line 46893
 HEAP8[$endptr16 + 4 >> 0] = HEAP8[103802] | 0; //@line 46893
 HEAP8[$endptr16 + 5 >> 0] = HEAP8[103803] | 0; //@line 46893
 HEAP8[$endptr16 + 6 >> 0] = HEAP8[103804] | 0; //@line 46893
 $27 = $2 + ((_strlen($2) | 0) + -1) | 0; //@line 46896
 if ((HEAP8[$27 >> 0] | 0) == 47) {
  HEAP8[$27 >> 0] = 0; //@line 46900
 }
 _mkdir($2, 511) | 0; //@line 46902
 _rename($3, $4) | 0; //@line 46903
 HEAP8[$3 >> 0] = 0; //@line 46904
 $30 = _strrchr($0, 47) | 0; //@line 46905
 $$0$i9 = ($30 | 0) == 0 ? $0 : $30 + 1 | 0; //@line 46908
 $34 = $$0$i9 - $9 | 0; //@line 46910
 _strncpy($3, $0, $34) | 0; //@line 46911
 HEAP8[$3 + $34 >> 0] = 0; //@line 46913
 $endptr18 = $3 + (_strlen($3) | 0) | 0; //@line 46915
 HEAP8[$endptr18 >> 0] = HEAP8[104080] | 0; //@line 46916
 HEAP8[$endptr18 + 1 >> 0] = HEAP8[104081] | 0; //@line 46916
 HEAP8[$endptr18 + 2 >> 0] = HEAP8[104082] | 0; //@line 46916
 HEAP8[$endptr18 + 3 >> 0] = HEAP8[104083] | 0; //@line 46916
 HEAP8[$endptr18 + 4 >> 0] = HEAP8[104084] | 0; //@line 46916
 HEAP8[$endptr18 + 5 >> 0] = HEAP8[104085] | 0; //@line 46916
 HEAP8[$endptr18 + 6 >> 0] = HEAP8[104086] | 0; //@line 46916
 _strncat($3, $$0$i9, 1023) | 0; //@line 46917
 HEAP8[$4 >> 0] = 0; //@line 46918
 $36 = _strrchr($1, 47) | 0; //@line 46919
 $$0$i10 = ($36 | 0) == 0 ? $1 : $36 + 1 | 0; //@line 46922
 $40 = $$0$i10 - $16 | 0; //@line 46924
 _strncpy($4, $1, $40) | 0; //@line 46925
 HEAP8[$4 + $40 >> 0] = 0; //@line 46927
 $endptr20 = $4 + (_strlen($4) | 0) | 0; //@line 46929
 HEAP8[$endptr20 >> 0] = HEAP8[104080] | 0; //@line 46930
 HEAP8[$endptr20 + 1 >> 0] = HEAP8[104081] | 0; //@line 46930
 HEAP8[$endptr20 + 2 >> 0] = HEAP8[104082] | 0; //@line 46930
 HEAP8[$endptr20 + 3 >> 0] = HEAP8[104083] | 0; //@line 46930
 HEAP8[$endptr20 + 4 >> 0] = HEAP8[104084] | 0; //@line 46930
 HEAP8[$endptr20 + 5 >> 0] = HEAP8[104085] | 0; //@line 46930
 HEAP8[$endptr20 + 6 >> 0] = HEAP8[104086] | 0; //@line 46930
 _strncat($4, $$0$i10, 1023) | 0; //@line 46931
 HEAP8[$2 >> 0] = 0; //@line 46932
 $42 = _strrchr($1, 47) | 0; //@line 46933
 $46 = (($42 | 0) == 0 ? $1 : $42 + 1 | 0) - $16 | 0; //@line 46938
 _strncpy($2, $1, $46) | 0; //@line 46939
 HEAP8[$2 + $46 >> 0] = 0; //@line 46941
 $endptr22 = $2 + (_strlen($2) | 0) | 0; //@line 46943
 HEAP8[$endptr22 >> 0] = HEAP8[104080] | 0; //@line 46944
 HEAP8[$endptr22 + 1 >> 0] = HEAP8[104081] | 0; //@line 46944
 HEAP8[$endptr22 + 2 >> 0] = HEAP8[104082] | 0; //@line 46944
 HEAP8[$endptr22 + 3 >> 0] = HEAP8[104083] | 0; //@line 46944
 HEAP8[$endptr22 + 4 >> 0] = HEAP8[104084] | 0; //@line 46944
 HEAP8[$endptr22 + 5 >> 0] = HEAP8[104085] | 0; //@line 46944
 HEAP8[$endptr22 + 6 >> 0] = HEAP8[104086] | 0; //@line 46944
 $50 = $2 + ((_strlen($2) | 0) + -1) | 0; //@line 46947
 if ((HEAP8[$50 >> 0] | 0) != 47) {
  _mkdir($2, 511) | 0; //@line 46951
  _rename($3, $4) | 0; //@line 46952
  $53 = _rename($0, $1) | 0; //@line 46953
  $54 = ($53 | 0) == 0; //@line 46954
  STACKTOP = sp; //@line 46955
  return $54 | 0; //@line 46955
 }
 HEAP8[$50 >> 0] = 0; //@line 46957
 _mkdir($2, 511) | 0; //@line 46958
 _rename($3, $4) | 0; //@line 46959
 $53 = _rename($0, $1) | 0; //@line 46960
 $54 = ($53 | 0) == 0; //@line 46961
 STACKTOP = sp; //@line 46962
 return $54 | 0; //@line 46962
}
function __Z19LoadPrefsFromStreamP8_IO_FILE($0) {
 $0 = $0 | 0;
 var $$0$i$i = 0, $$0$i$i31 = 0, $$0$i$ph = 0, $$0$lcssa = 0, $$014$i$i = 0, $$01416$i$i = 0, $$01418$i$i = 0, $$06$i$i = 0, $$06$i5$i = 0, $$1 = 0, $$lcssa = 0, $$sink$i$i = 0, $$sink$i$i33 = 0, $1 = 0, $13 = 0, $17 = 0, $23 = 0, $4 = 0, $5 = 0, $50 = 0, $51 = 0, $53 = 0, $58 = 0, $60 = 0, $75 = 0, $77 = 0, $82 = 0, $84 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 1467
 STACKTOP = STACKTOP + 272 | 0; //@line 1468
 $vararg_buffer = sp; //@line 1469
 $1 = sp + 8 | 0; //@line 1470
 if (!(_fgets($1, 255, $0) | 0)) {
  STACKTOP = sp; //@line 1474
  return;
 }
 $4 = $1 + 1 | 0; //@line 1476
 do {
  $5 = _strlen($1) | 0; //@line 1478
  L6 : do {
   if ($5 | 0) {
    HEAP8[$1 + ($5 + -1) >> 0] = 0; //@line 1484
    $9 = HEAP8[$1 >> 0] | 0; //@line 1485
    switch ($9 << 24 >> 24) {
    case 59:
    case 35:
     {
      break L6;
      break;
     }
    default:
     {}
    }
    if (!(_isspace($9 << 24 >> 24) | 0)) {
     $13 = $4; //@line 1498
     while (1) {
      $17 = $13 + 1 | 0; //@line 1504
      if (!(_isspace(HEAP8[$13 >> 0] | 0) | 0)) {
       $13 = $17; //@line 1506
      } else {
       $$0$lcssa = $13; //@line 1508
       $$lcssa = $17; //@line 1508
       break;
      }
     }
    } else {
     $$0$lcssa = $1; //@line 1513
     $$lcssa = $4; //@line 1513
    }
    HEAP8[$$0$lcssa >> 0] = 0; //@line 1515
    $$1 = $$lcssa; //@line 1516
    while (1) {
     if (!(_isspace(HEAP8[$$1 >> 0] | 0) | 0)) {
      break;
     } else {
      $$1 = $$1 + 1 | 0; //@line 1526
     }
    }
    $23 = _atol($$1) | 0; //@line 1529
    L16 : do {
     if ((HEAP32[91] | 0) == 3) {
      label = 12; //@line 1534
     } else {
      $$06$i$i = 360; //@line 1536
      while (1) {
       if (!(_strcmp(HEAP32[$$06$i$i >> 2] | 0, $1) | 0)) {
        $$0$i$ph = $$06$i$i; //@line 1542
        break L16;
       }
       if ((HEAP32[$$06$i$i + 20 >> 2] | 0) == 3) {
        label = 12; //@line 1550
        break;
       } else {
        $$06$i$i = $$06$i$i + 16 | 0; //@line 1553
       }
      }
     }
    } while (0);
    L20 : do {
     if ((label | 0) == 12) {
      label = 0; //@line 1560
      if ((HEAP32[1316] | 0) != 3) {
       $$06$i5$i = 5260; //@line 1564
       while (1) {
        if (!(_strcmp(HEAP32[$$06$i5$i >> 2] | 0, $1) | 0)) {
         $$0$i$ph = $$06$i5$i; //@line 1570
         break L20;
        }
        if ((HEAP32[$$06$i5$i + 20 >> 2] | 0) == 3) {
         break;
        } else {
         $$06$i5$i = $$06$i5$i + 16 | 0; //@line 1580
        }
       }
      }
      HEAP32[$vararg_buffer >> 2] = $1; //@line 1584
      _printf(89243, $vararg_buffer) | 0; //@line 1585
      break L6;
     }
    } while (0);
    switch (HEAP32[$$0$i$ph + 4 >> 2] | 0) {
    case 0:
     {
      if (!(HEAP8[$$0$i$ph + 8 >> 0] | 0)) {
       __Z18PrefsReplaceStringPKcS0_i($1, $$1, 0); //@line 1597
       break L6;
      }
      $50 = (_strlen($$1) | 0) + 1 | 0; //@line 1601
      $51 = _malloc($50) | 0; //@line 1602
      if (!$51) {
       break L6;
      }
      _memcpy($51 | 0, $$1 | 0, $50 | 0) | 0; //@line 1607
      $53 = __Znwj(16) | 0; //@line 1608
      HEAP32[$53 >> 2] = 0; //@line 1609
      HEAP32[$53 + 4 >> 2] = ___strdup($1) | 0; //@line 1612
      HEAP32[$53 + 8 >> 2] = 0; //@line 1614
      HEAP32[$53 + 12 >> 2] = $51; //@line 1616
      $58 = HEAP32[28198] | 0; //@line 1617
      if (!$58) {
       $$sink$i$i = 112792; //@line 1620
      } else {
       $$0$i$i = $58; //@line 1622
       while (1) {
        $60 = HEAP32[$$0$i$i >> 2] | 0; //@line 1624
        if (!$60) {
         break;
        } else {
         $$0$i$i = $60; //@line 1629
        }
       }
       $$sink$i$i = $$0$i$i; //@line 1632
      }
      HEAP32[$$sink$i$i >> 2] = $53; //@line 1634
      break L6;
      break;
     }
    case 1:
     {
      __Z16PrefsReplaceBoolPKcb($1, (_strcmp($$1, 88970) | 0) == 0); //@line 1641
      break L6;
      break;
     }
    case 2:
     {
      $$01416$i$i = HEAP32[28198] | 0; //@line 1646
      L41 : do {
       if ($$01416$i$i | 0) {
        $$01418$i$i = $$01416$i$i; //@line 1650
        while (1) {
         if ((HEAP32[$$01418$i$i + 8 >> 2] | 0) == 2) {
          if (!(_strcmp(HEAP32[$$01418$i$i + 4 >> 2] | 0, $1) | 0)) {
           break;
          }
         }
         $$014$i$i = HEAP32[$$01418$i$i >> 2] | 0; //@line 1664
         if (!$$014$i$i) {
          break L41;
         } else {
          $$01418$i$i = $$014$i$i; //@line 1669
         }
        }
        HEAP32[HEAP32[$$01418$i$i + 12 >> 2] >> 2] = $23; //@line 1674
        break L6;
       }
      } while (0);
      $75 = _malloc(4) | 0; //@line 1678
      if (!$75) {
       break L6;
      }
      HEAP8[$75 >> 0] = $23; //@line 1683
      HEAP8[$75 + 1 >> 0] = $23 >> 8; //@line 1683
      HEAP8[$75 + 2 >> 0] = $23 >> 16; //@line 1683
      HEAP8[$75 + 3 >> 0] = $23 >> 24; //@line 1683
      $77 = __Znwj(16) | 0; //@line 1684
      HEAP32[$77 >> 2] = 0; //@line 1685
      HEAP32[$77 + 4 >> 2] = ___strdup($1) | 0; //@line 1688
      HEAP32[$77 + 8 >> 2] = 2; //@line 1690
      HEAP32[$77 + 12 >> 2] = $75; //@line 1692
      $82 = HEAP32[28198] | 0; //@line 1693
      if (!$82) {
       $$sink$i$i33 = 112792; //@line 1696
      } else {
       $$0$i$i31 = $82; //@line 1698
       while (1) {
        $84 = HEAP32[$$0$i$i31 >> 2] | 0; //@line 1700
        if (!$84) {
         break;
        } else {
         $$0$i$i31 = $84; //@line 1705
        }
       }
       $$sink$i$i33 = $$0$i$i31; //@line 1708
      }
      HEAP32[$$sink$i$i33 >> 2] = $77; //@line 1710
      break L6;
      break;
     }
    default:
     {
      break L6;
     }
    }
   }
  } while (0);
 } while ((_fgets($1, 255, $0) | 0) != 0);
 STACKTOP = sp; //@line 1726
 return;
}
function __Z25disk_sparsebundle_factoryPKcbPP12disk_generic($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$018$off054 = 0, $$055 = 0, $$3 = 0, $$4 = 0, $11 = 0, $20 = 0, $23 = 0, $27 = 0, $3 = 0, $31 = 0, $38 = 0, $4 = 0, $42 = 0, $47 = 0, $51 = 0, $60 = 0, $61 = 0, $67 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 35473
 STACKTOP = STACKTOP + 4528 | 0; //@line 35474
 $vararg_buffer10 = sp + 32 | 0; //@line 35475
 $vararg_buffer8 = sp + 24 | 0; //@line 35476
 $vararg_buffer6 = sp + 16 | 0; //@line 35477
 $vararg_buffer2 = sp + 8 | 0; //@line 35478
 $vararg_buffer = sp; //@line 35479
 $3 = sp + 416 | 0; //@line 35480
 $4 = sp + 40 | 0; //@line 35481
 HEAP32[$vararg_buffer >> 2] = $0; //@line 35482
 HEAP32[$vararg_buffer + 4 >> 2] = 96972; //@line 35484
 if ((_snprintf($3, 4096, 96966, $vararg_buffer) | 0) > 4095) {
  $$4 = 0; //@line 35488
  STACKTOP = sp; //@line 35489
  return $$4 | 0; //@line 35489
 }
 __ZN8tinyxml211XMLDocumentC2EbNS_10WhitespaceE($4, 1, 1); //@line 35491
 L4 : do {
  if (!(__ZN8tinyxml211XMLDocument8LoadFileEPKc($4, $3) | 0)) {
   $9 = __ZNK8tinyxml27XMLNode17FirstChildElementEPKc($4, 96983) | 0; //@line 35496
   if ($9 | 0) {
    $11 = __ZNK8tinyxml27XMLNode17FirstChildElementEPKc($9, 96989) | 0; //@line 35499
    if ($11 | 0) {
     if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$11 >> 2] >> 2] & 127]($11) | 0) {
      $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$11 >> 2] >> 2] & 127]($11) | 0; //@line 35509
      HEAP32[$4 + 372 >> 2] = $20; //@line 35511
      if (!$20) {
       $$3 = 0; //@line 35514
       break;
      }
      $23 = __ZN5plist5valueEPKcS1_($4, 96994, 97016) | 0; //@line 35517
      if (!$23) {
       $$3 = 0; //@line 35520
       break;
      }
      if (_strcmp($23, 97023) | 0) {
       $$3 = 0; //@line 35526
       break;
      }
      $27 = __ZN5plist5valueEPKcS1_($4, 97056, 97084) | 0; //@line 35529
      do {
       if ($27 | 0) {
        if (HEAP8[$27 >> 0] | 0) {
         $31 = _strtoll($27, $vararg_buffer, 10) | 0; //@line 35536
         if (HEAP8[HEAP32[$vararg_buffer >> 2] >> 0] | 0) {
          break;
         }
         if (($31 | 0) == 1) {
          $38 = __ZN5plist5valueEPKcS1_($4, 97119, 97084) | 0; //@line 35546
          do {
           if ($38 | 0) {
            if (HEAP8[$38 >> 0] | 0) {
             $42 = _strtoll($38, $vararg_buffer, 10) | 0; //@line 35553
             if (HEAP8[HEAP32[$vararg_buffer >> 2] >> 0] | 0) {
              break;
             }
             $47 = __ZN5plist5valueEPKcS1_($4, 97129, 97084) | 0; //@line 35561
             if ($47 | 0) {
              if (!(HEAP8[$47 >> 0] | 0)) {
               break;
              }
              $51 = _strtoll($47, $vararg_buffer, 10) | 0; //@line 35569
              if (HEAP8[HEAP32[$vararg_buffer >> 2] >> 0] | 0) {
               break;
              }
              HEAP32[$vararg_buffer2 >> 2] = $0; //@line 35577
              HEAP32[$vararg_buffer2 + 4 >> 2] = 97165; //@line 35579
              if ((_snprintf($3, 4096, 96966, $vararg_buffer2) | 0) > 4095) {
               $$3 = 1; //@line 35583
               break L4;
              }
              $60 = _open($3, $1 ? 0 : 2, $vararg_buffer6) | 0; //@line 35587
              do {
               if (($60 | 0) != -1 | $1) {
                if (($60 | 0) == -1) {
                 label = 30; //@line 35594
                } else {
                 $$018$off054 = $1; //@line 35596
                 $$055 = $60; //@line 35596
                }
               } else {
                $61 = _open($3, 0, $vararg_buffer8) | 0; //@line 35599
                if (($61 | 0) == -1) {
                 label = 30; //@line 35602
                 break;
                }
                _fwrite(97171, 39, 1, HEAP32[22038] | 0) | 0; //@line 35606
                $$018$off054 = 1; //@line 35607
                $$055 = $61; //@line 35607
               }
              } while (0);
              if ((label | 0) == 30) {
               _perror(97211); //@line 35611
               $$3 = 1; //@line 35612
               break L4;
              }
              HEAP32[$vararg_buffer10 >> 2] = $0; //@line 35615
              HEAP32[$vararg_buffer10 + 4 >> 2] = 97238; //@line 35617
              if ((_snprintf($3, 4096, 96966, $vararg_buffer10) | 0) > 4095) {
               $$3 = 1; //@line 35621
               break L4;
              }
              $67 = __Znwj(36) | 0; //@line 35624
              HEAP32[$67 >> 2] = 1544; //@line 35626
              HEAP32[$67 + 4 >> 2] = $$055; //@line 35628
              HEAP8[$67 + 8 >> 0] = $$018$off054 & 1; //@line 35630
              HEAP32[$67 + 12 >> 2] = $42; //@line 35632
              HEAP32[$67 + 16 >> 2] = $51; //@line 35634
              HEAP32[$67 + 20 >> 2] = ___strdup($3) | 0; //@line 35637
              HEAP32[$67 + 24 >> 2] = -1; //@line 35639
              HEAP32[$67 + 28 >> 2] = -1; //@line 35641
              HEAP32[$67 + 32 >> 2] = -1; //@line 35643
              HEAP32[$2 >> 2] = $67; //@line 35644
              $$3 = 2; //@line 35645
              break L4;
             }
            }
           }
          } while (0);
          _fwrite(97134, 30, 1, HEAP32[22038] | 0) | 0; //@line 35652
          $$3 = 1; //@line 35653
          break L4;
         }
        }
       }
      } while (0);
      _fwrite(97092, 26, 1, HEAP32[22038] | 0) | 0; //@line 35660
      $$3 = 0; //@line 35661
      break;
     }
    }
   }
   HEAP32[$4 + 372 >> 2] = 0; //@line 35667
   $$3 = 0; //@line 35668
  } else {
   $$3 = 0; //@line 35670
  }
 } while (0);
 __ZN8tinyxml211XMLDocumentD2Ev($4); //@line 35673
 $$4 = $$3; //@line 35674
 STACKTOP = sp; //@line 35675
 return $$4 | 0; //@line 35675
}
function __Z11memory_initv() {
 var $$02330$us$i = 0, $$02330$us$i45 = 0, $$02427$i = 0, $$02427$i12 = 0, $$02427$i16 = 0, $$02427$i20 = 0, $$02427$i24 = 0, $$02427$i33 = 0, $$02427$i42 = 0, $$02427$i8 = 0, $$058 = 0, $$128$us$i = 0, $$128$us$i29 = 0, $$128$us$i38 = 0, $$128$us$i47 = 0, $0 = 0, $1 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $31 = 0, $33 = 0, $35 = 0, $36 = 0, $5 = 0, $56 = 0, $58 = 0, $60 = 0, $61 = 0, $73 = 0, $79 = 0, $85 = 0, $91 = 0;
 $$058 = 0; //@line 50133
 do {
  HEAP32[123608 + ($$058 << 2) >> 2] = 5404; //@line 50136
  $$058 = $$058 + 1 | 0; //@line 50137
 } while (($$058 | 0) != 65536);
 $0 = HEAP32[30895] | 0; //@line 50145
 $1 = HEAP32[30896] | 0; //@line 50146
 $5 = HEAP32[30893] | 0; //@line 50150
 HEAP32[96438] = (HEAP32[30894] | 0) - $5; //@line 50152
 HEAP32[96439] = (HEAP32[30897] | 0) - $1; //@line 50155
 HEAP32[96440] = (HEAP32[30899] | 0) + 1610612736; //@line 50158
 $13 = $5 >>> 16; //@line 50161
 $14 = ($0 >>> 0 > $1 >>> 0 ? $1 : $0) >>> 16; //@line 50162
 $15 = $5 >>> 0 > 16777215; //@line 50163
 $16 = $14 + $13 | 0; //@line 50164
 $17 = ($14 | 0) != 0; //@line 50165
 L4 : do {
  if (!(HEAP8[659480] | 0)) {
   if ($15) {
    if ($17) {
     $$02427$i33 = $13; //@line 50170
     do {
      HEAP32[123608 + (($$02427$i33 & 65535) << 2) >> 2] = 5432; //@line 50174
      $$02427$i33 = $$02427$i33 + 1 | 0; //@line 50175
     } while (($$02427$i33 | 0) < ($16 | 0));
    }
   } else {
    if ($17) {
     $$128$us$i38 = $13; //@line 50186
     do {
      HEAP32[123608 + (($$128$us$i38 & 65535) << 2) >> 2] = 5432; //@line 50190
      $$128$us$i38 = $$128$us$i38 + 1 | 0; //@line 50191
     } while (($$128$us$i38 | 0) < ($16 | 0));
    }
   }
   $56 = $1 >>> 16; //@line 50201
   $58 = (HEAP32[30898] | 0) >>> 16; //@line 50203
   $60 = $58 + $56 | 0; //@line 50205
   $61 = ($58 | 0) == 0; //@line 50206
   if ($1 >>> 0 > 16777215) {
    if ($61) {
     break;
    } else {
     $$02427$i24 = $56; //@line 50211
    }
    do {
     HEAP32[123608 + (($$02427$i24 & 65535) << 2) >> 2] = 5488; //@line 50216
     $$02427$i24 = $$02427$i24 + 1 | 0; //@line 50217
    } while (($$02427$i24 | 0) < ($60 | 0));
   } else {
    if ($61) {
     break;
    } else {
     $$128$us$i29 = $56; //@line 50229
    }
    do {
     HEAP32[123608 + (($$128$us$i29 & 65535) << 2) >> 2] = 5488; //@line 50234
     $$128$us$i29 = $$128$us$i29 + 1 | 0; //@line 50235
    } while (($$128$us$i29 | 0) < ($60 | 0));
   }
  } else {
   if ($15) {
    if ($17) {
     $$02427$i = $13; //@line 50247
     do {
      HEAP32[123608 + (($$02427$i & 65535) << 2) >> 2] = 5460; //@line 50251
      $$02427$i = $$02427$i + 1 | 0; //@line 50252
     } while (($$02427$i | 0) < ($16 | 0));
    }
   } else {
    if ($17) {
     $$02330$us$i = 0; //@line 50263
     do {
      $$128$us$i = $13; //@line 50265
      do {
       HEAP32[123608 + (($$128$us$i + $$02330$us$i & 65535) << 2) >> 2] = 5460; //@line 50270
       $$128$us$i = $$128$us$i + 1 | 0; //@line 50271
      } while (($$128$us$i | 0) < ($16 | 0));
      $$02330$us$i = $$02330$us$i + 256 | 0; //@line 50279
     } while ($$02330$us$i >>> 0 < 65536);
    }
   }
   $31 = $1 >>> 16; //@line 50289
   $33 = (HEAP32[30898] | 0) >>> 16; //@line 50291
   $35 = $33 + $31 | 0; //@line 50293
   $36 = ($33 | 0) == 0; //@line 50294
   if ($1 >>> 0 > 16777215) {
    if ($36) {
     break;
    } else {
     $$02427$i42 = $31; //@line 50299
    }
    while (1) {
     HEAP32[123608 + (($$02427$i42 & 65535) << 2) >> 2] = 5516; //@line 50304
     $$02427$i42 = $$02427$i42 + 1 | 0; //@line 50305
     if (($$02427$i42 | 0) >= ($35 | 0)) {
      break L4;
     }
    }
   }
   if (!$36) {
    $$02330$us$i45 = 0; //@line 50315
    do {
     $$128$us$i47 = $31; //@line 50317
     do {
      HEAP32[123608 + (($$128$us$i47 + $$02330$us$i45 & 65535) << 2) >> 2] = 5516; //@line 50322
      $$128$us$i47 = $$128$us$i47 + 1 | 0; //@line 50323
     } while (($$128$us$i47 | 0) < ($35 | 0));
     $$02330$us$i45 = $$02330$us$i45 + 256 | 0; //@line 50331
    } while ($$02330$us$i45 >>> 0 < 65536);
   }
  }
 } while (0);
 switch (HEAP32[30901] | 0) {
 case 1:
  {
   $73 = ((HEAP32[30900] | 0) >>> 16) + 40960 | 0; //@line 50347
   $$02427$i20 = 40960; //@line 50348
   while (1) {
    HEAP32[123608 + (($$02427$i20 & 65535) << 2) >> 2] = 5544; //@line 50352
    if (($$02427$i20 | 0) == ($73 | 0)) {
     break;
    } else {
     $$02427$i20 = $$02427$i20 + 1 | 0; //@line 50358
    }
   }
   return;
  }
 case 2:
  {
   $79 = ((HEAP32[30900] | 0) >>> 16) + 40960 | 0; //@line 50367
   $$02427$i16 = 40960; //@line 50368
   while (1) {
    HEAP32[123608 + (($$02427$i16 & 65535) << 2) >> 2] = 5572; //@line 50372
    if (($$02427$i16 | 0) == ($79 | 0)) {
     break;
    } else {
     $$02427$i16 = $$02427$i16 + 1 | 0; //@line 50378
    }
   }
   return;
  }
 case 3:
  {
   $85 = ((HEAP32[30900] | 0) >>> 16) + 40960 | 0; //@line 50387
   $$02427$i12 = 40960; //@line 50388
   while (1) {
    HEAP32[123608 + (($$02427$i12 & 65535) << 2) >> 2] = 5600; //@line 50392
    if (($$02427$i12 | 0) == ($85 | 0)) {
     break;
    } else {
     $$02427$i12 = $$02427$i12 + 1 | 0; //@line 50398
    }
   }
   return;
  }
 case 4:
  {
   $91 = ((HEAP32[30900] | 0) >>> 16) + 40960 | 0; //@line 50407
   $$02427$i8 = 40960; //@line 50408
   while (1) {
    HEAP32[123608 + (($$02427$i8 & 65535) << 2) >> 2] = 5628; //@line 50412
    if (($$02427$i8 | 0) == ($91 | 0)) {
     break;
    } else {
     $$02427$i8 = $$02427$i8 + 1 | 0; //@line 50418
    }
   }
   return;
  }
 default:
  {
   return;
  }
 }
}
function __ZN8tinyxml27XMLUtil15GetCharacterRefEPKcPcPi($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i = 0, $$06395 = 0, $$06398 = 0, $$06597 = 0, $$06996 = 0, $$091 = 0, $$094 = 0, $$1$i = 0, $$16693 = 0, $$170 = 0, $$2 = 0, $$2$i = 0, $$2104 = 0, $$2105 = 0, $$2106 = 0, $$375 = 0, $$392 = 0, $$5 = 0, $$5103 = 0, $$sink = 0, $11 = 0, $17 = 0, $18 = 0, $21 = 0, $26 = 0, $28 = 0, $3 = 0, $31 = 0, $37 = 0, $38 = 0, $41 = 0, $44 = 0, $46 = 0, $48 = 0, $6 = 0, $71 = 0, $8 = 0, label = 0;
 HEAP32[$2 >> 2] = 0; //@line 37212
 $3 = $0 + 1 | 0; //@line 37213
 if ((HEAP8[$3 >> 0] | 0) != 35) {
  $$375 = $3; //@line 37217
  return $$375 | 0; //@line 37218
 }
 $6 = $0 + 2 | 0; //@line 37220
 L4 : do {
  switch (HEAP8[$6 >> 0] | 0) {
  case 120:
   {
    $8 = $0 + 3 | 0; //@line 37225
    if (!(HEAP8[$8 >> 0] | 0)) {
     $$375 = 0; //@line 37229
     return $$375 | 0; //@line 37230
    }
    $11 = _strchr($8, 59) | 0; //@line 37232
    if (!$11) {
     $$375 = 0; //@line 37235
     return $$375 | 0; //@line 37236
    }
    if (!(HEAP8[$11 >> 0] | 0)) {
     $$375 = 0; //@line 37241
     return $$375 | 0; //@line 37242
    }
    $17 = $11 - $0 | 0; //@line 37246
    $$06395 = $11 + -1 | 0; //@line 37247
    $18 = HEAP8[$$06395 >> 0] | 0; //@line 37248
    if ($18 << 24 >> 24 == 120) {
     $$2106 = $17; //@line 37251
     $$5103 = 0; //@line 37251
     label = 25; //@line 37252
    } else {
     $$06398 = $$06395; //@line 37255
     $$06597 = 1; //@line 37255
     $$06996 = 0; //@line 37255
     $21 = $18; //@line 37255
     $26 = $18 << 24 >> 24; //@line 37255
     while (1) {
      if (($21 + -48 & 255) < 10) {
       $$sink = -48; //@line 37260
      } else {
       if (($21 + -97 & 255) < 6) {
        $$sink = -87; //@line 37265
       } else {
        if (($21 + -65 & 255) < 6) {
         $$sink = -55; //@line 37270
        } else {
         $$375 = 0; //@line 37272
         break;
        }
       }
      }
      $$170 = (Math_imul($$sink + $26 | 0, $$06597) | 0) + $$06996 | 0; //@line 37279
      $$06398 = $$06398 + -1 | 0; //@line 37281
      $28 = HEAP8[$$06398 >> 0] | 0; //@line 37282
      if ($28 << 24 >> 24 == 120) {
       $$2 = $17; //@line 37286
       $$5 = $$170; //@line 37286
       label = 18; //@line 37287
       break L4;
      } else {
       $$06597 = $$06597 << 4; //@line 37290
       $$06996 = $$170; //@line 37290
       $21 = $28; //@line 37290
       $26 = $28 << 24 >> 24; //@line 37290
      }
     }
     return $$375 | 0; //@line 37293
    }
    break;
   }
  case 0:
   {
    $$375 = $3; //@line 37298
    return $$375 | 0; //@line 37299
   }
  default:
   {
    $31 = _strchr($6, 59) | 0; //@line 37303
    if (!$31) {
     $$375 = 0; //@line 37306
     return $$375 | 0; //@line 37307
    }
    if (!(HEAP8[$31 >> 0] | 0)) {
     $$375 = 0; //@line 37312
     return $$375 | 0; //@line 37313
    }
    $37 = $31 - $0 | 0; //@line 37317
    $$091 = $31 + -1 | 0; //@line 37318
    $38 = HEAP8[$$091 >> 0] | 0; //@line 37319
    if ($38 << 24 >> 24 == 35) {
     $$2106 = $37; //@line 37322
     $$5103 = 0; //@line 37322
     label = 25; //@line 37323
    } else {
     $$094 = $$091; //@line 37326
     $$16693 = 1; //@line 37326
     $$392 = 0; //@line 37326
     $41 = $38; //@line 37326
     $44 = $38 << 24 >> 24; //@line 37326
     while (1) {
      if (($41 + -48 & 255) >= 10) {
       $$375 = 0; //@line 37331
       break;
      }
      $46 = (Math_imul($44 + -48 | 0, $$16693) | 0) + $$392 | 0; //@line 37336
      $$094 = $$094 + -1 | 0; //@line 37338
      $48 = HEAP8[$$094 >> 0] | 0; //@line 37339
      if ($48 << 24 >> 24 == 35) {
       $$2 = $37; //@line 37343
       $$5 = $46; //@line 37343
       label = 18; //@line 37344
       break L4;
      } else {
       $$16693 = $$16693 * 10 | 0; //@line 37347
       $$392 = $46; //@line 37347
       $41 = $48; //@line 37347
       $44 = $48 << 24 >> 24; //@line 37347
      }
     }
     return $$375 | 0; //@line 37350
    }
   }
  }
 } while (0);
 L36 : do {
  if ((label | 0) == 18) {
   if ($$5 >>> 0 < 128) {
    $$2106 = $$2; //@line 37359
    $$5103 = $$5; //@line 37359
    label = 25; //@line 37360
   } else {
    if ($$5 >>> 0 < 2048) {
     HEAP32[$2 >> 2] = 2; //@line 37364
     $$1$i = $$5; //@line 37365
    } else {
     do {
      if ($$5 >>> 0 < 65536) {
       HEAP32[$2 >> 2] = 3; //@line 37370
       $$0$i = $$5; //@line 37371
      } else {
       if ($$5 >>> 0 < 2097152) {
        HEAP32[$2 >> 2] = 4; //@line 37375
        HEAP8[$1 + 3 >> 0] = $$5 & 63 | 128; //@line 37380
        $$0$i = $$5 >>> 6; //@line 37382
        break;
       } else {
        HEAP32[$2 >> 2] = 0; //@line 37385
        $$2104 = $$2; //@line 37386
        break L36;
       }
      }
     } while (0);
     HEAP8[$1 + 2 >> 0] = $$0$i & 63 | 128; //@line 37395
     $$1$i = $$0$i >>> 6; //@line 37397
    }
    HEAP8[$1 + 1 >> 0] = $$1$i & 63 | 128; //@line 37403
    $$2$i = $$1$i >>> 6; //@line 37406
    $$2105 = $$2; //@line 37406
    $71 = HEAP32[$2 >> 2] | 0; //@line 37406
    label = 29; //@line 37407
   }
  }
 } while (0);
 if ((label | 0) == 25) {
  HEAP32[$2 >> 2] = 1; //@line 37412
  $$2$i = $$5103; //@line 37413
  $$2105 = $$2106; //@line 37413
  $71 = 1; //@line 37413
  label = 29; //@line 37414
 }
 if ((label | 0) == 29) {
  HEAP8[$1 >> 0] = HEAP32[1708 + ($71 << 2) >> 2] | $$2$i; //@line 37421
  $$2104 = $$2105; //@line 37422
 }
 $$375 = $0 + $$2104 + 1 | 0; //@line 37426
 return $$375 | 0; //@line 37427
}
function __Z18cpu_do_check_ticksv() {
 var $0 = 0, $105 = 0, $107 = 0, $11 = 0, $111 = 0, $113 = 0, $116 = 0, $120 = 0, $124 = 0, $125 = 0, $131 = 0, $137 = 0, $138 = 0, $139 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $145 = 0, $147 = 0, $15 = 0, $151 = 0, $155 = 0, $18 = 0, $21 = 0, $27 = 0, $28 = 0, $29 = 0, $34 = 0, $40 = 0, $41 = 0, $42 = 0, $47 = 0, $53 = 0, $56 = 0, $62 = 0, $71 = 0, $79 = 0, $80 = 0, $86 = 0, $87 = 0, $9 = 0, $95 = 0, $99 = 0, label = 0;
 $0 = 112640; //@line 47846
 if ((HEAP32[$0 >> 2] | 0) == 0 & (HEAP32[$0 + 4 >> 2] | 0) == 0) {
  $9 = __Z13GetTicks_usecv() | 0; //@line 47856
  $11 = 112640; //@line 47858
  HEAP32[$11 >> 2] = $9; //@line 47860
  HEAP32[$11 + 4 >> 2] = tempRet0; //@line 47863
 }
 $15 = HEAP32[1313] | 0; //@line 47865
 if (($15 | 0) < 1) {
  $18 = (HEAP32[1314] | 0) - $15 | 0; //@line 47869
  $21 = 112648; //@line 47872
  $27 = _i64Add($18 | 0, (($18 | 0) < 0) << 31 >> 31 | 0, HEAP32[$21 >> 2] | 0, HEAP32[$21 + 4 >> 2] | 0) | 0; //@line 47878
  $28 = tempRet0; //@line 47879
  $29 = 112648; //@line 47880
  HEAP32[$29 >> 2] = $27; //@line 47882
  HEAP32[$29 + 4 >> 2] = $28; //@line 47885
  if (($28 | 0) < 0) {
   _puts(104401) | 0; //@line 47888
   $34 = 112656; //@line 47889
   $139 = 0; //@line 47895
   $140 = 0; //@line 47895
   $141 = HEAP32[$34 >> 2] | 0; //@line 47895
   $142 = HEAP32[$34 + 4 >> 2] | 0; //@line 47895
   label = 22; //@line 47896
  } else {
   label = 6; //@line 47898
  }
 } else {
  label = 6; //@line 47901
 }
 do {
  if ((label | 0) == 6) {
   $40 = __Z13GetTicks_usecv() | 0; //@line 47905
   $41 = tempRet0; //@line 47906
   $42 = 112640; //@line 47907
   $47 = HEAP32[$42 + 4 >> 2] | 0; //@line 47912
   if ($47 >>> 0 < $41 >>> 0 | (($47 | 0) == ($41 | 0) ? (HEAP32[$42 >> 2] | 0) >>> 0 < $40 >>> 0 : 0)) {
    $53 = HEAP32[30883] | 0; //@line 47919
    HEAP32[30883] = $53 + 1; //@line 47921
    if (($53 | 0) > 59) {
     HEAP32[30883] = 0; //@line 47924
     $56 = __Z13TimerDateTimev() | 0; //@line 47925
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](524, $56); //@line 47929
     HEAP32[30882] = HEAP32[30882] | 2; //@line 47932
     __Z16TriggerInterruptv(); //@line 47933
     $62 = HEAP32[30884] | 0; //@line 47934
     HEAP32[30884] = $62 + 1; //@line 47936
     if (($62 | 0) > 59) {
      HEAP32[30884] = 0; //@line 47939
      if (_memcmp(659481, 656025, 256) | 0) {
       _memcpy(659481, 656025, 256) | 0; //@line 47943
       __Z9SaveXPRAMv(); //@line 47944
      }
     }
    }
    __Z12VideoRefreshv(); //@line 47948
    if (!((HEAP32[30883] | 0) % 11 | 0)) {
     __Z18audio_write_blocksi(1); //@line 47953
    }
    $71 = HEAP32[30882] | 8; //@line 47956
    HEAP32[30882] = $71; //@line 47957
    if ((HEAP16[325960] | 0) == 630) {
     if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](3324) | 0) == 1464619843) {
      $79 = HEAP32[30882] | 0; //@line 47967
      label = 16; //@line 47968
     }
    } else {
     $79 = $71; //@line 47971
     label = 16; //@line 47972
    }
    if ((label | 0) == 16) {
     HEAP32[30882] = $79 | 1; //@line 47976
     __Z16TriggerInterruptv(); //@line 47977
    }
    $80 = 112640; //@line 47979
    $86 = HEAP32[$80 >> 2] | 0; //@line 47985
    $87 = HEAP32[$80 + 4 >> 2] | 0; //@line 47985
    do {
     $86 = _i64Add($86 | 0, $87 | 0, 16625, 0) | 0; //@line 47987
     $87 = tempRet0; //@line 47988
    } while ($87 >>> 0 < $41 >>> 0 | ($87 | 0) == ($41 | 0) & $86 >>> 0 < $40 >>> 0);
    $95 = 112640; //@line 48000
    HEAP32[$95 >> 2] = $86; //@line 48002
    HEAP32[$95 + 4 >> 2] = $87; //@line 48005
    $99 = 112664; //@line 48006
    $105 = _i64Add(HEAP32[$99 >> 2] | 0, HEAP32[$99 + 4 >> 2] | 0, 1, 0) | 0; //@line 48012
    $107 = 112664; //@line 48014
    HEAP32[$107 >> 2] = $105; //@line 48016
    HEAP32[$107 + 4 >> 2] = tempRet0; //@line 48019
    $111 = 112656; //@line 48020
    $113 = HEAP32[$111 >> 2] | 0; //@line 48022
    $116 = HEAP32[$111 + 4 >> 2] | 0; //@line 48025
    if (($113 | 0) == 0 & ($116 | 0) == 0) {
     $120 = 112656; //@line 48030
     HEAP32[$120 >> 2] = $40; //@line 48032
     HEAP32[$120 + 4 >> 2] = $41; //@line 48035
     break;
    } else {
     $124 = _i64Subtract($40 | 0, $41 | 0, $113 | 0, $116 | 0) | 0; //@line 48038
     $125 = tempRet0; //@line 48039
     if ($125 >>> 0 > 0 | ($125 | 0) == 0 & $124 >>> 0 > 166250) {
      $139 = $40; //@line 48046
      $140 = $41; //@line 48046
      $141 = $113; //@line 48046
      $142 = $116; //@line 48046
      label = 22; //@line 48047
      break;
     } else {
      break;
     }
    }
   }
  }
 } while (0);
 if ((label | 0) == 22) {
  $131 = 112648; //@line 48057
  $137 = ___muldi3(HEAP32[$131 >> 2] | 0, HEAP32[$131 + 4 >> 2] | 0, 1e3, 0) | 0; //@line 48063
  $138 = tempRet0; //@line 48064
  $143 = _i64Subtract($139 | 0, $140 | 0, $141 | 0, $142 | 0) | 0; //@line 48065
  $145 = ___udivdi3($137 | 0, $138 | 0, $143 | 0, tempRet0 | 0) | 0; //@line 48067
  HEAP32[1314] = $145; //@line 48069
  $147 = 112648; //@line 48070
  HEAP32[$147 >> 2] = 0; //@line 48072
  HEAP32[$147 + 4 >> 2] = 0; //@line 48075
  $151 = 112656; //@line 48076
  HEAP32[$151 >> 2] = $139; //@line 48078
  HEAP32[$151 + 4 >> 2] = $140; //@line 48081
 }
 $155 = HEAP32[1313] | 0; //@line 48083
 if (($155 | 0) >= 1) {
  return;
 }
 HEAP32[1313] = (HEAP32[1314] | 0) + $155; //@line 48090
 return;
}
function __ZN12monitor_desc15set_gamma_tableEj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$03646 = 0, $$pre$i = 0, $$pre$i41 = 0, $10 = 0, $101 = 0, $110 = 0, $111 = 0, $114 = 0, $115 = 0, $117 = 0, $120 = 0, $125 = 0, $13 = 0, $19 = 0, $2 = 0, $26 = 0, $33 = 0, $4 = 0, $40 = 0, $47 = 0, $54 = 0, $55 = 0, $63 = 0, $69 = 0, $7 = 0, $77 = 0, $8 = 0, $83 = 0, $84 = 0, $90 = 0, $92 = 0, $98 = 0, sp = 0;
 sp = STACKTOP; //@line 23812
 STACKTOP = STACKTOP + 80 | 0; //@line 23813
 $2 = sp; //@line 23814
 if (!$1) {
  $4 = $0 + 800 | 0; //@line 23817
  $7 = $0 + 796 | 0; //@line 23820
  $8 = HEAP32[$7 >> 2] | 0; //@line 23821
  do {
   if ((HEAP32[$4 >> 2] | 0) < 268) {
    $$pre$i = $2 + 32 | 0; //@line 23825
    if ($8 | 0) {
     HEAP32[$$pre$i >> 2] = $8; //@line 23827
     _Execute68kTrap(-24545, $2); //@line 23828
     HEAP32[$7 >> 2] = 0; //@line 23829
     HEAP32[$4 >> 2] = 0; //@line 23830
    }
    HEAP32[$2 >> 2] = 268; //@line 23832
    _Execute68kTrap(-22754, $2); //@line 23833
    $10 = HEAP32[$$pre$i >> 2] | 0; //@line 23834
    if ($10 | 0) {
     HEAP32[$7 >> 2] = $10; //@line 23837
     HEAP32[$4 >> 2] = 268; //@line 23838
     $13 = $10; //@line 23839
     break;
    }
    STACKTOP = sp; //@line 23842
    return 1; //@line 23842
   } else {
    $13 = $8; //@line 23844
   }
  } while (0);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, 0); //@line 23852
  $19 = (HEAP32[$7 >> 2] | 0) + 2 | 0; //@line 23854
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($19, 0); //@line 23860
  $26 = (HEAP32[$7 >> 2] | 0) + 4 | 0; //@line 23862
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, 0); //@line 23868
  $33 = (HEAP32[$7 >> 2] | 0) + 6 | 0; //@line 23870
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($33, 1); //@line 23876
  $40 = (HEAP32[$7 >> 2] | 0) + 8 | 0; //@line 23878
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($40, 256); //@line 23884
  $47 = (HEAP32[$7 >> 2] | 0) + 10 | 0; //@line 23886
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($47 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($47, 8); //@line 23892
  $54 = (HEAP32[$7 >> 2] | 0) + 12 | 0; //@line 23894
  $$03646 = 0; //@line 23895
  do {
   $55 = $54 + $$03646 | 0; //@line 23897
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($55, $$03646); //@line 23903
   $$03646 = $$03646 + 1 | 0; //@line 23904
  } while (($$03646 | 0) != 256);
 } else {
  $63 = 123608 + ($1 >>> 16 << 2) | 0; //@line 23914
  if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$63 >> 2] | 0) + 4 >> 2] & 127]($1) | 0) {
   STACKTOP = sp; //@line 23921
   return 1; //@line 23921
  }
  $69 = $1 + 2 | 0; //@line 23923
  if (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($69 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($69) | 0) {
   STACKTOP = sp; //@line 23932
   return 1; //@line 23932
  }
  $77 = $1 + 6 | 0; //@line 23934
  $83 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($77 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($77) | 0; //@line 23940
  switch ($83 | 0) {
  case 1:
  case 3:
   {
    break;
   }
  default:
   {
    STACKTOP = sp; //@line 23946
    return 1; //@line 23946
   }
  }
  $84 = $1 + 10 | 0; //@line 23949
  $90 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($84 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($84) | 0; //@line 23955
  if (($90 | 0) > 8) {
   STACKTOP = sp; //@line 23958
   return 1; //@line 23958
  }
  $92 = $1 + 8 | 0; //@line 23960
  $98 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($92 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($92) | 0; //@line 23966
  if (($98 | 0) != (1 << $90 | 0)) {
   STACKTOP = sp; //@line 23970
   return 1; //@line 23970
  }
  $101 = $1 + 4 | 0; //@line 23972
  $110 = (Math_imul($98, $83) | 0) + 12 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($101 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($101) | 0) | 0; //@line 23981
  $111 = $0 + 800 | 0; //@line 23982
  $114 = $0 + 796 | 0; //@line 23985
  $115 = HEAP32[$114 >> 2] | 0; //@line 23986
  do {
   if ((HEAP32[$111 >> 2] | 0) < ($110 | 0)) {
    $$pre$i41 = $2 + 32 | 0; //@line 23990
    if ($115 | 0) {
     HEAP32[$$pre$i41 >> 2] = $115; //@line 23992
     _Execute68kTrap(-24545, $2); //@line 23993
     HEAP32[$114 >> 2] = 0; //@line 23994
     HEAP32[$111 >> 2] = 0; //@line 23995
    }
    HEAP32[$2 >> 2] = $110; //@line 23997
    _Execute68kTrap(-22754, $2); //@line 23998
    $117 = HEAP32[$$pre$i41 >> 2] | 0; //@line 23999
    if ($117 | 0) {
     HEAP32[$114 >> 2] = $117; //@line 24002
     HEAP32[$111 >> 2] = $110; //@line 24003
     $120 = $117; //@line 24004
     break;
    }
    STACKTOP = sp; //@line 24007
    return 1; //@line 24007
   } else {
    $120 = $115; //@line 24009
   }
  } while (0);
  $125 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($120 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($120) | 0; //@line 24017
  _memcpy($125 | 0, FUNCTION_TABLE_ii[HEAP32[(HEAP32[$63 >> 2] | 0) + 24 >> 2] & 127]($1) | 0, $110 | 0) | 0; //@line 24022
 }
 if ((HEAP32[(HEAP32[$0 + 16 >> 2] | 0) + 12 >> 2] | 1 | 0) != 5) {
  STACKTOP = sp; //@line 24031
  return 1; //@line 24031
 }
 __ZN12monitor_desc17load_ramp_paletteEv($0); //@line 24033
 STACKTOP = sp; //@line 24034
 return 1; //@line 24034
}
function __Z9PrimeTimeji($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0911$i = 0, $106 = 0, $16 = 0, $19 = 0, $2 = 0, $21 = 0, $28 = 0, $3 = 0, $30 = 0, $36 = 0, $37 = 0, $4 = 0, $42 = 0, $43 = 0, $47 = 0, $5 = 0, $52 = 0, $53 = 0, $57 = 0, $6 = 0, $62 = 0, $63 = 0, $67 = 0, $68 = 0, $7 = 0, $73 = 0, $74 = 0, $8 = 0, $81 = 0, $82 = 0, $87 = 0, $88 = 0, $9 = 0, $92 = 0, $97 = 0, $98 = 0, $tmpcast$byval_copy = 0, $tmpcast19$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 13246
 STACKTOP = STACKTOP + 80 | 0; //@line 13247
 $tmpcast19$byval_copy = sp + 72 | 0; //@line 13248
 $tmpcast$byval_copy = sp + 64 | 0; //@line 13249
 $2 = sp + 40 | 0; //@line 13250
 $3 = sp + 16 | 0; //@line 13251
 $4 = sp + 56 | 0; //@line 13252
 $5 = sp + 48 | 0; //@line 13253
 $6 = sp + 32 | 0; //@line 13254
 $7 = sp + 24 | 0; //@line 13255
 $8 = sp + 8 | 0; //@line 13256
 $9 = sp; //@line 13257
 $$0911$i = 0; //@line 13258
 while (1) {
  if (HEAP8[112848 + ($$0911$i << 4) + 12 >> 0] | 0) {
   if ((HEAP32[112848 + ($$0911$i << 4) >> 2] | 0) == ($0 | 0)) {
    label = 5; //@line 13268
    break;
   }
  }
  $16 = $$0911$i + 1 | 0; //@line 13272
  if (($16 | 0) < 64) {
   $$0911$i = $16; //@line 13275
  } else {
   break;
  }
 }
 if ((label | 0) == 5) {
  if (($$0911$i | 0) >= 0) {
   $19 = $0 + 4 | 0; //@line 13283
   $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 13285
   if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0) & 16384)) {
    __Z19timer_mac2host_timeR7timevali($2, $1); //@line 13293
    $81 = 112848 + ($$0911$i << 4) + 4 | 0; //@line 13294
    __Z18timer_current_timeR7timeval($81); //@line 13295
    $82 = $81; //@line 13296
    $87 = HEAP32[$82 + 4 >> 2] | 0; //@line 13301
    $88 = $8; //@line 13302
    HEAP32[$88 >> 2] = HEAP32[$82 >> 2]; //@line 13304
    HEAP32[$88 + 4 >> 2] = $87; //@line 13307
    $92 = $2; //@line 13308
    $97 = HEAP32[$92 + 4 >> 2] | 0; //@line 13313
    $98 = $9; //@line 13314
    HEAP32[$98 >> 2] = HEAP32[$92 >> 2]; //@line 13316
    HEAP32[$98 + 4 >> 2] = $97; //@line 13319
    HEAP32[$tmpcast$byval_copy >> 2] = HEAP32[$8 >> 2]; //@line 13320
    HEAP32[$tmpcast$byval_copy + 4 >> 2] = HEAP32[$8 + 4 >> 2]; //@line 13320
    HEAP32[$tmpcast19$byval_copy >> 2] = HEAP32[$9 >> 2]; //@line 13321
    HEAP32[$tmpcast19$byval_copy + 4 >> 2] = HEAP32[$9 + 4 >> 2]; //@line 13321
    __Z14timer_add_timeR7timevalS_S_($81, $tmpcast$byval_copy, $tmpcast19$byval_copy); //@line 13322
   } else {
    __Z19timer_mac2host_timeR7timevali($2, $1); //@line 13324
    $28 = $0 + 14 | 0; //@line 13325
    $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 13327
    if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0)) {
     __Z18timer_current_timeR7timeval($6); //@line 13333
     $67 = 112848 + ($$0911$i << 4) + 4 | 0; //@line 13334
     $68 = $2; //@line 13335
     $73 = HEAP32[$68 + 4 >> 2] | 0; //@line 13340
     $74 = $7; //@line 13341
     HEAP32[$74 >> 2] = HEAP32[$68 >> 2]; //@line 13343
     HEAP32[$74 + 4 >> 2] = $73; //@line 13346
     HEAP32[$tmpcast$byval_copy >> 2] = HEAP32[$6 >> 2]; //@line 13347
     HEAP32[$tmpcast$byval_copy + 4 >> 2] = HEAP32[$6 + 4 >> 2]; //@line 13347
     HEAP32[$tmpcast19$byval_copy >> 2] = HEAP32[$7 >> 2]; //@line 13348
     HEAP32[$tmpcast19$byval_copy + 4 >> 2] = HEAP32[$7 + 4 >> 2]; //@line 13348
     __Z14timer_add_timeR7timevalS_S_($67, $tmpcast$byval_copy, $tmpcast19$byval_copy); //@line 13349
    } else {
     if (!$1) {
      _puts(93363) | 0; //@line 13353
     }
     $36 = 112848 + ($$0911$i << 4) + 4 | 0; //@line 13355
     $37 = $36; //@line 13356
     $42 = HEAP32[$37 + 4 >> 2] | 0; //@line 13361
     $43 = $4; //@line 13362
     HEAP32[$43 >> 2] = HEAP32[$37 >> 2]; //@line 13364
     HEAP32[$43 + 4 >> 2] = $42; //@line 13367
     $47 = $2; //@line 13368
     $52 = HEAP32[$47 + 4 >> 2] | 0; //@line 13373
     $53 = $5; //@line 13374
     HEAP32[$53 >> 2] = HEAP32[$47 >> 2]; //@line 13376
     HEAP32[$53 + 4 >> 2] = $52; //@line 13379
     HEAP32[$tmpcast$byval_copy >> 2] = HEAP32[$4 >> 2]; //@line 13380
     HEAP32[$tmpcast$byval_copy + 4 >> 2] = HEAP32[$4 + 4 >> 2]; //@line 13380
     HEAP32[$tmpcast19$byval_copy >> 2] = HEAP32[$5 >> 2]; //@line 13381
     HEAP32[$tmpcast19$byval_copy + 4 >> 2] = HEAP32[$5 + 4 >> 2]; //@line 13381
     __Z14timer_add_timeR7timevalS_S_($3, $tmpcast$byval_copy, $tmpcast19$byval_copy); //@line 13382
     $57 = $3; //@line 13383
     $62 = HEAP32[$57 + 4 >> 2] | 0; //@line 13388
     $63 = $36; //@line 13389
     HEAP32[$63 >> 2] = HEAP32[$57 >> 2]; //@line 13391
     HEAP32[$63 + 4 >> 2] = $62; //@line 13394
    }
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, 305419896); //@line 13399
   }
   $106 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0 | 32768; //@line 13405
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $106); //@line 13409
   STACKTOP = sp; //@line 13410
   return 0; //@line 13410
  }
 }
 _puts(93322) | 0; //@line 13413
 STACKTOP = sp; //@line 13414
 return 0; //@line 13414
}
function __ZN17driver_fullscreenC2ER16SDL_monitor_desc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$0$i28 = 0, $$029 = 0, $$pr$i = 0, $11 = 0, $14 = 0, $16 = 0, $17 = 0, $2 = 0, $25 = 0, $27 = 0, $3 = 0, $32 = 0, $33 = 0, $34 = 0, $37 = 0, $53 = 0, $56 = 0, $6 = 0, $60 = 0, $61 = 0, $68 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 44524
 STACKTOP = STACKTOP + 48 | 0; //@line 44525
 $vararg_buffer2 = sp + 32 | 0; //@line 44526
 $vararg_buffer = sp; //@line 44527
 $2 = $0 + 4 | 0; //@line 44528
 HEAP32[$2 >> 2] = $1; //@line 44529
 $3 = $0 + 8 | 0; //@line 44530
 HEAP32[$3 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 44533
 $6 = $0 + 12 | 0; //@line 44534
 HEAP8[$6 >> 0] = 0; //@line 44535
 $7 = $0 + 16 | 0; //@line 44536
 HEAP32[$7 >> 2] = 0; //@line 44537
 HEAP32[30852] = 0; //@line 44538
 HEAP32[30854] = 0; //@line 44539
 HEAP32[$0 >> 2] = 4336; //@line 44540
 _puts(102648) | 0; //@line 44541
 $8 = HEAP32[$3 >> 2] | 0; //@line 44542
 $9 = HEAP32[$8 >> 2] | 0; //@line 44543
 $11 = HEAP32[$8 + 4 >> 2] | 0; //@line 44545
 __Z18ADBSetRelMouseModeb(0); //@line 44546
 $14 = HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0; //@line 44549
 L1 : do {
  if (($14 | 0) < 4) {
   $16 = 8; //@line 44553
  } else {
   switch ($14 | 0) {
   case 4:
    {
     $16 = 16; //@line 44557
     break L1;
     break;
    }
   case 5:
    {
     $16 = 32; //@line 44562
     break L1;
     break;
    }
   default:
    {
     _abort(); //@line 44567
    }
   }
  }
 } while (0);
 $17 = _SDL_SetVideoMode($9 | 0, $11 | 0, $16 | 0, -2147483647) | 0; //@line 44573
 HEAP32[$7 >> 2] = $17; //@line 44574
 if (!$17) {
  STACKTOP = sp; //@line 44577
  return;
 }
 $25 = Math_imul(HEAPU16[$17 + 16 >> 1] | 0, $11 + 15 & -16 | 2) | 0; //@line 44585
 HEAP32[30853] = $25; //@line 44586
 HEAP32[30854] = _calloc(1, $25) | 0; //@line 44588
 $27 = HEAP32[30861] | 0; //@line 44589
 do {
  if (!$27) {
   label = 10; //@line 44593
  } else {
   if ((__Z16vm_acquire_fixedPvji($27, $25, 2) | 0) < 0) {
    _puts(102685) | 0; //@line 44598
    HEAP32[30861] = 0; //@line 44599
    label = 10; //@line 44600
    break;
   } else {
    $$pr$i = HEAP32[30861] | 0; //@line 44603
    if (!$$pr$i) {
     label = 10; //@line 44606
     break;
    } else {
     $33 = $$pr$i; //@line 44609
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 10) {
  $32 = __Z10vm_acquireji($25, 10) | 0; //@line 44616
  HEAP32[30861] = $32; //@line 44617
  $33 = $32; //@line 44618
 }
 HEAP32[30852] = $33; //@line 44620
 $34 = HEAP32[30854] | 0; //@line 44621
 HEAP32[$vararg_buffer >> 2] = $33; //@line 44622
 HEAP32[$vararg_buffer + 4 >> 2] = $34; //@line 44624
 _printf(102745, $vararg_buffer) | 0; //@line 44625
 _SDL_ShowCursor(0) | 0; //@line 44626
 $37 = HEAP32[(HEAP32[$7 >> 2] | 0) + 4 >> 2] | 0; //@line 44629
 HEAP32[$vararg_buffer + 4 >> 2] = $16; //@line 44631
 HEAP32[$vararg_buffer + 8 >> 2] = HEAP32[$37 + 16 >> 2]; //@line 44635
 HEAP32[$vararg_buffer + 12 >> 2] = HEAP32[$37 + 20 >> 2]; //@line 44639
 HEAP32[$vararg_buffer + 16 >> 2] = HEAP32[$37 + 24 >> 2]; //@line 44643
 switch (HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0) {
 case 0:
  {
   $$0$i28 = 1; //@line 44649
   break;
  }
 case 1:
  {
   $$0$i28 = 2; //@line 44653
   break;
  }
 case 2:
  {
   $$0$i28 = 4; //@line 44657
   break;
  }
 case 3:
  {
   $$0$i28 = 8; //@line 44661
   break;
  }
 case 4:
  {
   $$0$i28 = 16; //@line 44665
   break;
  }
 case 5:
  {
   $$0$i28 = 32; //@line 44669
   break;
  }
 default:
  {
   _abort(); //@line 44673
  }
 }
 __Z19Screen_blitter_initRK12VisualFormatbi($vararg_buffer, 1, $$0$i28) | 0; //@line 44677
 $53 = HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0; //@line 44680
 if (($53 | 1 | 0) == 5) {
  $61 = $53; //@line 44684
 } else {
  $$029 = 0; //@line 44686
  do {
   $56 = $$029 & 255; //@line 44688
   HEAP32[122204 + ($$029 << 2) >> 2] = _SDL_MapRGB($37 | 0, $56 | 0, $56 | 0, $56 | 0) | 0; //@line 44691
   $$029 = $$029 + 1 | 0; //@line 44692
  } while (($$029 | 0) != 256);
  $61 = HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0; //@line 44703
 }
 $60 = HEAP32[$2 >> 2] | 0; //@line 44705
 switch ($61 | 0) {
 case 4:
  {
   $$0$i = (HEAP32[30862] | 0) == 15 ? 2 : 3; //@line 44711
   break;
  }
 case 5:
  {
   $$0$i = (HEAP32[30862] | 0) == 24 ? 4 : 1; //@line 44718
   break;
  }
 default:
  {
   $$0$i = 1; //@line 44722
  }
 }
 HEAP32[30901] = $$0$i; //@line 44725
 $68 = $60 + 20 | 0; //@line 44726
 HEAP32[$68 >> 2] = -1610612736; //@line 44727
 $70 = HEAP32[$60 + 16 >> 2] | 0; //@line 44729
 HEAP32[30899] = HEAP32[30852]; //@line 44731
 HEAP32[30900] = Math_imul(HEAP32[$70 + 4 >> 2] | 0, HEAP32[$70 + 16 >> 2] | 0) | 0; //@line 44737
 __Z22InitFrameBufferMappingv(); //@line 44738
 HEAP32[$vararg_buffer2 >> 2] = HEAP32[$68 >> 2]; //@line 44740
 _printf(102784, $vararg_buffer2) | 0; //@line 44741
 HEAP8[$6 >> 0] = 1; //@line 44742
 STACKTOP = sp; //@line 44743
 return;
}
function __Z25rpc_method_wait_for_replyP16rpc_connection_tz($0, $varargs) {
 $0 = $0 | 0;
 $varargs = $varargs | 0;
 var $$0 = 0, $$012$i$ph$i = 0, $$012$i$ph$i21 = 0, $$012$i$ph$i28 = 0, $$014$i$ph$i = 0, $$014$i$ph$i20 = 0, $$014$i$ph$i27 = 0, $$019 = 0, $$idx$val = 0, $$lcssa59 = 0, $$lcssa61 = 0, $$pre = 0, $1 = 0, $14 = 0, $15 = 0, $17 = 0, $18 = 0, $2 = 0, $21 = 0, $25 = 0, $3 = 0, $33 = 0, $36 = 0, $49 = 0, $60 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 43556
 STACKTOP = STACKTOP + 1056 | 0; //@line 43557
 $1 = sp + 1048 | 0; //@line 43558
 $2 = sp + 1032 | 0; //@line 43559
 $3 = sp; //@line 43560
 if (!$0) {
  $$0 = -1003; //@line 43563
  STACKTOP = sp; //@line 43564
  return $$0 | 0; //@line 43564
 }
 if ((HEAP32[$0 >> 2] | 0) != 1) {
  $$0 = -1004; //@line 43569
  STACKTOP = sp; //@line 43570
  return $$0 | 0; //@line 43570
 }
 $7 = $0 + 4 | 0; //@line 43572
 HEAP32[$7 >> 2] = 1; //@line 43573
 $$idx$val = HEAP32[$0 + 8 >> 2] | 0; //@line 43575
 HEAP32[$3 >> 2] = $$idx$val; //@line 43576
 HEAP32[$3 + 4 >> 2] = 0; //@line 43578
 HEAP32[$2 >> 2] = $varargs; //@line 43579
 $14 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 43591
 $15 = HEAP32[$14 >> 2] | 0; //@line 43592
 HEAP32[$2 >> 2] = $14 + 4; //@line 43594
 do {
  if (!$15) {
   label = 21; //@line 43598
  } else {
   $$012$i$ph$i21 = 4; //@line 43600
   $$014$i$ph$i20 = $1; //@line 43600
   $17 = $$idx$val; //@line 43600
   L9 : while (1) {
    $18 = _recv($17, $$014$i$ph$i20, $$012$i$ph$i21, 0) | 0; //@line 43602
    if (($18 | 0) > 0) {
     $$lcssa59 = $18; //@line 43605
     $$lcssa61 = $17; //@line 43605
    } else {
     $21 = $18; //@line 43607
     while (1) {
      if (($21 | 0) != -1) {
       label = 10; //@line 43611
       break L9;
      }
      if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
       label = 10; //@line 43618
       break L9;
      }
      $$pre = HEAP32[$3 >> 2] | 0; //@line 43621
      $25 = _recv($$pre, $$014$i$ph$i20, $$012$i$ph$i21, 0) | 0; //@line 43622
      if (($25 | 0) > 0) {
       $$lcssa59 = $25; //@line 43625
       $$lcssa61 = $$pre; //@line 43625
       break;
      } else {
       $21 = $25; //@line 43628
      }
     }
    }
    $$012$i$ph$i21 = $$012$i$ph$i21 - $$lcssa59 | 0; //@line 43632
    if (($$012$i$ph$i21 | 0) <= 0) {
     break;
    } else {
     $$014$i$ph$i20 = $$014$i$ph$i20 + $$lcssa59 | 0; //@line 43636
     $17 = $$lcssa61; //@line 43636
    }
   }
   if ((label | 0) == 10) {
    $$019 = -1001; //@line 43642
    break;
   }
   if ((_ntohl(HEAP32[$1 >> 2] | 0) | 0) == -3003) {
    HEAP32[$2 >> 2] = $varargs; //@line 43649
    $33 = __ZL21rpc_message_recv_argsP13rpc_message_tPi($3, $2) | 0; //@line 43650
    if (!$33) {
     $$012$i$ph$i28 = 4; //@line 43653
     $$014$i$ph$i27 = $1; //@line 43653
     L22 : while (1) {
      while (1) {
       $36 = _recv(HEAP32[$3 >> 2] | 0, $$014$i$ph$i27, $$012$i$ph$i28, 0) | 0; //@line 43657
       if (($36 | 0) > 0) {
        break;
       }
       if (($36 | 0) != -1) {
        label = 19; //@line 43664
        break L22;
       }
       if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
        label = 19; //@line 43671
        break L22;
       }
      }
      $$012$i$ph$i28 = $$012$i$ph$i28 - $36 | 0; //@line 43675
      if (($$012$i$ph$i28 | 0) <= 0) {
       label = 20; //@line 43681
       break;
      } else {
       $$014$i$ph$i27 = $$014$i$ph$i27 + $36 | 0; //@line 43679
      }
     }
     if ((label | 0) == 19) {
      $$019 = -1001; //@line 43686
      break;
     } else if ((label | 0) == 20) {
      if ((_ntohl(HEAP32[$1 >> 2] | 0) | 0) == -3001) {
       label = 21; //@line 43694
       break;
      } else {
       $$019 = -1005; //@line 43697
       break;
      }
     }
    } else {
     $$019 = $33; //@line 43702
    }
   } else {
    $$019 = -1005; //@line 43705
   }
  }
 } while (0);
 do {
  if ((label | 0) == 21) {
   $$012$i$ph$i = 4; //@line 43711
   $$014$i$ph$i = $1; //@line 43711
   L34 : while (1) {
    while (1) {
     $49 = _recv(HEAP32[$3 >> 2] | 0, $$014$i$ph$i, $$012$i$ph$i, 0) | 0; //@line 43715
     if (($49 | 0) > 0) {
      break;
     }
     if (($49 | 0) != -1) {
      label = 27; //@line 43722
      break L34;
     }
     if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
      label = 27; //@line 43729
      break L34;
     }
    }
    $$012$i$ph$i = $$012$i$ph$i - $49 | 0; //@line 43733
    if (($$012$i$ph$i | 0) <= 0) {
     label = 28; //@line 43739
     break;
    } else {
     $$014$i$ph$i = $$014$i$ph$i + $49 | 0; //@line 43737
    }
   }
   if ((label | 0) == 27) {
    $$019 = -1001; //@line 43744
    break;
   } else if ((label | 0) == 28) {
    $60 = (_ntohl(HEAP32[$1 >> 2] | 0) | 0) == -3002; //@line 43750
    $$019 = $60 ? 0 : -1005; //@line 43752
    break;
   }
  }
 } while (0);
 HEAP32[$7 >> 2] = 0; //@line 43757
 $$0 = $$019; //@line 43758
 STACKTOP = sp; //@line 43759
 return $$0 | 0; //@line 43759
}
function __ZNK8tinyxml210XMLElement12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$0$lcssa$i29 = 0, $$019$lcssa$i = 0, $$019$lcssa$i28 = 0, $$019$lcssa$i283537 = 0, $$019$lcssa$i3334 = 0, $$01923$i = 0, $$01923$i23 = 0, $$01941 = 0, $$01942 = 0, $$02022$i = 0, $$02022$i24 = 0, $$024$i = 0, $$024$i22 = 0, $$1 = 0, $$lcssa = 0, $$lcssa39 = 0, $10 = 0, $12 = 0, $14 = 0, $17 = 0, $20 = 0, $21 = 0, $26 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $38 = 0, $39 = 0, $41 = 0, $43 = 0, $46 = 0, $49 = 0, $5 = 0, $50 = 0, $55 = 0, $61 = 0, $62 = 0, $8 = 0, label = 0;
 $5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 24 >> 2] & 127]($1) | 0; //@line 37960
 if (!$5) {
  $$1 = 0; //@line 37963
  return $$1 | 0; //@line 37964
 }
 $8 = __ZN8tinyxml27StrPair6GetStrEv($5 + 12 | 0) | 0; //@line 37967
 $10 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 37969
 do {
  if (($8 | 0) != ($10 | 0)) {
   $12 = HEAP8[$8 >> 0] | 0; //@line 37973
   if (!($12 << 24 >> 24)) {
    $$019$lcssa$i3334 = $10; //@line 37976
   } else {
    $$01923$i = $10; //@line 37978
    $$02022$i = $8; //@line 37978
    $$024$i = 0; //@line 37978
    $17 = $12; //@line 37978
    while (1) {
     $14 = HEAP8[$$01923$i >> 0] | 0; //@line 37980
     if (!(($$024$i | 0) != 2147483647 & ($14 << 24 >> 24 ? $17 << 24 >> 24 == $14 << 24 >> 24 : 0))) {
      $$0$lcssa$i = $$024$i; //@line 37987
      $$019$lcssa$i = $$01923$i; //@line 37987
      $26 = $17; //@line 37987
      break;
     }
     $$02022$i = $$02022$i + 1 | 0; //@line 37990
     $20 = $$01923$i + 1 | 0; //@line 37991
     $21 = $$024$i + 1 | 0; //@line 37992
     $17 = HEAP8[$$02022$i >> 0] | 0; //@line 37993
     if (!($17 << 24 >> 24)) {
      $$0$lcssa$i = $21; //@line 37996
      $$019$lcssa$i = $20; //@line 37996
      $26 = 0; //@line 37996
      break;
     } else {
      $$01923$i = $20; //@line 37999
      $$024$i = $21; //@line 37999
     }
    }
    if (($$0$lcssa$i | 0) == 2147483647) {
     break;
    }
    if (!($26 << 24 >> 24)) {
     $$019$lcssa$i3334 = $$019$lcssa$i; //@line 38008
    } else {
     $$1 = 0; //@line 38010
     return $$1 | 0; //@line 38011
    }
   }
   if (HEAP8[$$019$lcssa$i3334 >> 0] | 0) {
    $$1 = 0; //@line 38017
    return $$1 | 0; //@line 38018
   }
  }
 } while (0);
 $$01941 = HEAP32[$0 + 48 >> 2] | 0; //@line 38024
 $31 = HEAP32[$5 + 48 >> 2] | 0; //@line 38025
 $32 = ($$01941 | 0) != 0; //@line 38026
 $33 = ($31 | 0) != 0; //@line 38027
 L16 : do {
  if ($32 & $33) {
   $$01942 = $$01941; //@line 38031
   $38 = $31; //@line 38031
   L17 : while (1) {
    $36 = __ZN8tinyxml27StrPair6GetStrEv($$01942 + 16 | 0) | 0; //@line 38034
    $39 = __ZN8tinyxml27StrPair6GetStrEv($38 + 16 | 0) | 0; //@line 38036
    do {
     if (($36 | 0) != ($39 | 0)) {
      $41 = HEAP8[$36 >> 0] | 0; //@line 38040
      if (!($41 << 24 >> 24)) {
       $$019$lcssa$i283537 = $39; //@line 38043
      } else {
       $$01923$i23 = $39; //@line 38045
       $$02022$i24 = $36; //@line 38045
       $$024$i22 = 0; //@line 38045
       $46 = $41; //@line 38045
       while (1) {
        $43 = HEAP8[$$01923$i23 >> 0] | 0; //@line 38047
        if (!(($$024$i22 | 0) != 2147483647 & ($43 << 24 >> 24 ? $46 << 24 >> 24 == $43 << 24 >> 24 : 0))) {
         $$0$lcssa$i29 = $$024$i22; //@line 38054
         $$019$lcssa$i28 = $$01923$i23; //@line 38054
         $55 = $46; //@line 38054
         break;
        }
        $$02022$i24 = $$02022$i24 + 1 | 0; //@line 38057
        $49 = $$01923$i23 + 1 | 0; //@line 38058
        $50 = $$024$i22 + 1 | 0; //@line 38059
        $46 = HEAP8[$$02022$i24 >> 0] | 0; //@line 38060
        if (!($46 << 24 >> 24)) {
         $$0$lcssa$i29 = $50; //@line 38063
         $$019$lcssa$i28 = $49; //@line 38063
         $55 = 0; //@line 38063
         break;
        } else {
         $$01923$i23 = $49; //@line 38066
         $$024$i22 = $50; //@line 38066
        }
       }
       if (($$0$lcssa$i29 | 0) == 2147483647) {
        break;
       }
       if (!($55 << 24 >> 24)) {
        $$019$lcssa$i283537 = $$019$lcssa$i28; //@line 38075
       } else {
        $$1 = 0; //@line 38077
        label = 19; //@line 38078
        break L17;
       }
      }
      if (HEAP8[$$019$lcssa$i283537 >> 0] | 0) {
       $$1 = 0; //@line 38085
       label = 19; //@line 38086
       break L17;
      }
     }
    } while (0);
    $$01942 = HEAP32[$$01942 + 28 >> 2] | 0; //@line 38093
    $38 = HEAP32[$38 + 28 >> 2] | 0; //@line 38094
    $61 = ($$01942 | 0) != 0; //@line 38095
    $62 = ($38 | 0) != 0; //@line 38096
    if (!($61 & $62)) {
     $$lcssa = $62; //@line 38101
     $$lcssa39 = $61; //@line 38101
     break L16;
    }
   }
   if ((label | 0) == 19) {
    return $$1 | 0; //@line 38106
   }
  } else {
   $$lcssa = $33; //@line 38109
   $$lcssa39 = $32; //@line 38109
  }
 } while (0);
 $$1 = ($$lcssa39 | $$lcssa) ^ 1; //@line 38114
 return $$1 | 0; //@line 38115
}
function __Z10SonyStatusjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$020$sink = 0, $$sroa$03$07$i = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $21 = 0, $24 = 0, $26 = 0, $32 = 0, $37 = 0, $46 = 0, $52 = 0, $54 = 0, $67 = 0, $70 = 0, $77 = 0, $8 = 0, $83 = 0, $89 = 0, $9 = 0, $trunc = 0, $vararg_buffer = 0, dest = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 17941
 STACKTOP = STACKTOP + 16 | 0; //@line 17942
 $vararg_buffer = sp; //@line 17943
 $2 = $0 + 26 | 0; //@line 17944
 $8 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0; //@line 17950
 $9 = $0 + 22 | 0; //@line 17951
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($9) | 0; //@line 17957
 $16 = HEAP32[28486] | 0; //@line 17958
 $17 = HEAP32[28485] | 0; //@line 17959
 L1 : do {
  if (($17 | 0) == ($16 | 0)) {
   $$020$sink = -56; //@line 17963
  } else {
   $$sroa$03$07$i = $17; //@line 17965
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($15 | 0)) {
     break;
    }
    $21 = $$sroa$03$07$i + 16 | 0; //@line 17972
    if (($21 | 0) == ($16 | 0)) {
     $$020$sink = -56; //@line 17975
     break L1;
    } else {
     $$sroa$03$07$i = $21; //@line 17978
    }
   }
   if (($$sroa$03$07$i | 0) == ($16 | 0)) {
    $$020$sink = -56; //@line 17983
   } else {
    $trunc = $8 & 65535; //@line 17985
    L7 : do {
     if ($trunc << 16 >> 16 < 10) {
      switch ($trunc << 16 >> 16) {
      case 6:
       {
        break;
       }
      case 8:
       {
        $52 = $0 + 28 | 0; //@line 17994
        $54 = HEAP32[$$sroa$03$07$i + 12 >> 2] | 0; //@line 17996
        dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($52 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($52) | 0; //@line 18009
        src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($54 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($54) | 0; //@line 18009
        stop = dest + 22 | 0; //@line 18009
        do {
         HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 18009
         dest = dest + 1 | 0; //@line 18009
         src = src + 1 | 0; //@line 18009
        } while ((dest | 0) < (stop | 0));
        $$020$sink = 0; //@line 18010
        break L1;
        break;
       }
      default:
       {
        break L7;
       }
      }
      $24 = $0 + 28 | 0; //@line 18018
      $26 = 123608 + ($24 >>> 16 << 2) | 0; //@line 18020
      if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$26 >> 2] | 0) + 4 >> 2] & 127]($24) | 0)) {
       $$020$sink = -50; //@line 18027
       break L1;
      }
      $32 = $0 + 30 | 0; //@line 18030
      $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($32 >>> 16 << 2) >> 2] >> 2] & 127]($32) | 0; //@line 18035
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$26 >> 2] | 0) + 16 >> 2] & 31]($24, 1); //@line 18039
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($37, 2880); //@line 18045
      $46 = $37 + 4 | 0; //@line 18046
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($46, -770572208); //@line 18052
      $$020$sink = 0; //@line 18053
      break L1;
     } else {
      if ($trunc << 16 >> 16 < 17494) {
       switch ($trunc << 16 >> 16) {
       case 10:
        {
         break;
        }
       default:
        {
         break L7;
        }
       }
       $67 = $0 + 28 | 0; //@line 18066
       $70 = (HEAP32[$$sroa$03$07$i + 12 >> 2] | 0) + 22 | 0; //@line 18069
       $77 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($70 >>> 16 << 2) >> 2] >> 2] & 127]($70) | 0) & -256 | 254; //@line 18076
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($67 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($67, $77); //@line 18082
       $$020$sink = 0; //@line 18083
       break L1;
      }
      if ($trunc << 16 >> 16 < 21315) {
       switch ($trunc << 16 >> 16) {
       case 17494:
        {
         break;
        }
       default:
        {
         break L7;
        }
       }
       $83 = $0 + 28 | 0; //@line 18096
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($83 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($83, 1040); //@line 18102
       $$020$sink = 0; //@line 18103
       break L1;
      } else {
       switch ($trunc << 16 >> 16) {
       case 21315:
        {
         break;
        }
       default:
        {
         break L7;
        }
       }
       $89 = $0 + 28 | 0; //@line 18114
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($89 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($89, 2); //@line 18120
       $$020$sink = 0; //@line 18121
       break L1;
      }
     }
    } while (0);
    HEAP32[$vararg_buffer >> 2] = $8 & 65535; //@line 18127
    _printf(94239, $vararg_buffer) | 0; //@line 18128
    $$020$sink = -18; //@line 18129
   }
  }
 } while (0);
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, $$020$sink << 16 >> 16); //@line 18137
 STACKTOP = sp; //@line 18138
 return $$020$sink | 0; //@line 18138
}
function __Z14ether_udp_readjiP11sockaddr_in($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i = 0, $$0$i$i = 0, $$0$ph$i$i = 0, $$0$ph$lcssa$i$i$i = 0, $$0$ph13$i$i$i = 0, $$024$i$i = 0, $$025$i33$i = 0, $$07$ph12$i$i$i = 0, $$0710$i$i$i = 0, $$in$i$i = 0, $13 = 0, $19 = 0, $20 = 0, $23 = 0, $24 = 0, $3 = 0, $32 = 0, $39 = 0, $41 = 0, $44 = 0, $45 = 0, $48 = 0, $49 = 0, $5 = 0, $55 = 0, $59 = 0, $63 = 0, $66 = 0, $72 = 0, $82 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 16789
 STACKTOP = STACKTOP + 80 | 0; //@line 16790
 $3 = sp; //@line 16791
 $5 = 123608 + ($0 >>> 16 << 2) | 0; //@line 16793
 if (!(_memcmp((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 24 >> 2] & 127]($0) | 0) + 6 | 0, 657344, 6) | 0)) {
  STACKTOP = sp; //@line 16802
  return;
 }
 $13 = $0 + 12 | 0; //@line 16804
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 16810
 $20 = $19 & 65535; //@line 16811
 $23 = $20 >>> 0 < 1501 ? 0 : $19 & 65535; //@line 16814
 $24 = HEAP32[28479] | 0; //@line 16815
 if (!$24) {
  STACKTOP = sp; //@line 16818
  return;
 } else {
  $$0$ph13$i$i$i = 113916; //@line 16820
  $$07$ph12$i$i$i = $24; //@line 16820
 }
 L6 : while (1) {
  $$0710$i$i$i = $$07$ph12$i$i$i; //@line 16823
  while (1) {
   if ((HEAPU16[$$0710$i$i$i + 16 >> 1] | 0) >= ($23 & 65535)) {
    break;
   }
   $32 = HEAP32[$$0710$i$i$i + 4 >> 2] | 0; //@line 16832
   if (!$32) {
    $$0$ph$lcssa$i$i$i = $$0$ph13$i$i$i; //@line 16835
    break L6;
   } else {
    $$0710$i$i$i = $32; //@line 16838
   }
  }
  $$07$ph12$i$i$i = HEAP32[$$0710$i$i$i >> 2] | 0; //@line 16841
  if (!$$07$ph12$i$i$i) {
   $$0$ph$lcssa$i$i$i = $$0710$i$i$i; //@line 16844
   break;
  } else {
   $$0$ph13$i$i$i = $$0710$i$i$i; //@line 16847
  }
 }
 if (($$0$ph$lcssa$i$i$i | 0) == 113916) {
  STACKTOP = sp; //@line 16852
  return;
 }
 if (($23 & 65535) < (HEAPU16[$$0$ph$lcssa$i$i$i + 16 >> 1] | 0)) {
  STACKTOP = sp; //@line 16858
  return;
 }
 $$0$i$i = 113916; //@line 16860
 $$024$i$i = $24; //@line 16860
 $48 = $24; //@line 16860
 while (1) {
  $39 = HEAP16[$$024$i$i + 16 >> 1] | 0; //@line 16863
  if (($23 & 65535) < ($39 & 65535)) {
   $41 = HEAP32[$$024$i$i >> 2] | 0; //@line 16866
   if (!$41) {
    $$025$i33$i = $$024$i$i; //@line 16869
    label = 16; //@line 16870
    break;
   } else {
    $$0$ph$i$i = $$024$i$i; //@line 16873
    $$in$i$i = $41; //@line 16873
   }
  } else {
   if (($39 & 65535) >= ($23 & 65535)) {
    label = 15; //@line 16878
    break;
   }
   $44 = $$024$i$i + 4 | 0; //@line 16881
   $45 = HEAP32[$44 >> 2] | 0; //@line 16882
   if (!$45) {
    $$025$i33$i = $44; //@line 16885
    label = 16; //@line 16886
    break;
   } else {
    $$0$ph$i$i = $44; //@line 16889
    $$in$i$i = $45; //@line 16889
   }
  }
  $$0$i$i = $$0$ph$i$i; //@line 16892
  $$024$i$i = $$in$i$i; //@line 16892
  $48 = $$in$i$i; //@line 16892
 }
 if ((label | 0) == 15) {
  if (!$48) {
   $$025$i33$i = $$0$i$i; //@line 16897
   label = 16; //@line 16898
  } else {
   $$0$i = $48; //@line 16900
  }
 }
 if ((label | 0) == 16) {
  $49 = __Znwj(24) | 0; //@line 16904
  HEAP16[$49 + 16 >> 1] = $23; //@line 16906
  HEAP32[$49 + 20 >> 2] = 0; //@line 16908
  HEAP32[$49 >> 2] = 0; //@line 16909
  HEAP32[$49 + 4 >> 2] = 0; //@line 16911
  HEAP32[$49 + 8 >> 2] = $$024$i$i; //@line 16913
  HEAP32[$$025$i33$i >> 2] = $49; //@line 16914
  $55 = HEAP32[HEAP32[28478] >> 2] | 0; //@line 16916
  if (!$55) {
   $59 = $49; //@line 16919
  } else {
   HEAP32[28478] = $55; //@line 16922
   $59 = HEAP32[$$025$i33$i >> 2] | 0; //@line 16924
  }
  __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[28479] | 0, $59); //@line 16927
  HEAP32[28480] = (HEAP32[28480] | 0) + 1; //@line 16930
  $$0$i = $49; //@line 16931
 }
 $63 = HEAP32[$$0$i + 20 >> 2] | 0; //@line 16934
 if (!$63) {
  STACKTOP = sp; //@line 16937
  return;
 }
 $66 = (HEAP32[28477] | 0) + 38 | 0; //@line 16940
 $72 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($66 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($66) | 0; //@line 16946
 dest = $72; //@line 16951
 src = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 24 >> 2] & 127]($0) | 0; //@line 16951
 stop = dest + 14 | 0; //@line 16951
 do {
  HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 16951
  dest = dest + 1 | 0; //@line 16951
  src = src + 1 | 0; //@line 16951
 } while ((dest | 0) < (stop | 0));
 HEAP32[$3 >> 2] = $20; //@line 16952
 HEAP32[$3 + 4 >> 2] = $1 + -14; //@line 16955
 HEAP32[$3 + 32 >> 2] = $0 + 14; //@line 16958
 $82 = (HEAP32[28477] | 0) + 52 | 0; //@line 16960
 HEAP32[$3 + 44 >> 2] = $82; //@line 16962
 HEAP32[$3 + 48 >> 2] = $82; //@line 16964
 _Execute68k($63, $3); //@line 16965
 STACKTOP = sp; //@line 16966
 return;
}
function __ZL13print_optionsPK10prefs_desc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$i = 0, $$0$i29 = 0, $$014$i$i = 0, $$014$i$i21 = 0, $$014$i$i27 = 0, $$01416$i$i = 0, $$01416$i$i18 = 0, $$01416$i$i24 = 0, $$01418$i$i = 0, $$01418$i$i19 = 0, $$01418$i$i25 = 0, $$015 = 0, $$01634 = 0, $$pre$phiZ2D = 0, $1 = 0, $22 = 0, $3 = 0, $36 = 0, $5 = 0, $50 = 0, $6 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 1066
 STACKTOP = STACKTOP + 64 | 0; //@line 1067
 $vararg_buffer1 = sp + 8 | 0; //@line 1068
 $vararg_buffer = sp; //@line 1069
 $1 = sp + 24 | 0; //@line 1070
 $3 = HEAP32[$0 + 4 >> 2] | 0; //@line 1072
 if (($3 | 0) == 3) {
  STACKTOP = sp; //@line 1075
  return;
 }
 $$01634 = $0; //@line 1077
 $8 = $3; //@line 1077
 while (1) {
  $5 = $$01634 + 12 | 0; //@line 1079
  $6 = HEAP32[$5 >> 2] | 0; //@line 1080
  if ($6 | 0) {
   L8 : do {
    switch ($8 | 0) {
    case 0:
     {
      $9 = HEAP32[$$01634 >> 2] | 0; //@line 1086
      $$01416$i$i = HEAP32[28198] | 0; //@line 1087
      L11 : do {
       if (!$$01416$i$i) {
        $$0$i = 0; //@line 1091
       } else {
        $$01418$i$i = $$01416$i$i; //@line 1093
        while (1) {
         if (!(HEAP32[$$01418$i$i + 8 >> 2] | 0)) {
          if (!(_strcmp(HEAP32[$$01418$i$i + 4 >> 2] | 0, $9) | 0)) {
           break;
          }
         }
         $$014$i$i = HEAP32[$$01418$i$i >> 2] | 0; //@line 1107
         if (!$$014$i$i) {
          $$0$i = 0; //@line 1110
          break L11;
         } else {
          $$01418$i$i = $$014$i$i; //@line 1113
         }
        }
        $$0$i = HEAP32[$$01418$i$i + 12 >> 2] | 0; //@line 1118
       }
      } while (0);
      $$0 = ($$0$i | 0) == 0 ? 89182 : $$0$i; //@line 1123
      $$015 = 89175; //@line 1123
      $$pre$phiZ2D = $$01634; //@line 1123
      $50 = $6; //@line 1123
      break;
     }
    case 1:
     {
      $22 = HEAP32[$$01634 >> 2] | 0; //@line 1127
      $$01416$i$i18 = HEAP32[28198] | 0; //@line 1128
      if (!$$01416$i$i18) {
       $$0 = 88982; //@line 1131
       $$015 = 89187; //@line 1131
       $$pre$phiZ2D = $$01634; //@line 1131
       $50 = $6; //@line 1131
      } else {
       $$01418$i$i19 = $$01416$i$i18; //@line 1133
       while (1) {
        if ((HEAP32[$$01418$i$i19 + 8 >> 2] | 0) == 1) {
         if (!(_strcmp(HEAP32[$$01418$i$i19 + 4 >> 2] | 0, $22) | 0)) {
          break;
         }
        }
        $$014$i$i21 = HEAP32[$$01418$i$i19 >> 2] | 0; //@line 1147
        if (!$$014$i$i21) {
         $$0 = 88982; //@line 1150
         $$015 = 89187; //@line 1150
         $$pre$phiZ2D = $$01634; //@line 1150
         $50 = $6; //@line 1150
         break L8;
        } else {
         $$01418$i$i19 = $$014$i$i21; //@line 1153
        }
       }
       $$0 = HEAP8[HEAP32[$$01418$i$i19 + 12 >> 2] >> 0] | 0 ? 88970 : 88982; //@line 1161
       $$015 = 89187; //@line 1161
       $$pre$phiZ2D = $$01634; //@line 1161
       $50 = $6; //@line 1161
      }
      break;
     }
    case 2:
     {
      $36 = HEAP32[$$01634 >> 2] | 0; //@line 1166
      $$01416$i$i24 = HEAP32[28198] | 0; //@line 1167
      L27 : do {
       if (!$$01416$i$i24) {
        $$0$i29 = 0; //@line 1171
       } else {
        $$01418$i$i25 = $$01416$i$i24; //@line 1173
        while (1) {
         if ((HEAP32[$$01418$i$i25 + 8 >> 2] | 0) == 2) {
          if (!(_strcmp(HEAP32[$$01418$i$i25 + 4 >> 2] | 0, $36) | 0)) {
           break;
          }
         }
         $$014$i$i27 = HEAP32[$$01418$i$i25 >> 2] | 0; //@line 1187
         if (!$$014$i$i27) {
          $$0$i29 = 0; //@line 1190
          break L27;
         } else {
          $$01418$i$i25 = $$014$i$i27; //@line 1193
         }
        }
        $$0$i29 = HEAP32[HEAP32[$$01418$i$i25 + 12 >> 2] >> 2] | 0; //@line 1199
       }
      } while (0);
      HEAP32[$vararg_buffer >> 2] = $$0$i29; //@line 1202
      _sprintf($1, 89199, $vararg_buffer) | 0; //@line 1203
      $$0 = $1; //@line 1205
      $$015 = 89192; //@line 1205
      $$pre$phiZ2D = $$01634; //@line 1205
      $50 = HEAP32[$5 >> 2] | 0; //@line 1205
      break;
     }
    default:
     {
      $$0 = 89182; //@line 1209
      $$015 = 89202; //@line 1209
      $$pre$phiZ2D = $$01634; //@line 1209
      $50 = $6; //@line 1209
     }
    }
   } while (0);
   HEAP32[$vararg_buffer1 >> 2] = HEAP32[$$pre$phiZ2D >> 2]; //@line 1214
   HEAP32[$vararg_buffer1 + 4 >> 2] = $$015; //@line 1216
   HEAP32[$vararg_buffer1 + 8 >> 2] = $50; //@line 1218
   HEAP32[$vararg_buffer1 + 12 >> 2] = $$0; //@line 1220
   _printf(89212, $vararg_buffer1) | 0; //@line 1221
  }
  $8 = HEAP32[$$01634 + 20 >> 2] | 0; //@line 1225
  if (($8 | 0) == 3) {
   break;
  } else {
   $$01634 = $$01634 + 16 | 0; //@line 1230
  }
 }
 STACKTOP = sp; //@line 1233
 return;
}
function __ZN8tinyxml211XMLDocument8LoadFileEP8_IO_FILE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i21 = 0, $$0$i2122 = 0, $$0$lcssa$i = 0, $$03$i = 0, $$2 = 0, $$pre$phi$i$iZ2D = 0, $11 = 0, $13 = 0, $16 = 0, $19 = 0, $2 = 0, $23 = 0, $3 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $41 = 0, $46 = 0, $47 = 0, $5 = 0, $50 = 0, $53 = 0, $56 = 0, $57 = 0, $6 = 0, $65 = 0, $68 = 0, $7 = 0, $8 = 0, label = 0;
 $2 = $0 + 24 | 0; //@line 41402
 $3 = HEAP32[$2 >> 2] | 0; //@line 41403
 if (!$3) {
  $$pre$phi$i$iZ2D = $0 + 28 | 0; //@line 41407
 } else {
  $5 = $0 + 28 | 0; //@line 41409
  $7 = $3; //@line 41410
  do {
   $6 = $7 + 36 | 0; //@line 41412
   $8 = HEAP32[$6 >> 2] | 0; //@line 41413
   HEAP32[$2 >> 2] = $8; //@line 41414
   $11 = $7 + 32 | 0; //@line 41417
   if ((HEAP32[$5 >> 2] | 0) == ($7 | 0)) {
    $13 = HEAP32[$11 >> 2] | 0; //@line 41420
    HEAP32[$5 >> 2] = $13; //@line 41421
    $16 = $13; //@line 41423
   } else {
    $16 = HEAP32[$11 >> 2] | 0; //@line 41426
   }
   if (!$16) {
    $19 = $8; //@line 41430
   } else {
    HEAP32[$16 + 36 >> 2] = $8; //@line 41433
    $19 = HEAP32[$6 >> 2] | 0; //@line 41435
   }
   if ($19 | 0) {
    HEAP32[$19 + 32 >> 2] = $16; //@line 41440
   }
   HEAP32[$7 + 8 >> 2] = 0; //@line 41443
   $23 = HEAP32[$7 + 40 >> 2] | 0; //@line 41445
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$7 >> 2] | 0) + 64 >> 2] & 4095]($7); //@line 41449
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($23, $7); //@line 41453
   $7 = HEAP32[$2 >> 2] | 0; //@line 41454
  } while (($7 | 0) != 0);
  $$pre$phi$i$iZ2D = $5; //@line 41457
 }
 HEAP32[$$pre$phi$i$iZ2D >> 2] = 0; //@line 41464
 HEAP32[$2 >> 2] = 0; //@line 41465
 $32 = $0 + 48 | 0; //@line 41466
 HEAP32[$32 >> 2] = 0; //@line 41467
 $33 = $0 + 56 | 0; //@line 41468
 HEAP32[$33 >> 2] = 0; //@line 41469
 $34 = $0 + 60 | 0; //@line 41470
 HEAP32[$34 >> 2] = 0; //@line 41471
 $35 = $0 + 64 | 0; //@line 41472
 $36 = HEAP32[$35 >> 2] | 0; //@line 41473
 if ($36 | 0) {
  __ZdaPv($36); //@line 41476
 }
 HEAP32[$35 >> 2] = 0; //@line 41478
 _fseek($1, 0, 2) | 0; //@line 41479
 $38 = _ftell($1) | 0; //@line 41480
 _fseek($1, 0, 0) | 0; //@line 41481
 if (!$38) {
  $$2 = HEAP32[$32 >> 2] | 0; //@line 41484
  return $$2 | 0; //@line 41485
 }
 $41 = __Znaj($38 + 1 | 0) | 0; //@line 41488
 HEAP32[$35 >> 2] = $41; //@line 41489
 if ((_fread($41, 1, $38, $1) | 0) != ($38 | 0)) {
  HEAP32[$32 >> 2] = 5; //@line 41493
  HEAP32[$33 >> 2] = 0; //@line 41494
  HEAP32[$34 >> 2] = 0; //@line 41495
  $$2 = HEAP32[$32 >> 2] | 0; //@line 41496
  return $$2 | 0; //@line 41497
 }
 HEAP8[(HEAP32[$35 >> 2] | 0) + $38 >> 0] = 0; //@line 41501
 $46 = HEAP32[$35 >> 2] | 0; //@line 41502
 $47 = HEAP8[$46 >> 0] | 0; //@line 41503
 L27 : do {
  if ($47 << 24 >> 24 > -1) {
   $$03$i = $46; //@line 41507
   $50 = $47; //@line 41507
   while (1) {
    if (!(_isspace($50 & 255) | 0)) {
     $$0$lcssa$i = $$03$i; //@line 41513
     break L27;
    }
    $53 = $$03$i + 1 | 0; //@line 41516
    $50 = HEAP8[$53 >> 0] | 0; //@line 41517
    if ($50 << 24 >> 24 <= -1) {
     $$0$lcssa$i = $53; //@line 41522
     break;
    } else {
     $$03$i = $53; //@line 41520
    }
   }
  } else {
   $$0$lcssa$i = $46; //@line 41527
  }
 } while (0);
 $56 = $0 + 44 | 0; //@line 41530
 HEAP8[$56 >> 0] = 0; //@line 41531
 $57 = HEAP8[$$0$lcssa$i >> 0] | 0; //@line 41532
 if ($57 << 24 >> 24 == -17) {
  if ((HEAP8[$$0$lcssa$i + 1 >> 0] | 0) == -69) {
   if ((HEAP8[$$0$lcssa$i + 2 >> 0] | 0) == -65) {
    HEAP8[$56 >> 0] = 1; //@line 41543
    $65 = $$0$lcssa$i + 3 | 0; //@line 41544
    $$0$i21 = $65; //@line 41546
    $68 = HEAP8[$65 >> 0] | 0; //@line 41546
    label = 25; //@line 41547
   } else {
    $$0$i2122 = $$0$lcssa$i; //@line 41549
    label = 27; //@line 41550
   }
  } else {
   $$0$i2122 = $$0$lcssa$i; //@line 41553
   label = 27; //@line 41554
  }
 } else {
  if (!$$0$lcssa$i) {
   label = 26; //@line 41559
  } else {
   $$0$i21 = $$0$lcssa$i; //@line 41561
   $68 = $57; //@line 41561
   label = 25; //@line 41562
  }
 }
 if ((label | 0) == 25) {
  if (!($68 << 24 >> 24)) {
   label = 26; //@line 41568
  } else {
   $$0$i2122 = $$0$i21; //@line 41570
   label = 27; //@line 41571
  }
 }
 if ((label | 0) == 26) {
  HEAP32[$32 >> 2] = 15; //@line 41575
  HEAP32[$33 >> 2] = 0; //@line 41576
  HEAP32[$34 >> 2] = 0; //@line 41577
  $$2 = HEAP32[$32 >> 2] | 0; //@line 41578
  return $$2 | 0; //@line 41579
 } else if ((label | 0) == 27) {
  FUNCTION_TABLE_iiii[HEAP32[(HEAP32[$0 >> 2] | 0) + 60 >> 2] & 15]($0, $$0$i2122, 0) | 0; //@line 41585
  $$2 = HEAP32[$32 >> 2] | 0; //@line 41586
  return $$2 | 0; //@line 41587
 }
 return 0; //@line 41589
}
function __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$062 = 0, $$sink = 0, $10 = 0, $11 = 0, $12 = 0, $15 = 0, $17 = 0, $2 = 0, $20 = 0, $26 = 0, $27 = 0, $28 = 0, $32 = 0, $33 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $46 = 0, $49 = 0, $54 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $66 = 0, $67 = 0, $7 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $80 = 0, $83 = 0, label = 0;
 $2 = ($1 | 0) == ($0 | 0); //@line 16078
 HEAP8[$1 + 12 >> 0] = $2 & 1; //@line 16081
 if ($2) {
  return;
 } else {
  $$062 = $1; //@line 16085
 }
 while (1) {
  $6 = HEAP32[$$062 + 8 >> 2] | 0; //@line 16089
  $7 = $6 + 12 | 0; //@line 16090
  if (HEAP8[$7 >> 0] | 0) {
   label = 23; //@line 16094
   break;
  }
  $10 = $6 + 8 | 0; //@line 16097
  $11 = HEAP32[$10 >> 2] | 0; //@line 16098
  $12 = HEAP32[$11 >> 2] | 0; //@line 16099
  if (($12 | 0) == ($6 | 0)) {
   $15 = HEAP32[$11 + 4 >> 2] | 0; //@line 16103
   if (!$15) {
    label = 7; //@line 16106
    break;
   }
   $17 = $15 + 12 | 0; //@line 16109
   if (!(HEAP8[$17 >> 0] | 0)) {
    $$sink = $17; //@line 16113
   } else {
    label = 7; //@line 16115
    break;
   }
  } else {
   if (!$12) {
    label = 16; //@line 16121
    break;
   }
   $54 = $12 + 12 | 0; //@line 16124
   if (!(HEAP8[$54 >> 0] | 0)) {
    $$sink = $54; //@line 16128
   } else {
    label = 16; //@line 16130
    break;
   }
  }
  HEAP8[$7 >> 0] = 1; //@line 16134
  $20 = ($11 | 0) == ($0 | 0); //@line 16135
  HEAP8[$11 + 12 >> 0] = $20 & 1; //@line 16138
  HEAP8[$$sink >> 0] = 1; //@line 16139
  if ($20) {
   label = 23; //@line 16141
   break;
  } else {
   $$062 = $11; //@line 16144
  }
 }
 if ((label | 0) == 7) {
  if ((HEAP32[$6 >> 2] | 0) == ($$062 | 0)) {
   $38 = $6; //@line 16151
   $40 = $11; //@line 16151
  } else {
   $26 = $6 + 4 | 0; //@line 16154
   $27 = HEAP32[$26 >> 2] | 0; //@line 16155
   $28 = HEAP32[$27 >> 2] | 0; //@line 16156
   HEAP32[$26 >> 2] = $28; //@line 16157
   if (!$28) {
    $32 = $11; //@line 16160
   } else {
    HEAP32[$28 + 8 >> 2] = $6; //@line 16163
    $32 = HEAP32[$10 >> 2] | 0; //@line 16165
   }
   HEAP32[$27 + 8 >> 2] = $32; //@line 16168
   $33 = HEAP32[$10 >> 2] | 0; //@line 16169
   HEAP32[((HEAP32[$33 >> 2] | 0) == ($6 | 0) ? $33 : $33 + 4 | 0) >> 2] = $27; //@line 16174
   HEAP32[$27 >> 2] = $6; //@line 16175
   HEAP32[$10 >> 2] = $27; //@line 16176
   $38 = $27; //@line 16179
   $40 = HEAP32[$27 + 8 >> 2] | 0; //@line 16179
  }
  HEAP8[$38 + 12 >> 0] = 1; //@line 16182
  HEAP8[$40 + 12 >> 0] = 0; //@line 16184
  $41 = HEAP32[$40 >> 2] | 0; //@line 16185
  $42 = $41 + 4 | 0; //@line 16186
  $43 = HEAP32[$42 >> 2] | 0; //@line 16187
  HEAP32[$40 >> 2] = $43; //@line 16188
  if ($43 | 0) {
   HEAP32[$43 + 8 >> 2] = $40; //@line 16192
  }
  $46 = $40 + 8 | 0; //@line 16194
  HEAP32[$41 + 8 >> 2] = HEAP32[$46 >> 2]; //@line 16197
  $49 = HEAP32[$46 >> 2] | 0; //@line 16198
  HEAP32[((HEAP32[$49 >> 2] | 0) == ($40 | 0) ? $49 : $49 + 4 | 0) >> 2] = $41; //@line 16203
  HEAP32[$42 >> 2] = $40; //@line 16204
  HEAP32[$46 >> 2] = $41; //@line 16205
  return;
 } else if ((label | 0) == 16) {
  if ((HEAP32[$6 >> 2] | 0) == ($$062 | 0)) {
   $60 = HEAP32[$6 >> 2] | 0; //@line 16213
   $61 = $60 + 4 | 0; //@line 16214
   $62 = HEAP32[$61 >> 2] | 0; //@line 16215
   HEAP32[$6 >> 2] = $62; //@line 16216
   if (!$62) {
    $66 = $11; //@line 16219
   } else {
    HEAP32[$62 + 8 >> 2] = $6; //@line 16222
    $66 = HEAP32[$10 >> 2] | 0; //@line 16224
   }
   HEAP32[$60 + 8 >> 2] = $66; //@line 16227
   $67 = HEAP32[$10 >> 2] | 0; //@line 16228
   HEAP32[((HEAP32[$67 >> 2] | 0) == ($6 | 0) ? $67 : $67 + 4 | 0) >> 2] = $60; //@line 16233
   HEAP32[$61 >> 2] = $6; //@line 16234
   HEAP32[$10 >> 2] = $60; //@line 16235
   $72 = $60; //@line 16238
   $74 = HEAP32[$60 + 8 >> 2] | 0; //@line 16238
  } else {
   $72 = $6; //@line 16240
   $74 = $11; //@line 16240
  }
  HEAP8[$72 + 12 >> 0] = 1; //@line 16243
  HEAP8[$74 + 12 >> 0] = 0; //@line 16245
  $75 = $74 + 4 | 0; //@line 16246
  $76 = HEAP32[$75 >> 2] | 0; //@line 16247
  $77 = HEAP32[$76 >> 2] | 0; //@line 16248
  HEAP32[$75 >> 2] = $77; //@line 16249
  if ($77 | 0) {
   HEAP32[$77 + 8 >> 2] = $74; //@line 16253
  }
  $80 = $74 + 8 | 0; //@line 16255
  HEAP32[$76 + 8 >> 2] = HEAP32[$80 >> 2]; //@line 16258
  $83 = HEAP32[$80 >> 2] | 0; //@line 16259
  HEAP32[((HEAP32[$83 >> 2] | 0) == ($74 | 0) ? $83 : $83 + 4 | 0) >> 2] = $76; //@line 16264
  HEAP32[$76 >> 2] = $74; //@line 16265
  HEAP32[$80 >> 2] = $76; //@line 16266
  return;
 } else if ((label | 0) == 23) {
  return;
 }
}
function __Z18audio_write_blocksi($0) {
 $0 = $0 | 0;
 var $$ = 0, $$05061 = 0, $$051$lcssa = 0, $$05662 = 0, $$4 = 0, $1 = 0, $10 = 0, $12 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $28 = 0, $33 = 0, $35 = 0, $40 = 0, $43 = 0, $45 = 0, $46 = 0, $50 = 0, $51 = 0, $52 = 0, $57 = 0, $6 = 0, $63 = 0, $70 = 0, $76 = 0, $77 = 0, $8 = 0, $86 = 0, $umax = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 47524
 STACKTOP = STACKTOP + 16 | 0; //@line 47525
 $vararg_buffer = sp; //@line 47526
 $1 = HEAP32[30879] | 0; //@line 47527
 if (($0 | 0) > 0 & ($1 | 0) > 0) {
  $6 = ~$1; //@line 47533
  $8 = -2 - $1 - (($6 | 0) > -2 ? $6 : -2) | 0; //@line 47536
  $10 = ~$0; //@line 47538
  $12 = -2 - $0 - (($10 | 0) > -2 ? $10 : -2) | 0; //@line 47541
  $umax = $8 >>> 0 > $12 >>> 0 ? $8 : $12; //@line 47543
  HEAP32[30879] = $umax + $1; //@line 47546
  $$051$lcssa = $umax + $0 | 0; //@line 47547
 } else {
  $$051$lcssa = $0; //@line 47549
 }
 if (!$$051$lcssa) {
  _puts(104306) | 0; //@line 47553
  STACKTOP = sp; //@line 47554
  return;
 }
 $17 = HEAP32[30878] | 0; //@line 47556
 $18 = ($17 | 0) / 2 | 0; //@line 47557
 $19 = $18 >>> 0 > 2147483647 ? -1 : $18 << 1; //@line 47560
 $20 = __Znaj($19) | 0; //@line 47561
 $21 = __Znaj($19) | 0; //@line 47562
 _memset($20 | 0, 0, $17 | 0) | 0; //@line 47563
 L8 : do {
  if (($$051$lcssa | 0) > 0) {
   $$05662 = 0; //@line 47567
   while (1) {
    do {
     if (!(HEAP32[30821] | 0)) {
      label = 17; //@line 47573
     } else {
      HEAP32[1312] = 99; //@line 47575
      __Z16SetInterruptFlagj(16); //@line 47576
      __Z16TriggerInterruptv(); //@line 47577
      _sem_wait(123464) | 0; //@line 47578
      $28 = (HEAP32[30824] | 0) + 200 | 0; //@line 47580
      $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($28 >>> 16 << 2) >> 2] >> 2] & 127]($28) | 0; //@line 47585
      if (!$33) {
       label = 17; //@line 47588
      } else {
       $35 = $33 + 16 | 0; //@line 47590
       $40 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($35 >>> 16 << 2) >> 2] >> 2] & 127]($35) | 0; //@line 47595
       $43 = Math_imul((HEAP32[30818] | 0) >>> 3, $40) | 0; //@line 47598
       $45 = Math_imul($43, HEAP32[30819] | 0) | 0; //@line 47600
       $46 = HEAP32[30878] | 0; //@line 47601
       $$ = ($45 | 0) > ($46 | 0) ? $46 : $45; //@line 47603
       if (!$$) {
        label = 17; //@line 47606
       } else {
        $50 = $33 + 20 | 0; //@line 47609
        $51 = (HEAP8[659478] | 0) != 0; //@line 47610
        if (!(($46 | 0) > ($45 | 0) | $51)) {
         $52 = HEAP32[1312] | 0; //@line 47614
         $57 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($50 >>> 16 << 2) >> 2] >> 2] & 127]($50) | 0; //@line 47619
         $63 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($57 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($57) | 0; //@line 47625
         $$4 = _emscripten_asm_const_iiii(12, $63 | 0, HEAP32[30878] | 0, $52 | 0) | 0; //@line 47628
         break;
        }
        $70 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($50 >>> 16 << 2) >> 2] >> 2] & 127]($50) | 0; //@line 47635
        $76 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($70 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($70) | 0; //@line 47641
        if ($51) {
         $77 = ($$ | 0) / 2 | 0; //@line 47643
         if (($$ | 0) > 1) {
          $$05061 = 0; //@line 47646
          do {
           HEAP16[$21 + ($$05061 << 1) >> 1] = _ntohs(HEAP16[$76 + ($$05061 << 1) >> 1] | 0) | 0; //@line 47652
           $$05061 = $$05061 + 1 | 0; //@line 47653
          } while (($$05061 | 0) < ($77 | 0));
         }
        } else {
         _memcpy($21 | 0, $76 | 0, $$ | 0) | 0; //@line 47663
        }
        $86 = HEAP32[30878] | 0; //@line 47666
        _memset($21 + $$ | 0, 0, $86 - $$ | 0) | 0; //@line 47668
        $$4 = _emscripten_asm_const_iiii(12, $21 | 0, $86 | 0, HEAP32[1312] | 0) | 0; //@line 47671
       }
      }
     }
    } while (0);
    if ((label | 0) == 17) {
     label = 0; //@line 47677
     HEAP32[1312] = 1; //@line 47678
     $$4 = _emscripten_asm_const_iiii(12, $20 | 0, HEAP32[30878] | 0, 1) | 0; //@line 47681
    }
    $$05662 = $$05662 + 1 | 0; //@line 47684
    if (!$$4) {
     break;
    }
    if (($$05662 | 0) >= ($$051$lcssa | 0)) {
     break L8;
    }
   }
   __ZdaPv($20); //@line 47695
   __ZdaPv($21); //@line 47696
   HEAP32[30879] = 3; //@line 47697
   HEAP32[$vararg_buffer >> 2] = 3; //@line 47698
   _printf(104382, $vararg_buffer) | 0; //@line 47699
   STACKTOP = sp; //@line 47700
   return;
  }
 } while (0);
 __ZdaPv($20); //@line 47703
 __ZdaPv($21); //@line 47704
 STACKTOP = sp; //@line 47705
 return;
}
function _scanexp($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$04861 = 0, $$049 = 0, $$1$be = 0, $$160 = 0, $$2$be = 0, $$2$lcssa = 0, $$254 = 0, $$3$be = 0, $$lcssa = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $13 = 0, $14 = 0, $2 = 0, $22 = 0, $3 = 0, $38 = 0, $4 = 0, $50 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $81 = 0, $83 = 0, $87 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 $2 = $0 + 4 | 0; //@line 61298
 $3 = HEAP32[$2 >> 2] | 0; //@line 61299
 $4 = $0 + 100 | 0; //@line 61300
 if ($3 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
  HEAP32[$2 >> 2] = $3 + 1; //@line 61305
  $11 = HEAPU8[$3 >> 0] | 0; //@line 61308
 } else {
  $11 = ___shgetc($0) | 0; //@line 61311
 }
 switch ($11 | 0) {
 case 43:
 case 45:
  {
   $13 = ($11 | 0) == 45 & 1; //@line 61316
   $14 = HEAP32[$2 >> 2] | 0; //@line 61317
   if ($14 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
    HEAP32[$2 >> 2] = $14 + 1; //@line 61322
    $22 = HEAPU8[$14 >> 0] | 0; //@line 61325
   } else {
    $22 = ___shgetc($0) | 0; //@line 61328
   }
   if (($1 | 0) != 0 & ($22 + -48 | 0) >>> 0 > 9) {
    if (!(HEAP32[$4 >> 2] | 0)) {
     $$0 = $13; //@line 61338
     $$049 = $22; //@line 61338
    } else {
     HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + -1; //@line 61342
     $$0 = $13; //@line 61343
     $$049 = $22; //@line 61343
    }
   } else {
    $$0 = $13; //@line 61346
    $$049 = $22; //@line 61346
   }
   break;
  }
 default:
  {
   $$0 = 0; //@line 61351
   $$049 = $11; //@line 61351
  }
 }
 if (($$049 + -48 | 0) >>> 0 > 9) {
  if (!(HEAP32[$4 >> 2] | 0)) {
   $100 = -2147483648; //@line 61360
   $101 = 0; //@line 61360
  } else {
   HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + -1; //@line 61364
   $100 = -2147483648; //@line 61365
   $101 = 0; //@line 61365
  }
 } else {
  $$04861 = 0; //@line 61368
  $$160 = $$049; //@line 61368
  while (1) {
   $$04861 = $$160 + -48 + ($$04861 * 10 | 0) | 0; //@line 61372
   $38 = HEAP32[$2 >> 2] | 0; //@line 61373
   if ($38 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
    HEAP32[$2 >> 2] = $38 + 1; //@line 61378
    $$1$be = HEAPU8[$38 >> 0] | 0; //@line 61381
   } else {
    $$1$be = ___shgetc($0) | 0; //@line 61384
   }
   if (!(($$1$be + -48 | 0) >>> 0 < 10 & ($$04861 | 0) < 214748364)) {
    break;
   } else {
    $$160 = $$1$be; //@line 61391
   }
  }
  $50 = (($$04861 | 0) < 0) << 31 >> 31; //@line 61397
  if (($$1$be + -48 | 0) >>> 0 < 10) {
   $$254 = $$1$be; //@line 61401
   $56 = $$04861; //@line 61401
   $57 = $50; //@line 61401
   while (1) {
    $58 = ___muldi3($56 | 0, $57 | 0, 10, 0) | 0; //@line 61403
    $59 = tempRet0; //@line 61404
    $62 = _i64Add($$254 | 0, (($$254 | 0) < 0) << 31 >> 31 | 0, -48, -1) | 0; //@line 61407
    $64 = _i64Add($62 | 0, tempRet0 | 0, $58 | 0, $59 | 0) | 0; //@line 61409
    $65 = tempRet0; //@line 61410
    $66 = HEAP32[$2 >> 2] | 0; //@line 61411
    if ($66 >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
     HEAP32[$2 >> 2] = $66 + 1; //@line 61416
     $$2$be = HEAPU8[$66 >> 0] | 0; //@line 61419
    } else {
     $$2$be = ___shgetc($0) | 0; //@line 61422
    }
    if (($$2$be + -48 | 0) >>> 0 < 10 & (($65 | 0) < 21474836 | ($65 | 0) == 21474836 & $64 >>> 0 < 2061584302)) {
     $$254 = $$2$be; //@line 61433
     $56 = $64; //@line 61433
     $57 = $65; //@line 61433
    } else {
     $$2$lcssa = $$2$be; //@line 61435
     $94 = $64; //@line 61435
     $95 = $65; //@line 61435
     break;
    }
   }
  } else {
   $$2$lcssa = $$1$be; //@line 61440
   $94 = $$04861; //@line 61440
   $95 = $50; //@line 61440
  }
  $55 = HEAP32[$4 >> 2] | 0; //@line 61444
  if (($$2$lcssa + -48 | 0) >>> 0 < 10) {
   $83 = $55; //@line 61446
   while (1) {
    $81 = HEAP32[$2 >> 2] | 0; //@line 61448
    if ($81 >>> 0 < $83 >>> 0) {
     HEAP32[$2 >> 2] = $81 + 1; //@line 61452
     $$3$be = HEAPU8[$81 >> 0] | 0; //@line 61455
     $102 = $83; //@line 61455
    } else {
     $87 = ___shgetc($0) | 0; //@line 61457
     $$3$be = $87; //@line 61459
     $102 = HEAP32[$4 >> 2] | 0; //@line 61459
    }
    if (($$3$be + -48 | 0) >>> 0 < 10) {
     $83 = $102; //@line 61464
    } else {
     $$lcssa = $102; //@line 61466
     break;
    }
   }
  } else {
   $$lcssa = $55; //@line 61471
  }
  if ($$lcssa | 0) {
   HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + -1; //@line 61477
  }
  $93 = ($$0 | 0) != 0; //@line 61479
  $96 = _i64Subtract(0, 0, $94 | 0, $95 | 0) | 0; //@line 61480
  $100 = $93 ? tempRet0 : $95; //@line 61484
  $101 = $93 ? $96 : $94; //@line 61484
 }
 tempRet0 = $100; //@line 61486
 return $101 | 0; //@line 61487
}
function ___stpncpy($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$lcssa = 0, $$037$lcssa = 0, $$03753 = 0, $$038$lcssa = 0, $$038$lcssa79 = 0, $$03866 = 0, $$039$lcssa = 0, $$039$lcssa78 = 0, $$03965 = 0, $$041$lcssa = 0, $$041$lcssa77 = 0, $$04164 = 0, $$054 = 0, $$1$lcssa = 0, $$140$ph = 0, $$14046 = 0, $$142$ph = 0, $$14245 = 0, $$152 = 0, $$2$ph = 0, $$243 = 0, $$247 = 0, $$3 = 0, $$lcssa = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $19 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $34 = 0, $38 = 0, label = 0;
 $3 = $1; //@line 2204
 do {
  if (!(($3 ^ $0) & 3)) {
   $10 = ($2 | 0) != 0; //@line 2213
   L3 : do {
    if ($10 & ($3 & 3 | 0) != 0) {
     $$03866 = $2; //@line 2217
     $$03965 = $1; //@line 2217
     $$04164 = $0; //@line 2217
     while (1) {
      $11 = HEAP8[$$03965 >> 0] | 0; //@line 2219
      HEAP8[$$04164 >> 0] = $11; //@line 2220
      if (!($11 << 24 >> 24)) {
       $$038$lcssa79 = $$03866; //@line 2223
       $$039$lcssa78 = $$03965; //@line 2223
       $$041$lcssa77 = $$04164; //@line 2223
       break L3;
      }
      $13 = $$03866 + -1 | 0; //@line 2226
      $14 = $$03965 + 1 | 0; //@line 2227
      $15 = $$04164 + 1 | 0; //@line 2228
      $19 = ($13 | 0) != 0; //@line 2232
      if ($19 & ($14 & 3 | 0) != 0) {
       $$03866 = $13; //@line 2235
       $$03965 = $14; //@line 2235
       $$04164 = $15; //@line 2235
      } else {
       $$038$lcssa = $13; //@line 2237
       $$039$lcssa = $14; //@line 2237
       $$041$lcssa = $15; //@line 2237
       $$lcssa = $19; //@line 2237
       label = 5; //@line 2238
       break;
      }
     }
    } else {
     $$038$lcssa = $2; //@line 2243
     $$039$lcssa = $1; //@line 2243
     $$041$lcssa = $0; //@line 2243
     $$lcssa = $10; //@line 2243
     label = 5; //@line 2244
    }
   } while (0);
   if ((label | 0) == 5) {
    if ($$lcssa) {
     $$038$lcssa79 = $$038$lcssa; //@line 2249
     $$039$lcssa78 = $$039$lcssa; //@line 2249
     $$041$lcssa77 = $$041$lcssa; //@line 2249
    } else {
     $$243 = $$041$lcssa; //@line 2251
     $$3 = 0; //@line 2251
     break;
    }
   }
   if (!(HEAP8[$$039$lcssa78 >> 0] | 0)) {
    $$243 = $$041$lcssa77; //@line 2258
    $$3 = $$038$lcssa79; //@line 2258
   } else {
    L11 : do {
     if ($$038$lcssa79 >>> 0 > 3) {
      $$03753 = $$041$lcssa77; //@line 2263
      $$054 = $$039$lcssa78; //@line 2263
      $$152 = $$038$lcssa79; //@line 2263
      while (1) {
       $23 = HEAP32[$$054 >> 2] | 0; //@line 2265
       if (($23 & -2139062144 ^ -2139062144) & $23 + -16843009 | 0) {
        $$0$lcssa = $$054; //@line 2272
        $$037$lcssa = $$03753; //@line 2272
        $$1$lcssa = $$152; //@line 2272
        break L11;
       }
       HEAP32[$$03753 >> 2] = $23; //@line 2275
       $29 = $$152 + -4 | 0; //@line 2276
       $30 = $$054 + 4 | 0; //@line 2277
       $31 = $$03753 + 4 | 0; //@line 2278
       if ($29 >>> 0 > 3) {
        $$03753 = $31; //@line 2281
        $$054 = $30; //@line 2281
        $$152 = $29; //@line 2281
       } else {
        $$0$lcssa = $30; //@line 2283
        $$037$lcssa = $31; //@line 2283
        $$1$lcssa = $29; //@line 2283
        break;
       }
      }
     } else {
      $$0$lcssa = $$039$lcssa78; //@line 2288
      $$037$lcssa = $$041$lcssa77; //@line 2288
      $$1$lcssa = $$038$lcssa79; //@line 2288
     }
    } while (0);
    $$140$ph = $$0$lcssa; //@line 2291
    $$142$ph = $$037$lcssa; //@line 2291
    $$2$ph = $$1$lcssa; //@line 2291
    label = 11; //@line 2292
   }
  } else {
   $$140$ph = $1; //@line 2295
   $$142$ph = $0; //@line 2295
   $$2$ph = $2; //@line 2295
   label = 11; //@line 2296
  }
 } while (0);
 L16 : do {
  if ((label | 0) == 11) {
   if (!$$2$ph) {
    $$243 = $$142$ph; //@line 2303
    $$3 = 0; //@line 2303
   } else {
    $$14046 = $$140$ph; //@line 2305
    $$14245 = $$142$ph; //@line 2305
    $$247 = $$2$ph; //@line 2305
    while (1) {
     $34 = HEAP8[$$14046 >> 0] | 0; //@line 2307
     HEAP8[$$14245 >> 0] = $34; //@line 2308
     if (!($34 << 24 >> 24)) {
      $$243 = $$14245; //@line 2311
      $$3 = $$247; //@line 2311
      break L16;
     }
     $$247 = $$247 + -1 | 0; //@line 2314
     $38 = $$14245 + 1 | 0; //@line 2316
     if (!$$247) {
      $$243 = $38; //@line 2319
      $$3 = 0; //@line 2319
      break;
     } else {
      $$14046 = $$14046 + 1 | 0; //@line 2322
      $$14245 = $38; //@line 2322
     }
    }
   }
  }
 } while (0);
 _memset($$243 | 0, 0, $$3 | 0) | 0; //@line 2328
 return $$243 | 0; //@line 2329
}
function __Z11m68k_move2ciPj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $15 = 0, $2 = 0, $38 = 0, $41 = 0, $51 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 51430
 STACKTOP = STACKTOP + 16 | 0; //@line 51431
 $vararg_buffer2 = sp + 8 | 0; //@line 51432
 $vararg_buffer = sp; //@line 51433
 $2 = HEAP32[30880] | 0; //@line 51434
 switch ($2 | 0) {
 case 1:
  {
   if (($0 & 2046) >>> 0 < 2) {
    label = 6; //@line 51440
   } else {
    label = 5; //@line 51442
   }
   break;
  }
 case 3:
 case 2:
  {
   if (($0 & 2047) >>> 0 < 3 | ($0 + -3 | 0) >>> 0 < 2) {
    label = 6; //@line 51453
   } else {
    label = 5; //@line 51455
   }
   break;
  }
 case 4:
  {
   if (($0 | 0) != 2050 & ($0 & 2040) >>> 0 < 8) {
    label = 6; //@line 51465
   } else {
    label = 5; //@line 51467
   }
   break;
  }
 default:
  {
   label = 5; //@line 51472
  }
 }
 L5 : do {
  if ((label | 0) == 5) {
   $15 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 51481
   HEAP32[$vararg_buffer >> 2] = 20091; //@line 51482
   HEAP32[$vararg_buffer + 4 >> 2] = $15; //@line 51484
   _printf(105458, $vararg_buffer) | 0; //@line 51485
   __Z9Exceptionij(4, 0); //@line 51486
   $$0 = 0; //@line 51487
  } else if ((label | 0) == 6) {
   do {
    switch ($0 | 0) {
    case 0:
     {
      HEAP32[162774] = HEAP32[$1 >> 2] & 7; //@line 51495
      $$0 = 1; //@line 51496
      break L5;
      break;
     }
    case 1:
     {
      HEAP32[162775] = HEAP32[$1 >> 2] & 7; //@line 51503
      $$0 = 1; //@line 51504
      break L5;
      break;
     }
    case 2:
     {
      HEAP32[162811] = (($2 | 0) < 4 ? 3 : -2147450880) & HEAP32[$1 >> 2]; //@line 51513
      $$0 = 1; //@line 51514
      break L5;
      break;
     }
    case 3:
     {
      HEAP32[162812] = HEAP32[$1 >> 2] & 49152; //@line 51521
      $$0 = 1; //@line 51522
      break L5;
      break;
     }
    case 4:
     {
      HEAP32[162813] = HEAP32[$1 >> 2] & -7324; //@line 51529
      $$0 = 1; //@line 51530
      break L5;
      break;
     }
    case 5:
     {
      HEAP32[162814] = HEAP32[$1 >> 2] & -7324; //@line 51537
      $$0 = 1; //@line 51538
      break L5;
      break;
     }
    case 6:
     {
      HEAP32[162815] = HEAP32[$1 >> 2] & -7324; //@line 51545
      $$0 = 1; //@line 51546
      break L5;
      break;
     }
    case 7:
     {
      HEAP32[162816] = HEAP32[$1 >> 2] & -7324; //@line 51553
      $$0 = 1; //@line 51554
      break L5;
      break;
     }
    case 2048:
     {
      HEAP32[162776] = HEAP32[$1 >> 2]; //@line 51560
      $$0 = 1; //@line 51561
      break L5;
      break;
     }
    case 2049:
     {
      HEAP32[162773] = HEAP32[$1 >> 2]; //@line 51567
      $$0 = 1; //@line 51568
      break L5;
      break;
     }
    case 2050:
     {
      HEAP32[162817] = HEAP32[$1 >> 2] & 252; //@line 51575
      $$0 = 1; //@line 51576
      break L5;
      break;
     }
    case 2051:
     {
      $38 = HEAP32[$1 >> 2] | 0; //@line 51581
      HEAP32[162778] = $38; //@line 51582
      if ((HEAP8[651121] | 0) != 1) {
       $$0 = 1; //@line 51586
       break L5;
      }
      HEAP32[162767] = $38; //@line 51589
      $$0 = 1; //@line 51590
      break L5;
      break;
     }
    case 2052:
     {
      $41 = HEAP32[$1 >> 2] | 0; //@line 51595
      HEAP32[162777] = $41; //@line 51596
      if (HEAP8[651121] | 0) {
       $$0 = 1; //@line 51600
       break L5;
      }
      HEAP32[162767] = $41; //@line 51603
      $$0 = 1; //@line 51604
      break L5;
      break;
     }
    case 2053:
     {
      HEAP32[162818] = HEAP32[$1 >> 2]; //@line 51610
      $$0 = 1; //@line 51611
      break L5;
      break;
     }
    case 2054:
     {
      HEAP32[162819] = HEAP32[$1 >> 2]; //@line 51617
      $$0 = 1; //@line 51618
      break L5;
      break;
     }
    case 2055:
     {
      HEAP32[162820] = HEAP32[$1 >> 2]; //@line 51624
      $$0 = 1; //@line 51625
      break L5;
      break;
     }
    default:
     {
      $51 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 51634
      HEAP32[$vararg_buffer2 >> 2] = 20091; //@line 51635
      HEAP32[$vararg_buffer2 + 4 >> 2] = $51; //@line 51637
      _printf(105458, $vararg_buffer2) | 0; //@line 51638
      __Z9Exceptionij(4, 0); //@line 51639
      $$0 = 0; //@line 51640
      break L5;
     }
    }
   } while (0);
  }
 } while (0);
 STACKTOP = sp; //@line 51647
 return $$0 | 0; //@line 51647
}
function __ZN13driver_windowC2ER16SDL_monitor_desc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$0$i31 = 0, $$0$i32 = 0, $$033 = 0, $13 = 0, $18 = 0, $2 = 0, $20 = 0, $24 = 0, $25 = 0, $3 = 0, $40 = 0, $41 = 0, $42 = 0, $45 = 0, $6 = 0, $61 = 0, $7 = 0, $71 = 0, $72 = 0, $79 = 0, $8 = 0, $81 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, sp = 0;
 sp = STACKTOP; //@line 44315
 STACKTOP = STACKTOP + 48 | 0; //@line 44316
 $vararg_buffer2 = sp + 32 | 0; //@line 44317
 $vararg_buffer = sp; //@line 44318
 $2 = $0 + 4 | 0; //@line 44319
 HEAP32[$2 >> 2] = $1; //@line 44320
 $3 = $0 + 8 | 0; //@line 44321
 HEAP32[$3 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 44324
 $6 = $0 + 12 | 0; //@line 44325
 HEAP8[$6 >> 0] = 0; //@line 44326
 $7 = $0 + 16 | 0; //@line 44327
 HEAP32[$7 >> 2] = 0; //@line 44328
 HEAP32[30852] = 0; //@line 44329
 HEAP32[30854] = 0; //@line 44330
 HEAP32[$0 >> 2] = 4292; //@line 44331
 $8 = $0 + 20 | 0; //@line 44332
 HEAP8[$8 >> 0] = 0; //@line 44333
 _puts(102815) | 0; //@line 44334
 $13 = (HEAP32[(HEAP32[$3 >> 2] | 0) + 4 >> 2] | 0) + 15 & -16; //@line 44339
 __Z18ADBSetRelMouseModeb((HEAP8[$8 >> 0] | 0) != 0); //@line 44342
 if (HEAP8[659474] | 0) {
  _SDL_QuitSubSystem(32); //@line 44346
 }
 $18 = HEAP32[$3 >> 2] | 0; //@line 44348
 $20 = HEAP32[$18 + 12 >> 2] | 0; //@line 44350
 if (!(($20 | 0) < 4 | ($20 & -2 | 0) == 4)) {
  _abort(); //@line 44356
 }
 $24 = HEAP32[$18 + 16 >> 2] | 0; //@line 44360
 $25 = HEAP32[30860] | 0; //@line 44361
 if (!$25) {
  $$0$i31 = _malloc(Math_imul($24 - (($24 >>> 0) % ((HEAP32[$18 >> 2] | 0) >>> 0) | 0) | 0, HEAP32[$18 + 4 >> 2] | 0) | 0) | 0; //@line 44371
 } else {
  $$0$i31 = $25; //@line 44373
 }
 HEAP32[30860] = $$0$i31; //@line 44375
 _emscripten_asm_const_ii(0, $$0$i31 | 0) | 0; //@line 44376
 HEAP8[659474] = 1; //@line 44377
 _puts(102873) | 0; //@line 44378
 $40 = Math_imul(HEAPU16[(HEAP32[$7 >> 2] | 0) + 16 >> 1] | 0, $13 | 2) | 0; //@line 44384
 HEAP32[30853] = $40; //@line 44385
 $41 = _calloc(1, $40) | 0; //@line 44386
 HEAP32[30854] = $41; //@line 44387
 $42 = _malloc($40) | 0; //@line 44388
 HEAP32[30852] = $42; //@line 44389
 HEAP32[$vararg_buffer >> 2] = $42; //@line 44390
 HEAP32[$vararg_buffer + 4 >> 2] = $41; //@line 44392
 _printf(102745, $vararg_buffer) | 0; //@line 44393
 _SDL_ShowCursor(0) | 0; //@line 44394
 $45 = HEAP32[(HEAP32[$7 >> 2] | 0) + 4 >> 2] | 0; //@line 44397
 HEAP32[$vararg_buffer + 4 >> 2] = 32; //@line 44399
 HEAP32[$vararg_buffer + 8 >> 2] = HEAP32[$45 + 16 >> 2]; //@line 44403
 HEAP32[$vararg_buffer + 12 >> 2] = HEAP32[$45 + 20 >> 2]; //@line 44407
 HEAP32[$vararg_buffer + 16 >> 2] = HEAP32[$45 + 24 >> 2]; //@line 44411
 switch (HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0) {
 case 0:
  {
   $$0$i32 = 1; //@line 44417
   break;
  }
 case 1:
  {
   $$0$i32 = 2; //@line 44421
   break;
  }
 case 2:
  {
   $$0$i32 = 4; //@line 44425
   break;
  }
 case 3:
  {
   $$0$i32 = 8; //@line 44429
   break;
  }
 case 4:
  {
   $$0$i32 = 16; //@line 44433
   break;
  }
 case 5:
  {
   $$0$i32 = 32; //@line 44437
   break;
  }
 default:
  {
   _abort(); //@line 44441
  }
 }
 __Z19Screen_blitter_initRK12VisualFormatbi($vararg_buffer, 1, $$0$i32) | 0; //@line 44445
 $61 = HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0; //@line 44448
 if (($61 | 1 | 0) == 5) {
  $72 = $61; //@line 44452
 } else {
  $$033 = 0; //@line 44454
  do {
   HEAP32[122204 + ($$033 << 2) >> 2] = $$033 | $$033 << 8 | $$033 << 16 | -16777216; //@line 44462
   $$033 = $$033 + 1 | 0; //@line 44463
  } while (($$033 | 0) != 256);
  $72 = HEAP32[(HEAP32[$3 >> 2] | 0) + 12 >> 2] | 0; //@line 44474
 }
 $71 = HEAP32[$2 >> 2] | 0; //@line 44476
 switch ($72 | 0) {
 case 4:
  {
   $$0$i = (HEAP32[30862] | 0) == 15 ? 2 : 3; //@line 44482
   break;
  }
 case 5:
  {
   $$0$i = (HEAP32[30862] | 0) == 24 ? 4 : 1; //@line 44489
   break;
  }
 default:
  {
   $$0$i = 1; //@line 44493
  }
 }
 HEAP32[30901] = $$0$i; //@line 44496
 $79 = $71 + 20 | 0; //@line 44497
 HEAP32[$79 >> 2] = -1610612736; //@line 44498
 $81 = HEAP32[$71 + 16 >> 2] | 0; //@line 44500
 HEAP32[30899] = HEAP32[30852]; //@line 44502
 HEAP32[30900] = Math_imul(HEAP32[$81 + 4 >> 2] | 0, HEAP32[$81 + 16 >> 2] | 0) | 0; //@line 44508
 __Z22InitFrameBufferMappingv(); //@line 44509
 HEAP32[$vararg_buffer2 >> 2] = HEAP32[$79 >> 2]; //@line 44511
 _printf(102784, $vararg_buffer2) | 0; //@line 44512
 HEAP8[$6 >> 0] = 1; //@line 44513
 STACKTOP = sp; //@line 44514
 return;
}
function __ZL8exec_tibj($0) {
 $0 = $0 | 0;
 var $$037 = 0, $$1$ph = 0, $$sink2 = 0, $12 = 0, $13 = 0, $15 = 0, $18 = 0, $19 = 0, $27 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $45 = 0, $46 = 0, $50 = 0, $54 = 0, $58 = 0, $6 = 0, $66 = 0, $7 = 0, $72 = 0, $9 = 0, $_ZL8sg_index$sink3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 22906
 STACKTOP = STACKTOP + 16 | 0; //@line 22907
 $vararg_buffer = sp; //@line 22908
 $$037 = $0; //@line 22909
 L1 : while (1) {
  $6 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$037 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$037) | 0; //@line 22916
  $7 = $$037 + 2 | 0; //@line 22917
  $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 22919
  $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 22922
  $13 = $$037 + 6 | 0; //@line 22923
  $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 22925
  $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($13) | 0; //@line 22928
  $19 = $$037 + 10 | 0; //@line 22929
  switch (($6 & 65535) << 16 >> 16) {
  case 6:
   {
    $$037 = $19; //@line 22933
    continue L1;
    break;
   }
  case 8:
   {
    label = 13; //@line 22938
    break L1;
    break;
   }
  case 7:
   {
    $$1$ph = 0; //@line 22943
    label = 15; //@line 22944
    break L1;
    break;
   }
  case 1:
   {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $18 + $12 | 0); //@line 22953
    break;
   }
  case 2:
   {
    break;
   }
  case 3:
   {
    $54 = 123608 + ($12 >>> 16 << 2) | 0; //@line 22961
    $58 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$54 >> 2] >> 2] & 127]($12) | 0) + $18 | 0; //@line 22965
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$54 >> 2] | 0) + 12 >> 2] & 31]($12, $58); //@line 22969
    $$037 = $19; //@line 22970
    continue L1;
    break;
   }
  case 4:
   {
    $66 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 22979
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $66); //@line 22985
    $$037 = $19; //@line 22986
    continue L1;
    break;
   }
  case 5:
   {
    $72 = $18 + -1 | 0; //@line 22991
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 12 >> 2] & 31]($13, $72); //@line 22995
    $$037 = ($72 | 0) == 0 ? $19 : $12 + $$037 | 0; //@line 22999
    continue L1;
    break;
   }
  default:
   {
    label = 14; //@line 23004
    break L1;
   }
  }
  $27 = 123608 + ($12 >>> 16 << 2) | 0; //@line 23011
  if ((HEAP32[28497] | 0) > 0) {
   $31 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$27 >> 2] | 0) + 24 >> 2] & 127]($12) | 0; //@line 23016
   $32 = HEAP32[28497] | 0; //@line 23017
   $33 = $32 + -1 | 0; //@line 23018
   $36 = 118096 + ($33 << 2) | 0; //@line 23021
   $37 = HEAP32[$36 >> 2] | 0; //@line 23022
   if (($31 | 0) == ((HEAP32[114e3 + ($33 << 2) >> 2] | 0) + $37 | 0)) {
    $$sink2 = $18; //@line 23026
    $50 = $37; //@line 23026
    $_ZL8sg_index$sink3 = $36; //@line 23026
   } else {
    if (($32 | 0) == 1024) {
     label = 7; //@line 23030
     break;
    } else {
     label = 8; //@line 23033
    }
   }
  } else {
   label = 8; //@line 23037
  }
  if ((label | 0) == 8) {
   label = 0; //@line 23040
   $45 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$27 >> 2] | 0) + 24 >> 2] & 127]($12) | 0; //@line 23044
   $46 = HEAP32[28497] | 0; //@line 23045
   HEAP32[114e3 + ($46 << 2) >> 2] = $45; //@line 23047
   HEAP32[118096 + ($46 << 2) >> 2] = $18; //@line 23049
   $$sink2 = 1; //@line 23050
   $50 = $46; //@line 23050
   $_ZL8sg_index$sink3 = 113988; //@line 23050
  }
  HEAP32[$_ZL8sg_index$sink3 >> 2] = $50 + $$sink2; //@line 23053
  HEAP32[28499] = (HEAP32[28499] | 0) + $18; //@line 23056
  $$037 = $19; //@line 23057
 }
 if ((label | 0) == 7) {
  __Z10ErrorAlertPKc(__Z9GetStringi(1011) | 0); //@line 23061
  $$1$ph = -108; //@line 23062
  STACKTOP = sp; //@line 23063
  return $$1$ph | 0; //@line 23063
 } else if ((label | 0) == 13) {
  _puts(96232) | 0; //@line 23066
  $$1$ph = 6; //@line 23067
  STACKTOP = sp; //@line 23068
  return $$1$ph | 0; //@line 23068
 } else if ((label | 0) == 14) {
  HEAP32[$vararg_buffer >> 2] = $6 & 65535; //@line 23072
  _printf(96269, $vararg_buffer) | 0; //@line 23073
  $$1$ph = 4; //@line 23074
  STACKTOP = sp; //@line 23075
  return $$1$ph | 0; //@line 23075
 } else if ((label | 0) == 15) {
  STACKTOP = sp; //@line 23078
  return $$1$ph | 0; //@line 23078
 }
 return 0; //@line 23080
}
function __Z8SonyOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$08$030 = 0, $103 = 0, $11 = 0, $112 = 0, $119 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $30 = 0, $42 = 0, $43 = 0, $45 = 0, $47 = 0, $48 = 0, $51 = 0, $53 = 0, $54 = 0, $61 = 0, $68 = 0, $75 = 0, $82 = 0, $89 = 0, $9 = 0, $96 = 0, sp = 0;
 sp = STACKTOP; //@line 17237
 STACKTOP = STACKTOP + 80 | 0; //@line 17238
 $2 = sp; //@line 17239
 $3 = $1 + 16 | 0; //@line 17240
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, 0); //@line 17246
 $9 = $1 + 6 | 0; //@line 17247
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 17249
 $17 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 4 >> 2] & 127]($9) | 0) & 65280 | 3; //@line 17255
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 16 >> 2] & 31]($9, $17); //@line 17259
 HEAP8[657352] = 0; //@line 17260
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](284) | 0; //@line 17263
 $24 = $23 + 4 | 0; //@line 17264
 $25 = $23 + 16 | 0; //@line 17265
 $30 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($25 >>> 16 << 2) >> 2] >> 2] & 127]($25) | 0; //@line 17270
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $30); //@line 17276
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](308, -559038737); //@line 17280
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, 0); //@line 17284
 $42 = HEAP32[28486] | 0; //@line 17285
 $43 = HEAP32[28485] | 0; //@line 17286
 if (($43 | 0) == ($42 | 0)) {
  STACKTOP = sp; //@line 17289
  return 0; //@line 17289
 }
 $45 = $2 + 32 | 0; //@line 17291
 $$sroa$08$030 = $43; //@line 17292
 do {
  HEAP32[$$sroa$08$030 >> 2] = __Z19FindFreeDriveNumberi(1) | 0; //@line 17295
  $47 = $$sroa$08$030 + 8 | 0; //@line 17296
  HEAP8[$47 >> 0] = 0; //@line 17297
  $48 = $$sroa$08$030 + 4 | 0; //@line 17298
  if (HEAP32[$48 >> 2] | 0) {
   HEAP32[$2 >> 2] = 30; //@line 17302
   _Execute68kTrap(-22754, $2); //@line 17303
   $51 = HEAP32[$45 >> 2] | 0; //@line 17304
   if ($51 | 0) {
    $53 = $$sroa$08$030 + 12 | 0; //@line 17307
    HEAP32[$53 >> 2] = $51; //@line 17308
    $54 = $51 + 10 | 0; //@line 17309
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($54 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($54, 0); //@line 17315
    $61 = (HEAP32[$53 >> 2] | 0) + 4 | 0; //@line 17317
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($61 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($61, 1); //@line 17323
    $68 = (HEAP32[$53 >> 2] | 0) + 5 | 0; //@line 17325
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($68 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($68, 255); //@line 17331
    $75 = (HEAP32[$53 >> 2] | 0) + 18 | 0; //@line 17333
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($75 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($75, 255); //@line 17339
    $82 = (HEAP32[$53 >> 2] | 0) + 19 | 0; //@line 17341
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($82, 255); //@line 17347
    $89 = (HEAP32[$53 >> 2] | 0) + 22 | 0; //@line 17349
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($89 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($89, 255); //@line 17355
    $96 = (HEAP32[$53 >> 2] | 0) + 23 | 0; //@line 17357
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($96 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($96, 255); //@line 17363
    $103 = (HEAP32[$53 >> 2] | 0) + 24 | 0; //@line 17365
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($103 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($103, 255); //@line 17371
    if (__Z17SysIsDiskInsertedPv(HEAP32[$48 >> 2] | 0) | 0) {
     $112 = (HEAP32[$53 >> 2] | 0) + 3 | 0; //@line 17376
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($112 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($112, 1); //@line 17382
     $119 = (HEAP32[$53 >> 2] | 0) + 2 | 0; //@line 17384
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($119 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($119, HEAP8[$$sroa$08$030 + 9 >> 0] | 0 ? 255 : 0); //@line 17394
     HEAP8[$47 >> 0] = 1; //@line 17395
    }
    HEAP32[$2 >> 2] = HEAP32[$$sroa$08$030 >> 2] << 16 | 65531; //@line 17400
    HEAP32[$45 >> 2] = (HEAP32[$53 >> 2] | 0) + 6; //@line 17403
    _Execute68kTrap(-24498, $2); //@line 17404
   }
  }
  $$sroa$08$030 = $$sroa$08$030 + 16 | 0; //@line 17407
 } while (($$sroa$08$030 | 0) != ($42 | 0));
 STACKTOP = sp; //@line 17415
 return 0; //@line 17415
}
function __ZL11write_prefsP8_IO_FILEPK10prefs_desc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$0$i28 = 0, $$014$i$i = 0, $$014$i$i20 = 0, $$014$i$i26 = 0, $$01416$i$i17 = 0, $$01416$i$i23 = 0, $$01416$i$i33 = 0, $$01416$i$i35 = 0, $$01418$i$i = 0, $$01418$i$i18 = 0, $$01418$i$i24 = 0, $$01634 = 0, $$017$i$i = 0, $$1$i$i = 0, $17 = 0, $21 = 0, $35 = 0, $36 = 0, $5 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, sp = 0;
 sp = STACKTOP; //@line 1743
 STACKTOP = STACKTOP + 32 | 0; //@line 1744
 $vararg_buffer6 = sp + 16 | 0; //@line 1745
 $vararg_buffer2 = sp + 8 | 0; //@line 1746
 $vararg_buffer = sp; //@line 1747
 $$0 = $1; //@line 1748
 L1 : while (1) {
  L3 : do {
   switch (HEAP32[$$0 + 4 >> 2] | 0) {
   case 3:
    {
     break L1;
     break;
    }
   case 0:
    {
     $$01416$i$i33 = HEAP32[28198] | 0; //@line 1759
     if ($$01416$i$i33 | 0) {
      $$01416$i$i35 = $$01416$i$i33; //@line 1762
      $$01634 = 0; //@line 1762
      while (1) {
       $5 = HEAP32[$$0 >> 2] | 0; //@line 1764
       $$01418$i$i = $$01416$i$i35; //@line 1765
       $$017$i$i = 0; //@line 1765
       while (1) {
        if (!(HEAP32[$$01418$i$i + 8 >> 2] | 0)) {
         if (!(_strcmp(HEAP32[$$01418$i$i + 4 >> 2] | 0, $5) | 0)) {
          if (($$017$i$i | 0) == ($$01634 | 0)) {
           break;
          }
          $$1$i$i = $$017$i$i + 1 | 0; //@line 1781
         } else {
          $$1$i$i = $$017$i$i; //@line 1783
         }
        } else {
         $$1$i$i = $$017$i$i; //@line 1786
        }
        $$014$i$i = HEAP32[$$01418$i$i >> 2] | 0; //@line 1788
        if (!$$014$i$i) {
         break L3;
        } else {
         $$01418$i$i = $$014$i$i; //@line 1793
         $$017$i$i = $$1$i$i; //@line 1793
        }
       }
       $17 = HEAP32[$$01418$i$i + 12 >> 2] | 0; //@line 1797
       if (!$17) {
        break L3;
       }
       HEAP32[$vararg_buffer >> 2] = $5; //@line 1803
       HEAP32[$vararg_buffer + 4 >> 2] = $17; //@line 1805
       _fprintf($0, 89286, $vararg_buffer) | 0; //@line 1806
       $$01416$i$i35 = HEAP32[28198] | 0; //@line 1807
       if (!$$01416$i$i35) {
        break;
       } else {
        $$01634 = $$01634 + 1 | 0; //@line 1812
       }
      }
     }
     break;
    }
   case 1:
    {
     $21 = HEAP32[$$0 >> 2] | 0; //@line 1819
     $$01416$i$i17 = HEAP32[28198] | 0; //@line 1820
     L17 : do {
      if (!$$01416$i$i17) {
       $35 = 88982; //@line 1824
      } else {
       $$01418$i$i18 = $$01416$i$i17; //@line 1826
       while (1) {
        if ((HEAP32[$$01418$i$i18 + 8 >> 2] | 0) == 1) {
         if (!(_strcmp(HEAP32[$$01418$i$i18 + 4 >> 2] | 0, $21) | 0)) {
          break;
         }
        }
        $$014$i$i20 = HEAP32[$$01418$i$i18 >> 2] | 0; //@line 1840
        if (!$$014$i$i20) {
         $35 = 88982; //@line 1843
         break L17;
        } else {
         $$01418$i$i18 = $$014$i$i20; //@line 1846
        }
       }
       $35 = HEAP8[HEAP32[$$01418$i$i18 + 12 >> 2] >> 0] | 0 ? 88970 : 88982; //@line 1854
      }
     } while (0);
     HEAP32[$vararg_buffer2 >> 2] = $21; //@line 1857
     HEAP32[$vararg_buffer2 + 4 >> 2] = $35; //@line 1859
     _fprintf($0, 89286, $vararg_buffer2) | 0; //@line 1860
     break;
    }
   case 2:
    {
     $36 = HEAP32[$$0 >> 2] | 0; //@line 1864
     $$01416$i$i23 = HEAP32[28198] | 0; //@line 1865
     L26 : do {
      if (!$$01416$i$i23) {
       $$0$i28 = 0; //@line 1869
      } else {
       $$01418$i$i24 = $$01416$i$i23; //@line 1871
       while (1) {
        if ((HEAP32[$$01418$i$i24 + 8 >> 2] | 0) == 2) {
         if (!(_strcmp(HEAP32[$$01418$i$i24 + 4 >> 2] | 0, $36) | 0)) {
          break;
         }
        }
        $$014$i$i26 = HEAP32[$$01418$i$i24 >> 2] | 0; //@line 1885
        if (!$$014$i$i26) {
         $$0$i28 = 0; //@line 1888
         break L26;
        } else {
         $$01418$i$i24 = $$014$i$i26; //@line 1891
        }
       }
       $$0$i28 = HEAP32[HEAP32[$$01418$i$i24 + 12 >> 2] >> 2] | 0; //@line 1897
      }
     } while (0);
     HEAP32[$vararg_buffer6 >> 2] = $36; //@line 1900
     HEAP32[$vararg_buffer6 + 4 >> 2] = $$0$i28; //@line 1902
     _fprintf($0, 89293, $vararg_buffer6) | 0; //@line 1903
     break;
    }
   default:
    {}
   }
  } while (0);
  $$0 = $$0 + 16 | 0; //@line 1911
 }
 STACKTOP = sp; //@line 1913
 return;
}
function __Z8Sys_openPKcb($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$082$off095$ph = 0, $$084 = 0, $$183$off0 = 0, $$3$ph = 0, $$6 = 0, $10 = 0, $16 = 0, $17 = 0, $2 = 0, $21 = 0, $28 = 0, $36 = 0, $4 = 0, $40 = 0, $43 = 0, $44 = 0, $50 = 0, $51 = 0, $53 = 0, $67 = 0, $72 = 0, $8 = 0, $narrow = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, sp = 0;
 sp = STACKTOP; //@line 1975
 STACKTOP = STACKTOP + 288 | 0; //@line 1976
 $vararg_buffer3 = sp + 264 | 0; //@line 1977
 $vararg_buffer = sp; //@line 1979
 $2 = sp + 272 | 0; //@line 1980
 $4 = (_strncmp($0, 90675, 5) | 0) != 0; //@line 1982
 $8 = (_strncmp($0, 90681, 7) | 0) == 0 & 1; //@line 1986
 $10 = (_strncmp($0, 90689, 7) | 0) == 0; //@line 1988
 $narrow = $10 | (_strncmp($0, 90697, 10) | 0) == 0; //@line 1992
 if ($1) {
  $$082$off095$ph = 1; //@line 1994
 } else {
  $$082$off095$ph = (_access($0, 2) | 0) != 0; //@line 1998
 }
 switch (__Z25disk_sparsebundle_factoryPKcbPP12disk_generic($0, $$082$off095$ph, $2) | 0) {
 case 1:
  {
   $$3$ph = 0; //@line 2003
   break;
  }
 case 2:
  {
   $16 = __Znwj(28) | 0; //@line 2007
   $17 = $16 + 8 | 0; //@line 2008
   HEAP32[$17 >> 2] = 0; //@line 2009
   HEAP32[$17 + 4 >> 2] = 0; //@line 2009
   HEAP32[$17 + 8 >> 2] = 0; //@line 2009
   HEAP32[$17 + 12 >> 2] = 0; //@line 2009
   HEAP32[$16 >> 2] = ___strdup($0) | 0; //@line 2011
   HEAP32[$16 + 4 >> 2] = -1; //@line 2013
   $21 = HEAP32[$2 >> 2] | 0; //@line 2015
   HEAP32[$16 + 24 >> 2] = $21; //@line 2016
   HEAP32[$16 + 16 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 127]($21) | 0; //@line 2024
   $28 = HEAP32[$2 >> 2] | 0; //@line 2025
   HEAP8[$16 + 11 >> 0] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$28 >> 2] | 0) + 8 >> 2] & 127]($28) | 0) & 1; //@line 2032
   HEAP8[$16 + 20 >> 0] = 1; //@line 2034
   $36 = __Znwj(8) | 0; //@line 2035
   HEAP32[$36 >> 2] = $16; //@line 2036
   HEAP32[$36 + 4 >> 2] = HEAP32[28199]; //@line 2039
   HEAP32[28199] = $36; //@line 2040
   $$3$ph = $16; //@line 2041
   break;
  }
 default:
  {
   $40 = _open($0, $$082$off095$ph ? 0 : 2, $vararg_buffer) | 0; //@line 2046
   if ($$082$off095$ph | ($40 | 0) > -1) {
    $$084 = $40; //@line 2050
    $$183$off0 = $$082$off095$ph; //@line 2050
   } else {
    $$084 = _open($0, 0, sp + 256 | 0) | 0; //@line 2053
    $$183$off0 = 1; //@line 2053
   }
   if (!($narrow | ($$084 | 0) > -1)) {
    $72 = _strerror(HEAP32[(___errno_location() | 0) >> 2] | 0) | 0; //@line 2060
    HEAP32[$vararg_buffer3 >> 2] = $0; //@line 2061
    HEAP32[$vararg_buffer3 + 4 >> 2] = $72; //@line 2063
    _printf(104154, $vararg_buffer3) | 0; //@line 2064
    $$6 = 0; //@line 2065
    STACKTOP = sp; //@line 2066
    return $$6 | 0; //@line 2066
   }
   $43 = __Znwj(28) | 0; //@line 2068
   $44 = $43 + 8 | 0; //@line 2069
   HEAP32[$44 >> 2] = 0; //@line 2070
   HEAP32[$44 + 4 >> 2] = 0; //@line 2070
   HEAP32[$44 + 8 >> 2] = 0; //@line 2070
   HEAP32[$44 + 12 >> 2] = 0; //@line 2070
   HEAP32[$43 >> 2] = ___strdup($0) | 0; //@line 2072
   HEAP32[$43 + 24 >> 2] = 0; //@line 2075
   HEAP32[$43 + 4 >> 2] = $$084; //@line 2076
   HEAP8[$44 >> 0] = $4 & 1; //@line 2077
   HEAP8[$43 + 11 >> 0] = $$183$off0 & 1; //@line 2080
   $50 = $43 + 9 | 0; //@line 2081
   HEAP8[$50 >> 0] = $10 & 1; //@line 2082
   $51 = $43 + 10 | 0; //@line 2083
   HEAP8[$51 >> 0] = $8; //@line 2084
   if ($4) {
    HEAP8[$43 + 20 >> 0] = 1; //@line 2087
    $53 = _lseek($$084, 0, 2) | 0; //@line 2088
    _lseek($$084, 0, 0) | 0; //@line 2089
    _read($$084, $vararg_buffer, 256) | 0; //@line 2090
    __Z14FileDiskLayoutiPhRiS0_($53, $vararg_buffer, $43 + 12 | 0, $43 + 16 | 0); //@line 2093
   } else {
    if (!(_fstat($$084, $vararg_buffer) | 0)) {
     HEAP8[$43 + 20 >> 0] = 1; //@line 2099
     if ((HEAP32[$vararg_buffer + 12 >> 2] & 61440 | 0) == 24576) {
      HEAP8[$51 >> 0] = $8; //@line 2105
     }
    }
   }
   if ((HEAP8[$50 >> 0] | 0) != 0 & (HEAP32[28200] | 0) == 0) {
    HEAP32[28200] = $43; //@line 2115
   }
   $67 = __Znwj(8) | 0; //@line 2117
   HEAP32[$67 >> 2] = $43; //@line 2118
   HEAP32[$67 + 4 >> 2] = HEAP32[28199]; //@line 2121
   HEAP32[28199] = $67; //@line 2122
   $$6 = $43; //@line 2123
   STACKTOP = sp; //@line 2124
   return $$6 | 0; //@line 2124
  }
 }
 $$6 = $$3$ph; //@line 2127
 STACKTOP = sp; //@line 2128
 return $$6 | 0; //@line 2128
}
function _expm1($0) {
 $0 = +$0;
 var $$0 = 0.0, $$0105 = 0, $$0106 = 0.0, $$0109 = 0.0, $$0110 = 0.0, $$0111 = 0.0, $$1 = 0, $2 = 0, $20 = 0, $25 = 0.0, $26 = 0, $27 = 0.0, $3 = 0, $31 = 0.0, $35 = 0.0, $36 = 0.0, $4 = 0, $46 = 0.0, $48 = 0.0, $53 = 0.0, $61 = 0.0, $7 = 0, $73 = 0, $74 = 0, $75 = 0.0, $78 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $9 = 0, label = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 55812
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 55813
 $3 = $2 & 2147483647; //@line 55814
 $4 = _bitshift64Lshr(HEAP32[tempDoublePtr >> 2] | 0, $2 | 0, 63) | 0; //@line 55815
 do {
  if ($3 >>> 0 > 1078159481) {
   $7 = ___DOUBLE_BITS_260($0) | 0; //@line 55820
   $9 = tempRet0 & 2147483647; //@line 55822
   if ($9 >>> 0 > 2146435072 | ($9 | 0) == 2146435072 & $7 >>> 0 > 0) {
    $$0 = $0; //@line 55829
   } else {
    if (!$4) {
     if ($0 > 709.782712893384) {
      $$0 = $0 * 8.98846567431158e+307; //@line 55836
     } else {
      $25 = .5; //@line 55838
      label = 12; //@line 55839
     }
    } else {
     $$0 = -1.0; //@line 55842
    }
   }
  } else {
   if ($3 >>> 0 <= 1071001154) {
    if ($3 >>> 0 < 1016070144) {
     $$0 = $0; //@line 55850
     break;
    } else {
     $$0106 = $0; //@line 55853
     $$0111 = 0.0; //@line 55853
     $$1 = 0; //@line 55853
     label = 15; //@line 55854
     break;
    }
   }
   $20 = ($4 | 0) != 0; //@line 55859
   if ($3 >>> 0 >= 1072734898) {
    $25 = $20 ? -.5 : .5; //@line 55862
    label = 12; //@line 55863
    break;
   }
   if ($20) {
    $$0105 = -1; //@line 55868
    $$0109 = $0 + .6931471803691238; //@line 55868
    $$0110 = -1.9082149292705877e-10; //@line 55868
    label = 13; //@line 55869
    break;
   } else {
    $$0105 = 1; //@line 55873
    $$0109 = $0 + -.6931471803691238; //@line 55873
    $$0110 = 1.9082149292705877e-10; //@line 55873
    label = 13; //@line 55874
    break;
   }
  }
 } while (0);
 if ((label | 0) == 12) {
  $26 = ~~($0 * 1.4426950408889634 + $25); //@line 55882
  $27 = +($26 | 0); //@line 55883
  $$0105 = $26; //@line 55887
  $$0109 = $0 - $27 * .6931471803691238; //@line 55887
  $$0110 = $27 * 1.9082149292705877e-10; //@line 55887
  label = 13; //@line 55888
 }
 if ((label | 0) == 13) {
  $31 = $$0109 - $$0110; //@line 55891
  $$0106 = $31; //@line 55894
  $$0111 = $$0109 - $31 - $$0110; //@line 55894
  $$1 = $$0105; //@line 55894
  label = 15; //@line 55895
 }
 L20 : do {
  if ((label | 0) == 15) {
   $35 = $$0106 * .5; //@line 55899
   $36 = $$0106 * $35; //@line 55900
   $46 = $36 * ($36 * ($36 * ($36 * (4008217827329362.0e-21 - $36 * 2.0109921818362437e-7) + -793650757867488.0e-19) + .0015873015872548146) + -.03333333333333313) + 1.0; //@line 55910
   $48 = 3.0 - $35 * $46; //@line 55912
   $53 = $36 * (($46 - $48) / (6.0 - $$0106 * $48)); //@line 55917
   if (!$$1) {
    $$0 = $$0106 - ($$0106 * $53 - $36); //@line 55923
    break;
   }
   $61 = $$0106 * ($53 - $$0111) - $$0111 - $36; //@line 55929
   switch ($$1 | 0) {
   case -1:
    {
     $$0 = ($$0106 - $61) * .5 + -.5; //@line 55935
     break L20;
     break;
    }
   case 1:
    {
     if ($$0106 < -.25) {
      $$0 = ($61 - ($$0106 + .5)) * -2.0; //@line 55945
      break L20;
     } else {
      $$0 = ($$0106 - $61) * 2.0 + 1.0; //@line 55951
      break L20;
     }
     break;
    }
   default:
    {
     $73 = _bitshift64Shl($$1 + 1023 | 0, 0, 52) | 0; //@line 55958
     $74 = tempRet0; //@line 55959
     HEAP32[tempDoublePtr >> 2] = $73; //@line 55960
     HEAP32[tempDoublePtr + 4 >> 2] = $74; //@line 55960
     $75 = +HEAPF64[tempDoublePtr >> 3]; //@line 55960
     if ($$1 >>> 0 > 56) {
      $78 = $$0106 - $61 + 1.0; //@line 55964
      $$0 = (($$1 | 0) == 1024 ? $78 * 2.0 * 8.98846567431158e+307 : $75 * $78) + -1.0; //@line 55971
      break L20;
     } else {
      $85 = _bitshift64Shl(1023 - $$1 | 0, 0, 52) | 0; //@line 55975
      $86 = tempRet0; //@line 55976
      $87 = ($$1 | 0) < 20; //@line 55977
      HEAP32[tempDoublePtr >> 2] = $85; //@line 55978
      HEAP32[tempDoublePtr + 4 >> 2] = $86; //@line 55978
      $88 = +HEAPF64[tempDoublePtr >> 3]; //@line 55978
      $$0 = $75 * (($87 ? 1.0 - $88 : 1.0) + ($$0106 - ($87 ? $61 : $88 + $61))); //@line 55986
      break L20;
     }
    }
   }
  }
 } while (0);
 return +$$0;
}
function __Z5ADBOphPh($trunc, $0) {
 $trunc = $trunc | 0;
 $0 = $0 | 0;
 var $$ = 0, $$1 = 0, $$160 = 0, $$160$ = 0, $$3 = 0, $$3$ = 0, $$5 = 0, $$sink = 0, $$sink1 = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $47 = 0, $48 = 0, $6 = 0, $7 = 0, $70 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0;
 $1 = $trunc & 255; //@line 13826
 if (!($1 & 15)) {
  HEAP8[93412] = 99; //@line 13830
  HEAP8[93413] = 1; //@line 13831
  HEAP8[93414] = -1; //@line 13832
  HEAP8[93415] = 98; //@line 13833
  HEAP8[93411] = HEAP8[93410] | 0; //@line 13835
  return;
 }
 $6 = $1 >>> 2; //@line 13839
 $7 = $6 & 3; //@line 13840
 $9 = ($trunc & 255) >>> 4 & 255; //@line 13842
 $10 = HEAP8[93412] | 0; //@line 13843
 $11 = $10 & 255; //@line 13844
 if (($9 | 0) == ($11 & 15 | 0)) {
  switch ($6 & 3) {
  case 2:
   {
    if (($1 & 3 | 0) != 3) {
     return;
    }
    $15 = HEAP8[$0 + 2 >> 0] | 0; //@line 13857
    switch ($15 << 24 >> 24) {
    case -2:
     {
      HEAP8[93412] = HEAP8[$0 + 1 >> 0] & 15 | $11 & 240; //@line 13867
      return;
     }
    case 4:
    case 2:
    case 1:
     {
      HEAP8[93413] = $15; //@line 13872
      return;
     }
    case 0:
     {
      HEAP8[93412] = HEAP8[$0 + 1 >> 0] & 47 | $11 & 208; //@line 13884
      return;
     }
    default:
     {
      return;
     }
    }
    break;
   }
  case 3:
   {
    switch ($trunc & 3) {
    case 1:
     {
      HEAP8[$0 >> 0] = 8; //@line 13898
      HEAP8[$0 + 1 >> 0] = 97; //@line 13900
      HEAP8[$0 + 2 >> 0] = 112; //@line 13902
      HEAP8[$0 + 3 >> 0] = 112; //@line 13904
      HEAP8[$0 + 4 >> 0] = 108; //@line 13906
      HEAP8[$0 + 5 >> 0] = 1; //@line 13908
      HEAP8[$0 + 6 >> 0] = 44; //@line 13910
      HEAP8[$0 + 7 >> 0] = 1; //@line 13912
      $$sink = 3; //@line 13914
      $$sink1 = $0 + 8 | 0; //@line 13914
      break;
     }
    case 3:
     {
      HEAP8[$0 >> 0] = 2; //@line 13918
      HEAP8[$0 + 1 >> 0] = $10 & -16 & 255 | (_rand() | 0) & 15; //@line 13926
      $$sink = HEAP8[93413] | 0; //@line 13929
      $$sink1 = $0 + 2 | 0; //@line 13929
      break;
     }
    default:
     {
      $$sink = 0; //@line 13933
      $$sink1 = $0; //@line 13933
     }
    }
    HEAP8[$$sink1 >> 0] = $$sink; //@line 13936
    return;
   }
  default:
   {
    return;
   }
  }
 }
 $47 = HEAP8[93415] | 0; //@line 13945
 $48 = $47 & 255; //@line 13946
 if (($9 | 0) != ($48 & 15 | 0)) {
  if (($7 | 0) != 3) {
   return;
  }
  HEAP8[$0 >> 0] = 0; //@line 13954
  return;
 }
 switch ($6 & 3) {
 case 2:
  {
   switch ($trunc & 3) {
   case 2:
    {
     HEAP8[93414] = HEAP8[$0 + 2 >> 0] | 0; //@line 13966
     return;
    }
   case 3:
    {
     switch (HEAP8[$0 + 2 >> 0] | 0) {
     case -2:
      {
       HEAP8[93415] = HEAP8[$0 + 1 >> 0] & 15 | $48 & 240; //@line 13982
       return;
      }
     case 0:
      {
       HEAP8[93415] = HEAP8[$0 + 1 >> 0] & 47 | $48 & 208; //@line 13994
       return;
      }
     default:
      {
       return;
      }
     }
     break;
    }
   default:
    {
     return;
    }
   }
   break;
  }
 case 3:
  {
   switch ($trunc & 3) {
   case 2:
    {
     $70 = HEAP8[93414] | -8; //@line 14015
     $$ = (HEAP8[657318] & 16) == 0 ? $70 : $70 & -65; //@line 14020
     $$1 = (HEAP8[657313] & 1) == 0 ? $$ : $$ & 127; //@line 14025
     $79 = HEAP8[657311] | 0; //@line 14026
     $80 = ($79 | -2) ^ 1; //@line 14028
     $81 = HEAP8[657312] | 0; //@line 14029
     $82 = $81 & 255; //@line 14030
     $$160 = ($82 & 32 | 0) == 0 ? $80 : $80 & -3; //@line 14034
     $$160$ = ($82 & 128 | 0) == 0 ? $$160 : $$160 & -5; //@line 14038
     $$3 = ($79 & 2) == 0 ? $$160$ : $$160$ & -9; //@line 14042
     $$3$ = ($81 & 64) == 0 ? $$3 : $$3 & -33; //@line 14046
     $$5 = (HEAP8[657319] & 4) == 0 ? $$3$ : $$3$ & -65; //@line 14051
     HEAP8[$0 >> 0] = 2; //@line 14052
     HEAP8[$0 + 1 >> 0] = $$5; //@line 14054
     HEAP8[$0 + 2 >> 0] = $$1; //@line 14056
     return;
    }
   case 3:
    {
     HEAP8[$0 >> 0] = 2; //@line 14061
     HEAP8[$0 + 1 >> 0] = $47 & -16 & 255 | (_rand() | 0) & 15; //@line 14069
     HEAP8[$0 + 2 >> 0] = HEAP8[93411] | 0; //@line 14072
     return;
    }
   default:
    {
     HEAP8[$0 >> 0] = 0; //@line 14077
     return;
    }
   }
   break;
  }
 default:
  {
   return;
  }
 }
}
function __Z10fpuop_savej($0) {
 $0 = $0 | 0;
 var $$sink = 0, $1 = 0, $102 = 0, $108 = 0, $11 = 0, $119 = 0, $120 = 0, $122 = 0, $17 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $37 = 0, $43 = 0, $49 = 0, $55 = 0, $61 = 0, $74 = 0, $78 = 0, $84 = 0, $90 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 55880
 STACKTOP = STACKTOP + 16 | 0; //@line 55881
 $1 = sp; //@line 55882
 $2 = $0 & 56; //@line 55883
 $3 = ($2 | 0) == 32; //@line 55884
 if (!(__ZL9get_fp_adjPj($0, $1) | 0)) {
  $11 = (HEAP32[162768] | 0) + -2 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 55893
  $17 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($11) | 0; //@line 55899
  HEAP32[162770] = $17; //@line 55900
  HEAP32[162769] = $17; //@line 55901
  HEAP32[162768] = $11; //@line 55902
  __Z7op_illgj($0); //@line 55903
  STACKTOP = sp; //@line 55904
  return;
 }
 $20 = HEAP32[$1 >> 2] | 0; //@line 55908
 do {
  if ((HEAP32[30880] | 0) == 4) {
   if ($3) {
    $21 = $20 + -4 | 0; //@line 55912
    HEAP32[$1 >> 2] = $21; //@line 55913
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($21, 1090519040); //@line 55919
    $122 = $21; //@line 55920
    label = 12; //@line 55921
    break;
   } else {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($20, 1090519040); //@line 55929
    $$sink = 4; //@line 55930
    break;
   }
  } else {
   if ($3) {
    $78 = $20 + -4 | 0; //@line 55935
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($78 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($78, 1879048192); //@line 55941
    $84 = $20 + -8 | 0; //@line 55942
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($84 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($84, 0); //@line 55948
    $90 = $20 + -12 | 0; //@line 55949
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($90 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($90, 0); //@line 55955
    $96 = $20 + -16 | 0; //@line 55956
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($96 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($96, 0); //@line 55962
    $102 = $20 + -20 | 0; //@line 55963
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($102 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($102, 0); //@line 55969
    $108 = $20 + -24 | 0; //@line 55970
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($108 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($108, 0); //@line 55976
    $119 = HEAP32[(HEAP32[123608 + (($20 + -28 | 0) >>> 16 << 2) >> 2] | 0) + 12 >> 2] | 0; //@line 55982
    $120 = $20 + -28 | 0; //@line 55983
    HEAP32[$1 >> 2] = $120; //@line 55984
    FUNCTION_TABLE_vii[$119 & 31]($120, 521666560); //@line 55985
    $122 = $120; //@line 55986
    label = 12; //@line 55987
    break;
   } else {
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($20, 521666560); //@line 55995
    $37 = $20 + 4 | 0; //@line 55996
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($37, 0); //@line 56002
    $43 = $20 + 8 | 0; //@line 56003
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($43 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($43, 0); //@line 56009
    $49 = $20 + 12 | 0; //@line 56010
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($49 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($49, 0); //@line 56016
    $55 = $20 + 16 | 0; //@line 56017
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($55, 0); //@line 56023
    $61 = $20 + 20 | 0; //@line 56024
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($61 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($61, 0); //@line 56030
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + (($20 + 24 | 0) >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($20 + 24 | 0, 1879048192); //@line 56038
    $$sink = 28; //@line 56039
    break;
   }
  }
 } while (0);
 if ((label | 0) == 12) {
  HEAP32[651040 + (($0 & 7) << 2) >> 2] = $122; //@line 56047
  STACKTOP = sp; //@line 56048
  return;
 }
 $74 = $20 + $$sink | 0; //@line 56050
 HEAP32[$1 >> 2] = $74; //@line 56051
 if (($2 | 0) != 24) {
  STACKTOP = sp; //@line 56054
  return;
 }
 HEAP32[651040 + (($0 & 7) << 2) >> 2] = $74; //@line 56058
 STACKTOP = sp; //@line 56059
 return;
}
function __ZL15get_current_dirjjRjb($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0 = 0, $16 = 0, $18 = 0, $21 = 0, $32 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $47 = 0, $5 = 0, $55 = 0, $59 = 0, $6 = 0, $64 = 0, $65 = 0, $66 = 0, $68 = 0, $75 = 0, $77 = 0, $85 = 0, $86 = 0, $88 = 0, sp = 0;
 sp = STACKTOP; //@line 35225
 STACKTOP = STACKTOP + 80 | 0; //@line 35226
 $4 = sp; //@line 35227
 $5 = $4 + 32 | 0; //@line 35228
 HEAP32[$5 >> 2] = $0; //@line 35229
 $6 = HEAP32[30848] | 0; //@line 35230
 HEAP32[$4 + 36 >> 2] = $6 + 306; //@line 35233
 HEAP32[$4 + 40 >> 2] = $6 + 308; //@line 35236
 HEAP32[$4 + 44 >> 2] = $6 + 310; //@line 35239
 HEAP32[$4 + 48 >> 2] = $6 + 312; //@line 35242
 if ($3) {
  $16 = $0 + 18 | 0; //@line 35244
  $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 35246
  $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$18 >> 2] >> 2] & 127]($16) | 0; //@line 35249
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 12 >> 2] & 31]($16, 0); //@line 35253
  _Execute68k((HEAP32[30848] | 0) + 594 | 0, $4); //@line 35256
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($16, $21); //@line 35262
 } else {
  _Execute68k($6 + 594 | 0, $4); //@line 35265
 }
 $32 = (HEAP32[30848] | 0) + 306 | 0; //@line 35268
 $38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($32) | 0; //@line 35274
 $39 = HEAP32[$4 >> 2] | 0; //@line 35275
 $40 = $39 & 65535; //@line 35276
 if ($39 & 65535 | 0) {
  $$0 = $40; //@line 35280
  STACKTOP = sp; //@line 35281
  return $$0 | 0; //@line 35281
 }
 switch ($38 << 16 >> 16 | 0) {
 case 1:
  {
   HEAP32[$2 >> 2] = 2; //@line 35287
   $$0 = $40; //@line 35288
   STACKTOP = sp; //@line 35289
   return $$0 | 0; //@line 35289
  }
 case 4:
 case 2:
  {
   HEAP32[$2 >> 2] = $1 | 0 ? $1 : 2; //@line 35295
   $$0 = $40; //@line 35296
   STACKTOP = sp; //@line 35297
   return $$0 | 0; //@line 35297
  }
 case 3:
  {
   if ($1 | 0) {
    HEAP32[$2 >> 2] = $1; //@line 35303
    $$0 = $40; //@line 35304
    STACKTOP = sp; //@line 35305
    return $$0 | 0; //@line 35305
   }
   HEAP32[$4 >> 2] = 0; //@line 35307
   HEAP32[$4 + 4 >> 2] = 0; //@line 35309
   $47 = $0 + 22 | 0; //@line 35310
   HEAP32[$4 + 8 >> 2] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($47 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($47) | 0; //@line 35318
   $55 = HEAP32[30848] | 0; //@line 35319
   HEAP32[$5 >> 2] = $55 + 306; //@line 35321
   _Execute68k($55 + 614 | 0, $4); //@line 35323
   $59 = (HEAP32[30848] | 0) + 306 | 0; //@line 35325
   $64 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($59 >>> 16 << 2) >> 2] >> 2] & 127]($59) | 0; //@line 35330
   $65 = HEAP32[$4 >> 2] | 0; //@line 35331
   $66 = $65 & 65535; //@line 35332
   if ($65 & 65535 | 0) {
    $$0 = $66; //@line 35336
    STACKTOP = sp; //@line 35337
    return $$0 | 0; //@line 35337
   }
   $68 = $64 + 4 | 0; //@line 35339
   HEAP32[$2 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($68 >>> 16 << 2) >> 2] >> 2] & 127]($68) | 0; //@line 35345
   $$0 = $66; //@line 35346
   STACKTOP = sp; //@line 35347
   return $$0 | 0; //@line 35347
  }
 case 5:
  {
   if ($1 | 0) {
    HEAP32[$2 >> 2] = $1; //@line 35353
    $$0 = $40; //@line 35354
    STACKTOP = sp; //@line 35355
    return $$0 | 0; //@line 35355
   }
   $75 = HEAP32[30848] | 0; //@line 35357
   $77 = $75 + 324 | 0; //@line 35359
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($77 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($77, 0); //@line 35365
   HEAP32[$5 >> 2] = $75 + 306; //@line 35366
   _Execute68k((HEAP32[30848] | 0) + 632 | 0, $4); //@line 35369
   $85 = HEAP32[$4 >> 2] | 0; //@line 35370
   $86 = $85 & 65535; //@line 35371
   if ($85 & 65535 | 0) {
    $$0 = $86; //@line 35375
    STACKTOP = sp; //@line 35376
    return $$0 | 0; //@line 35376
   }
   $88 = $75 + 354 | 0; //@line 35378
   HEAP32[$2 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($88 >>> 16 << 2) >> 2] >> 2] & 127]($88) | 0; //@line 35384
   $$0 = $86; //@line 35385
   STACKTOP = sp; //@line 35386
   return $$0 | 0; //@line 35386
  }
 default:
  {
   $$0 = -50; //@line 35390
   STACKTOP = sp; //@line 35391
   return $$0 | 0; //@line 35391
  }
 }
 return 0; //@line 35394
}
function __Z9EtherOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $106 = 0, $113 = 0, $12 = 0, $120 = 0, $127 = 0, $13 = 0, $134 = 0, $141 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $36 = 0, $4 = 0, $43 = 0, $50 = 0, $57 = 0, $6 = 0, $64 = 0, $71 = 0, $78 = 0, $85 = 0, $92 = 0, $99 = 0, sp = 0;
 sp = STACKTOP; //@line 15250
 STACKTOP = STACKTOP + 80 | 0; //@line 15251
 $2 = sp; //@line 15252
 HEAP32[$2 >> 2] = 76; //@line 15253
 _Execute68kTrap(-22754, $2); //@line 15254
 $4 = HEAP32[$2 + 32 >> 2] | 0; //@line 15256
 if (!$4) {
  $$0 = -23; //@line 15259
  STACKTOP = sp; //@line 15260
  return $$0 | 0; //@line 15260
 }
 HEAP32[28477] = $4; //@line 15262
 $6 = $4 + 4 | 0; //@line 15263
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($6, 7); //@line 15269
 $12 = HEAP32[28477] | 0; //@line 15270
 $13 = $12 + 8 | 0; //@line 15271
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $12 + 20 | 0); //@line 15278
 $20 = HEAP32[28477] | 0; //@line 15279
 $21 = $20 + 12 | 0; //@line 15280
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($21, $20 + 30 | 0); //@line 15287
 $29 = (HEAP32[28477] | 0) + 20 | 0; //@line 15289
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, 8217); //@line 15295
 $36 = (HEAP32[28477] | 0) + 22 | 0; //@line 15297
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($36, 8785); //@line 15303
 $43 = (HEAP32[28477] | 0) + 24 | 0; //@line 15305
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($43 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($43, 544737532); //@line 15311
 $50 = (HEAP32[28477] | 0) + 28 | 0; //@line 15313
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($50, 20176); //@line 15319
 $57 = (HEAP32[28477] | 0) + 34 | 0; //@line 15321
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($57 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($57, $1); //@line 15327
 $64 = (HEAP32[28477] | 0) + 52 | 0; //@line 15329
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($64 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($64, 24592); //@line 15335
 $71 = (HEAP32[28477] | 0) + 54 | 0; //@line 15337
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($71 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($71, 12291); //@line 15343
 $78 = (HEAP32[28477] | 0) + 56 | 0; //@line 15345
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($78 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($78, 36929); //@line 15351
 $85 = (HEAP32[28477] | 0) + 58 | 0; //@line 15353
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($85 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($85, 19011); //@line 15359
 $92 = (HEAP32[28477] | 0) + 60 | 0; //@line 15361
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($92 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($92, 26370); //@line 15367
 $99 = (HEAP32[28477] | 0) + 62 | 0; //@line 15369
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($99 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($99, 28962); //@line 15375
 $106 = (HEAP32[28477] | 0) + 64 | 0; //@line 15377
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($106 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($106, 13824); //@line 15383
 $113 = (HEAP32[28477] | 0) + 66 | 0; //@line 15385
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($113 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($113, 28672); //@line 15391
 $120 = (HEAP32[28477] | 0) + 68 | 0; //@line 15393
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($120 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($120, 20085); //@line 15399
 $127 = (HEAP32[28477] | 0) + 70 | 0; //@line 15401
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($127 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($127, 28962); //@line 15407
 $134 = (HEAP32[28477] | 0) + 72 | 0; //@line 15409
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($134 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($134, 19011); //@line 15415
 $141 = (HEAP32[28477] | 0) + 74 | 0; //@line 15417
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($141 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($141, 20085); //@line 15423
 $$0 = 0; //@line 15424
 STACKTOP = sp; //@line 15425
 return $$0 | 0; //@line 15425
}
function __Z10SerialOpenjji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$3 = 0, $107 = 0, $113 = 0, $119 = 0, $19 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $36 = 0, $39 = 0, $45 = 0, $46 = 0, $52 = 0, $64 = 0, $70 = 0, $76 = 0, $8 = 0, $82 = 0, $88 = 0, $89 = 0, $9 = 0, $95 = 0, sp = 0;
 sp = STACKTOP; //@line 14574
 STACKTOP = STACKTOP + 80 | 0; //@line 14575
 $3 = sp; //@line 14576
 if (($2 | 2 | 0) == 2) {
  $$3 = 0; //@line 14580
  STACKTOP = sp; //@line 14581
  return $$3 | 0; //@line 14581
 }
 $8 = HEAP32[113900 + ($2 >> 1 << 2) >> 2] | 0; //@line 14585
 $9 = $8 + 4 | 0; //@line 14586
 if (HEAP8[$9 >> 0] | 0) {
  $$3 = 0; //@line 14590
  STACKTOP = sp; //@line 14591
  return $$3 | 0; //@line 14591
 }
 HEAP8[$8 + 12 >> 0] = 0; //@line 14594
 HEAP8[$8 + 6 >> 0] = 0; //@line 14596
 HEAP8[$8 + 13 >> 0] = 0; //@line 14598
 HEAP8[$8 + 7 >> 0] = 0; //@line 14600
 HEAP8[$8 + 5 >> 0] = 0; //@line 14602
 $19 = HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] | 0; //@line 14605
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[30902] | 0) + 4 >> 2] & 127]($2 & 2 | 508) | 0) & 65535; //@line 14612
 $27 = FUNCTION_TABLE_iii[$19 & 31]($8, $26) | 0; //@line 14613
 if ($27 << 16 >> 16) {
  $$3 = $27; //@line 14616
  STACKTOP = sp; //@line 14617
  return $$3 | 0; //@line 14617
 }
 HEAP32[$3 >> 2] = 76; //@line 14619
 _Execute68kTrap(-22754, $3); //@line 14620
 $29 = $3 + 32 | 0; //@line 14621
 $30 = HEAP32[$29 >> 2] | 0; //@line 14622
 if (!$30) {
  FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 28 >> 2] & 127]($8) | 0; //@line 14628
  $$0 = -23; //@line 14629
 } else {
  HEAP32[$8 + 8 >> 2] = $30; //@line 14632
  $36 = HEAP32[$29 >> 2] | 0; //@line 14633
  HEAP32[$8 + 16 >> 2] = $36 + 38; //@line 14636
  $39 = $30 + 4 | 0; //@line 14637
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($39, 7); //@line 14643
  $45 = $30 + 8 | 0; //@line 14644
  $46 = $30 + 20 | 0; //@line 14645
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($45 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($45, $46); //@line 14651
  $52 = $30 + 12 | 0; //@line 14652
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($52 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($52, $30 + 30 | 0); //@line 14659
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($46, 8217); //@line 14665
  $64 = $30 + 22 | 0; //@line 14666
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($64 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($64, 8785); //@line 14672
  $70 = $30 + 24 | 0; //@line 14673
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($70 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($70, 544737532); //@line 14679
  $76 = $30 + 28 | 0; //@line 14680
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($76 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($76, 20176); //@line 14686
  $82 = $36 + 42 | 0; //@line 14687
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($82, 7); //@line 14693
  $88 = $36 + 46 | 0; //@line 14694
  $89 = $36 + 58 | 0; //@line 14695
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($88 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($88, $89); //@line 14701
  $95 = $36 + 50 | 0; //@line 14702
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($95 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($95, $36 + 68 | 0); //@line 14709
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($89 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($89, 8217); //@line 14715
  $107 = $36 + 60 | 0; //@line 14716
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($107 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($107, 8785); //@line 14722
  $113 = $36 + 62 | 0; //@line 14723
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($113 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($113, 544737532); //@line 14729
  $119 = $36 + 66 | 0; //@line 14730
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($119 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($119, 20176); //@line 14736
  HEAP8[$9 >> 0] = 1; //@line 14737
  $$0 = 0; //@line 14738
 }
 $$3 = $$0; //@line 14740
 STACKTOP = sp; //@line 14741
 return $$3 | 0; //@line 14741
}
function __Z9CDROMOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$023$i = 0, $$sroa$03$027 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $2 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $33 = 0, $40 = 0, $49 = 0, $56 = 0, $57 = 0, $58 = 0, $65 = 0, $69 = 0, $73 = 0, $75 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 20031
 STACKTOP = STACKTOP + 80 | 0; //@line 20032
 $2 = sp; //@line 20033
 $3 = $1 + 16 | 0; //@line 20034
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, 0); //@line 20040
 HEAP8[657354] = 0; //@line 20041
 $9 = HEAP32[28494] | 0; //@line 20042
 $10 = HEAP32[28493] | 0; //@line 20043
 if (($10 | 0) == ($9 | 0)) {
  STACKTOP = sp; //@line 20046
  return 0; //@line 20046
 }
 $12 = $2 + 32 | 0; //@line 20048
 $$sroa$03$027 = $10; //@line 20049
 do {
  HEAP32[$$sroa$03$027 >> 2] = __Z19FindFreeDriveNumberi(1) | 0; //@line 20052
  $14 = $$sroa$03$027 + 20 | 0; //@line 20053
  HEAP8[$14 >> 0] = 0; //@line 20054
  $15 = $$sroa$03$027 + 4 | 0; //@line 20055
  if (HEAP32[$15 >> 2] | 0) {
   HEAP8[$$sroa$03$027 + 21 >> 0] = 1; //@line 20060
   HEAP32[$$sroa$03$027 + 8 >> 2] = 512; //@line 20062
   HEAP32[$$sroa$03$027 + 12 >> 2] = -1; //@line 20064
   HEAP8[$$sroa$03$027 + 832 >> 0] = 9; //@line 20066
   HEAP8[$$sroa$03$027 + 833 >> 0] = 0; //@line 20068
   HEAP32[$2 >> 2] = 30; //@line 20069
   _Execute68kTrap(-22754, $2); //@line 20070
   $23 = HEAP32[$12 >> 2] | 0; //@line 20071
   if ($23 | 0) {
    $25 = $$sroa$03$027 + 836 | 0; //@line 20074
    HEAP32[$25 >> 2] = $23; //@line 20075
    $26 = $23 + 2 | 0; //@line 20076
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, 128); //@line 20082
    $33 = (HEAP32[$25 >> 2] | 0) + 4 | 0; //@line 20084
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($33, 1); //@line 20090
    $40 = (HEAP32[$25 >> 2] | 0) + 5 | 0; //@line 20092
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($40, 1); //@line 20098
    if (__Z17SysIsDiskInsertedPv(HEAP32[$15 >> 2] | 0) | 0) {
     $49 = (HEAP32[$25 >> 2] | 0) + 3 | 0; //@line 20103
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($49 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($49, 1); //@line 20109
     _memset($$sroa$03$027 + 22 | 0, 0, 804) | 0; //@line 20111
     $56 = $$sroa$03$027 + 826 | 0; //@line 20112
     HEAP8[$56 >> 0] = 0; //@line 20113
     $57 = $$sroa$03$027 + 827 | 0; //@line 20114
     HEAP8[$57 >> 0] = 0; //@line 20115
     $58 = $$sroa$03$027 + 828 | 0; //@line 20116
     HEAP8[$58 >> 0] = 0; //@line 20117
     $$023$i = 4; //@line 20118
     while (1) {
      if ((HEAP8[($$023$i | 2) + ($$sroa$03$027 + 22) >> 0] | 0) == -86) {
       label = 8; //@line 20125
       break;
      }
      $75 = $$023$i + 8 | 0; //@line 20128
      if (($75 | 0) < 804) {
       $$023$i = $75; //@line 20131
      } else {
       break;
      }
     }
     if ((label | 0) == 8) {
      label = 0; //@line 20137
      $65 = HEAP8[$$023$i + 5 + ($$sroa$03$027 + 22) >> 0] | 0; //@line 20140
      HEAP8[$56 >> 0] = $65; //@line 20141
      HEAP8[$$sroa$03$027 + 829 >> 0] = $65; //@line 20143
      $69 = HEAP8[$$023$i + 6 + ($$sroa$03$027 + 22) >> 0] | 0; //@line 20146
      HEAP8[$57 >> 0] = $69; //@line 20147
      HEAP8[$$sroa$03$027 + 830 >> 0] = $69; //@line 20149
      $73 = HEAP8[$$023$i + 7 + ($$sroa$03$027 + 22) >> 0] | 0; //@line 20152
      HEAP8[$58 >> 0] = $73; //@line 20153
      HEAP8[$$sroa$03$027 + 831 >> 0] = $73; //@line 20155
     }
     __ZL18find_hfs_partitionR16cdrom_drive_info($$sroa$03$027); //@line 20157
     HEAP8[$14 >> 0] = 1; //@line 20158
    }
    HEAP32[$2 >> 2] = HEAP32[$$sroa$03$027 >> 2] << 16 | 65474; //@line 20163
    HEAP32[$12 >> 2] = (HEAP32[$25 >> 2] | 0) + 6; //@line 20166
    _Execute68kTrap(-24498, $2); //@line 20167
   }
  }
  $$sroa$03$027 = $$sroa$03$027 + 840 | 0; //@line 20170
 } while (($$sroa$03$027 | 0) != ($9 | 0));
 STACKTOP = sp; //@line 20178
 return 0; //@line 20178
}
function _pop_arg($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $10 = 0, $108 = 0, $109 = 0.0, $115 = 0, $116 = 0.0, $16 = 0, $17 = 0, $20 = 0, $29 = 0, $30 = 0, $31 = 0, $40 = 0, $41 = 0, $43 = 0, $46 = 0, $47 = 0, $56 = 0, $57 = 0, $59 = 0, $62 = 0, $71 = 0, $72 = 0, $73 = 0, $82 = 0, $83 = 0, $85 = 0, $88 = 0, $9 = 0, $97 = 0, $98 = 0, $99 = 0;
 L1 : do {
  if ($1 >>> 0 <= 20) {
   do {
    switch ($1 | 0) {
    case 9:
     {
      $9 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57257
      $10 = HEAP32[$9 >> 2] | 0; //@line 57258
      HEAP32[$2 >> 2] = $9 + 4; //@line 57260
      HEAP32[$0 >> 2] = $10; //@line 57261
      break L1;
      break;
     }
    case 10:
     {
      $16 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57277
      $17 = HEAP32[$16 >> 2] | 0; //@line 57278
      HEAP32[$2 >> 2] = $16 + 4; //@line 57280
      $20 = $0; //@line 57283
      HEAP32[$20 >> 2] = $17; //@line 57285
      HEAP32[$20 + 4 >> 2] = (($17 | 0) < 0) << 31 >> 31; //@line 57288
      break L1;
      break;
     }
    case 11:
     {
      $29 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57304
      $30 = HEAP32[$29 >> 2] | 0; //@line 57305
      HEAP32[$2 >> 2] = $29 + 4; //@line 57307
      $31 = $0; //@line 57308
      HEAP32[$31 >> 2] = $30; //@line 57310
      HEAP32[$31 + 4 >> 2] = 0; //@line 57313
      break L1;
      break;
     }
    case 12:
     {
      $40 = (HEAP32[$2 >> 2] | 0) + (8 - 1) & ~(8 - 1); //@line 57329
      $41 = $40; //@line 57330
      $43 = HEAP32[$41 >> 2] | 0; //@line 57332
      $46 = HEAP32[$41 + 4 >> 2] | 0; //@line 57335
      HEAP32[$2 >> 2] = $40 + 8; //@line 57337
      $47 = $0; //@line 57338
      HEAP32[$47 >> 2] = $43; //@line 57340
      HEAP32[$47 + 4 >> 2] = $46; //@line 57343
      break L1;
      break;
     }
    case 13:
     {
      $56 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57359
      $57 = HEAP32[$56 >> 2] | 0; //@line 57360
      HEAP32[$2 >> 2] = $56 + 4; //@line 57362
      $59 = ($57 & 65535) << 16 >> 16; //@line 57364
      $62 = $0; //@line 57367
      HEAP32[$62 >> 2] = $59; //@line 57369
      HEAP32[$62 + 4 >> 2] = (($59 | 0) < 0) << 31 >> 31; //@line 57372
      break L1;
      break;
     }
    case 14:
     {
      $71 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57388
      $72 = HEAP32[$71 >> 2] | 0; //@line 57389
      HEAP32[$2 >> 2] = $71 + 4; //@line 57391
      $73 = $0; //@line 57393
      HEAP32[$73 >> 2] = $72 & 65535; //@line 57395
      HEAP32[$73 + 4 >> 2] = 0; //@line 57398
      break L1;
      break;
     }
    case 15:
     {
      $82 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57414
      $83 = HEAP32[$82 >> 2] | 0; //@line 57415
      HEAP32[$2 >> 2] = $82 + 4; //@line 57417
      $85 = ($83 & 255) << 24 >> 24; //@line 57419
      $88 = $0; //@line 57422
      HEAP32[$88 >> 2] = $85; //@line 57424
      HEAP32[$88 + 4 >> 2] = (($85 | 0) < 0) << 31 >> 31; //@line 57427
      break L1;
      break;
     }
    case 16:
     {
      $97 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 57443
      $98 = HEAP32[$97 >> 2] | 0; //@line 57444
      HEAP32[$2 >> 2] = $97 + 4; //@line 57446
      $99 = $0; //@line 57448
      HEAP32[$99 >> 2] = $98 & 255; //@line 57450
      HEAP32[$99 + 4 >> 2] = 0; //@line 57453
      break L1;
      break;
     }
    case 17:
     {
      $108 = (HEAP32[$2 >> 2] | 0) + (8 - 1) & ~(8 - 1); //@line 57469
      $109 = +HEAPF64[$108 >> 3]; //@line 57470
      HEAP32[$2 >> 2] = $108 + 8; //@line 57472
      HEAPF64[$0 >> 3] = $109; //@line 57473
      break L1;
      break;
     }
    case 18:
     {
      $115 = (HEAP32[$2 >> 2] | 0) + (8 - 1) & ~(8 - 1); //@line 57489
      $116 = +HEAPF64[$115 >> 3]; //@line 57490
      HEAP32[$2 >> 2] = $115 + 8; //@line 57492
      HEAPF64[$0 >> 3] = $116; //@line 57493
      break L1;
      break;
     }
    default:
     {
      break L1;
     }
    }
   } while (0);
  }
 } while (0);
 return;
}
function __Z7InitAllPKc($0) {
 $0 = $0 | 0;
 var $$ = 0, $$2 = 0, $$215 = 0, $$sink = 0, $$sink4$shrunk = 0, $11 = 0, $14 = 0, $26 = 0, $30 = 0, $35 = 0, $38 = 0, $4 = 0, $7 = 0, label = 0;
 if (!(__Z8CheckROMv() | 0)) {
  __Z10ErrorAlertPKc(__Z9GetStringi(1007) | 0); //@line 51
  $$215 = 0; //@line 52
  return $$215 | 0; //@line 53
 }
 switch (HEAP16[325960] | 0) {
 case 630:
 case 117:
 case 0:
  {
   HEAP32[30880] = 0; //@line 58
   $$sink = 1; //@line 59
   $$sink4$shrunk = 0; //@line 59
   label = 7; //@line 60
   break;
  }
 case 376:
  {
   $4 = __Z14PrefsFindInt32PKc(90125) | 0; //@line 64
   $$ = ($4 | 0) > 2 ? $4 : 2; //@line 66
   HEAP32[30880] = ($$ | 0) < 4 ? $$ : 4; //@line 69
   $7 = __Z13PrefsFindBoolPKc(90166) | 0; //@line 70
   HEAP32[30881] = $7 & 1; //@line 72
   $$sink = 1; //@line 76
   $$sink4$shrunk = $7 | (HEAP32[30880] | 0) == 4; //@line 76
   label = 7; //@line 77
   break;
  }
 case 1660:
  {
   $11 = __Z14PrefsFindInt32PKc(90125) | 0; //@line 81
   $$2 = ($11 | 0) > 2 ? $11 : 2; //@line 83
   HEAP32[30880] = ($$2 | 0) < 4 ? $$2 : 4; //@line 86
   $14 = __Z13PrefsFindBoolPKc(90166) | 0; //@line 87
   HEAP32[30881] = $14 & 1; //@line 89
   $$sink = 0; //@line 93
   $$sink4$shrunk = $14 | (HEAP32[30880] | 0) == 4; //@line 93
   label = 7; //@line 94
   break;
  }
 default:
  {}
 }
 if ((label | 0) == 7) {
  HEAP32[30881] = $$sink4$shrunk & 1; //@line 102
  HEAP8[659480] = $$sink; //@line 103
 }
 HEAP8[659479] = 0; //@line 105
 __Z9XPRAMInitPKc($0); //@line 106
 if (!((HEAP8[656037] | 0) == 78 & (HEAP8[656038] | 0) == 117 & (HEAP8[656039] | 0) == 77 & (HEAP8[656040] | 0) == 99)) {
  _memset(656025, 0, 256) | 0; //@line 119
  HEAP8[656037] = 78; //@line 120
  HEAP8[656038] = 117; //@line 121
  HEAP8[656039] = 77; //@line 122
  HEAP8[656040] = 99; //@line 123
  HEAP8[656026] = -128; //@line 124
  HEAP8[656041] = -88; //@line 125
  HEAP8[656042] = 0; //@line 126
  HEAP8[656043] = 0; //@line 127
  HEAP8[656044] = 34; //@line 128
  HEAP8[656045] = -52; //@line 129
  HEAP8[656046] = 10; //@line 130
  HEAP8[656047] = -52; //@line 131
  HEAP8[656048] = 10; //@line 132
  HEAP8[656053] = 0; //@line 133
  HEAP8[656054] = 2; //@line 134
  HEAP8[656055] = 99; //@line 135
  HEAP8[656056] = 0; //@line 136
  HEAP8[656033] = 19; //@line 137
  HEAP8[656034] = -120; //@line 138
  HEAP8[656035] = 0; //@line 139
  HEAP8[656036] = -52; //@line 140
  HEAP8[656143] = 0; //@line 141
  HEAP8[656144] = 1; //@line 142
 }
 $26 = __Z14PrefsFindInt32PKc(89952) | 0; //@line 144
 HEAP8[656145] = $26 >>> 8; //@line 147
 HEAP8[656146] = $26; //@line 149
 $30 = __Z14PrefsFindInt32PKc(89980) | 0; //@line 150
 HEAP8[656147] = $30 >>> 8; //@line 153
 HEAP8[656148] = $30; //@line 155
 __Z8SonyInitv(); //@line 156
 __Z8DiskInitv(); //@line 157
 __Z9CDROMInitv(); //@line 158
 __Z8SCSIInitv(); //@line 159
 __Z9ExtFSInitv(); //@line 160
 __Z10SerialInitv(); //@line 161
 __Z9EtherInitv(); //@line 162
 __Z9TimerInitv(); //@line 163
 __Z7ADBInitv(); //@line 164
 __Z9AudioInitv(); //@line 165
 _puts(88900) | 0; //@line 166
 switch (HEAP16[325960] | 0) {
 case 630:
 case 117:
 case 0:
  {
   $35 = 1; //@line 170
   break;
  }
 default:
  {
   $35 = 0; //@line 174
  }
 }
 if (!(__Z9VideoInitb($35) | 0)) {
  $$215 = 0; //@line 179
  return $$215 | 0; //@line 180
 }
 HEAP8[656111] = 66; //@line 182
 HEAP8[656112] = 50; //@line 183
 $38 = HEAP32[HEAP32[30548] >> 2] | 0; //@line 185
 HEAP8[656113] = HEAP16[$38 + 824 + (HEAP32[(HEAP32[$38 + 16 >> 2] | 0) + 12 >> 2] << 1) >> 1]; //@line 193
 HEAP8[656114] = 0; //@line 194
 _puts(88910) | 0; //@line 195
 if (!(__Z9Init680x0v() | 0)) {
  $$215 = 0; //@line 198
  return $$215 | 0; //@line 199
 }
 _puts(88920) | 0; //@line 201
 if (__Z8PatchROMv() | 0) {
  $$215 = 1; //@line 204
  return $$215 | 0; //@line 205
 }
 __Z10ErrorAlertPKc(__Z9GetStringi(1007) | 0); //@line 208
 $$215 = 0; //@line 209
 return $$215 | 0; //@line 210
}
function __Z12extfs_removePKc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$i = 0, $$0$i7 = 0, $1 = 0, $13 = 0, $2 = 0, $23 = 0, $32 = 0, $6 = 0, $7 = 0, $9 = 0, $endptr = 0, $endptr10 = 0, $endptr12 = 0, $endptr14 = 0, sp = 0;
 sp = STACKTOP; //@line 46740
 STACKTOP = STACKTOP + 1024 | 0; //@line 46741
 $1 = sp; //@line 46742
 HEAP8[$1 >> 0] = 0; //@line 46743
 $2 = _strrchr($0, 47) | 0; //@line 46744
 $$0$i = ($2 | 0) == 0 ? $0 : $2 + 1 | 0; //@line 46747
 $6 = $0; //@line 46749
 $7 = $$0$i - $6 | 0; //@line 46750
 _strncpy($1, $0, $7) | 0; //@line 46751
 HEAP8[$1 + $7 >> 0] = 0; //@line 46753
 $endptr = $1 + (_strlen($1) | 0) | 0; //@line 46755
 HEAP8[$endptr >> 0] = HEAP8[103798] | 0; //@line 46756
 HEAP8[$endptr + 1 >> 0] = HEAP8[103799] | 0; //@line 46756
 HEAP8[$endptr + 2 >> 0] = HEAP8[103800] | 0; //@line 46756
 HEAP8[$endptr + 3 >> 0] = HEAP8[103801] | 0; //@line 46756
 HEAP8[$endptr + 4 >> 0] = HEAP8[103802] | 0; //@line 46756
 HEAP8[$endptr + 5 >> 0] = HEAP8[103803] | 0; //@line 46756
 HEAP8[$endptr + 6 >> 0] = HEAP8[103804] | 0; //@line 46756
 _strncat($1, $$0$i, 1023) | 0; //@line 46757
 _remove($1) | 0; //@line 46758
 HEAP8[$1 >> 0] = 0; //@line 46759
 $9 = _strrchr($0, 47) | 0; //@line 46760
 $$0$i7 = ($9 | 0) == 0 ? $0 : $9 + 1 | 0; //@line 46763
 $13 = $$0$i7 - $6 | 0; //@line 46765
 _strncpy($1, $0, $13) | 0; //@line 46766
 HEAP8[$1 + $13 >> 0] = 0; //@line 46768
 $endptr10 = $1 + (_strlen($1) | 0) | 0; //@line 46770
 HEAP8[$endptr10 >> 0] = HEAP8[104080] | 0; //@line 46771
 HEAP8[$endptr10 + 1 >> 0] = HEAP8[104081] | 0; //@line 46771
 HEAP8[$endptr10 + 2 >> 0] = HEAP8[104082] | 0; //@line 46771
 HEAP8[$endptr10 + 3 >> 0] = HEAP8[104083] | 0; //@line 46771
 HEAP8[$endptr10 + 4 >> 0] = HEAP8[104084] | 0; //@line 46771
 HEAP8[$endptr10 + 5 >> 0] = HEAP8[104085] | 0; //@line 46771
 HEAP8[$endptr10 + 6 >> 0] = HEAP8[104086] | 0; //@line 46771
 _strncat($1, $$0$i7, 1023) | 0; //@line 46772
 _remove($1) | 0; //@line 46773
 if ((_remove($0) | 0) >= 0) {
  $$0 = 1; //@line 46777
  STACKTOP = sp; //@line 46778
  return $$0 | 0; //@line 46778
 }
 if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 21) {
  if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 39) {
   $$0 = 0; //@line 46788
   STACKTOP = sp; //@line 46789
   return $$0 | 0; //@line 46789
  }
 }
 HEAP8[$1 >> 0] = 0; //@line 46792
 _strncpy($1, $0, 1023) | 0; //@line 46793
 $23 = _strlen($1) | 0; //@line 46794
 if (($23 | 0) < 1023) {
  if ((HEAP8[$1 + ($23 + -1) >> 0] | 0) != 47) {
   HEAP8[$1 + $23 >> 0] = 47; //@line 46805
   HEAP8[$1 + ($23 + 1) >> 0] = 0; //@line 46806
  }
 }
 $endptr12 = $1 + (_strlen($1) | 0) | 0; //@line 46810
 HEAP8[$endptr12 >> 0] = HEAP8[104087] | 0; //@line 46811
 HEAP8[$endptr12 + 1 >> 0] = HEAP8[104088] | 0; //@line 46811
 HEAP8[$endptr12 + 2 >> 0] = HEAP8[104089] | 0; //@line 46811
 HEAP8[$endptr12 + 3 >> 0] = HEAP8[104090] | 0; //@line 46811
 HEAP8[$endptr12 + 4 >> 0] = HEAP8[104091] | 0; //@line 46811
 HEAP8[$endptr12 + 5 >> 0] = HEAP8[104092] | 0; //@line 46811
 _rmdir($1) | 0; //@line 46812
 HEAP8[$1 >> 0] = 0; //@line 46813
 _strncpy($1, $0, 1023) | 0; //@line 46814
 $32 = _strlen($1) | 0; //@line 46815
 if (($32 | 0) < 1023) {
  if ((HEAP8[$1 + ($32 + -1) >> 0] | 0) != 47) {
   HEAP8[$1 + $32 >> 0] = 47; //@line 46826
   HEAP8[$1 + ($32 + 1) >> 0] = 0; //@line 46827
  }
 }
 $endptr14 = $1 + (_strlen($1) | 0) | 0; //@line 46831
 HEAP8[$endptr14 >> 0] = HEAP8[104093] | 0; //@line 46832
 HEAP8[$endptr14 + 1 >> 0] = HEAP8[104094] | 0; //@line 46832
 HEAP8[$endptr14 + 2 >> 0] = HEAP8[104095] | 0; //@line 46832
 HEAP8[$endptr14 + 3 >> 0] = HEAP8[104096] | 0; //@line 46832
 HEAP8[$endptr14 + 4 >> 0] = HEAP8[104097] | 0; //@line 46832
 HEAP8[$endptr14 + 5 >> 0] = HEAP8[104098] | 0; //@line 46832
 _rmdir($1) | 0; //@line 46833
 $$0 = (_rmdir($0) | 0) == 0; //@line 46836
 STACKTOP = sp; //@line 46837
 return $$0 | 0; //@line 46837
}
function __ZN8tinyxml210XMLElement21FindOrCreateAttributeEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$0$lcssa$i = 0, $$018$lcssa = 0, $$019$lcssa$i = 0, $$019$lcssa$i1920 = 0, $$01923$i = 0, $$02022$i = 0, $$023 = 0, $$024 = 0, $$024$i = 0, $$1 = 0, $$pre$i$i$i = 0, $12 = 0, $15 = 0, $16 = 0, $2 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $31 = 0, $34 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $42 = 0, $5 = 0, $7 = 0, $9 = 0, label = 0;
 $2 = $0 + 48 | 0; //@line 39018
 $$023 = HEAP32[$2 >> 2] | 0; //@line 39019
 L1 : do {
  if (!$$023) {
   $$018$lcssa = 0; //@line 39023
  } else {
   $$024 = $$023; //@line 39025
   while (1) {
    $5 = __ZN8tinyxml27StrPair6GetStrEv($$024 + 4 | 0) | 0; //@line 39028
    if (($5 | 0) == ($1 | 0)) {
     $$1 = $$024; //@line 39031
     label = 11; //@line 39032
     break;
    }
    $7 = HEAP8[$5 >> 0] | 0; //@line 39035
    if (!($7 << 24 >> 24)) {
     $$019$lcssa$i1920 = $1; //@line 39038
     label = 8; //@line 39039
    } else {
     $$01923$i = $1; //@line 39041
     $$02022$i = $5; //@line 39041
     $$024$i = 0; //@line 39041
     $12 = $7; //@line 39041
     while (1) {
      $9 = HEAP8[$$01923$i >> 0] | 0; //@line 39043
      if (!(($$024$i | 0) != 2147483647 & ($9 << 24 >> 24 ? $12 << 24 >> 24 == $9 << 24 >> 24 : 0))) {
       $$0$lcssa$i = $$024$i; //@line 39050
       $$019$lcssa$i = $$01923$i; //@line 39050
       $21 = $12; //@line 39050
       break;
      }
      $$02022$i = $$02022$i + 1 | 0; //@line 39053
      $15 = $$01923$i + 1 | 0; //@line 39054
      $16 = $$024$i + 1 | 0; //@line 39055
      $12 = HEAP8[$$02022$i >> 0] | 0; //@line 39056
      if (!($12 << 24 >> 24)) {
       $$0$lcssa$i = $16; //@line 39059
       $$019$lcssa$i = $15; //@line 39059
       $21 = 0; //@line 39059
       break;
      } else {
       $$01923$i = $15; //@line 39062
       $$024$i = $16; //@line 39062
      }
     }
     if (($$0$lcssa$i | 0) == 2147483647) {
      $$1 = $$024; //@line 39067
      label = 11; //@line 39068
      break;
     }
     if (!($21 << 24 >> 24)) {
      $$019$lcssa$i1920 = $$019$lcssa$i; //@line 39073
      label = 8; //@line 39074
     }
    }
    if ((label | 0) == 8) {
     label = 0; //@line 39078
     if (!(HEAP8[$$019$lcssa$i1920 >> 0] | 0)) {
      $$1 = $$024; //@line 39082
      label = 11; //@line 39083
      break;
     }
    }
    $$0 = HEAP32[$$024 + 28 >> 2] | 0; //@line 39088
    if (!$$0) {
     $$018$lcssa = $$024; //@line 39091
     break L1;
    } else {
     $$024 = $$0; //@line 39094
    }
   }
   if ((label | 0) == 11) {
    return $$1 | 0; //@line 39098
   }
  }
 } while (0);
 $26 = $0 + 4 | 0; //@line 39102
 $29 = __ZN8tinyxml28MemPoolTILi36EE5AllocEv((HEAP32[$26 >> 2] | 0) + 144 | 0) | 0; //@line 39105
 HEAP32[$29 >> 2] = 2144; //@line 39106
 $30 = $29 + 4 | 0; //@line 39107
 $31 = $29 + 16 | 0; //@line 39108
 HEAP32[$31 >> 2] = 0; //@line 39109
 HEAP32[$31 + 4 >> 2] = 0; //@line 39109
 HEAP32[$31 + 8 >> 2] = 0; //@line 39109
 HEAP32[$31 + 12 >> 2] = 0; //@line 39109
 $34 = $29 + 32 | 0; //@line 39112
 HEAP32[$34 >> 2] = (HEAP32[$26 >> 2] | 0) + 144; //@line 39113
 HEAP32[($$018$lcssa | 0 ? $$018$lcssa + 28 | 0 : $2) >> 2] = $29; //@line 39117
 $$pre$i$i$i = $29 + 8 | 0; //@line 39118
 HEAP32[$30 >> 2] = 0; //@line 39119
 HEAP32[$$pre$i$i$i >> 2] = 0; //@line 39120
 $37 = $29 + 12 | 0; //@line 39121
 HEAP32[$37 >> 2] = 0; //@line 39122
 $38 = _strlen($1) | 0; //@line 39123
 $39 = $38 + 1 | 0; //@line 39124
 $40 = __Znaj($39) | 0; //@line 39125
 HEAP32[$$pre$i$i$i >> 2] = $40; //@line 39126
 _memcpy($40 | 0, $1 | 0, $39 | 0) | 0; //@line 39127
 HEAP32[$37 >> 2] = $40 + $38; //@line 39129
 HEAP32[$30 >> 2] = 512; //@line 39130
 $42 = HEAP32[$34 >> 2] | 0; //@line 39131
 FUNCTION_TABLE_vi[HEAP32[(HEAP32[$42 >> 2] | 0) + 20 >> 2] & 4095]($42); //@line 39135
 $$1 = $29; //@line 39136
 return $$1 | 0; //@line 39137
}
function __Z9SonyPrimejj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sink$sink$sink = 0, $$sroa$03$07$i = 0, $102 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $20 = 0, $23 = 0, $25 = 0, $34 = 0, $4 = 0, $40 = 0, $45 = 0, $51 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $63 = 0, $67 = 0, $8 = 0;
 $2 = $0 + 40 | 0; //@line 17427
 $4 = 123608 + ($2 >>> 16 << 2) | 0; //@line 17429
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, 0); //@line 17433
 $8 = $0 + 22 | 0; //@line 17434
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 17440
 $15 = HEAP32[28486] | 0; //@line 17441
 $16 = HEAP32[28485] | 0; //@line 17442
 L1 : do {
  if (($16 | 0) == ($15 | 0)) {
   $$sink$sink$sink = -56; //@line 17446
  } else {
   $$sroa$03$07$i = $16; //@line 17448
   while (1) {
    if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($14 | 0)) {
     break;
    }
    $20 = $$sroa$03$07$i + 16 | 0; //@line 17455
    if (($20 | 0) == ($15 | 0)) {
     $$sink$sink$sink = -56; //@line 17458
     break L1;
    } else {
     $$sroa$03$07$i = $20; //@line 17461
    }
   }
   if (($$sroa$03$07$i | 0) == ($15 | 0)) {
    $$sink$sink$sink = -56; //@line 17466
   } else {
    $23 = $$sroa$03$07$i + 12 | 0; //@line 17468
    $25 = (HEAP32[$23 >> 2] | 0) + 3 | 0; //@line 17470
    if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($25) | 0)) {
     $$sink$sink$sink = -65; //@line 17479
    } else {
     $34 = (HEAP32[$23 >> 2] | 0) + 3 | 0; //@line 17482
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, 2); //@line 17488
     $40 = $0 + 32 | 0; //@line 17489
     $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($40 >>> 16 << 2) >> 2] >> 2] & 127]($40) | 0; //@line 17494
     $51 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($45 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($45) | 0; //@line 17500
     $52 = $0 + 36 | 0; //@line 17501
     $57 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($52 >>> 16 << 2) >> 2] >> 2] & 127]($52) | 0; //@line 17506
     $58 = $1 + 16 | 0; //@line 17507
     $60 = 123608 + ($58 >>> 16 << 2) | 0; //@line 17509
     $63 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$60 >> 2] >> 2] & 127]($58) | 0; //@line 17512
     if (!(($63 | $57) & 511)) {
      $67 = $0 + 6 | 0; //@line 17517
      if (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($67 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($67) | 0) & 255 | 0) == 2) {
       if ((__Z8Sys_readPvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $51, $63, $57) | 0) != ($57 | 0)) {
        $$sink$sink$sink = -19; //@line 17532
        break;
       }
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](764, 0); //@line 17538
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](768, 0); //@line 17542
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 12 >> 2] & 31](772, 0); //@line 17546
      } else {
       if (HEAP8[$$sroa$03$07$i + 9 >> 0] | 0) {
        $$sink$sink$sink = -44; //@line 17552
        break;
       }
       if ((__Z9Sys_writePvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $51, $63, $57) | 0) != ($57 | 0)) {
        $$sink$sink$sink = -20; //@line 17560
        break;
       }
      }
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, $57); //@line 17567
      $102 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$60 >> 2] >> 2] & 127]($58) | 0) + $57 | 0; //@line 17571
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[$60 >> 2] | 0) + 12 >> 2] & 31]($58, $102); //@line 17575
      $$sink$sink$sink = 0; //@line 17576
     } else {
      $$sink$sink$sink = -50; //@line 17578
     }
    }
   }
  }
 } while (0);
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[30902] | 0) + 16 >> 2] & 31](322, $$sink$sink$sink << 16 >> 16); //@line 17588
 return $$sink$sink$sink | 0; //@line 17589
}
function __Z9DiskPrimejj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$2 = 0, $$sroa$03$07$i = 0, $111 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $20 = 0, $25 = 0, $33 = 0, $38 = 0, $4 = 0, $44 = 0, $45 = 0, $50 = 0, $51 = 0, $53 = 0, $56 = 0, $57 = 0, $66 = 0, $71 = 0, $79 = 0, $8 = 0, label = 0;
 $2 = $0 + 40 | 0; //@line 18735
 $4 = 123608 + ($2 >>> 16 << 2) | 0; //@line 18737
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, 0); //@line 18741
 $8 = $0 + 22 | 0; //@line 18742
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 18748
 $15 = HEAP32[28490] | 0; //@line 18749
 $16 = HEAP32[28489] | 0; //@line 18750
 if (($16 | 0) == ($15 | 0)) {
  $$2 = -56; //@line 18753
  return $$2 | 0; //@line 18754
 } else {
  $$sroa$03$07$i = $16; //@line 18756
 }
 while (1) {
  if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($14 | 0)) {
   break;
  }
  $20 = $$sroa$03$07$i + 24 | 0; //@line 18764
  if (($20 | 0) == ($15 | 0)) {
   $$2 = -56; //@line 18767
   label = 14; //@line 18768
   break;
  } else {
   $$sroa$03$07$i = $20; //@line 18771
  }
 }
 if ((label | 0) == 14) {
  return $$2 | 0; //@line 18775
 }
 if (($$sroa$03$07$i | 0) == ($15 | 0)) {
  $$2 = -56; //@line 18779
  return $$2 | 0; //@line 18780
 }
 $25 = (HEAP32[$$sroa$03$07$i + 20 >> 2] | 0) + 3 | 0; //@line 18784
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($25) | 0)) {
  $$2 = -65; //@line 18793
  return $$2 | 0; //@line 18794
 }
 $33 = $0 + 32 | 0; //@line 18796
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($33 >>> 16 << 2) >> 2] >> 2] & 127]($33) | 0; //@line 18801
 $44 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($38 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($38) | 0; //@line 18807
 $45 = $0 + 36 | 0; //@line 18808
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 18813
 $51 = $1 + 16 | 0; //@line 18814
 $53 = 123608 + ($51 >>> 16 << 2) | 0; //@line 18816
 $56 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$53 >> 2] >> 2] & 127]($51) | 0; //@line 18819
 $57 = $0 + 44 | 0; //@line 18820
 if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($57 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($57) | 0) & 256 | 0) {
  $66 = $0 + 46 | 0; //@line 18830
  FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($66 >>> 16 << 2) >> 2] >> 2] & 127]($66) | 0; //@line 18835
  $71 = $0 + 50 | 0; //@line 18836
  FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($71 >>> 16 << 2) >> 2] >> 2] & 127]($71) | 0; //@line 18841
  $$2 = -50; //@line 18842
  return $$2 | 0; //@line 18843
 }
 if (($56 | $50) & 511 | 0) {
  $$2 = -50; //@line 18849
  return $$2 | 0; //@line 18850
 }
 $79 = $0 + 6 | 0; //@line 18852
 if (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($79 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($79) | 0) & 255 | 0) == 2) {
  if ((__Z8Sys_readPvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $44, (HEAP32[$$sroa$03$07$i + 8 >> 2] | 0) + $56 | 0, $50) | 0) != ($50 | 0)) {
   $$2 = -19; //@line 18870
   return $$2 | 0; //@line 18871
  }
 } else {
  if (HEAP8[$$sroa$03$07$i + 17 >> 0] | 0) {
   $$2 = -44; //@line 18878
   return $$2 | 0; //@line 18879
  }
  if ((__Z9Sys_writePvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $44, (HEAP32[$$sroa$03$07$i + 8 >> 2] | 0) + $56 | 0, $50) | 0) != ($50 | 0)) {
   $$2 = -20; //@line 18889
   return $$2 | 0; //@line 18890
  }
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, $50); //@line 18896
 $111 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$53 >> 2] >> 2] & 127]($51) | 0) + $50 | 0; //@line 18900
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$53 >> 2] | 0) + 12 >> 2] & 31]($51, $111); //@line 18904
 $$2 = 0; //@line 18905
 return $$2 | 0; //@line 18906
}
function __Z15rpc_init_clientPKc($0) {
 $0 = $0 | 0;
 var $$02829$i = 0, $$03642 = 0, $$1 = 0, $$1$i = 0, $1 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $21 = 0, $28 = 0, $29 = 0, $3 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 41670
 STACKTOP = STACKTOP + 112 | 0; //@line 41671
 $1 = sp; //@line 41672
 if (!$0) {
  $$1 = 0; //@line 41675
  STACKTOP = sp; //@line 41676
  return $$1 | 0; //@line 41676
 }
 $3 = _malloc(1064) | 0; //@line 41678
 if (!$3) {
  $$1 = 0; //@line 41681
  STACKTOP = sp; //@line 41682
  return $$1 | 0; //@line 41682
 }
 HEAP32[$3 >> 2] = 1; //@line 41684
 HEAP32[$3 + 4 >> 2] = 0; //@line 41686
 HEAP32[$3 + 16 >> 2] = -1; //@line 41688
 HEAP32[$3 + 28 >> 2] = 0; //@line 41690
 HEAP32[$3 + 32 >> 2] = 0; //@line 41692
 $9 = _socket(1, 1, 0) | 0; //@line 41693
 HEAP32[$3 + 8 >> 2] = $9; //@line 41695
 if (($9 | 0) < 0) {
  _perror(102195); //@line 41698
  _free($3); //@line 41699
  $$1 = 0; //@line 41700
  STACKTOP = sp; //@line 41701
  return $$1 | 0; //@line 41701
 }
 dest = $1 + 2 | 0; //@line 41704
 stop = dest + 108 | 0; //@line 41704
 do {
  HEAP16[dest >> 1] = 0; //@line 41704
  dest = dest + 2 | 0; //@line 41704
 } while ((dest | 0) < (stop | 0));
 HEAP16[$1 >> 1] = 1; //@line 41705
 $13 = $3 + 12 | 0; //@line 41706
 HEAP32[$13 >> 2] = 0; //@line 41707
 $14 = _strlen($0) | 0; //@line 41708
 $15 = $14 + 5 | 0; //@line 41709
 $17 = _malloc($14 + 6 | 0) | 0; //@line 41711
 if (!$17) {
  $$1$i = 0; //@line 41714
  $28 = 0; //@line 41714
 } else {
  HEAP8[$17 >> 0] = HEAP8[102189] | 0; //@line 41716
  HEAP8[$17 + 1 >> 0] = HEAP8[102190] | 0; //@line 41716
  HEAP8[$17 + 2 >> 0] = HEAP8[102191] | 0; //@line 41716
  HEAP8[$17 + 3 >> 0] = HEAP8[102192] | 0; //@line 41716
  HEAP8[$17 + 4 >> 0] = HEAP8[102193] | 0; //@line 41716
  HEAP8[$17 + 5 >> 0] = HEAP8[102194] | 0; //@line 41716
  if (($14 | 0) > 0) {
   $$02829$i = 0; //@line 41719
   do {
    $21 = HEAP8[$0 + $$02829$i >> 0] | 0; //@line 41722
    HEAP8[$17 + ($$02829$i + 5) >> 0] = $21 << 24 >> 24 == 47 ? 95 : $21; //@line 41727
    $$02829$i = $$02829$i + 1 | 0; //@line 41728
   } while (($$02829$i | 0) != ($14 | 0));
  }
  HEAP8[$17 + $15 >> 0] = 0; //@line 41738
  HEAP32[$13 >> 2] = $17; //@line 41739
  $$1$i = $15; //@line 41740
  $28 = $17; //@line 41740
 }
 _memcpy($1 + 2 | 0, $28 | 0, $$1$i | 0) | 0; //@line 41743
 $29 = $$1$i + 2 | 0; //@line 41744
 if (!(_connect($9, $1, $29) | 0)) {
  $$1 = $3; //@line 41748
  STACKTOP = sp; //@line 41749
  return $$1 | 0; //@line 41749
 } else {
  $$03642 = 500; //@line 41751
 }
 while (1) {
  if (($$03642 | 0) <= 1) {
   label = 15; //@line 41756
   break;
  }
  if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 111) {
   if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 2) {
    label = 13; //@line 41767
    break;
   }
  }
  _usleep(10) | 0; //@line 41772
  if (!(_connect($9, $1, $29) | 0)) {
   $$1 = $3; //@line 41776
   label = 17; //@line 41777
   break;
  } else {
   $$03642 = $$03642 + -1 | 0; //@line 41780
  }
 }
 if ((label | 0) == 13) {
  _perror(102209); //@line 41784
  _close($9) | 0; //@line 41785
  _free($3); //@line 41786
  $$1 = 0; //@line 41787
  STACKTOP = sp; //@line 41788
  return $$1 | 0; //@line 41788
 } else if ((label | 0) == 15) {
  _usleep(10) | 0; //@line 41791
  if (($$03642 | 0) != 1) {
   $$1 = $3; //@line 41794
   STACKTOP = sp; //@line 41795
   return $$1 | 0; //@line 41795
  }
  _close($9) | 0; //@line 41797
  _free($3); //@line 41798
  $$1 = 0; //@line 41799
  STACKTOP = sp; //@line 41800
  return $$1 | 0; //@line 41800
 } else if ((label | 0) == 17) {
  STACKTOP = sp; //@line 41803
  return $$1 | 0; //@line 41803
 }
 return 0; //@line 41805
}
function __Z11InstallSERDv() {
 var $0 = 0, $104 = 0, $11 = 0, $114 = 0, $120 = 0, $21 = 0, $27 = 0, $37 = 0, $42 = 0, $5 = 0, $52 = 0, $58 = 0, $6 = 0, $68 = 0, $73 = 0, $83 = 0, $89 = 0, $99 = 0, sp = 0;
 sp = STACKTOP; //@line 2624
 STACKTOP = STACKTOP + 80 | 0; //@line 2625
 $0 = sp; //@line 2626
 HEAP32[$0 >> 2] = -6; //@line 2627
 $5 = $0 + 32 | 0; //@line 2632
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 256 + (HEAP32[28208] | 0); //@line 2633
 _Execute68kTrap(-23235, $0); //@line 2634
 _Execute68kTrap(-24535, $0); //@line 2635
 $6 = HEAP32[$5 >> 2] | 0; //@line 2636
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 2641
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($11, (HEAP32[30896] | 0) + 256 + (HEAP32[28208] | 0) | 0); //@line 2651
 $21 = $11 + 4 | 0; //@line 2652
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($21, 19712); //@line 2658
 $27 = $11 + 6 | 0; //@line 2659
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($27, 9); //@line 2665
 HEAP32[$0 >> 2] = -7; //@line 2666
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 512 + (HEAP32[28208] | 0); //@line 2671
 _Execute68kTrap(-23235, $0); //@line 2672
 _Execute68kTrap(-24535, $0); //@line 2673
 $37 = HEAP32[$5 >> 2] | 0; //@line 2674
 $42 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($37 >>> 16 << 2) >> 2] >> 2] & 127]($37) | 0; //@line 2679
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($42 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($42, (HEAP32[30896] | 0) + 512 + (HEAP32[28208] | 0) | 0); //@line 2689
 $52 = $42 + 4 | 0; //@line 2690
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($52 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($52, 19968); //@line 2696
 $58 = $42 + 6 | 0; //@line 2697
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($58 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($58, 9); //@line 2703
 HEAP32[$0 >> 2] = -8; //@line 2704
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 768 + (HEAP32[28208] | 0); //@line 2709
 _Execute68kTrap(-23235, $0); //@line 2710
 _Execute68kTrap(-24535, $0); //@line 2711
 $68 = HEAP32[$5 >> 2] | 0; //@line 2712
 $73 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($68 >>> 16 << 2) >> 2] >> 2] & 127]($68) | 0; //@line 2717
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($73 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($73, (HEAP32[30896] | 0) + 768 + (HEAP32[28208] | 0) | 0); //@line 2727
 $83 = $73 + 4 | 0; //@line 2728
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($83 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($83, 19712); //@line 2734
 $89 = $73 + 6 | 0; //@line 2735
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($89 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($89, 9); //@line 2741
 HEAP32[$0 >> 2] = -9; //@line 2742
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 1024 + (HEAP32[28208] | 0); //@line 2747
 _Execute68kTrap(-23235, $0); //@line 2748
 _Execute68kTrap(-24535, $0); //@line 2749
 $99 = HEAP32[$5 >> 2] | 0; //@line 2750
 $104 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($99 >>> 16 << 2) >> 2] >> 2] & 127]($99) | 0; //@line 2755
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($104 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($104, (HEAP32[30896] | 0) + 1024 + (HEAP32[28208] | 0) | 0); //@line 2765
 $114 = $104 + 4 | 0; //@line 2766
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($114 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($114, 19968); //@line 2772
 $120 = $104 + 6 | 0; //@line 2773
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($120 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($120, 9); //@line 2779
 STACKTOP = sp; //@line 2780
 return;
}
function __ZN8tinyxml212XMLAttribute9ParseDeepEPcb($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$0$i = 0, $$0$lcssa$i18 = 0, $$01921$i = 0, $$03$i = 0, $$03$i16 = 0, $$pre$i$i$i = 0, $10 = 0, $13 = 0, $14 = 0, $18 = 0, $19 = 0, $22 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $35 = 0, $38 = 0, $42 = 0, $47 = 0, $5 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 38793
 STACKTOP = STACKTOP + 16 | 0; //@line 38794
 $3 = sp; //@line 38795
 $5 = __ZN8tinyxml27StrPair9ParseNameEPc($0 + 4 | 0, $1) | 0; //@line 38797
 if (!$5) {
  $$0 = 0; //@line 38800
  STACKTOP = sp; //@line 38801
  return $$0 | 0; //@line 38801
 }
 $7 = HEAP8[$5 >> 0] | 0; //@line 38803
 if ($7 << 24 >> 24 > 0) {
  $$03$i = $5; //@line 38806
  $10 = $7; //@line 38806
 } else {
  $$0 = 0; //@line 38808
  STACKTOP = sp; //@line 38809
  return $$0 | 0; //@line 38809
 }
 while (1) {
  if (!(_isspace($10 & 255) | 0)) {
   break;
  }
  $13 = $$03$i + 1 | 0; //@line 38818
  $14 = HEAP8[$13 >> 0] | 0; //@line 38819
  if ($14 << 24 >> 24 > -1) {
   $$03$i = $13; //@line 38822
   $10 = $14; //@line 38822
  } else {
   $$0 = 0; //@line 38824
   label = 19; //@line 38825
   break;
  }
 }
 if ((label | 0) == 19) {
  STACKTOP = sp; //@line 38830
  return $$0 | 0; //@line 38830
 }
 if (!(($$03$i | 0) != 0 & $10 << 24 >> 24 == 61)) {
  $$0 = 0; //@line 38836
  STACKTOP = sp; //@line 38837
  return $$0 | 0; //@line 38837
 }
 $18 = $$03$i + 1 | 0; //@line 38839
 $19 = HEAP8[$18 >> 0] | 0; //@line 38840
 L15 : do {
  if ($19 << 24 >> 24 > -1) {
   $$03$i16 = $18; //@line 38844
   $22 = $19; //@line 38844
   while (1) {
    if (!(_isspace($22 & 255) | 0)) {
     $$0$lcssa$i18 = $$03$i16; //@line 38850
     $28 = $22; //@line 38850
     break L15;
    }
    $25 = $$03$i16 + 1 | 0; //@line 38853
    $26 = HEAP8[$25 >> 0] | 0; //@line 38854
    if ($26 << 24 >> 24 > -1) {
     $$03$i16 = $25; //@line 38857
     $22 = $26; //@line 38857
    } else {
     $$0$lcssa$i18 = $25; //@line 38859
     $28 = $26; //@line 38859
     break;
    }
   }
  } else {
   $$0$lcssa$i18 = $18; //@line 38864
   $28 = $19; //@line 38864
  }
 } while (0);
 switch ($28 << 24 >> 24) {
 case 39:
 case 34:
  {
   break;
  }
 default:
  {
   $$0 = 0; //@line 38872
   STACKTOP = sp; //@line 38873
   return $$0 | 0; //@line 38873
  }
 }
 HEAP8[$3 >> 0] = $28; //@line 38876
 HEAP8[$3 + 1 >> 0] = 0; //@line 38878
 $30 = $$0$lcssa$i18 + 1 | 0; //@line 38879
 $31 = _strlen($3) | 0; //@line 38880
 $32 = HEAP8[$30 >> 0] | 0; //@line 38881
 L23 : do {
  if (!($32 << 24 >> 24)) {
   $$0$i = 0; //@line 38885
  } else {
   $$01921$i = $30; //@line 38887
   $35 = $32; //@line 38887
   while (1) {
    if ($35 << 24 >> 24 == $28 << 24 >> 24) {
     if (!(_strncmp($$01921$i, $3, $31) | 0)) {
      break;
     }
    }
    $47 = $$01921$i + 1 | 0; //@line 38897
    $35 = HEAP8[$47 >> 0] | 0; //@line 38898
    if (!($35 << 24 >> 24)) {
     $$0$i = 0; //@line 38901
     break L23;
    } else {
     $$01921$i = $47; //@line 38904
    }
   }
   $38 = $0 + 16 | 0; //@line 38907
   $$pre$i$i$i = $0 + 20 | 0; //@line 38911
   if (HEAP32[$38 >> 2] & 512 | 0) {
    $42 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 38913
    if ($42 | 0) {
     __ZdaPv($42); //@line 38916
    }
   }
   HEAP32[$$pre$i$i$i >> 2] = $30; //@line 38920
   HEAP32[$0 + 24 >> 2] = $$01921$i; //@line 38921
   HEAP32[$38 >> 2] = $2 ? 259 : 258; //@line 38923
   $$0$i = $$01921$i + $31 | 0; //@line 38925
  }
 } while (0);
 $$0 = $$0$i; //@line 38928
 STACKTOP = sp; //@line 38929
 return $$0 | 0; //@line 38929
}
function __Z8DiskOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$05$030 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $18 = 0, $2 = 0, $20 = 0, $21 = 0, $28 = 0, $3 = 0, $37 = 0, $46 = 0, $53 = 0, $71 = 0, $72 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 18580
 STACKTOP = STACKTOP + 80 | 0; //@line 18581
 $2 = sp; //@line 18582
 $3 = $1 + 16 | 0; //@line 18583
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, 0); //@line 18589
 HEAP8[657353] = 0; //@line 18590
 $9 = HEAP32[28490] | 0; //@line 18591
 $10 = HEAP32[28489] | 0; //@line 18592
 if (($10 | 0) == ($9 | 0)) {
  STACKTOP = sp; //@line 18595
  return 0; //@line 18595
 }
 $12 = $2 + 32 | 0; //@line 18597
 $$sroa$05$030 = $10; //@line 18598
 do {
  HEAP32[$$sroa$05$030 >> 2] = __Z19FindFreeDriveNumberi(1) | 0; //@line 18601
  $14 = $$sroa$05$030 + 16 | 0; //@line 18602
  HEAP8[$14 >> 0] = 0; //@line 18603
  $15 = $$sroa$05$030 + 4 | 0; //@line 18604
  if (HEAP32[$15 >> 2] | 0) {
   HEAP32[$2 >> 2] = 30; //@line 18608
   _Execute68kTrap(-22754, $2); //@line 18609
   $18 = HEAP32[$12 >> 2] | 0; //@line 18610
   if ($18 | 0) {
    $20 = $$sroa$05$030 + 20 | 0; //@line 18613
    HEAP32[$20 >> 2] = $18; //@line 18614
    $21 = $18 + 10 | 0; //@line 18615
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($21, 1); //@line 18621
    $28 = (HEAP32[$20 >> 2] | 0) + 4 | 0; //@line 18623
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, 1); //@line 18629
    if (__Z14SysIsFixedDiskPv(HEAP32[$15 >> 2] | 0) | 0) {
     $37 = (HEAP32[$20 >> 2] | 0) + 3 | 0; //@line 18634
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($37, 8); //@line 18640
     label = 9; //@line 18641
    } else {
     if (__Z17SysIsDiskInsertedPv(HEAP32[$15 >> 2] | 0) | 0) {
      $46 = (HEAP32[$20 >> 2] | 0) + 3 | 0; //@line 18647
      FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($46, 1); //@line 18653
      label = 9; //@line 18654
     }
    }
    if ((label | 0) == 9) {
     label = 0; //@line 18658
     $53 = (HEAP32[$20 >> 2] | 0) + 2 | 0; //@line 18660
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($53, HEAP8[$$sroa$05$030 + 17 >> 0] | 0 ? 128 : 0); //@line 18670
     __ZL18find_hfs_partitionR15disk_drive_info($$sroa$05$030); //@line 18671
     if (!(HEAP32[$$sroa$05$030 + 8 >> 2] | 0)) {
      HEAP32[$$sroa$05$030 + 12 >> 2] = (__Z14SysGetFileSizePv(HEAP32[$15 >> 2] | 0) | 0) / 512 | 0; //@line 18680
     }
     HEAP8[$14 >> 0] = 1; //@line 18682
    }
    $71 = (HEAP32[$20 >> 2] | 0) + 18 | 0; //@line 18685
    $72 = $$sroa$05$030 + 12 | 0; //@line 18686
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($71 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($71, HEAP32[$72 >> 2] & 65535); //@line 18694
    $81 = (HEAP32[$20 >> 2] | 0) + 20 | 0; //@line 18696
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($81 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($81, (HEAP32[$72 >> 2] | 0) >>> 16); //@line 18704
    HEAP32[$2 >> 2] = HEAP32[$$sroa$05$030 >> 2] << 16 | 65473; //@line 18708
    HEAP32[$12 >> 2] = (HEAP32[$20 >> 2] | 0) + 6; //@line 18711
    _Execute68kTrap(-24498, $2); //@line 18712
   }
  }
  $$sroa$05$030 = $$sroa$05$030 + 24 | 0; //@line 18715
 } while (($$sroa$05$030 | 0) != ($9 | 0));
 STACKTOP = sp; //@line 18723
 return 0; //@line 18723
}
function _memchr($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$lcssa = 0, $$035$lcssa = 0, $$035$lcssa65 = 0, $$03555 = 0, $$036$lcssa = 0, $$036$lcssa64 = 0, $$03654 = 0, $$046 = 0, $$137$lcssa = 0, $$13745 = 0, $$140 = 0, $$2 = 0, $$23839 = 0, $$3 = 0, $$lcssa = 0, $11 = 0, $12 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $35 = 0, $7 = 0, $8 = 0, label = 0;
 $3 = $1 & 255; //@line 57658
 $7 = ($2 | 0) != 0; //@line 57662
 L1 : do {
  if ($7 & ($0 & 3 | 0) != 0) {
   $8 = $1 & 255; //@line 57666
   $$03555 = $0; //@line 57667
   $$03654 = $2; //@line 57667
   while (1) {
    if ((HEAP8[$$03555 >> 0] | 0) == $8 << 24 >> 24) {
     $$035$lcssa65 = $$03555; //@line 57672
     $$036$lcssa64 = $$03654; //@line 57672
     label = 6; //@line 57673
     break L1;
    }
    $11 = $$03555 + 1 | 0; //@line 57676
    $12 = $$03654 + -1 | 0; //@line 57677
    $16 = ($12 | 0) != 0; //@line 57681
    if ($16 & ($11 & 3 | 0) != 0) {
     $$03555 = $11; //@line 57684
     $$03654 = $12; //@line 57684
    } else {
     $$035$lcssa = $11; //@line 57686
     $$036$lcssa = $12; //@line 57686
     $$lcssa = $16; //@line 57686
     label = 5; //@line 57687
     break;
    }
   }
  } else {
   $$035$lcssa = $0; //@line 57692
   $$036$lcssa = $2; //@line 57692
   $$lcssa = $7; //@line 57692
   label = 5; //@line 57693
  }
 } while (0);
 if ((label | 0) == 5) {
  if ($$lcssa) {
   $$035$lcssa65 = $$035$lcssa; //@line 57698
   $$036$lcssa64 = $$036$lcssa; //@line 57698
   label = 6; //@line 57699
  } else {
   $$2 = $$035$lcssa; //@line 57701
   $$3 = 0; //@line 57701
  }
 }
 L8 : do {
  if ((label | 0) == 6) {
   $18 = $1 & 255; //@line 57707
   if ((HEAP8[$$035$lcssa65 >> 0] | 0) == $18 << 24 >> 24) {
    $$2 = $$035$lcssa65; //@line 57710
    $$3 = $$036$lcssa64; //@line 57710
   } else {
    $20 = Math_imul($3, 16843009) | 0; //@line 57712
    L11 : do {
     if ($$036$lcssa64 >>> 0 > 3) {
      $$046 = $$035$lcssa65; //@line 57716
      $$13745 = $$036$lcssa64; //@line 57716
      while (1) {
       $23 = HEAP32[$$046 >> 2] ^ $20; //@line 57719
       if (($23 & -2139062144 ^ -2139062144) & $23 + -16843009 | 0) {
        break;
       }
       $29 = $$046 + 4 | 0; //@line 57728
       $30 = $$13745 + -4 | 0; //@line 57729
       if ($30 >>> 0 > 3) {
        $$046 = $29; //@line 57732
        $$13745 = $30; //@line 57732
       } else {
        $$0$lcssa = $29; //@line 57734
        $$137$lcssa = $30; //@line 57734
        label = 11; //@line 57735
        break L11;
       }
      }
      $$140 = $$046; //@line 57739
      $$23839 = $$13745; //@line 57739
     } else {
      $$0$lcssa = $$035$lcssa65; //@line 57741
      $$137$lcssa = $$036$lcssa64; //@line 57741
      label = 11; //@line 57742
     }
    } while (0);
    if ((label | 0) == 11) {
     if (!$$137$lcssa) {
      $$2 = $$0$lcssa; //@line 57748
      $$3 = 0; //@line 57748
      break;
     } else {
      $$140 = $$0$lcssa; //@line 57751
      $$23839 = $$137$lcssa; //@line 57751
     }
    }
    while (1) {
     if ((HEAP8[$$140 >> 0] | 0) == $18 << 24 >> 24) {
      $$2 = $$140; //@line 57758
      $$3 = $$23839; //@line 57758
      break L8;
     }
     $35 = $$140 + 1 | 0; //@line 57761
     $$23839 = $$23839 + -1 | 0; //@line 57762
     if (!$$23839) {
      $$2 = $35; //@line 57765
      $$3 = 0; //@line 57765
      break;
     } else {
      $$140 = $35; //@line 57768
     }
    }
   }
  }
 } while (0);
 return ($$3 | 0 ? $$2 : 0) | 0; //@line 57776
}
function _Execute68kTrap($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $11 = 0, $13 = 0, $15 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $28 = 0, $30 = 0, $32 = 0, $34 = 0, $37 = 0, $4 = 0, $44 = 0, $5 = 0, $51 = 0, $57 = 0, $65 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[162770] | 0; //@line 49185
 $5 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) | 0; //@line 49186
 HEAP32[162752] = HEAP32[$1 >> 2]; //@line 49188
 $7 = $1 + 4 | 0; //@line 49189
 HEAP32[162753] = HEAP32[$7 >> 2]; //@line 49191
 $9 = $1 + 8 | 0; //@line 49192
 HEAP32[162754] = HEAP32[$9 >> 2]; //@line 49194
 $11 = $1 + 12 | 0; //@line 49195
 HEAP32[162755] = HEAP32[$11 >> 2]; //@line 49197
 $13 = $1 + 16 | 0; //@line 49198
 HEAP32[162756] = HEAP32[$13 >> 2]; //@line 49200
 $15 = $1 + 20 | 0; //@line 49201
 HEAP32[162757] = HEAP32[$15 >> 2]; //@line 49203
 $17 = $1 + 24 | 0; //@line 49204
 HEAP32[162758] = HEAP32[$17 >> 2]; //@line 49206
 $19 = $1 + 28 | 0; //@line 49207
 HEAP32[162759] = HEAP32[$19 >> 2]; //@line 49209
 $21 = $5 - $4 | 0; //@line 49210
 $22 = $1 + 32 | 0; //@line 49211
 HEAP32[162760] = HEAP32[$22 >> 2]; //@line 49213
 $24 = $1 + 36 | 0; //@line 49214
 HEAP32[162761] = HEAP32[$24 >> 2]; //@line 49216
 $26 = $1 + 40 | 0; //@line 49217
 HEAP32[162762] = HEAP32[$26 >> 2]; //@line 49219
 $28 = $1 + 44 | 0; //@line 49220
 HEAP32[162763] = HEAP32[$28 >> 2]; //@line 49222
 $30 = $1 + 48 | 0; //@line 49223
 HEAP32[162764] = HEAP32[$30 >> 2]; //@line 49225
 $32 = $1 + 52 | 0; //@line 49226
 HEAP32[162765] = HEAP32[$32 >> 2]; //@line 49228
 $34 = $1 + 56 | 0; //@line 49229
 HEAP32[162766] = HEAP32[$34 >> 2]; //@line 49231
 $37 = (HEAP32[162767] | 0) + -2 | 0; //@line 49233
 HEAP32[162767] = $37; //@line 49234
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($37, 28928); //@line 49240
 $44 = (HEAP32[162767] | 0) + -2 | 0; //@line 49242
 HEAP32[162767] = $44; //@line 49243
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($44 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($44, $0 & 65535); //@line 49250
 $51 = HEAP32[162767] | 0; //@line 49251
 $57 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($51) | 0; //@line 49257
 HEAP32[162770] = $57; //@line 49258
 HEAP32[162769] = $57; //@line 49259
 HEAP32[162768] = $51; //@line 49260
 HEAP8[659737] = 0; //@line 49261
 __Z12m68k_executev(); //@line 49262
 HEAP32[162767] = (HEAP32[162767] | 0) + 4; //@line 49265
 $65 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($21) | 0; //@line 49271
 HEAP32[162770] = $65; //@line 49272
 HEAP32[162769] = $65; //@line 49273
 HEAP32[162768] = $21; //@line 49274
 HEAP32[$1 >> 2] = HEAP32[162752]; //@line 49276
 HEAP32[$7 >> 2] = HEAP32[162753]; //@line 49278
 HEAP32[$9 >> 2] = HEAP32[162754]; //@line 49280
 HEAP32[$11 >> 2] = HEAP32[162755]; //@line 49282
 HEAP32[$13 >> 2] = HEAP32[162756]; //@line 49284
 HEAP32[$15 >> 2] = HEAP32[162757]; //@line 49286
 HEAP32[$17 >> 2] = HEAP32[162758]; //@line 49288
 HEAP32[$19 >> 2] = HEAP32[162759]; //@line 49290
 HEAP32[$22 >> 2] = HEAP32[162760]; //@line 49292
 HEAP32[$24 >> 2] = HEAP32[162761]; //@line 49294
 HEAP32[$26 >> 2] = HEAP32[162762]; //@line 49296
 HEAP32[$28 >> 2] = HEAP32[162763]; //@line 49298
 HEAP32[$30 >> 2] = HEAP32[162764]; //@line 49300
 HEAP32[$32 >> 2] = HEAP32[162765]; //@line 49302
 HEAP32[$34 >> 2] = HEAP32[162766]; //@line 49304
 HEAP8[659737] = 0; //@line 49305
 return;
}
function _Execute68k($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $11 = 0, $13 = 0, $15 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $28 = 0, $30 = 0, $32 = 0, $34 = 0, $37 = 0, $4 = 0, $43 = 0, $44 = 0, $5 = 0, $55 = 0, $63 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[162770] | 0; //@line 49318
 $5 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) | 0; //@line 49319
 HEAP32[162752] = HEAP32[$1 >> 2]; //@line 49321
 $7 = $1 + 4 | 0; //@line 49322
 HEAP32[162753] = HEAP32[$7 >> 2]; //@line 49324
 $9 = $1 + 8 | 0; //@line 49325
 HEAP32[162754] = HEAP32[$9 >> 2]; //@line 49327
 $11 = $1 + 12 | 0; //@line 49328
 HEAP32[162755] = HEAP32[$11 >> 2]; //@line 49330
 $13 = $1 + 16 | 0; //@line 49331
 HEAP32[162756] = HEAP32[$13 >> 2]; //@line 49333
 $15 = $1 + 20 | 0; //@line 49334
 HEAP32[162757] = HEAP32[$15 >> 2]; //@line 49336
 $17 = $1 + 24 | 0; //@line 49337
 HEAP32[162758] = HEAP32[$17 >> 2]; //@line 49339
 $19 = $1 + 28 | 0; //@line 49340
 HEAP32[162759] = HEAP32[$19 >> 2]; //@line 49342
 $21 = $5 - $4 | 0; //@line 49343
 $22 = $1 + 32 | 0; //@line 49344
 HEAP32[162760] = HEAP32[$22 >> 2]; //@line 49346
 $24 = $1 + 36 | 0; //@line 49347
 HEAP32[162761] = HEAP32[$24 >> 2]; //@line 49349
 $26 = $1 + 40 | 0; //@line 49350
 HEAP32[162762] = HEAP32[$26 >> 2]; //@line 49352
 $28 = $1 + 44 | 0; //@line 49353
 HEAP32[162763] = HEAP32[$28 >> 2]; //@line 49355
 $30 = $1 + 48 | 0; //@line 49356
 HEAP32[162764] = HEAP32[$30 >> 2]; //@line 49358
 $32 = $1 + 52 | 0; //@line 49359
 HEAP32[162765] = HEAP32[$32 >> 2]; //@line 49361
 $34 = $1 + 56 | 0; //@line 49362
 HEAP32[162766] = HEAP32[$34 >> 2]; //@line 49364
 $37 = (HEAP32[162767] | 0) + -2 | 0; //@line 49366
 HEAP32[162767] = $37; //@line 49367
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($37, 28928); //@line 49373
 $43 = HEAP32[162767] | 0; //@line 49374
 $44 = $43 + -4 | 0; //@line 49375
 HEAP32[162767] = $44; //@line 49376
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($44 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($44, $43); //@line 49382
 $55 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($0 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($0) | 0; //@line 49388
 HEAP32[162770] = $55; //@line 49389
 HEAP32[162769] = $55; //@line 49390
 HEAP32[162768] = $0; //@line 49391
 HEAP8[659737] = 0; //@line 49392
 __Z12m68k_executev(); //@line 49393
 HEAP32[162767] = (HEAP32[162767] | 0) + 2; //@line 49396
 $63 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($21) | 0; //@line 49402
 HEAP32[162770] = $63; //@line 49403
 HEAP32[162769] = $63; //@line 49404
 HEAP32[162768] = $21; //@line 49405
 HEAP32[$1 >> 2] = HEAP32[162752]; //@line 49407
 HEAP32[$7 >> 2] = HEAP32[162753]; //@line 49409
 HEAP32[$9 >> 2] = HEAP32[162754]; //@line 49411
 HEAP32[$11 >> 2] = HEAP32[162755]; //@line 49413
 HEAP32[$13 >> 2] = HEAP32[162756]; //@line 49415
 HEAP32[$15 >> 2] = HEAP32[162757]; //@line 49417
 HEAP32[$17 >> 2] = HEAP32[162758]; //@line 49419
 HEAP32[$19 >> 2] = HEAP32[162759]; //@line 49421
 HEAP32[$22 >> 2] = HEAP32[162760]; //@line 49423
 HEAP32[$24 >> 2] = HEAP32[162761]; //@line 49425
 HEAP32[$26 >> 2] = HEAP32[162762]; //@line 49427
 HEAP32[$28 >> 2] = HEAP32[162763]; //@line 49429
 HEAP32[$30 >> 2] = HEAP32[162764]; //@line 49431
 HEAP32[$32 >> 2] = HEAP32[162765]; //@line 49433
 HEAP32[$34 >> 2] = HEAP32[162766]; //@line 49435
 HEAP8[659737] = 0; //@line 49436
 return;
}
function __Z9init_m68kv() {
 var $$0 = 0, $$01618 = 0, $$04458$i = 0, $$04560$i = 0, $$04749$i = 0, $$14657$i = 0, $$156$i = 0, $$hi = 0, $$lo = 0, $1 = 0, $12 = 0, $13 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $31 = 0, $36 = 0, $42 = 0, $47 = 0, $50 = 0, $62 = 0, label = 0;
 $$01618 = 0; //@line 50924
 do {
  $$0 = 0; //@line 50926
  while (1) {
   $1 = 1 << $$0; //@line 50929
   if (($$0 | 0) < 8 & ($1 & $$01618 | 0) == 0) {
    $$0 = $$0 + 1 | 0; //@line 50935
   } else {
    break;
   }
  }
  HEAP32[385792 + ($$01618 << 2) >> 2] = $$0; //@line 50941
  HEAP32[386816 + ($$01618 << 2) >> 2] = 7 - $$0; //@line 50944
  HEAP32[387840 + ($$01618 << 2) >> 2] = $$01618 & ~$1; //@line 50948
  $$01618 = $$01618 + 1 | 0; //@line 50949
 } while (($$01618 | 0) != 256);
 _read_table68k(); //@line 50957
 _do_merges(); //@line 50958
 $12 = HEAP32[30880] | 0; //@line 50959
 $13 = ($12 | 0) == 4; //@line 50960
 if ($13) {
  $$04749$i = 4; //@line 50962
  $19 = 6768; //@line 50962
 } else {
  if (!(HEAP32[30881] | 0)) {
   $16 = ($12 | 0) > 1; //@line 50967
   $17 = ($12 | 0) == 1; //@line 50968
   $$04749$i = $16 ? 2 : $17 & 1; //@line 50973
   $19 = $16 ? 36464 : $17 ? 50888 : 63664; //@line 50973
  } else {
   $$04749$i = 3; //@line 50975
   $19 = 21720; //@line 50975
  }
 }
 $$04560$i = 0; //@line 50978
 do {
  HEAP32[388864 + ($$04560$i << 2) >> 2] = 2222; //@line 50981
  $$04560$i = $$04560$i + 1 | 0; //@line 50982
 } while (($$04560$i | 0) != 65536);
 $18 = HEAP32[$19 >> 2] | 0; //@line 50990
 $20 = ($18 | 0) == 0; //@line 50991
 if (!$20) {
  $$04458$i = 0; //@line 50993
  $31 = $18; //@line 50993
  do {
   if (!(HEAP16[$19 + ($$04458$i << 3) + 4 >> 1] | 0)) {
    HEAP32[388864 + (HEAPU16[$19 + ($$04458$i << 3) + 6 >> 1] << 2) >> 2] = $31; //@line 51003
   }
   $$04458$i = $$04458$i + 1 | 0; //@line 51005
   $31 = HEAP32[$19 + ($$04458$i << 3) >> 2] | 0; //@line 51007
  } while (($31 | 0) != 0);
 }
 $23 = HEAP32[162823] | 0; //@line 51016
 $$14657$i = 0; //@line 51017
 do {
  $36 = $23 + ($$14657$i << 4) + 9 | 0; //@line 51019
  $$lo = HEAPU8[$36 >> 0] | HEAPU8[$36 + 1 >> 0] << 8 | HEAPU8[$36 + 2 >> 0] << 16 | HEAPU8[$36 + 3 >> 0] << 24; //@line 51020
  $$hi = $36 + 4 | 0; //@line 51021
  if (!(($$lo & 16711680 | 0) == 0 & 0 == 0)) {
   $42 = _bitshift64Lshr($$lo | 0, ((HEAPU8[$$hi >> 0] | HEAPU8[$$hi + 1 >> 0] << 8) & 65535 | HEAPU8[$$hi + 2 >> 0] << 16) & 16777215 | 0, 48) | 0; //@line 51035
   if (($42 & 7) >>> 0 <= $$04749$i >>> 0) {
    $47 = HEAP32[$23 + ($$14657$i << 4) >> 2] | 0; //@line 51041
    if (($47 | 0) != -1) {
     $50 = HEAP32[388864 + ($47 << 2) >> 2] | 0; //@line 51045
     if (($50 | 0) == 2222) {
      label = 20; //@line 51048
      break;
     }
     HEAP32[388864 + ($$14657$i << 2) >> 2] = $50; //@line 51052
    }
   }
  }
  $$14657$i = $$14657$i + 1 | 0; //@line 51056
 } while ($$14657$i >>> 0 < 65536);
 if ((label | 0) == 20) {
  _abort(); //@line 51065
 }
 if ($20) {
  __Z8fpu_initb($13); //@line 51069
  return;
 } else {
  $$156$i = 0; //@line 51072
  $62 = $18; //@line 51072
 }
 do {
  if (HEAP16[$19 + ($$156$i << 3) + 4 >> 1] | 0) {
   HEAP32[388864 + (HEAPU16[$19 + ($$156$i << 3) + 6 >> 1] << 2) >> 2] = $62; //@line 51083
  }
  $$156$i = $$156$i + 1 | 0; //@line 51085
  $62 = HEAP32[$19 + ($$156$i << 3) >> 2] | 0; //@line 51087
 } while (($62 | 0) != 0);
 __Z8fpu_initb($13); //@line 51095
 return;
}
function __ZL9get_fp_adjPj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$cast = 0, $11 = 0, $12 = 0, $19 = 0, $24 = 0, $25 = 0, $3 = 0, $32 = 0, $35 = 0, $42 = 0, $45 = 0, $62 = 0, $65 = 0, $68 = 0, $69 = 0, $76 = 0, $81 = 0, $84 = 0, $91 = 0;
 $3 = $0 & 7; //@line 55610
 switch ($0 >>> 3 & 7) {
 case 2:
  {
   HEAP32[$1 >> 2] = HEAP32[651040 + ($3 << 2) >> 2]; //@line 55617
   $$0 = 1; //@line 55618
   return $$0 | 0; //@line 55619
  }
 case 3:
  {
   HEAP32[$1 >> 2] = HEAP32[651040 + ($3 << 2) >> 2]; //@line 55625
   $$0 = 1; //@line 55626
   return $$0 | 0; //@line 55627
  }
 case 4:
  {
   HEAP32[$1 >> 2] = HEAP32[651040 + ($3 << 2) >> 2]; //@line 55633
   $$0 = 1; //@line 55634
   return $$0 | 0; //@line 55635
  }
 case 5:
  {
   $11 = HEAP32[651040 + ($3 << 2) >> 2] | 0; //@line 55640
   $12 = HEAP32[162769] | 0; //@line 55641
   $19 = (HEAPU8[$12 >> 0] | 0) << 8 | (HEAPU8[$12 + 1 >> 0] | 0); //@line 55648
   HEAP32[162769] = $12 + 2; //@line 55650
   HEAP32[$1 >> 2] = ($19 << 16 >> 16) + $11; //@line 55654
   $$0 = 1; //@line 55655
   return $$0 | 0; //@line 55656
  }
 case 6:
  {
   $24 = HEAP32[651040 + ($3 << 2) >> 2] | 0; //@line 55661
   $25 = HEAP32[162769] | 0; //@line 55662
   $32 = (HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0); //@line 55669
   HEAP32[162769] = $25 + 2; //@line 55671
   HEAP32[$1 >> 2] = __Z15get_disp_ea_020jj($24, $32) | 0; //@line 55673
   $$0 = 1; //@line 55674
   return $$0 | 0; //@line 55675
  }
 case 7:
  {
   switch ($0 & 7) {
   case 0:
    {
     $35 = HEAP32[162769] | 0; //@line 55683
     $42 = (HEAPU8[$35 >> 0] | 0) << 8 | (HEAPU8[$35 + 1 >> 0] | 0); //@line 55690
     HEAP32[162769] = $35 + 2; //@line 55692
     HEAP32[$1 >> 2] = $42 << 16 >> 16; //@line 55695
     $$0 = 1; //@line 55696
     return $$0 | 0; //@line 55697
    }
   case 1:
    {
     $45 = HEAP32[162769] | 0; //@line 55701
     $62 = (HEAPU8[$45 + 1 >> 0] | 0) << 16 | (HEAPU8[$45 >> 0] | 0) << 24 | (HEAPU8[$45 + 2 >> 0] | 0) << 8 | (HEAPU8[$45 + 3 >> 0] | 0); //@line 55718
     HEAP32[162769] = $45 + 4; //@line 55720
     HEAP32[$1 >> 2] = $62; //@line 55721
     $$0 = 1; //@line 55722
     return $$0 | 0; //@line 55723
    }
   case 2:
    {
     $65 = HEAP32[162769] | 0; //@line 55728
     $68 = $65 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 55731
     HEAP32[$1 >> 2] = $68; //@line 55732
     $69 = $65; //@line 55733
     $76 = (HEAPU8[$69 >> 0] | 0) << 8 | (HEAPU8[$69 + 1 >> 0] | 0); //@line 55740
     HEAP32[162769] = $69 + 2; //@line 55742
     HEAP32[$1 >> 2] = ($76 << 16 >> 16) + $68; //@line 55746
     $$0 = 1; //@line 55747
     return $$0 | 0; //@line 55748
    }
   case 3:
    {
     $81 = HEAP32[162769] | 0; //@line 55753
     $84 = $81 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 55756
     $$cast = $81; //@line 55757
     $91 = (HEAPU8[$$cast >> 0] | 0) << 8 | (HEAPU8[$$cast + 1 >> 0] | 0); //@line 55764
     HEAP32[162769] = $$cast + 2; //@line 55766
     HEAP32[$1 >> 2] = __Z15get_disp_ea_020jj($84, $91) | 0; //@line 55768
     $$0 = 1; //@line 55769
     return $$0 | 0; //@line 55770
    }
   default:
    {
     $$0 = 0; //@line 55774
     return $$0 | 0; //@line 55775
    }
   }
   break;
  }
 case 1:
 case 0:
  {
   $$0 = 0; //@line 55781
   return $$0 | 0; //@line 55782
  }
 default:
  {}
 }
 return 0; //@line 55789
}
function __Z10CDROMPrimejj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$2 = 0, $$sroa$03$07$i = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $20 = 0, $25 = 0, $33 = 0, $38 = 0, $4 = 0, $44 = 0, $45 = 0, $50 = 0, $51 = 0, $53 = 0, $56 = 0, $63 = 0, $68 = 0, $8 = 0, $91 = 0, label = 0;
 $2 = $0 + 40 | 0; //@line 20189
 $4 = 123608 + ($2 >>> 16 << 2) | 0; //@line 20191
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, 0); //@line 20195
 $8 = $0 + 22 | 0; //@line 20196
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 20202
 $15 = HEAP32[28494] | 0; //@line 20203
 $16 = HEAP32[28493] | 0; //@line 20204
 if (($16 | 0) == ($15 | 0)) {
  $$2 = -56; //@line 20207
  return $$2 | 0; //@line 20208
 } else {
  $$sroa$03$07$i = $16; //@line 20210
 }
 while (1) {
  if ((HEAP32[$$sroa$03$07$i >> 2] | 0) == ($14 | 0)) {
   break;
  }
  $20 = $$sroa$03$07$i + 840 | 0; //@line 20218
  if (($20 | 0) == ($15 | 0)) {
   $$2 = -56; //@line 20221
   label = 12; //@line 20222
   break;
  } else {
   $$sroa$03$07$i = $20; //@line 20225
  }
 }
 if ((label | 0) == 12) {
  return $$2 | 0; //@line 20229
 }
 if (($$sroa$03$07$i | 0) == ($15 | 0)) {
  $$2 = -56; //@line 20233
  return $$2 | 0; //@line 20234
 }
 $25 = (HEAP32[$$sroa$03$07$i + 836 >> 2] | 0) + 3 | 0; //@line 20238
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($25) | 0)) {
  $$2 = -65; //@line 20247
  return $$2 | 0; //@line 20248
 }
 $33 = $0 + 32 | 0; //@line 20250
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($33 >>> 16 << 2) >> 2] >> 2] & 127]($33) | 0; //@line 20255
 $44 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($38 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($38) | 0; //@line 20261
 $45 = $0 + 36 | 0; //@line 20262
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 20267
 $51 = $1 + 16 | 0; //@line 20268
 $53 = 123608 + ($51 >>> 16 << 2) | 0; //@line 20270
 $56 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$53 >> 2] >> 2] & 127]($51) | 0; //@line 20273
 if ((HEAP32[$$sroa$03$07$i + 8 >> 2] | 0) + -1 & ($56 | $50) | 0) {
  $$2 = -50; //@line 20281
  return $$2 | 0; //@line 20282
 }
 $63 = $$sroa$03$07$i + 16 | 0; //@line 20284
 HEAP32[$$sroa$03$07$i + 12 >> 2] = (HEAP32[$63 >> 2] | 0) + $56 & 2047; //@line 20289
 $68 = $0 + 6 | 0; //@line 20290
 if (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($68 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($68) | 0) & 255 | 0) != 2) {
  $$2 = -44; //@line 20300
  return $$2 | 0; //@line 20301
 }
 do {
  if ((__Z8Sys_readPvS_ij(HEAP32[$$sroa$03$07$i + 4 >> 2] | 0, $44, (HEAP32[$63 >> 2] | 0) + $56 | 0, $50) | 0) == ($50 | 0)) {
   $$0 = $50; //@line 20311
  } else {
   if (($50 | 0) == 512 & ($56 | 0) == 1024) {
    _memset($44 | 0, 0, 512) | 0; //@line 20317
    $$0 = 512; //@line 20318
    break;
   } else {
    $$2 = -19; //@line 20321
    return $$2 | 0; //@line 20322
   }
  }
 } while (0);
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 12 >> 2] & 31]($2, $$0); //@line 20329
 $91 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$53 >> 2] >> 2] & 127]($51) | 0) + $$0 | 0; //@line 20333
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$53 >> 2] | 0) + 12 >> 2] & 31]($51, $91); //@line 20337
 $$2 = 0; //@line 20338
 return $$2 | 0; //@line 20339
}
function __ZN12monitor_desc17load_ramp_paletteEv($0) {
 $0 = $0 | 0;
 var $$05665 = 0, $$05665$us = 0, $$05764 = 0, $$05764$us = 0, $$058 = 0, $$059 = 0, $$060 = 0, $$062$off0 = 0, $$063 = 0, $$1 = 0, $$161 = 0, $12 = 0, $18 = 0, $19 = 0, $2 = 0, $27 = 0, $33 = 0, $34 = 0, $36 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $54 = 0, $59 = 0, $60 = 0, $66 = 0, $67 = 0, $68 = 0, $71 = 0;
 $2 = HEAP32[$0 + 796 >> 2] | 0; //@line 23684
 if (!$2) {
  $$058 = 0; //@line 23687
  $$062$off0 = 0; //@line 23687
  $$063 = 0; //@line 23687
  $$1 = 0; //@line 23687
  $$161 = 0; //@line 23687
 } else {
  $5 = $2 + 4 | 0; //@line 23690
  $12 = $2 + 12 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0) | 0; //@line 23697
  $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($12) | 0; //@line 23703
  $19 = $2 + 6 | 0; //@line 23704
  if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($19) | 0) == 1) {
   $$059 = $18; //@line 23713
   $$060 = $18; //@line 23713
  } else {
   $27 = $2 + 8 | 0; //@line 23715
   $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 23721
   $34 = $18 + $33 | 0; //@line 23722
   $$059 = $34; //@line 23724
   $$060 = $34 + $33 | 0; //@line 23724
  }
  $36 = $2 + 10 | 0; //@line 23726
  $$058 = $18; //@line 23733
  $$062$off0 = 1; //@line 23733
  $$063 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($36) | 0; //@line 23733
  $$1 = $$059; //@line 23733
  $$161 = $$060; //@line 23733
 }
 $48 = (HEAP32[(HEAP32[$0 + 16 >> 2] | 0) + 12 >> 2] | 0) == 4 ? 32 : 256; //@line 23740
 $49 = $0 + 25 | 0; //@line 23741
 $50 = 8 - $$063 | 0; //@line 23742
 if ($$062$off0) {
  $$05665$us = 0; //@line 23744
  $$05764$us = $49; //@line 23744
  while (1) {
   $54 = ((($$05665$us << 8 | 0) / ($48 | 0) | 0) & 255) >>> $50; //@line 23749
   $59 = HEAP8[$$1 + $54 >> 0] | 0; //@line 23754
   $60 = HEAP8[$$161 + $54 >> 0] | 0; //@line 23755
   HEAP8[$$05764$us >> 0] = HEAP8[$$058 + $54 >> 0] | 0; //@line 23757
   HEAP8[$$05764$us + 1 >> 0] = $59; //@line 23759
   HEAP8[$$05764$us + 2 >> 0] = $60; //@line 23761
   $$05665$us = $$05665$us + 1 | 0; //@line 23762
   if (($$05665$us | 0) >= ($48 | 0)) {
    break;
   } else {
    $$05764$us = $$05764$us + 3 | 0; //@line 23765
   }
  }
  $66 = HEAP32[$0 >> 2] | 0; //@line 23770
  $67 = $66 + 12 | 0; //@line 23771
  $68 = HEAP32[$67 >> 2] | 0; //@line 23772
  FUNCTION_TABLE_viii[$68 & 7]($0, $49, $48); //@line 23773
  return;
 } else {
  $$05665 = 0; //@line 23776
  $$05764 = $49; //@line 23776
  while (1) {
   $71 = (($$05665 << 8 | 0) / ($48 | 0) | 0) & 255; //@line 23780
   HEAP8[$$05764 >> 0] = $71; //@line 23782
   HEAP8[$$05764 + 1 >> 0] = $71; //@line 23784
   HEAP8[$$05764 + 2 >> 0] = $71; //@line 23786
   $$05665 = $$05665 + 1 | 0; //@line 23787
   if (($$05665 | 0) >= ($48 | 0)) {
    break;
   } else {
    $$05764 = $$05764 + 3 | 0; //@line 23790
   }
  }
  $66 = HEAP32[$0 >> 2] | 0; //@line 23795
  $67 = $66 + 12 | 0; //@line 23796
  $68 = HEAP32[$67 >> 2] | 0; //@line 23797
  FUNCTION_TABLE_viii[$68 & 7]($0, $49, $48); //@line 23798
  return;
 }
}
function __ZL8fpp_condi($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$86 = 0, $1 = 0.0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $narrow = 0, $narrow99 = 0, $not$ = 0;
 $1 = +HEAPF64[14092]; //@line 55291
 $2 = $1 < 0.0; //@line 55292
 $3 = $1 == 0.0; //@line 55293
 HEAPF64[tempDoublePtr >> 3] = $1; //@line 55294
 $4 = HEAP32[tempDoublePtr >> 2] | 0; //@line 55294
 $11 = (HEAP32[tempDoublePtr + 4 >> 2] & 2147483647 | ($4 | 0 - $4) >>> 31) >>> 0 > 2146435072; //@line 55301
 $12 = $11 & 1; //@line 55302
 $not$ = $11 ^ 1; //@line 55303
 $narrow = $2 & $not$; //@line 55304
 $narrow99 = $3 & $not$; //@line 55305
 $$86 = $narrow99 & 1; //@line 55306
 do {
  switch ($0 | 0) {
  case 16:
  case 0:
   {
    $$0 = 0; //@line 55310
    break;
   }
  case 1:
   {
    $$0 = $$86; //@line 55314
    break;
   }
  case 2:
   {
    $$0 = ($11 | $2 ^ 1) & (($11 | $narrow99) ^ 1) & 1; //@line 55324
    break;
   }
  case 3:
   {
    $$0 = (($11 | $narrow & ($3 ^ 1)) ^ 1) & 1; //@line 55333
    break;
   }
  case 4:
   {
    $$0 = (($11 | $2 ^ 1 | $narrow99) ^ 1) & 1; //@line 55342
    break;
   }
  case 5:
   {
    $$0 = ($narrow | $narrow99) & 1; //@line 55348
    break;
   }
  case 6:
   {
    $$0 = (($11 | $narrow99) ^ 1) & 1; //@line 55355
    break;
   }
  case 7:
   {
    $$0 = $not$ & 1; //@line 55360
    break;
   }
  case 8:
   {
    $$0 = $12; //@line 55364
    break;
   }
  case 9:
   {
    $$0 = ($11 | $narrow99) & 1; //@line 55370
    break;
   }
  case 10:
   {
    $$0 = ($11 | ($narrow | $narrow99) ^ 1) & 1; //@line 55378
    break;
   }
  case 11:
   {
    $$0 = ($11 | $narrow99 | $2 ^ 1) & 1; //@line 55386
    break;
   }
  case 12:
   {
    $$0 = ($11 | ($11 | $3 ^ 1) & $narrow) & 1; //@line 55395
    break;
   }
  case 13:
   {
    $$0 = ($narrow | ($11 | $narrow99)) & 1; //@line 55402
    break;
   }
  case 14:
   {
    $$0 = $$86 ^ 1; //@line 55407
    break;
   }
  case 15:
   {
    $$0 = 1; //@line 55411
    break;
   }
  case 17:
   {
    $$0 = $$86; //@line 55415
    break;
   }
  case 18:
   {
    $$0 = ($11 | $2 ^ 1) & (($11 | $narrow99) ^ 1) & 1; //@line 55425
    break;
   }
  case 19:
   {
    $$0 = (($11 | $narrow & ($3 ^ 1)) ^ 1) & 1; //@line 55434
    break;
   }
  case 20:
   {
    $$0 = (($11 | $2 ^ 1 | $narrow99) ^ 1) & 1; //@line 55443
    break;
   }
  case 21:
   {
    $$0 = ($narrow | $narrow99) & 1; //@line 55449
    break;
   }
  case 22:
   {
    $$0 = (($11 | $narrow99) ^ 1) & 1; //@line 55456
    break;
   }
  case 23:
   {
    $$0 = $not$ & 1; //@line 55461
    break;
   }
  case 24:
   {
    $$0 = $12; //@line 55465
    break;
   }
  case 25:
   {
    $$0 = ($11 | $narrow99) & 1; //@line 55471
    break;
   }
  case 26:
   {
    $$0 = ($11 | ($narrow | $narrow99) ^ 1) & 1; //@line 55479
    break;
   }
  case 27:
   {
    $$0 = ($11 | $narrow99 | $2 ^ 1) & 1; //@line 55487
    break;
   }
  case 28:
   {
    $$0 = ($11 | ($11 | $3 ^ 1) & $narrow) & 1; //@line 55496
    break;
   }
  case 29:
   {
    $$0 = ($narrow | ($11 | $narrow99)) & 1; //@line 55503
    break;
   }
  case 30:
   {
    $$0 = $$86 ^ 1; //@line 55508
    break;
   }
  case 31:
   {
    $$0 = 1; //@line 55512
    break;
   }
  default:
   {
    $$0 = -1; //@line 55516
   }
  }
 } while (0);
 return $$0 | 0; //@line 55520
}
function __ZL10open_audiov() {
 var $0 = 0, $1 = 0, $10 = 0, $12 = 0, $15 = 0, $18 = 0, $21 = 0, $23 = 0, $26 = 0, $27 = 0, $29 = 0, $31 = 0, $36 = 0, $37 = 0, $4 = 0, $41 = 0, $42 = 0, $46 = 0, $47 = 0, $55 = 0, $61 = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 47295
 STACKTOP = STACKTOP + 16 | 0; //@line 47296
 $0 = sp; //@line 47297
 _puts(104184) | 0; //@line 47298
 HEAP8[659478] = 1; //@line 47299
 HEAP32[1312] = 69; //@line 47300
 _puts(104195) | 0; //@line 47301
 $1 = HEAP32[30811] | 0; //@line 47302
 if (($1 | 0) == (HEAP32[30812] | 0)) {
  HEAP32[$0 >> 2] = 1445068800; //@line 47306
  $4 = HEAP32[30809] | 0; //@line 47307
  if (($4 | 0) == (HEAP32[30810] | 0)) {
   __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_(123232, $0); //@line 47311
   $10 = HEAP32[30812] | 0; //@line 47313
  } else {
   HEAP32[$4 >> 2] = 1445068800; //@line 47315
   HEAP32[30809] = $4 + 4; //@line 47317
   $10 = $1; //@line 47318
  }
  HEAP16[$0 >> 1] = 16; //@line 47320
  if (($10 | 0) == (HEAP32[30813] | 0)) {
   __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_(123244, $0); //@line 47324
  } else {
   HEAP16[$10 >> 1] = 16; //@line 47326
   HEAP32[30812] = $10 + 2; //@line 47328
  }
  HEAP16[$0 >> 1] = 1; //@line 47330
  $12 = HEAP32[30815] | 0; //@line 47331
  if (($12 | 0) == (HEAP32[30816] | 0)) {
   __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_(123256, $0); //@line 47335
   $29 = HEAP32[30815] | 0; //@line 47337
  } else {
   HEAP16[$12 >> 1] = 1; //@line 47339
   $15 = $12 + 2 | 0; //@line 47340
   HEAP32[30815] = $15; //@line 47341
   $29 = $15; //@line 47343
  }
  $18 = HEAP32[30808] | 0; //@line 47346
  $21 = ((HEAP32[30809] | 0) - $18 >> 2) + -1 | 0; //@line 47349
  HEAP32[30875] = $21; //@line 47350
  $23 = HEAP32[30811] | 0; //@line 47352
  $26 = ((HEAP32[30812] | 0) - $23 >> 1) + -1 | 0; //@line 47355
  HEAP32[30876] = $26; //@line 47356
  $27 = HEAP32[30814] | 0; //@line 47357
  $31 = ($29 - $27 >> 1) + -1 | 0; //@line 47360
  HEAP32[30877] = $31; //@line 47361
  $36 = $18; //@line 47365
  $37 = $21; //@line 47365
  $41 = $23; //@line 47365
  $42 = $26; //@line 47365
  $46 = $27; //@line 47365
  $47 = $31; //@line 47365
 } else {
  $36 = HEAP32[30808] | 0; //@line 47372
  $37 = HEAP32[30875] | 0; //@line 47372
  $41 = $1; //@line 47372
  $42 = HEAP32[30876] | 0; //@line 47372
  $46 = HEAP32[30814] | 0; //@line 47372
  $47 = HEAP32[30877] | 0; //@line 47372
 }
 HEAP32[30822] = 4096; //@line 47374
 _emscripten_asm_const_iiiii(11, (HEAP32[$36 + ($37 << 2) >> 2] | 0) >>> 16 | 0, HEAPU16[$41 + ($42 << 1) >> 1] | 0 | 0, HEAPU16[$46 + ($47 << 1) >> 1] | 0 | 0, 4096) | 0; //@line 47384
 $55 = HEAPU16[(HEAP32[30811] | 0) + (HEAP32[30876] << 1) >> 1] | 0; //@line 47389
 $61 = HEAPU16[(HEAP32[30814] | 0) + (HEAP32[30877] << 1) >> 1] | 0; //@line 47395
 $62 = Math_imul($61, $55 >>> 3) | 0; //@line 47396
 HEAP32[30878] = Math_imul($62, HEAP32[30822] | 0) | 0; //@line 47399
 HEAP32[30817] = HEAP32[(HEAP32[30808] | 0) + (HEAP32[30875] << 2) >> 2]; //@line 47404
 HEAP32[30818] = $55; //@line 47405
 HEAP32[30819] = $61; //@line 47406
 _puts(104255) | 0; //@line 47407
 HEAP8[657356] = 1; //@line 47408
 STACKTOP = sp; //@line 47409
 return;
}
function __ZNK8tinyxml27XMLNode18NextSiblingElementEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$010$lcssa15 = 0, $$01017 = 0, $$01018 = 0, $$01018$us = 0, $$019$lcssa$i = 0, $$019$lcssa$i1213 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $$lcssa = 0, $15 = 0, $17 = 0, $19 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $37 = 0;
 $$01017 = HEAP32[$0 + 36 >> 2] | 0; //@line 41083
 if (!$$01017) {
  $37 = 0; //@line 41086
  return $37 | 0; //@line 41087
 }
 L4 : do {
  if (!$1) {
   $$01018$us = $$01017; //@line 41092
   while (1) {
    if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$$01018$us >> 2] >> 2] & 127]($$01018$us) | 0) {
     $$010$lcssa15 = $$01018$us; //@line 41099
     $$lcssa = $$01018$us; //@line 41099
     break L4;
    }
    $$01018$us = HEAP32[$$01018$us + 36 >> 2] | 0; //@line 41103
    if (!$$01018$us) {
     $37 = 0; //@line 41106
     break;
    }
   }
   return $37 | 0; //@line 41112
  } else {
   $$01018 = $$01017; //@line 41114
   while (1) {
    do {
     if (FUNCTION_TABLE_ii[HEAP32[HEAP32[$$01018 >> 2] >> 2] & 127]($$01018) | 0) {
      $15 = __ZN8tinyxml27StrPair6GetStrEv($$01018 + 12 | 0) | 0; //@line 41123
      if (($15 | 0) == ($1 | 0)) {
       $$010$lcssa15 = $$01018; //@line 41126
       $$lcssa = $$01018; //@line 41126
       break L4;
      }
      $17 = HEAP8[$1 >> 0] | 0; //@line 41129
      if (!($17 << 24 >> 24)) {
       $$019$lcssa$i1213 = $15; //@line 41132
      } else {
       $$01923$i = $15; //@line 41134
       $$02022$i = $1; //@line 41134
       $$024$i = 0; //@line 41134
       $22 = $17; //@line 41134
       while (1) {
        $19 = HEAP8[$$01923$i >> 0] | 0; //@line 41136
        if (!(($$024$i | 0) != 2147483647 & ($19 << 24 >> 24 ? $22 << 24 >> 24 == $19 << 24 >> 24 : 0))) {
         $$0$lcssa$i = $$024$i; //@line 41143
         $$019$lcssa$i = $$01923$i; //@line 41143
         $31 = $22; //@line 41143
         break;
        }
        $$02022$i = $$02022$i + 1 | 0; //@line 41146
        $25 = $$01923$i + 1 | 0; //@line 41147
        $26 = $$024$i + 1 | 0; //@line 41148
        $22 = HEAP8[$$02022$i >> 0] | 0; //@line 41149
        if (!($22 << 24 >> 24)) {
         $$0$lcssa$i = $26; //@line 41152
         $$019$lcssa$i = $25; //@line 41152
         $31 = 0; //@line 41152
         break;
        } else {
         $$01923$i = $25; //@line 41155
         $$024$i = $26; //@line 41155
        }
       }
       if (($$0$lcssa$i | 0) == 2147483647) {
        $$010$lcssa15 = $$01018; //@line 41160
        $$lcssa = $$01018; //@line 41160
        break L4;
       }
       if (!($31 << 24 >> 24)) {
        $$019$lcssa$i1213 = $$019$lcssa$i; //@line 41165
       } else {
        break;
       }
      }
      if (!(HEAP8[$$019$lcssa$i1213 >> 0] | 0)) {
       $$010$lcssa15 = $$01018; //@line 41173
       $$lcssa = $$01018; //@line 41173
       break L4;
      }
     }
    } while (0);
    $$01018 = HEAP32[$$01018 + 36 >> 2] | 0; //@line 41179
    if (!$$01018) {
     $37 = 0; //@line 41182
     break;
    }
   }
   return $37 | 0; //@line 41188
  }
 } while (0);
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$$lcssa >> 2] >> 2] & 127]($$010$lcssa15) | 0; //@line 41194
 return $37 | 0; //@line 41195
}
function __Z11op_cfc_0_ffj($0) {
 $0 = $0 | 0;
 var $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $13 = 0, $18 = 0, $19 = 0, $22 = 0, $25 = 0, $27 = 0, $31 = 0, $37 = 0, $4 = 0, $40 = 0, $41 = 0, $45 = 0, $50 = 0, $55 = 0, $56 = 0, $60 = 0, $65 = 0, $8 = 0, $85 = 0, $91 = 0, $95 = 0, $96 = 0, $sext$lobit = 0, $sext66$lobit = 0, $sext67$lobit = 0, $sext69$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 20997
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 21000
 $8 = HEAPU8[$1 + 3 >> 0] | 0; //@line 21004
 $10 = $8 << 16 | $4 << 24; //@line 21006
 $13 = HEAPU8[$1 + 4 >> 0] | 0; //@line 21009
 $18 = HEAPU8[$1 + 5 >> 0] | 0; //@line 21014
 $19 = $10 | $13 << 8 | $18; //@line 21015
 $22 = HEAP32[651008 + ($4 >>> 4 << 2) >> 2] | 0; //@line 21018
 $25 = HEAP32[651008 + ($13 >>> 4 << 2) >> 2] | 0; //@line 21021
 $27 = 123608 + ($22 >>> 16 << 2) | 0; //@line 21023
 $31 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$27 >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 21027
 $37 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($25) | 0; //@line 21033
 $40 = HEAP32[651008 + (($8 & 7) << 2) >> 2] | 0; //@line 21036
 $41 = $31 - $40 | 0; //@line 21037
 $sext$lobit = $31 >>> 15 & 1; //@line 21041
 $sext66$lobit = $41 >>> 15 & 1; //@line 21043
 $45 = ($41 & 65535 | 0) == 0; //@line 21045
 HEAP32[96442] = $45 & 1; //@line 21047
 HEAP32[96444] = ($40 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext66$lobit | 0) != ($sext$lobit | 0) & 1; //@line 21052
 $50 = $31 & 65535; //@line 21054
 HEAP32[96441] = ($40 & 65535) >>> 0 > $50 >>> 0 & 1; //@line 21057
 HEAP32[96443] = $sext66$lobit; //@line 21058
 if ($45) {
  $55 = HEAP32[651008 + (($18 & 7) << 2) >> 2] | 0; //@line 21062
  $56 = $37 - $55 | 0; //@line 21063
  $sext67$lobit = $37 >>> 15 & 1; //@line 21067
  $sext69$lobit = $56 >>> 15 & 1; //@line 21069
  $60 = ($56 & 65535 | 0) == 0; //@line 21071
  HEAP32[96442] = $60 & 1; //@line 21073
  HEAP32[96444] = ($55 >>> 15 & 1 | 0) != ($sext67$lobit | 0) & ($sext69$lobit | 0) != ($sext67$lobit | 0) & 1; //@line 21078
  $65 = $37 & 65535; //@line 21080
  HEAP32[96441] = ($55 & 65535) >>> 0 > $65 >>> 0 & 1; //@line 21083
  HEAP32[96443] = $sext69$lobit; //@line 21084
  if ($60) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$27 >> 2] | 0) + 16 >> 2] & 31]($22, HEAP32[651008 + (($10 >>> 22 & 7) << 2) >> 2] | 0); //@line 21093
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$27 >> 2] | 0) + 16 >> 2] & 31]($22, HEAP32[651008 + (($19 >>> 6 & 7) << 2) >> 2] | 0); //@line 21101
   if (!(HEAP32[96442] | 0)) {
    $$pre$phiZ2D = $65; //@line 21105
   } else {
    $95 = HEAP32[162769] | 0; //@line 21107
    $96 = $95 + 6 | 0; //@line 21108
    HEAP32[162769] = $96; //@line 21109
    return;
   }
  } else {
   $$pre$phiZ2D = $65; //@line 21113
  }
 } else {
  $$pre$phiZ2D = $37 & 65535; //@line 21117
 }
 $85 = 651008 + (($10 >>> 22 & 7) << 2) | 0; //@line 21121
 HEAP32[$85 >> 2] = HEAP32[$85 >> 2] & -65536 | $50; //@line 21125
 $91 = 651008 + (($19 >>> 6 & 7) << 2) | 0; //@line 21128
 HEAP32[$91 >> 2] = HEAP32[$91 >> 2] & -65536 | $$pre$phiZ2D; //@line 21132
 $95 = HEAP32[162769] | 0; //@line 21133
 $96 = $95 + 6 | 0; //@line 21134
 HEAP32[162769] = $96; //@line 21135
 return;
}
function _mbrtowc($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$ = 0, $$0 = 0, $$03952 = 0, $$04051 = 0, $$04350 = 0, $$1 = 0, $$141 = 0, $$144 = 0, $$2 = 0, $$47 = 0, $12 = 0, $21 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $34 = 0, $4 = 0, $43 = 0, $6 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 62018
 STACKTOP = STACKTOP + 16 | 0; //@line 62019
 $4 = sp; //@line 62020
 $$ = ($3 | 0) == 0 ? 651900 : $3; //@line 62022
 $6 = HEAP32[$$ >> 2] | 0; //@line 62023
 L1 : do {
  if (!$1) {
   if (!$6) {
    $$0 = 0; //@line 62029
   } else {
    label = 17; //@line 62031
   }
  } else {
   $$47 = ($0 | 0) == 0 ? $4 : $0; //@line 62035
   if (!$2) {
    $$0 = -2; //@line 62038
   } else {
    if (!$6) {
     $12 = HEAP8[$1 >> 0] | 0; //@line 62042
     if ($12 << 24 >> 24 > -1) {
      HEAP32[$$47 >> 2] = $12 & 255; //@line 62046
      $$0 = $12 << 24 >> 24 != 0 & 1; //@line 62049
      break;
     }
     $not$ = (HEAP32[HEAP32[(___pthread_self_422() | 0) + 188 >> 2] >> 2] | 0) == 0; //@line 62056
     $21 = HEAP8[$1 >> 0] | 0; //@line 62057
     if ($not$) {
      HEAP32[$$47 >> 2] = $21 << 24 >> 24 & 57343; //@line 62061
      $$0 = 1; //@line 62062
      break;
     }
     $25 = ($21 & 255) + -194 | 0; //@line 62066
     if ($25 >>> 0 > 50) {
      label = 17; //@line 62069
      break;
     }
     $29 = HEAP32[87948 + ($25 << 2) >> 2] | 0; //@line 62074
     $30 = $2 + -1 | 0; //@line 62075
     if (!$30) {
      $$2 = $29; //@line 62078
     } else {
      $$03952 = $1 + 1 | 0; //@line 62080
      $$04051 = $29; //@line 62080
      $$04350 = $30; //@line 62080
      label = 11; //@line 62081
     }
    } else {
     $$03952 = $1; //@line 62084
     $$04051 = $6; //@line 62084
     $$04350 = $2; //@line 62084
     label = 11; //@line 62085
    }
    L14 : do {
     if ((label | 0) == 11) {
      $32 = HEAP8[$$03952 >> 0] | 0; //@line 62089
      $34 = ($32 & 255) >>> 3; //@line 62091
      if (($34 + -16 | $34 + ($$04051 >> 26)) >>> 0 > 7) {
       label = 17; //@line 62098
       break L1;
      } else {
       $$1 = $$03952; //@line 62101
       $$141 = $$04051; //@line 62101
       $$144 = $$04350; //@line 62101
       $43 = $32; //@line 62101
      }
      while (1) {
       $$1 = $$1 + 1 | 0; //@line 62105
       $$141 = ($43 & 255) + -128 | $$141 << 6; //@line 62108
       $$144 = $$144 + -1 | 0; //@line 62109
       if (($$141 | 0) >= 0) {
        break;
       }
       if (!$$144) {
        $$2 = $$141; //@line 62116
        break L14;
       }
       $43 = HEAP8[$$1 >> 0] | 0; //@line 62119
       if (($43 & -64) << 24 >> 24 != -128) {
        label = 17; //@line 62125
        break L1;
       }
      }
      HEAP32[$$ >> 2] = 0; //@line 62129
      HEAP32[$$47 >> 2] = $$141; //@line 62130
      $$0 = $2 - $$144 | 0; //@line 62132
      break L1;
     }
    } while (0);
    HEAP32[$$ >> 2] = $$2; //@line 62136
    $$0 = -2; //@line 62137
   }
  }
 } while (0);
 if ((label | 0) == 17) {
  HEAP32[$$ >> 2] = 0; //@line 62142
  HEAP32[(___errno_location() | 0) >> 2] = 84; //@line 62144
  $$0 = -1; //@line 62145
 }
 STACKTOP = sp; //@line 62147
 return $$0 | 0; //@line 62147
}
function __ZN8tinyxml27XMLNodeD2Ev($0) {
 $0 = $0 | 0;
 var $$pre$i$i2 = 0, $$pre$phi$iZ2D = 0, $$pre11$i = 0, $1 = 0, $10 = 0, $12 = 0, $15 = 0, $18 = 0, $2 = 0, $22 = 0, $31 = 0, $32 = 0, $34 = 0, $39 = 0, $4 = 0, $42 = 0, $43 = 0, $46 = 0, $49 = 0, $5 = 0, $52 = 0, $56 = 0, $58 = 0, $6 = 0, $7 = 0;
 HEAP32[$0 >> 2] = 1576; //@line 36474
 $1 = $0 + 24 | 0; //@line 36475
 $2 = HEAP32[$1 >> 2] | 0; //@line 36476
 if (!$2) {
  $$pre$phi$iZ2D = $0 + 28 | 0; //@line 36480
 } else {
  $4 = $0 + 28 | 0; //@line 36482
  $6 = $2; //@line 36483
  do {
   $5 = $6 + 36 | 0; //@line 36485
   $7 = HEAP32[$5 >> 2] | 0; //@line 36486
   HEAP32[$1 >> 2] = $7; //@line 36487
   $10 = $6 + 32 | 0; //@line 36490
   if ((HEAP32[$4 >> 2] | 0) == ($6 | 0)) {
    $12 = HEAP32[$10 >> 2] | 0; //@line 36493
    HEAP32[$4 >> 2] = $12; //@line 36494
    $15 = $12; //@line 36496
   } else {
    $15 = HEAP32[$10 >> 2] | 0; //@line 36499
   }
   if (!$15) {
    $18 = $7; //@line 36503
   } else {
    HEAP32[$15 + 36 >> 2] = $7; //@line 36506
    $18 = HEAP32[$5 >> 2] | 0; //@line 36508
   }
   if ($18 | 0) {
    HEAP32[$18 + 32 >> 2] = $15; //@line 36513
   }
   HEAP32[$6 + 8 >> 2] = 0; //@line 36516
   $22 = HEAP32[$6 + 40 >> 2] | 0; //@line 36518
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$6 >> 2] | 0) + 64 >> 2] & 4095]($6); //@line 36522
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$22 >> 2] | 0) + 16 >> 2] & 31]($22, $6); //@line 36526
   $6 = HEAP32[$1 >> 2] | 0; //@line 36527
  } while (($6 | 0) != 0);
  $$pre$phi$iZ2D = $4; //@line 36530
 }
 HEAP32[$$pre$phi$iZ2D >> 2] = 0; //@line 36537
 HEAP32[$1 >> 2] = 0; //@line 36538
 $31 = $0 + 8 | 0; //@line 36539
 $32 = HEAP32[$31 >> 2] | 0; //@line 36540
 if ($32 | 0) {
  $34 = $32 + 24 | 0; //@line 36543
  if ((HEAP32[$34 >> 2] | 0) == ($0 | 0)) {
   HEAP32[$34 >> 2] = HEAP32[$0 + 36 >> 2]; //@line 36549
  }
  $39 = $32 + 28 | 0; //@line 36551
  $42 = $0 + 32 | 0; //@line 36554
  if ((HEAP32[$39 >> 2] | 0) == ($0 | 0)) {
   $43 = HEAP32[$42 >> 2] | 0; //@line 36556
   HEAP32[$39 >> 2] = $43; //@line 36557
   $46 = $43; //@line 36559
  } else {
   $46 = HEAP32[$42 >> 2] | 0; //@line 36562
  }
  $$pre11$i = $0 + 36 | 0; //@line 36565
  if ($46 | 0) {
   HEAP32[$46 + 36 >> 2] = HEAP32[$$pre11$i >> 2]; //@line 36569
  }
  $49 = HEAP32[$$pre11$i >> 2] | 0; //@line 36571
  if ($49 | 0) {
   HEAP32[$49 + 32 >> 2] = $46; //@line 36575
  }
  HEAP32[$31 >> 2] = 0; //@line 36577
 }
 $52 = $0 + 12 | 0; //@line 36579
 $$pre$i$i2 = $0 + 16 | 0; //@line 36583
 if (!(HEAP32[$52 >> 2] & 512)) {
  HEAP32[$52 >> 2] = 0; //@line 36585
  HEAP32[$$pre$i$i2 >> 2] = 0; //@line 36586
  $58 = $0 + 20 | 0; //@line 36587
  HEAP32[$58 >> 2] = 0; //@line 36588
  return;
 }
 $56 = HEAP32[$$pre$i$i2 >> 2] | 0; //@line 36591
 if (!$56) {
  HEAP32[$52 >> 2] = 0; //@line 36594
  HEAP32[$$pre$i$i2 >> 2] = 0; //@line 36595
  $58 = $0 + 20 | 0; //@line 36596
  HEAP32[$58 >> 2] = 0; //@line 36597
  return;
 }
 __ZdaPv($56); //@line 36600
 HEAP32[$52 >> 2] = 0; //@line 36601
 HEAP32[$$pre$i$i2 >> 2] = 0; //@line 36602
 $58 = $0 + 20 | 0; //@line 36603
 HEAP32[$58 >> 2] = 0; //@line 36604
 return;
}
function __Z11m68k_movec2iPj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$sink = 0, $15 = 0, $40 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 51655
 STACKTOP = STACKTOP + 16 | 0; //@line 51656
 $vararg_buffer2 = sp + 8 | 0; //@line 51657
 $vararg_buffer = sp; //@line 51658
 switch (HEAP32[30880] | 0) {
 case 1:
  {
   if (($0 & 2046) >>> 0 >= 2) {
    label = 5; //@line 51665
   }
   break;
  }
 case 3:
 case 2:
  {
   if (!(($0 & 2047) >>> 0 < 3 | ($0 + -3 | 0) >>> 0 < 2)) {
    label = 5; //@line 51676
   }
   break;
  }
 case 4:
  {
   if (!(($0 | 0) != 2050 & ($0 & 2040) >>> 0 < 8)) {
    label = 5; //@line 51686
   }
   break;
  }
 default:
  {
   label = 5; //@line 51691
  }
 }
 if ((label | 0) == 5) {
  $15 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 51699
  HEAP32[$vararg_buffer >> 2] = 20090; //@line 51700
  HEAP32[$vararg_buffer + 4 >> 2] = $15; //@line 51702
  _printf(105458, $vararg_buffer) | 0; //@line 51703
  __Z9Exceptionij(4, 0); //@line 51704
  $$0 = 0; //@line 51705
  STACKTOP = sp; //@line 51706
  return $$0 | 0; //@line 51706
 }
 do {
  switch ($0 | 0) {
  case 0:
   {
    $$sink = HEAP32[162774] | 0; //@line 51712
    break;
   }
  case 1:
   {
    $$sink = HEAP32[162775] | 0; //@line 51717
    break;
   }
  case 2:
   {
    $$sink = HEAP32[162811] | 0; //@line 51722
    break;
   }
  case 3:
   {
    $$sink = HEAP32[162812] | 0; //@line 51727
    break;
   }
  case 4:
   {
    $$sink = HEAP32[162813] | 0; //@line 51732
    break;
   }
  case 5:
   {
    $$sink = HEAP32[162814] | 0; //@line 51737
    break;
   }
  case 6:
   {
    $$sink = HEAP32[162815] | 0; //@line 51742
    break;
   }
  case 7:
   {
    $$sink = HEAP32[162816] | 0; //@line 51747
    break;
   }
  case 2048:
   {
    $$sink = HEAP32[162776] | 0; //@line 51752
    break;
   }
  case 2049:
   {
    $$sink = HEAP32[162773] | 0; //@line 51757
    break;
   }
  case 2050:
   {
    $$sink = HEAP32[162817] | 0; //@line 51762
    break;
   }
  case 2051:
   {
    $$sink = (HEAP8[651121] | 0) == 1 ? HEAP32[162767] | 0 : HEAP32[162778] | 0; //@line 51771
    break;
   }
  case 2052:
   {
    $$sink = (HEAP8[651121] | 0) == 0 ? HEAP32[162767] | 0 : HEAP32[162777] | 0; //@line 51780
    break;
   }
  case 2053:
   {
    $$sink = HEAP32[162818] | 0; //@line 51785
    break;
   }
  case 2054:
   {
    $$sink = HEAP32[162819] | 0; //@line 51790
    break;
   }
  case 2055:
   {
    $$sink = HEAP32[162820] | 0; //@line 51795
    break;
   }
  default:
   {
    $40 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 51803
    HEAP32[$vararg_buffer2 >> 2] = 20090; //@line 51804
    HEAP32[$vararg_buffer2 + 4 >> 2] = $40; //@line 51806
    _printf(105458, $vararg_buffer2) | 0; //@line 51807
    __Z9Exceptionij(4, 0); //@line 51808
    $$0 = 0; //@line 51809
    STACKTOP = sp; //@line 51810
    return $$0 | 0; //@line 51810
   }
  }
 } while (0);
 HEAP32[$1 >> 2] = $$sink; //@line 51814
 $$0 = 1; //@line 51815
 STACKTOP = sp; //@line 51816
 return $$0 | 0; //@line 51816
}
function __ZNK8tinyxml27XMLNode17FirstChildElementEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$01623 = 0, $$01624 = 0, $$01624$us = 0, $$019$lcssa$i = 0, $$019$lcssa$i1718 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $$115 = 0, $13 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $26 = 0, $27 = 0, $32 = 0, $7 = 0, label = 0;
 $$01623 = HEAP32[$0 + 24 >> 2] | 0; //@line 40957
 if (!$$01623) {
  $$115 = 0; //@line 40960
  return $$115 | 0; //@line 40961
 }
 if (!$1) {
  $$01624$us = $$01623; //@line 40965
  while (1) {
   $7 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$$01624$us >> 2] >> 2] & 127]($$01624$us) | 0; //@line 40969
   if ($7 | 0) {
    $$115 = $7; //@line 40972
    label = 14; //@line 40973
    break;
   }
   $$01624$us = HEAP32[$$01624$us + 36 >> 2] | 0; //@line 40977
   if (!$$01624$us) {
    $$115 = 0; //@line 40980
    label = 14; //@line 40981
    break;
   }
  }
  if ((label | 0) == 14) {
   return $$115 | 0; //@line 40988
  }
 } else {
  $$01624 = $$01623; //@line 40991
 }
 L11 : while (1) {
  $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$$01624 >> 2] >> 2] & 127]($$01624) | 0; //@line 40996
  do {
   if ($13 | 0) {
    $16 = __ZN8tinyxml27StrPair6GetStrEv($13 + 12 | 0) | 0; //@line 41001
    if (($16 | 0) == ($1 | 0)) {
     $$115 = $13; //@line 41004
     label = 14; //@line 41005
     break L11;
    }
    $18 = HEAP8[$16 >> 0] | 0; //@line 41008
    if (!($18 << 24 >> 24)) {
     $$019$lcssa$i1718 = $1; //@line 41011
    } else {
     $$01923$i = $1; //@line 41013
     $$02022$i = $16; //@line 41013
     $$024$i = 0; //@line 41013
     $23 = $18; //@line 41013
     while (1) {
      $20 = HEAP8[$$01923$i >> 0] | 0; //@line 41015
      if (!(($$024$i | 0) != 2147483647 & ($20 << 24 >> 24 ? $23 << 24 >> 24 == $20 << 24 >> 24 : 0))) {
       $$0$lcssa$i = $$024$i; //@line 41022
       $$019$lcssa$i = $$01923$i; //@line 41022
       $32 = $23; //@line 41022
       break;
      }
      $$02022$i = $$02022$i + 1 | 0; //@line 41025
      $26 = $$01923$i + 1 | 0; //@line 41026
      $27 = $$024$i + 1 | 0; //@line 41027
      $23 = HEAP8[$$02022$i >> 0] | 0; //@line 41028
      if (!($23 << 24 >> 24)) {
       $$0$lcssa$i = $27; //@line 41031
       $$019$lcssa$i = $26; //@line 41031
       $32 = 0; //@line 41031
       break;
      } else {
       $$01923$i = $26; //@line 41034
       $$024$i = $27; //@line 41034
      }
     }
     if (($$0$lcssa$i | 0) == 2147483647) {
      $$115 = $13; //@line 41039
      label = 14; //@line 41040
      break L11;
     }
     if (!($32 << 24 >> 24)) {
      $$019$lcssa$i1718 = $$019$lcssa$i; //@line 41045
     } else {
      break;
     }
    }
    if (!(HEAP8[$$019$lcssa$i1718 >> 0] | 0)) {
     $$115 = $13; //@line 41053
     label = 14; //@line 41054
     break L11;
    }
   }
  } while (0);
  $$01624 = HEAP32[$$01624 + 36 >> 2] | 0; //@line 41060
  if (!$$01624) {
   $$115 = 0; //@line 41063
   label = 14; //@line 41064
   break;
  }
 }
 if ((label | 0) == 14) {
  return $$115 | 0; //@line 41071
 }
 return 0; //@line 41073
}
function __ZN8tinyxml27XMLText9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$ = 0, $$01921$i = 0, $$01921$i22 = 0, $$pre$i$i$i = 0, $$pre$i$i$i24 = 0, $12 = 0, $16 = 0, $18 = 0, $24 = 0, $29 = 0, $33 = 0, $38 = 0, $41 = 0, $45 = 0, $47 = 0, $58 = 0, $6 = 0, $9 = 0, $lhsc = 0, label = 0;
 if (!(HEAP8[$0 + 44 >> 0] | 0)) {
  $29 = HEAP32[$0 + 4 >> 2] | 0; //@line 39525
  $33 = HEAP8[$29 + 45 >> 0] | 0 ? 3 : 2; //@line 39529
  $$ = (HEAP32[$29 + 52 >> 2] | 0) == 1 ? $33 | 4 : $33; //@line 39534
  $38 = HEAP8[$1 >> 0] | 0; //@line 39535
  L3 : do {
   if (!($38 << 24 >> 24)) {
    label = 18; //@line 39539
   } else {
    $$01921$i = $1; //@line 39541
    $lhsc = $38; //@line 39541
    while (1) {
     if ($lhsc << 24 >> 24 == 60) {
      break;
     }
     $47 = $$01921$i + 1 | 0; //@line 39547
     $lhsc = HEAP8[$47 >> 0] | 0; //@line 39548
     if (!($lhsc << 24 >> 24)) {
      label = 18; //@line 39551
      break L3;
     } else {
      $$01921$i = $47; //@line 39554
     }
    }
    $41 = $0 + 12 | 0; //@line 39557
    $$pre$i$i$i = $0 + 16 | 0; //@line 39561
    if (HEAP32[$41 >> 2] & 512 | 0) {
     $45 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 39563
     if ($45 | 0) {
      __ZdaPv($45); //@line 39566
     }
    }
    HEAP32[$$pre$i$i$i >> 2] = $1; //@line 39570
    HEAP32[$0 + 20 >> 2] = $$01921$i; //@line 39571
    HEAP32[$41 >> 2] = $$ | 256; //@line 39573
    if (HEAP8[$$01921$i + 1 >> 0] | 0) {
     $58 = $$01921$i; //@line 39578
     return $58 | 0; //@line 39579
    }
   }
  } while (0);
  if ((label | 0) == 18) {
   HEAP32[$29 + 48 >> 2] = 10; //@line 39585
   HEAP32[$29 + 56 >> 2] = $1; //@line 39587
   HEAP32[$29 + 60 >> 2] = 0; //@line 39589
  }
  $58 = 0; //@line 39591
  return $58 | 0; //@line 39592
 } else {
  $6 = HEAP8[$1 >> 0] | 0; //@line 39594
  L18 : do {
   if ($6 << 24 >> 24) {
    $$01921$i22 = $1; //@line 39598
    $9 = $6; //@line 39598
    while (1) {
     if ($9 << 24 >> 24 == 93) {
      if (!(_strncmp($$01921$i22, 97407, 3) | 0)) {
       break;
      }
     }
     $18 = $$01921$i22 + 1 | 0; //@line 39608
     $9 = HEAP8[$18 >> 0] | 0; //@line 39609
     if (!($9 << 24 >> 24)) {
      break L18;
     } else {
      $$01921$i22 = $18; //@line 39614
     }
    }
    $12 = $0 + 12 | 0; //@line 39617
    $$pre$i$i$i24 = $0 + 16 | 0; //@line 39621
    if (HEAP32[$12 >> 2] & 512 | 0) {
     $16 = HEAP32[$$pre$i$i$i24 >> 2] | 0; //@line 39623
     if ($16 | 0) {
      __ZdaPv($16); //@line 39626
     }
    }
    HEAP32[$$pre$i$i$i24 >> 2] = $1; //@line 39630
    HEAP32[$0 + 20 >> 2] = $$01921$i22; //@line 39631
    HEAP32[$12 >> 2] = 258; //@line 39632
    $58 = $$01921$i22 + 3 | 0; //@line 39634
    return $58 | 0; //@line 39635
   }
  } while (0);
  $24 = HEAP32[$0 + 4 >> 2] | 0; //@line 39639
  HEAP32[$24 + 48 >> 2] = 11; //@line 39641
  HEAP32[$24 + 56 >> 2] = $1; //@line 39643
  HEAP32[$24 + 60 >> 2] = 0; //@line 39645
  $58 = 0; //@line 39646
  return $58 | 0; //@line 39647
 }
 return 0; //@line 39649
}
function ___stdio_write($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$04756 = 0, $$04855 = 0, $$04954 = 0, $$051 = 0, $$1 = 0, $$150 = 0, $12 = 0, $13 = 0, $17 = 0, $20 = 0, $26 = 0, $3 = 0, $36 = 0, $37 = 0, $4 = 0, $43 = 0, $5 = 0, $7 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 54580
 STACKTOP = STACKTOP + 48 | 0; //@line 54581
 $vararg_buffer3 = sp + 16 | 0; //@line 54582
 $vararg_buffer = sp; //@line 54583
 $3 = sp + 32 | 0; //@line 54584
 $4 = $0 + 28 | 0; //@line 54585
 $5 = HEAP32[$4 >> 2] | 0; //@line 54586
 HEAP32[$3 >> 2] = $5; //@line 54587
 $7 = $0 + 20 | 0; //@line 54589
 $9 = (HEAP32[$7 >> 2] | 0) - $5 | 0; //@line 54591
 HEAP32[$3 + 4 >> 2] = $9; //@line 54592
 HEAP32[$3 + 8 >> 2] = $1; //@line 54594
 HEAP32[$3 + 12 >> 2] = $2; //@line 54596
 $12 = $9 + $2 | 0; //@line 54597
 $13 = $0 + 60 | 0; //@line 54598
 HEAP32[$vararg_buffer >> 2] = HEAP32[$13 >> 2]; //@line 54601
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 54603
 HEAP32[$vararg_buffer + 8 >> 2] = 2; //@line 54605
 $17 = ___syscall_ret(___syscall146(146, $vararg_buffer | 0) | 0) | 0; //@line 54607
 L1 : do {
  if (($12 | 0) == ($17 | 0)) {
   label = 3; //@line 54611
  } else {
   $$04756 = 2; //@line 54613
   $$04855 = $12; //@line 54613
   $$04954 = $3; //@line 54613
   $26 = $17; //@line 54613
   while (1) {
    if (($26 | 0) < 0) {
     break;
    }
    $$04855 = $$04855 - $26 | 0; //@line 54619
    $36 = HEAP32[$$04954 + 4 >> 2] | 0; //@line 54621
    $37 = $26 >>> 0 > $36 >>> 0; //@line 54622
    $$150 = $37 ? $$04954 + 8 | 0 : $$04954; //@line 54624
    $$1 = ($37 << 31 >> 31) + $$04756 | 0; //@line 54626
    $$0 = $26 - ($37 ? $36 : 0) | 0; //@line 54628
    HEAP32[$$150 >> 2] = (HEAP32[$$150 >> 2] | 0) + $$0; //@line 54631
    $43 = $$150 + 4 | 0; //@line 54632
    HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) - $$0; //@line 54635
    HEAP32[$vararg_buffer3 >> 2] = HEAP32[$13 >> 2]; //@line 54638
    HEAP32[$vararg_buffer3 + 4 >> 2] = $$150; //@line 54640
    HEAP32[$vararg_buffer3 + 8 >> 2] = $$1; //@line 54642
    $26 = ___syscall_ret(___syscall146(146, $vararg_buffer3 | 0) | 0) | 0; //@line 54644
    if (($$04855 | 0) == ($26 | 0)) {
     label = 3; //@line 54647
     break L1;
    } else {
     $$04756 = $$1; //@line 54650
     $$04954 = $$150; //@line 54650
    }
   }
   HEAP32[$0 + 16 >> 2] = 0; //@line 54654
   HEAP32[$4 >> 2] = 0; //@line 54655
   HEAP32[$7 >> 2] = 0; //@line 54656
   HEAP32[$0 >> 2] = HEAP32[$0 >> 2] | 32; //@line 54659
   if (($$04756 | 0) == 2) {
    $$051 = 0; //@line 54662
   } else {
    $$051 = $2 - (HEAP32[$$04954 + 4 >> 2] | 0) | 0; //@line 54667
   }
  }
 } while (0);
 if ((label | 0) == 3) {
  $20 = HEAP32[$0 + 44 >> 2] | 0; //@line 54673
  HEAP32[$0 + 16 >> 2] = $20 + (HEAP32[$0 + 48 >> 2] | 0); //@line 54678
  HEAP32[$4 >> 2] = $20; //@line 54679
  HEAP32[$7 >> 2] = $20; //@line 54680
  $$051 = $2; //@line 54681
 }
 STACKTOP = sp; //@line 54683
 return $$051 | 0; //@line 54683
}
function __Z14InstallDriversj($0) {
 $0 = $0 | 0;
 var $1 = 0, $16 = 0, $22 = 0, $27 = 0, $37 = 0, $43 = 0, $49 = 0, $5 = 0, $61 = 0, $67 = 0, $72 = 0, $82 = 0, sp = 0;
 sp = STACKTOP; //@line 2489
 STACKTOP = STACKTOP + 80 | 0; //@line 2490
 $1 = sp; //@line 2491
 $5 = $1 + 32 | 0; //@line 2495
 HEAP32[$5 >> 2] = (HEAP32[28205] | 0) + (HEAP32[30896] | 0); //@line 2496
 HEAP32[$1 >> 2] = 41107; //@line 2497
 _Execute68kTrap(-23993, $1); //@line 2498
 HEAP32[$5 >> 2] = (HEAP32[28206] | 0) + (HEAP32[30896] | 0); //@line 2502
 HEAP32[$1 >> 2] = 41101; //@line 2503
 _Execute68kTrap(-23993, $1); //@line 2504
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 256 + (HEAP32[28207] | 0); //@line 2509
 HEAP32[$1 >> 2] = -63; //@line 2510
 _Execute68kTrap(-23491, $1); //@line 2511
 $16 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](284) | 0) + 248 | 0; //@line 2515
 HEAP32[$5 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 2521
 _Execute68kTrap(-24535, $1); //@line 2522
 $22 = HEAP32[$5 >> 2] | 0; //@line 2523
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($22 >>> 16 << 2) >> 2] >> 2] & 127]($22) | 0; //@line 2528
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($27, (HEAP32[30896] | 0) + 256 + (HEAP32[28207] | 0) | 0); //@line 2538
 $37 = $27 + 4 | 0; //@line 2539
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($37, 28420); //@line 2545
 $43 = $0 + 18 | 0; //@line 2546
 $49 = 123608 + ($43 >>> 16 << 2) | 0; //@line 2552
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$49 >> 2] | 0) + 12 >> 2] & 31]($43, (HEAP32[30896] | 0) + 274 + (HEAP32[28207] | 0) | 0); //@line 2556
 HEAP32[$5 >> 2] = $0; //@line 2557
 _Execute68kTrap(-24576, $1); //@line 2558
 if (__Z13PrefsFindBoolPKc(90708) | 0) {
  STACKTOP = sp; //@line 2561
  return;
 }
 HEAP32[$5 >> 2] = (HEAP32[30896] | 0) + 512 + (HEAP32[28207] | 0); //@line 2567
 HEAP32[$1 >> 2] = -62; //@line 2568
 _Execute68kTrap(-23491, $1); //@line 2569
 $61 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](284) | 0) + 244 | 0; //@line 2573
 HEAP32[$5 >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($61 >>> 16 << 2) >> 2] >> 2] & 127]($61) | 0; //@line 2579
 _Execute68kTrap(-24535, $1); //@line 2580
 $67 = HEAP32[$5 >> 2] | 0; //@line 2581
 $72 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($67 >>> 16 << 2) >> 2] >> 2] & 127]($67) | 0; //@line 2586
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($72 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($72, (HEAP32[30896] | 0) + 512 + (HEAP32[28207] | 0) | 0); //@line 2596
 $82 = $72 + 4 | 0; //@line 2597
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($82 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($82, 27908); //@line 2603
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$49 >> 2] | 0) + 12 >> 2] & 31]($43, (HEAP32[30896] | 0) + 530 + (HEAP32[28207] | 0) | 0); //@line 2611
 HEAP32[$5 >> 2] = $0; //@line 2612
 _Execute68kTrap(-24576, $1); //@line 2613
 STACKTOP = sp; //@line 2614
 return;
}
function ___fdopen($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $16 = 0, $17 = 0, $2 = 0, $22 = 0, $27 = 0, $29 = 0, $3 = 0, $7 = 0, $vararg_buffer = 0, $vararg_buffer12 = 0, $vararg_buffer3 = 0, $vararg_buffer7 = 0, dest = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 92
 STACKTOP = STACKTOP + 64 | 0; //@line 93
 $vararg_buffer12 = sp + 40 | 0; //@line 94
 $vararg_buffer7 = sp + 24 | 0; //@line 95
 $vararg_buffer3 = sp + 16 | 0; //@line 96
 $vararg_buffer = sp; //@line 97
 $2 = sp + 56 | 0; //@line 98
 $3 = HEAP8[$1 >> 0] | 0; //@line 99
 if (!(_memchr(112512, $3 << 24 >> 24, 4) | 0)) {
  HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 105
  $$0 = 0; //@line 106
 } else {
  $7 = _malloc(1156) | 0; //@line 108
  if (!$7) {
   $$0 = 0; //@line 111
  } else {
   dest = $7; //@line 113
   stop = dest + 124 | 0; //@line 113
   do {
    HEAP32[dest >> 2] = 0; //@line 113
    dest = dest + 4 | 0; //@line 113
   } while ((dest | 0) < (stop | 0));
   if (!(_strchr($1, 43) | 0)) {
    HEAP32[$7 >> 2] = $3 << 24 >> 24 == 114 ? 8 : 4; //@line 119
   }
   if (!(_strchr($1, 101) | 0)) {
    $16 = $3; //@line 124
   } else {
    HEAP32[$vararg_buffer >> 2] = $0; //@line 126
    HEAP32[$vararg_buffer + 4 >> 2] = 2; //@line 128
    HEAP32[$vararg_buffer + 8 >> 2] = 1; //@line 130
    ___syscall221(221, $vararg_buffer | 0) | 0; //@line 131
    $16 = HEAP8[$1 >> 0] | 0; //@line 133
   }
   if ($16 << 24 >> 24 == 97) {
    HEAP32[$vararg_buffer3 >> 2] = $0; //@line 137
    HEAP32[$vararg_buffer3 + 4 >> 2] = 3; //@line 139
    $17 = ___syscall221(221, $vararg_buffer3 | 0) | 0; //@line 140
    if (!($17 & 1024)) {
     HEAP32[$vararg_buffer7 >> 2] = $0; //@line 145
     HEAP32[$vararg_buffer7 + 4 >> 2] = 4; //@line 147
     HEAP32[$vararg_buffer7 + 8 >> 2] = $17 | 1024; //@line 149
     ___syscall221(221, $vararg_buffer7 | 0) | 0; //@line 150
    }
    $22 = HEAP32[$7 >> 2] | 128; //@line 153
    HEAP32[$7 >> 2] = $22; //@line 154
    $29 = $22; //@line 155
   } else {
    $29 = HEAP32[$7 >> 2] | 0; //@line 158
   }
   HEAP32[$7 + 60 >> 2] = $0; //@line 161
   HEAP32[$7 + 44 >> 2] = $7 + 132; //@line 164
   HEAP32[$7 + 48 >> 2] = 1024; //@line 166
   $27 = $7 + 75 | 0; //@line 167
   HEAP8[$27 >> 0] = -1; //@line 168
   if (!($29 & 8)) {
    HEAP32[$vararg_buffer12 >> 2] = $0; //@line 173
    HEAP32[$vararg_buffer12 + 4 >> 2] = 21523; //@line 175
    HEAP32[$vararg_buffer12 + 8 >> 2] = $2; //@line 177
    if (!(___syscall54(54, $vararg_buffer12 | 0) | 0)) {
     HEAP8[$27 >> 0] = 10; //@line 181
    }
   }
   HEAP32[$7 + 32 >> 2] = 14; //@line 185
   HEAP32[$7 + 36 >> 2] = 9; //@line 187
   HEAP32[$7 + 40 >> 2] = 10; //@line 189
   HEAP32[$7 + 12 >> 2] = 65; //@line 191
   if (!(HEAP32[162960] | 0)) {
    HEAP32[$7 + 76 >> 2] = -1; //@line 196
   }
   ___ofl_add($7) | 0; //@line 198
   $$0 = $7; //@line 199
  }
 }
 STACKTOP = sp; //@line 202
 return $$0 | 0; //@line 202
}
function _fgets($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$06266 = 0, $$063 = 0, $$064 = 0, $$1 = 0, $10 = 0, $12 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $33 = 0, $34 = 0, $35 = 0, $42 = 0, $50 = 0, $51 = 0, $7 = 0, $9 = 0, label = 0;
 if ((HEAP32[$2 + 76 >> 2] | 0) > -1) {
  $17 = ___lockfile($2) | 0; //@line 445
 } else {
  $17 = 0; //@line 447
 }
 $7 = $1 + -1 | 0; //@line 449
 $9 = ($7 | 0) != 0; //@line 451
 if (($1 | 0) < 2) {
  $10 = $2 + 74 | 0; //@line 453
  $12 = HEAP8[$10 >> 0] | 0; //@line 455
  HEAP8[$10 >> 0] = $12 + 255 | $12; //@line 459
  if ($17 | 0) {
   ___unlockfile($2); //@line 462
  }
  if ($9) {
   $$0 = 0; //@line 465
  } else {
   HEAP8[$0 >> 0] = 0; //@line 467
   $$0 = $0; //@line 468
  }
 } else {
  L11 : do {
   if ($9) {
    $18 = $2 + 4 | 0; //@line 473
    $19 = $2 + 8 | 0; //@line 474
    $$063 = $7; //@line 475
    $$064 = $0; //@line 475
    while (1) {
     $20 = HEAP32[$18 >> 2] | 0; //@line 477
     $22 = $20; //@line 479
     $23 = (HEAP32[$19 >> 2] | 0) - $22 | 0; //@line 480
     $24 = _memchr($20, 10, $23) | 0; //@line 481
     $25 = ($24 | 0) == 0; //@line 482
     $29 = $25 ? $23 : 1 - $22 + $24 | 0; //@line 486
     $31 = $29 >>> 0 < $$063 >>> 0 ? $29 : $$063; //@line 488
     _memcpy($$064 | 0, $20 | 0, $31 | 0) | 0; //@line 489
     $33 = (HEAP32[$18 >> 2] | 0) + $31 | 0; //@line 491
     HEAP32[$18 >> 2] = $33; //@line 492
     $34 = $$064 + $31 | 0; //@line 493
     $35 = $$063 - $31 | 0; //@line 494
     if (!($25 & ($35 | 0) != 0)) {
      $$1 = $34; //@line 498
      label = 17; //@line 499
      break L11;
     }
     if ($33 >>> 0 < (HEAP32[$19 >> 2] | 0) >>> 0) {
      HEAP32[$18 >> 2] = $33 + 1; //@line 506
      $50 = HEAPU8[$33 >> 0] | 0; //@line 509
     } else {
      $42 = ___uflow($2) | 0; //@line 511
      if (($42 | 0) < 0) {
       break;
      } else {
       $50 = $42; //@line 516
      }
     }
     $$063 = $35 + -1 | 0; //@line 519
     $51 = $34 + 1 | 0; //@line 521
     HEAP8[$34 >> 0] = $50; //@line 522
     if (!(($$063 | 0) != 0 & ($50 & 255 | 0) != 10)) {
      $$1 = $51; //@line 530
      label = 17; //@line 531
      break L11;
     } else {
      $$064 = $51; //@line 528
     }
    }
    if (($34 | 0) == ($0 | 0)) {
     $$06266 = 0; //@line 537
    } else {
     if (!(HEAP32[$2 >> 2] & 16)) {
      $$06266 = 0; //@line 543
     } else {
      $$1 = $34; //@line 545
      label = 17; //@line 546
     }
    }
   } else {
    $$1 = $0; //@line 550
    label = 17; //@line 551
   }
  } while (0);
  if ((label | 0) == 17) {
   if (!$0) {
    $$06266 = 0; //@line 557
   } else {
    HEAP8[$$1 >> 0] = 0; //@line 559
    $$06266 = $0; //@line 560
   }
  }
  if (!$17) {
   $$0 = $$06266; //@line 565
  } else {
   ___unlockfile($2); //@line 567
   $$0 = $$06266; //@line 568
  }
 }
 return $$0 | 0; //@line 571
}
function __Z7RmvTimej($0) {
 $0 = $0 | 0;
 var $$0911$i = 0, $1 = 0, $10 = 0, $13 = 0, $15 = 0, $2 = 0, $26 = 0, $3 = 0, $31 = 0, $36 = 0, $37 = 0, $4 = 0, $41 = 0, $42 = 0, $48 = 0, $tmpcast$byval_copy = 0, $tmpcast13$byval_copy = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 13142
 STACKTOP = STACKTOP + 48 | 0; //@line 13143
 $tmpcast13$byval_copy = sp + 40 | 0; //@line 13144
 $tmpcast$byval_copy = sp + 32 | 0; //@line 13145
 $vararg_buffer = sp + 16 | 0; //@line 13146
 $1 = sp + 24 | 0; //@line 13147
 $2 = sp + 8 | 0; //@line 13148
 $3 = sp; //@line 13149
 $$0911$i = 0; //@line 13150
 while (1) {
  $4 = 112848 + ($$0911$i << 4) + 12 | 0; //@line 13152
  if (HEAP8[$4 >> 0] | 0) {
   if ((HEAP32[112848 + ($$0911$i << 4) >> 2] | 0) == ($0 | 0)) {
    label = 5; //@line 13160
    break;
   }
  }
  $10 = $$0911$i + 1 | 0; //@line 13164
  if (($10 | 0) < 64) {
   $$0911$i = $10; //@line 13167
  } else {
   break;
  }
 }
 if ((label | 0) == 5) {
  if (($$0911$i | 0) >= 0) {
   $13 = $0 + 4 | 0; //@line 13175
   $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 13177
   if (!((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0) & 32768)) {
    $48 = $0 + 10 | 0; //@line 13185
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($48 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($48, 0); //@line 13191
   } else {
    $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0) & 32767; //@line 13197
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $26); //@line 13201
    __Z18timer_current_timeR7timeval($2); //@line 13202
    $31 = 112848 + ($$0911$i << 4) + 4 | 0; //@line 13204
    $36 = HEAP32[$31 + 4 >> 2] | 0; //@line 13209
    $37 = $1; //@line 13210
    HEAP32[$37 >> 2] = HEAP32[$31 >> 2]; //@line 13212
    HEAP32[$37 + 4 >> 2] = $36; //@line 13215
    HEAP32[$tmpcast$byval_copy >> 2] = HEAP32[$1 >> 2]; //@line 13216
    HEAP32[$tmpcast$byval_copy + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 13216
    HEAP32[$tmpcast13$byval_copy >> 2] = HEAP32[$2 >> 2]; //@line 13217
    HEAP32[$tmpcast13$byval_copy + 4 >> 2] = HEAP32[$2 + 4 >> 2]; //@line 13217
    __Z14timer_sub_timeR7timevalS_S_($3, $tmpcast$byval_copy, $tmpcast13$byval_copy); //@line 13218
    $41 = $0 + 10 | 0; //@line 13219
    HEAP32[$tmpcast13$byval_copy >> 2] = HEAP32[$3 >> 2]; //@line 13220
    HEAP32[$tmpcast13$byval_copy + 4 >> 2] = HEAP32[$3 + 4 >> 2]; //@line 13220
    $42 = __Z19timer_host2mac_time7timeval($tmpcast13$byval_copy) | 0; //@line 13221
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($41, $42); //@line 13227
   }
   HEAP8[$4 >> 0] = 0; //@line 13229
   STACKTOP = sp; //@line 13230
   return 0; //@line 13230
  }
 }
 HEAP32[$vararg_buffer >> 2] = $0; //@line 13233
 _printf(93276, $vararg_buffer) | 0; //@line 13234
 STACKTOP = sp; //@line 13235
 return 0; //@line 13235
}
function __Z9EtherInitv() {
 var $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $13 = 0, $2 = 0, $22 = 0, $23 = 0, $29 = 0, $38 = 0, $6 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 15081
 STACKTOP = STACKTOP + 288 | 0; //@line 15082
 $vararg_buffer = sp; //@line 15083
 $0 = sp + 272 | 0; //@line 15084
 $1 = sp + 264 | 0; //@line 15085
 $2 = sp + 8 | 0; //@line 15086
 HEAP8[657350] = 0; //@line 15087
 HEAP8[657351] = 0; //@line 15088
 if (!(__Z13PrefsFindBoolPKc(93527) | 0)) {
  if (!(__Z10ether_initv() | 0)) {
   STACKTOP = sp; //@line 15093
   return;
  }
  HEAP8[657350] = 1; //@line 15095
  STACKTOP = sp; //@line 15096
  return;
 }
 HEAP8[657351] = 1; //@line 15098
 HEAP16[325961] = __Z14PrefsFindInt32PKc(93537) | 0; //@line 15101
 $6 = _socket(2, 2, 0) | 0; //@line 15102
 HEAP32[370] = $6; //@line 15103
 if (($6 | 0) < 0) {
  _perror(93545); //@line 15106
  STACKTOP = sp; //@line 15107
  return;
 }
 $9 = $0 + 8 | 0; //@line 15110
 HEAP32[$9 >> 2] = 0; //@line 15112
 HEAP32[$9 + 4 >> 2] = 0; //@line 15115
 HEAP16[$0 >> 1] = 2; //@line 15116
 $13 = $0 + 4 | 0; //@line 15117
 HEAP32[$13 >> 2] = 0; //@line 15118
 HEAP16[$0 + 2 >> 1] = _htons(HEAP16[325961] | 0) | 0; //@line 15122
 if ((_bind(HEAP32[370] | 0, $0, 16) | 0) < 0) {
  _perror(93552); //@line 15127
  _close(HEAP32[370] | 0) | 0; //@line 15129
  HEAP32[370] = -1; //@line 15130
  STACKTOP = sp; //@line 15131
  return;
 }
 HEAP32[$1 >> 2] = 16; //@line 15133
 _getsockname(HEAP32[370] | 0, $0, $1) | 0; //@line 15135
 $22 = HEAP32[$13 >> 2] | 0; //@line 15136
 if (($22 | 0) < 2130706433) {
  switch ($22 | 0) {
  case 0:
   {
    label = 7; //@line 15141
    break;
   }
  default:
   {
    $$1 = $22; //@line 15145
   }
  }
 } else {
  switch ($22 | 0) {
  case 2130706433:
   {
    label = 7; //@line 15151
    break;
   }
  default:
   {
    $$1 = $22; //@line 15155
   }
  }
 }
 if ((label | 0) == 7) {
  _gethostname($2, 256) | 0; //@line 15160
  $23 = _gethostbyname($2 | 0) | 0; //@line 15161
  if (!$23) {
   $$0 = $22; //@line 15164
  } else {
   $$0 = HEAP32[HEAP32[HEAP32[$23 + 16 >> 2] >> 2] >> 2] | 0; //@line 15170
  }
  $$1 = $$0; //@line 15172
 }
 $29 = _ntohl($$1) | 0; //@line 15174
 HEAP8[657344] = 66; //@line 15175
 HEAP8[657345] = 50; //@line 15176
 HEAP8[657346] = $29 >>> 24; //@line 15179
 HEAP8[657347] = $29 >>> 16; //@line 15182
 HEAP8[657348] = $29 >>> 8; //@line 15185
 HEAP8[657349] = $29; //@line 15187
 HEAP32[$2 >> 2] = 1; //@line 15188
 _setsockopt(HEAP32[370] | 0, 1, 6, $2, 4) | 0; //@line 15190
 $38 = HEAP32[370] | 0; //@line 15191
 HEAP32[$vararg_buffer >> 2] = $2; //@line 15192
 _ioctl($38, 21537, $vararg_buffer) | 0; //@line 15193
 if (__Z22ether_start_udp_threadi(HEAP32[370] | 0) | 0) {
  HEAP8[657350] = 1; //@line 15197
 } else {
  _close(HEAP32[370] | 0) | 0; //@line 15200
  HEAP32[370] = -1; //@line 15201
 }
 STACKTOP = sp; //@line 15203
 return;
}
function __ZNK8tinyxml210XMLElement12ShallowCloneEPNS_11XMLDocumentE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$012 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i = 0, $10 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $6 = 0, $7 = 0, $8 = 0;
 if (!$1) {
  $$012 = HEAP32[$0 + 4 >> 2] | 0; //@line 37866
 } else {
  $$012 = $1; //@line 37868
 }
 $6 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 37871
 $7 = $$012 + 68 | 0; //@line 37872
 $8 = __ZN8tinyxml28MemPoolTILi52EE5AllocEv($7) | 0; //@line 37873
 HEAP32[$8 + 4 >> 2] = $$012; //@line 37875
 $10 = $8 + 8 | 0; //@line 37876
 HEAP32[$10 >> 2] = 0; //@line 37877
 HEAP32[$10 + 4 >> 2] = 0; //@line 37877
 HEAP32[$10 + 8 >> 2] = 0; //@line 37877
 HEAP32[$10 + 12 >> 2] = 0; //@line 37877
 HEAP32[$10 + 16 >> 2] = 0; //@line 37877
 HEAP32[$10 + 20 >> 2] = 0; //@line 37877
 HEAP32[$10 + 24 >> 2] = 0; //@line 37877
 HEAP32[$10 + 28 >> 2] = 0; //@line 37877
 HEAP32[$8 >> 2] = 2064; //@line 37878
 HEAP32[$8 + 44 >> 2] = 0; //@line 37880
 HEAP32[$8 + 48 >> 2] = 0; //@line 37882
 HEAP32[$8 + 40 >> 2] = $7; //@line 37884
 $14 = $8 + 12 | 0; //@line 37885
 $$pre$i$i$i$i$i = $8 + 16 | 0; //@line 37886
 HEAP32[$14 >> 2] = 0; //@line 37887
 HEAP32[$$pre$i$i$i$i$i >> 2] = 0; //@line 37888
 $15 = $8 + 20 | 0; //@line 37889
 HEAP32[$15 >> 2] = 0; //@line 37890
 $16 = _strlen($6) | 0; //@line 37891
 $17 = $16 + 1 | 0; //@line 37892
 $18 = __Znaj($17) | 0; //@line 37893
 HEAP32[$$pre$i$i$i$i$i >> 2] = $18; //@line 37894
 _memcpy($18 | 0, $6 | 0, $17 | 0) | 0; //@line 37895
 HEAP32[$15 >> 2] = $18 + $16; //@line 37897
 HEAP32[$14 >> 2] = 512; //@line 37898
 $21 = HEAP32[$0 + 48 >> 2] | 0; //@line 37900
 if (!$21) {
  return $8 | 0; //@line 37903
 } else {
  $24 = $21; //@line 37905
 }
 do {
  $25 = __ZN8tinyxml27StrPair6GetStrEv($24 + 4 | 0) | 0; //@line 37909
  $27 = __ZN8tinyxml27StrPair6GetStrEv($24 + 16 | 0) | 0; //@line 37911
  $28 = __ZN8tinyxml210XMLElement21FindOrCreateAttributeEPKc($8, $25) | 0; //@line 37912
  $29 = $28 + 16 | 0; //@line 37913
  $$pre$i$i$i$i = $28 + 20 | 0; //@line 37917
  if (HEAP32[$29 >> 2] & 512 | 0) {
   $33 = HEAP32[$$pre$i$i$i$i >> 2] | 0; //@line 37919
   if ($33 | 0) {
    __ZdaPv($33); //@line 37922
   }
  }
  HEAP32[$29 >> 2] = 0; //@line 37925
  HEAP32[$$pre$i$i$i$i >> 2] = 0; //@line 37926
  $35 = $28 + 24 | 0; //@line 37927
  HEAP32[$35 >> 2] = 0; //@line 37928
  $36 = _strlen($27) | 0; //@line 37929
  $37 = $36 + 1 | 0; //@line 37930
  $38 = __Znaj($37) | 0; //@line 37931
  HEAP32[$$pre$i$i$i$i >> 2] = $38; //@line 37932
  _memcpy($38 | 0, $27 | 0, $37 | 0) | 0; //@line 37933
  HEAP32[$35 >> 2] = $38 + $36; //@line 37935
  HEAP32[$29 >> 2] = 512; //@line 37936
  $24 = HEAP32[$24 + 28 >> 2] | 0; //@line 37938
 } while (($24 | 0) != 0);
 return $8 | 0; //@line 37946
}
function __ZN8tinyxml28MemPoolTILi36EE5AllocEv($0) {
 $0 = $0 | 0;
 var $$015 = 0, $$pre2$i = 0, $1 = 0, $12 = 0, $14 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $$015$looptemp = 0;
 $1 = $0 + 56 | 0; //@line 38691
 $2 = HEAP32[$1 >> 2] | 0; //@line 38692
 if (!$2) {
  $4 = __Znwj(4068) | 0; //@line 38695
  _memset($4 | 0, 0, 4068) | 0; //@line 38696
  $5 = $0 + 4 | 0; //@line 38697
  $6 = $0 + 52 | 0; //@line 38698
  $7 = HEAP32[$6 >> 2] | 0; //@line 38699
  $8 = $0 + 48 | 0; //@line 38700
  if ((HEAP32[$8 >> 2] | 0) > ($7 | 0)) {
   $21 = $7; //@line 38705
   $23 = HEAP32[$5 >> 2] | 0; //@line 38705
  } else {
   $12 = ($7 << 1) + 2 | 0; //@line 38708
   $14 = __Znaj($12 >>> 0 > 1073741823 ? -1 : $12 << 2) | 0; //@line 38712
   $15 = HEAP32[$5 >> 2] | 0; //@line 38713
   _memcpy($14 | 0, $15 | 0, $7 << 2 | 0) | 0; //@line 38715
   if (($15 | 0) == 0 | ($15 | 0) == ($0 + 8 | 0)) {
    $$pre2$i = $7; //@line 38721
   } else {
    __ZdaPv($15); //@line 38723
    $$pre2$i = HEAP32[$6 >> 2] | 0; //@line 38725
   }
   HEAP32[$5 >> 2] = $14; //@line 38727
   HEAP32[$8 >> 2] = $12; //@line 38728
   $21 = $$pre2$i; //@line 38729
   $23 = $14; //@line 38729
  }
  HEAP32[$6 >> 2] = $21 + 1; //@line 38732
  HEAP32[$23 + ($21 << 2) >> 2] = $4; //@line 38734
  $$015 = 0; //@line 38735
  do {
   $$015$looptemp = $$015;
   $$015 = $$015 + 1 | 0; //@line 38737
   HEAP32[$4 + ($$015$looptemp * 36 | 0) >> 2] = $4 + ($$015 * 36 | 0); //@line 38740
  } while (($$015 | 0) != 112);
  HEAP32[$4 + 4032 >> 2] = 0; //@line 38749
  HEAP32[$1 >> 2] = $4; //@line 38750
  $29 = $4; //@line 38751
 } else {
  $29 = $2; //@line 38753
 }
 HEAP32[$1 >> 2] = HEAP32[$29 >> 2]; //@line 38756
 $30 = $0 + 60 | 0; //@line 38757
 $31 = HEAP32[$30 >> 2] | 0; //@line 38758
 $32 = $31 + 1 | 0; //@line 38759
 HEAP32[$30 >> 2] = $32; //@line 38760
 $33 = $0 + 68 | 0; //@line 38761
 if (($31 | 0) < (HEAP32[$33 >> 2] | 0)) {
  $36 = $0 + 64 | 0; //@line 38765
  $37 = HEAP32[$36 >> 2] | 0; //@line 38766
  $38 = $37 + 1 | 0; //@line 38767
  HEAP32[$36 >> 2] = $38; //@line 38768
  $39 = $0 + 72 | 0; //@line 38769
  $40 = HEAP32[$39 >> 2] | 0; //@line 38770
  $41 = $40 + 1 | 0; //@line 38771
  HEAP32[$39 >> 2] = $41; //@line 38772
  return $29 | 0; //@line 38773
 }
 HEAP32[$33 >> 2] = $32; //@line 38775
 $36 = $0 + 64 | 0; //@line 38776
 $37 = HEAP32[$36 >> 2] | 0; //@line 38777
 $38 = $37 + 1 | 0; //@line 38778
 HEAP32[$36 >> 2] = $38; //@line 38779
 $39 = $0 + 72 | 0; //@line 38780
 $40 = HEAP32[$39 >> 2] | 0; //@line 38781
 $41 = $40 + 1 | 0; //@line 38782
 HEAP32[$39 >> 2] = $41; //@line 38783
 return $29 | 0; //@line 38784
}
function __ZN8tinyxml28MemPoolTILi52EE5AllocEv($0) {
 $0 = $0 | 0;
 var $$015 = 0, $$pre2$i = 0, $1 = 0, $12 = 0, $14 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $$015$looptemp = 0;
 $1 = $0 + 56 | 0; //@line 37748
 $2 = HEAP32[$1 >> 2] | 0; //@line 37749
 if (!$2) {
  $4 = __Znwj(4056) | 0; //@line 37752
  _memset($4 | 0, 0, 4056) | 0; //@line 37753
  $5 = $0 + 4 | 0; //@line 37754
  $6 = $0 + 52 | 0; //@line 37755
  $7 = HEAP32[$6 >> 2] | 0; //@line 37756
  $8 = $0 + 48 | 0; //@line 37757
  if ((HEAP32[$8 >> 2] | 0) > ($7 | 0)) {
   $21 = $7; //@line 37762
   $23 = HEAP32[$5 >> 2] | 0; //@line 37762
  } else {
   $12 = ($7 << 1) + 2 | 0; //@line 37765
   $14 = __Znaj($12 >>> 0 > 1073741823 ? -1 : $12 << 2) | 0; //@line 37769
   $15 = HEAP32[$5 >> 2] | 0; //@line 37770
   _memcpy($14 | 0, $15 | 0, $7 << 2 | 0) | 0; //@line 37772
   if (($15 | 0) == 0 | ($15 | 0) == ($0 + 8 | 0)) {
    $$pre2$i = $7; //@line 37778
   } else {
    __ZdaPv($15); //@line 37780
    $$pre2$i = HEAP32[$6 >> 2] | 0; //@line 37782
   }
   HEAP32[$5 >> 2] = $14; //@line 37784
   HEAP32[$8 >> 2] = $12; //@line 37785
   $21 = $$pre2$i; //@line 37786
   $23 = $14; //@line 37786
  }
  HEAP32[$6 >> 2] = $21 + 1; //@line 37789
  HEAP32[$23 + ($21 << 2) >> 2] = $4; //@line 37791
  $$015 = 0; //@line 37792
  do {
   $$015$looptemp = $$015;
   $$015 = $$015 + 1 | 0; //@line 37794
   HEAP32[$4 + ($$015$looptemp * 52 | 0) >> 2] = $4 + ($$015 * 52 | 0); //@line 37797
  } while (($$015 | 0) != 77);
  HEAP32[$4 + 4004 >> 2] = 0; //@line 37806
  HEAP32[$1 >> 2] = $4; //@line 37807
  $29 = $4; //@line 37808
 } else {
  $29 = $2; //@line 37810
 }
 HEAP32[$1 >> 2] = HEAP32[$29 >> 2]; //@line 37813
 $30 = $0 + 60 | 0; //@line 37814
 $31 = HEAP32[$30 >> 2] | 0; //@line 37815
 $32 = $31 + 1 | 0; //@line 37816
 HEAP32[$30 >> 2] = $32; //@line 37817
 $33 = $0 + 68 | 0; //@line 37818
 if (($31 | 0) < (HEAP32[$33 >> 2] | 0)) {
  $36 = $0 + 64 | 0; //@line 37822
  $37 = HEAP32[$36 >> 2] | 0; //@line 37823
  $38 = $37 + 1 | 0; //@line 37824
  HEAP32[$36 >> 2] = $38; //@line 37825
  $39 = $0 + 72 | 0; //@line 37826
  $40 = HEAP32[$39 >> 2] | 0; //@line 37827
  $41 = $40 + 1 | 0; //@line 37828
  HEAP32[$39 >> 2] = $41; //@line 37829
  return $29 | 0; //@line 37830
 }
 HEAP32[$33 >> 2] = $32; //@line 37832
 $36 = $0 + 64 | 0; //@line 37833
 $37 = HEAP32[$36 >> 2] | 0; //@line 37834
 $38 = $37 + 1 | 0; //@line 37835
 HEAP32[$36 >> 2] = $38; //@line 37836
 $39 = $0 + 72 | 0; //@line 37837
 $40 = HEAP32[$39 >> 2] | 0; //@line 37838
 $41 = $40 + 1 | 0; //@line 37839
 HEAP32[$39 >> 2] = $41; //@line 37840
 return $29 | 0; //@line 37841
}
function __ZN8tinyxml28MemPoolTILi48EE5AllocEv($0) {
 $0 = $0 | 0;
 var $$015 = 0, $$pre2$i = 0, $1 = 0, $12 = 0, $14 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $$015$looptemp = 0;
 $1 = $0 + 56 | 0; //@line 37647
 $2 = HEAP32[$1 >> 2] | 0; //@line 37648
 if (!$2) {
  $4 = __Znwj(4080) | 0; //@line 37651
  _memset($4 | 0, 0, 4080) | 0; //@line 37652
  $5 = $0 + 4 | 0; //@line 37653
  $6 = $0 + 52 | 0; //@line 37654
  $7 = HEAP32[$6 >> 2] | 0; //@line 37655
  $8 = $0 + 48 | 0; //@line 37656
  if ((HEAP32[$8 >> 2] | 0) > ($7 | 0)) {
   $21 = $7; //@line 37661
   $23 = HEAP32[$5 >> 2] | 0; //@line 37661
  } else {
   $12 = ($7 << 1) + 2 | 0; //@line 37664
   $14 = __Znaj($12 >>> 0 > 1073741823 ? -1 : $12 << 2) | 0; //@line 37668
   $15 = HEAP32[$5 >> 2] | 0; //@line 37669
   _memcpy($14 | 0, $15 | 0, $7 << 2 | 0) | 0; //@line 37671
   if (($15 | 0) == 0 | ($15 | 0) == ($0 + 8 | 0)) {
    $$pre2$i = $7; //@line 37677
   } else {
    __ZdaPv($15); //@line 37679
    $$pre2$i = HEAP32[$6 >> 2] | 0; //@line 37681
   }
   HEAP32[$5 >> 2] = $14; //@line 37683
   HEAP32[$8 >> 2] = $12; //@line 37684
   $21 = $$pre2$i; //@line 37685
   $23 = $14; //@line 37685
  }
  HEAP32[$6 >> 2] = $21 + 1; //@line 37688
  HEAP32[$23 + ($21 << 2) >> 2] = $4; //@line 37690
  $$015 = 0; //@line 37691
  do {
   $$015$looptemp = $$015;
   $$015 = $$015 + 1 | 0; //@line 37693
   HEAP32[$4 + ($$015$looptemp * 48 | 0) >> 2] = $4 + ($$015 * 48 | 0); //@line 37696
  } while (($$015 | 0) != 84);
  HEAP32[$4 + 4032 >> 2] = 0; //@line 37705
  HEAP32[$1 >> 2] = $4; //@line 37706
  $29 = $4; //@line 37707
 } else {
  $29 = $2; //@line 37709
 }
 HEAP32[$1 >> 2] = HEAP32[$29 >> 2]; //@line 37712
 $30 = $0 + 60 | 0; //@line 37713
 $31 = HEAP32[$30 >> 2] | 0; //@line 37714
 $32 = $31 + 1 | 0; //@line 37715
 HEAP32[$30 >> 2] = $32; //@line 37716
 $33 = $0 + 68 | 0; //@line 37717
 if (($31 | 0) < (HEAP32[$33 >> 2] | 0)) {
  $36 = $0 + 64 | 0; //@line 37721
  $37 = HEAP32[$36 >> 2] | 0; //@line 37722
  $38 = $37 + 1 | 0; //@line 37723
  HEAP32[$36 >> 2] = $38; //@line 37724
  $39 = $0 + 72 | 0; //@line 37725
  $40 = HEAP32[$39 >> 2] | 0; //@line 37726
  $41 = $40 + 1 | 0; //@line 37727
  HEAP32[$39 >> 2] = $41; //@line 37728
  return $29 | 0; //@line 37729
 }
 HEAP32[$33 >> 2] = $32; //@line 37731
 $36 = $0 + 64 | 0; //@line 37732
 $37 = HEAP32[$36 >> 2] | 0; //@line 37733
 $38 = $37 + 1 | 0; //@line 37734
 HEAP32[$36 >> 2] = $38; //@line 37735
 $39 = $0 + 72 | 0; //@line 37736
 $40 = HEAP32[$39 >> 2] | 0; //@line 37737
 $41 = $40 + 1 | 0; //@line 37738
 HEAP32[$39 >> 2] = $41; //@line 37739
 return $29 | 0; //@line 37740
}
function __ZN8tinyxml28MemPoolTILi44EE5AllocEv($0) {
 $0 = $0 | 0;
 var $$015 = 0, $$pre2$i = 0, $1 = 0, $12 = 0, $14 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $$015$looptemp = 0;
 $1 = $0 + 56 | 0; //@line 37546
 $2 = HEAP32[$1 >> 2] | 0; //@line 37547
 if (!$2) {
  $4 = __Znwj(4092) | 0; //@line 37550
  _memset($4 | 0, 0, 4092) | 0; //@line 37551
  $5 = $0 + 4 | 0; //@line 37552
  $6 = $0 + 52 | 0; //@line 37553
  $7 = HEAP32[$6 >> 2] | 0; //@line 37554
  $8 = $0 + 48 | 0; //@line 37555
  if ((HEAP32[$8 >> 2] | 0) > ($7 | 0)) {
   $21 = $7; //@line 37560
   $23 = HEAP32[$5 >> 2] | 0; //@line 37560
  } else {
   $12 = ($7 << 1) + 2 | 0; //@line 37563
   $14 = __Znaj($12 >>> 0 > 1073741823 ? -1 : $12 << 2) | 0; //@line 37567
   $15 = HEAP32[$5 >> 2] | 0; //@line 37568
   _memcpy($14 | 0, $15 | 0, $7 << 2 | 0) | 0; //@line 37570
   if (($15 | 0) == 0 | ($15 | 0) == ($0 + 8 | 0)) {
    $$pre2$i = $7; //@line 37576
   } else {
    __ZdaPv($15); //@line 37578
    $$pre2$i = HEAP32[$6 >> 2] | 0; //@line 37580
   }
   HEAP32[$5 >> 2] = $14; //@line 37582
   HEAP32[$8 >> 2] = $12; //@line 37583
   $21 = $$pre2$i; //@line 37584
   $23 = $14; //@line 37584
  }
  HEAP32[$6 >> 2] = $21 + 1; //@line 37587
  HEAP32[$23 + ($21 << 2) >> 2] = $4; //@line 37589
  $$015 = 0; //@line 37590
  do {
   $$015$looptemp = $$015;
   $$015 = $$015 + 1 | 0; //@line 37592
   HEAP32[$4 + ($$015$looptemp * 44 | 0) >> 2] = $4 + ($$015 * 44 | 0); //@line 37595
  } while (($$015 | 0) != 92);
  HEAP32[$4 + 4048 >> 2] = 0; //@line 37604
  HEAP32[$1 >> 2] = $4; //@line 37605
  $29 = $4; //@line 37606
 } else {
  $29 = $2; //@line 37608
 }
 HEAP32[$1 >> 2] = HEAP32[$29 >> 2]; //@line 37611
 $30 = $0 + 60 | 0; //@line 37612
 $31 = HEAP32[$30 >> 2] | 0; //@line 37613
 $32 = $31 + 1 | 0; //@line 37614
 HEAP32[$30 >> 2] = $32; //@line 37615
 $33 = $0 + 68 | 0; //@line 37616
 if (($31 | 0) < (HEAP32[$33 >> 2] | 0)) {
  $36 = $0 + 64 | 0; //@line 37620
  $37 = HEAP32[$36 >> 2] | 0; //@line 37621
  $38 = $37 + 1 | 0; //@line 37622
  HEAP32[$36 >> 2] = $38; //@line 37623
  $39 = $0 + 72 | 0; //@line 37624
  $40 = HEAP32[$39 >> 2] | 0; //@line 37625
  $41 = $40 + 1 | 0; //@line 37626
  HEAP32[$39 >> 2] = $41; //@line 37627
  return $29 | 0; //@line 37628
 }
 HEAP32[$33 >> 2] = $32; //@line 37630
 $36 = $0 + 64 | 0; //@line 37631
 $37 = HEAP32[$36 >> 2] | 0; //@line 37632
 $38 = $37 + 1 | 0; //@line 37633
 HEAP32[$36 >> 2] = $38; //@line 37634
 $39 = $0 + 72 | 0; //@line 37635
 $40 = HEAP32[$39 >> 2] | 0; //@line 37636
 $41 = $40 + 1 | 0; //@line 37637
 HEAP32[$39 >> 2] = $41; //@line 37638
 return $29 | 0; //@line 37639
}
function __Z9ExtFSInitv() {
 var $$0$i = 0, $$0$i27 = 0, $$05$i = 0, $$05$i25 = 0, $$06$i = 0, $$06$i26 = 0, $$pn$i = 0, $$pn$i24 = 0, $0 = 0, $10 = 0, $14 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $3 = 0, $31 = 0, $4 = 0, $5 = 0, $8 = 0, $9 = 0;
 $0 = __Z9GetStringi(5e3) | 0; //@line 28551
 HEAP8[657358] = _strlen($0) | 0; //@line 28554
 $$05$i = $0; //@line 28555
 $$pn$i = 657358; //@line 28555
 L1 : while (1) {
  $$06$i = $$pn$i + 1 | 0; //@line 28557
  $3 = $$05$i + 1 | 0; //@line 28558
  $4 = HEAP8[$$05$i >> 0] | 0; //@line 28559
  switch ($4 << 24 >> 24) {
  case 0:
   {
    break L1;
    break;
   }
  case 58:
   {
    $$0$i = 47; //@line 28566
    break;
   }
  default:
   {
    $$0$i = $4; //@line 28570
   }
  }
  HEAP8[$$06$i >> 0] = $$0$i; //@line 28573
  $$05$i = $3; //@line 28574
  $$pn$i = $$06$i; //@line 28574
 }
 $5 = __Z9GetStringi(5001) | 0; //@line 28576
 HEAP8[657390] = _strlen($5) | 0; //@line 28579
 $$05$i25 = $5; //@line 28580
 $$pn$i24 = 657390; //@line 28580
 L7 : while (1) {
  $$06$i26 = $$pn$i24 + 1 | 0; //@line 28582
  $8 = $$05$i25 + 1 | 0; //@line 28583
  $9 = HEAP8[$$05$i25 >> 0] | 0; //@line 28584
  switch ($9 << 24 >> 24) {
  case 0:
   {
    break L7;
    break;
   }
  case 58:
   {
    $$0$i27 = 47; //@line 28591
    break;
   }
  default:
   {
    $$0$i27 = $9; //@line 28595
   }
  }
  HEAP8[$$06$i26 >> 0] = $$0$i27; //@line 28598
  $$05$i25 = $8; //@line 28599
  $$pn$i24 = $$06$i26; //@line 28599
 }
 $10 = __Znwj(60) | 0; //@line 28601
 HEAP32[30826] = $10; //@line 28602
 HEAP32[$10 + 4 >> 2] = 1; //@line 28604
 HEAP32[$10 + 8 >> 2] = 0; //@line 28606
 HEAP32[$10 + 12 >> 2] = 0; //@line 28608
 $14 = __Znaj(1) | 0; //@line 28609
 HEAP32[$10 + 16 >> 2] = $14; //@line 28611
 HEAP8[$14 >> 0] = 0; //@line 28612
 HEAP8[$10 + 20 >> 0] = 0; //@line 28614
 $17 = __Znwj(60) | 0; //@line 28615
 HEAP32[$10 >> 2] = $17; //@line 28616
 HEAP32[$17 >> 2] = 0; //@line 28617
 HEAP32[30827] = $17; //@line 28618
 HEAP32[$17 + 4 >> 2] = 2; //@line 28620
 HEAP32[$17 + 8 >> 2] = 1; //@line 28622
 HEAP32[$17 + 12 >> 2] = HEAP32[30826]; //@line 28625
 $22 = __Z9GetStringi(5001) | 0; //@line 28626
 $25 = __Znaj((_strlen($22) | 0) + 1 | 0) | 0; //@line 28629
 $26 = $17 + 16 | 0; //@line 28630
 HEAP32[$26 >> 2] = $25; //@line 28631
 _strcpy($25, $22) | 0; //@line 28632
 _strncpy($17 + 20 | 0, __Z25host_encoding_to_macromanPKc(HEAP32[$26 >> 2] | 0) | 0, 32) | 0; //@line 28636
 HEAP8[$17 + 51 >> 0] = 0; //@line 28638
 $31 = __Z15PrefsFindStringPKci(105378, 0) | 0; //@line 28639
 HEAP32[30828] = $31; //@line 28640
 if (!$31) {
  return;
 }
 if (_stat($31, 123316) | 0) {
  return;
 }
 if ((HEAP32[30832] & 61440 | 0) != 16384) {
  return;
 }
 HEAP8[657422] = 1; //@line 28656
 return;
}
function __ZN8tinyxml27StrPair18CollapseWhitespaceEv($0) {
 $0 = $0 | 0;
 var $$0$lcssa$i = 0, $$0$lcssa$i19$ph = 0, $$0$lcssa$i21 = 0, $$0$lcssa$ph = 0, $$01523 = 0, $$024 = 0, $$03$i = 0, $$03$i17 = 0, $$1 = 0, $$116 = 0, $1 = 0, $13 = 0, $16 = 0, $2 = 0, $21 = 0, $24 = 0, $3 = 0, $30 = 0, $31 = 0, $6 = 0, label = 0;
 $1 = $0 + 4 | 0; //@line 37435
 $2 = HEAP32[$1 >> 2] | 0; //@line 37436
 $3 = HEAP8[$2 >> 0] | 0; //@line 37437
 L1 : do {
  if ($3 << 24 >> 24 > -1) {
   $$03$i = $2; //@line 37441
   $6 = $3; //@line 37441
   do {
    if (!(_isspace($6 & 255) | 0)) {
     $$0$lcssa$i = $$03$i; //@line 37447
     label = 5; //@line 37448
     break L1;
    }
    $$03$i = $$03$i + 1 | 0; //@line 37451
    $6 = HEAP8[$$03$i >> 0] | 0; //@line 37452
   } while ($6 << 24 >> 24 > -1);
   HEAP32[$1 >> 2] = $$03$i; //@line 37460
   $$0$lcssa$i21 = $$03$i; //@line 37461
  } else {
   $$0$lcssa$i = $2; //@line 37463
   label = 5; //@line 37464
  }
 } while (0);
 if ((label | 0) == 5) {
  HEAP32[$1 >> 2] = $$0$lcssa$i; //@line 37468
  if (!$$0$lcssa$i) {
   return;
  } else {
   $$0$lcssa$i21 = $$0$lcssa$i; //@line 37473
  }
 }
 $13 = HEAP8[$$0$lcssa$i21 >> 0] | 0; //@line 37476
 if (!($13 << 24 >> 24)) {
  return;
 } else {
  $$01523 = $$0$lcssa$i21; //@line 37481
  $$024 = $$0$lcssa$i21; //@line 37481
  $16 = $13; //@line 37481
 }
 while (1) {
  if ($16 << 24 >> 24 > -1) {
   if (!(_isspace($16 & 255) | 0)) {
    $$1 = $$024; //@line 37490
    $$116 = $$01523; //@line 37490
    $30 = $16; //@line 37490
   } else {
    $$03$i17 = $$01523; //@line 37492
    $21 = $16; //@line 37492
    while (1) {
     if (!(_isspace($21 & 255) | 0)) {
      $$0$lcssa$i19$ph = $$03$i17; //@line 37498
      break;
     }
     $24 = $$03$i17 + 1 | 0; //@line 37501
     $21 = HEAP8[$24 >> 0] | 0; //@line 37502
     if ($21 << 24 >> 24 <= -1) {
      $$0$lcssa$i19$ph = $24; //@line 37507
      break;
     } else {
      $$03$i17 = $24; //@line 37505
     }
    }
    if (!(HEAP8[$$0$lcssa$i19$ph >> 0] | 0)) {
     $$0$lcssa$ph = $$024; //@line 37514
     break;
    }
    HEAP8[$$024 >> 0] = 32; //@line 37517
    $$1 = $$024 + 1 | 0; //@line 37520
    $$116 = $$0$lcssa$i19$ph; //@line 37520
    $30 = HEAP8[$$0$lcssa$i19$ph >> 0] | 0; //@line 37520
   }
  } else {
   $$1 = $$024; //@line 37523
   $$116 = $$01523; //@line 37523
   $30 = $16; //@line 37523
  }
  HEAP8[$$1 >> 0] = $30; //@line 37525
  $31 = $$1 + 1 | 0; //@line 37526
  $$01523 = $$116 + 1 | 0; //@line 37527
  $16 = HEAP8[$$01523 >> 0] | 0; //@line 37528
  if (!($16 << 24 >> 24)) {
   $$0$lcssa$ph = $31; //@line 37531
   break;
  } else {
   $$024 = $31; //@line 37534
  }
 }
 HEAP8[$$0$lcssa$ph >> 0] = 0; //@line 37537
 return;
}
function ___stpcpy($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa = 0, $$025$lcssa = 0, $$02536 = 0, $$026$lcssa = 0, $$02642 = 0, $$027$lcssa = 0, $$02741 = 0, $$029 = 0, $$037 = 0, $$1$ph = 0, $$128$ph = 0, $$12834 = 0, $$135 = 0, $11 = 0, $12 = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $24 = 0, $31 = 0, $34 = 0, $35 = 0, $9 = 0, label = 0;
 $2 = $1; //@line 62183
 L1 : do {
  if (!(($2 ^ $0) & 3)) {
   if (!($2 & 3)) {
    $$026$lcssa = $1; //@line 62193
    $$027$lcssa = $0; //@line 62193
   } else {
    $$02642 = $1; //@line 62195
    $$02741 = $0; //@line 62195
    while (1) {
     $9 = HEAP8[$$02642 >> 0] | 0; //@line 62197
     HEAP8[$$02741 >> 0] = $9; //@line 62198
     if (!($9 << 24 >> 24)) {
      $$029 = $$02741; //@line 62201
      break L1;
     }
     $11 = $$02642 + 1 | 0; //@line 62204
     $12 = $$02741 + 1 | 0; //@line 62205
     if (!($11 & 3)) {
      $$026$lcssa = $11; //@line 62210
      $$027$lcssa = $12; //@line 62210
      break;
     } else {
      $$02642 = $11; //@line 62213
      $$02741 = $12; //@line 62213
     }
    }
   }
   $16 = HEAP32[$$026$lcssa >> 2] | 0; //@line 62217
   if (!(($16 & -2139062144 ^ -2139062144) & $16 + -16843009)) {
    $$02536 = $$027$lcssa; //@line 62224
    $$037 = $$026$lcssa; //@line 62224
    $24 = $16; //@line 62224
    while (1) {
     $22 = $$037 + 4 | 0; //@line 62226
     $23 = $$02536 + 4 | 0; //@line 62227
     HEAP32[$$02536 >> 2] = $24; //@line 62228
     $24 = HEAP32[$22 >> 2] | 0; //@line 62229
     if (($24 & -2139062144 ^ -2139062144) & $24 + -16843009 | 0) {
      $$0$lcssa = $22; //@line 62238
      $$025$lcssa = $23; //@line 62238
      break;
     } else {
      $$02536 = $23; //@line 62236
      $$037 = $22; //@line 62236
     }
    }
   } else {
    $$0$lcssa = $$026$lcssa; //@line 62243
    $$025$lcssa = $$027$lcssa; //@line 62243
   }
   $$1$ph = $$0$lcssa; //@line 62245
   $$128$ph = $$025$lcssa; //@line 62245
   label = 8; //@line 62246
  } else {
   $$1$ph = $1; //@line 62248
   $$128$ph = $0; //@line 62248
   label = 8; //@line 62249
  }
 } while (0);
 if ((label | 0) == 8) {
  $31 = HEAP8[$$1$ph >> 0] | 0; //@line 62253
  HEAP8[$$128$ph >> 0] = $31; //@line 62254
  if (!($31 << 24 >> 24)) {
   $$029 = $$128$ph; //@line 62257
  } else {
   $$12834 = $$128$ph; //@line 62259
   $$135 = $$1$ph; //@line 62259
   while (1) {
    $$135 = $$135 + 1 | 0; //@line 62261
    $34 = $$12834 + 1 | 0; //@line 62262
    $35 = HEAP8[$$135 >> 0] | 0; //@line 62263
    HEAP8[$34 >> 0] = $35; //@line 62264
    if (!($35 << 24 >> 24)) {
     $$029 = $34; //@line 62267
     break;
    } else {
     $$12834 = $34; //@line 62270
    }
   }
  }
 }
 return $$029 | 0; //@line 62275
}
function _memcpy(dest, src, num) {
 dest = dest | 0;
 src = src | 0;
 num = num | 0;
 var ret = 0, aligned_dest_end = 0, block_aligned_dest_end = 0, dest_end = 0;
 if ((num | 0) >= 8192) {
  return _emscripten_memcpy_big(dest | 0, src | 0, num | 0) | 0; //@line 4414
 }
 ret = dest | 0; //@line 4417
 dest_end = dest + num | 0; //@line 4418
 if ((dest & 3) == (src & 3)) {
  while (dest & 3) {
   if (!num) return ret | 0; //@line 4422
   HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 4423
   dest = dest + 1 | 0; //@line 4424
   src = src + 1 | 0; //@line 4425
   num = num - 1 | 0; //@line 4426
  }
  aligned_dest_end = dest_end & -4 | 0; //@line 4428
  block_aligned_dest_end = aligned_dest_end - 64 | 0; //@line 4429
  while ((dest | 0) <= (block_aligned_dest_end | 0)) {
   HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 4431
   HEAP32[dest + 4 >> 2] = HEAP32[src + 4 >> 2]; //@line 4432
   HEAP32[dest + 8 >> 2] = HEAP32[src + 8 >> 2]; //@line 4433
   HEAP32[dest + 12 >> 2] = HEAP32[src + 12 >> 2]; //@line 4434
   HEAP32[dest + 16 >> 2] = HEAP32[src + 16 >> 2]; //@line 4435
   HEAP32[dest + 20 >> 2] = HEAP32[src + 20 >> 2]; //@line 4436
   HEAP32[dest + 24 >> 2] = HEAP32[src + 24 >> 2]; //@line 4437
   HEAP32[dest + 28 >> 2] = HEAP32[src + 28 >> 2]; //@line 4438
   HEAP32[dest + 32 >> 2] = HEAP32[src + 32 >> 2]; //@line 4439
   HEAP32[dest + 36 >> 2] = HEAP32[src + 36 >> 2]; //@line 4440
   HEAP32[dest + 40 >> 2] = HEAP32[src + 40 >> 2]; //@line 4441
   HEAP32[dest + 44 >> 2] = HEAP32[src + 44 >> 2]; //@line 4442
   HEAP32[dest + 48 >> 2] = HEAP32[src + 48 >> 2]; //@line 4443
   HEAP32[dest + 52 >> 2] = HEAP32[src + 52 >> 2]; //@line 4444
   HEAP32[dest + 56 >> 2] = HEAP32[src + 56 >> 2]; //@line 4445
   HEAP32[dest + 60 >> 2] = HEAP32[src + 60 >> 2]; //@line 4446
   dest = dest + 64 | 0; //@line 4447
   src = src + 64 | 0; //@line 4448
  }
  while ((dest | 0) < (aligned_dest_end | 0)) {
   HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 4451
   dest = dest + 4 | 0; //@line 4452
   src = src + 4 | 0; //@line 4453
  }
 } else {
  aligned_dest_end = dest_end - 4 | 0; //@line 4457
  while ((dest | 0) < (aligned_dest_end | 0)) {
   HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 4459
   HEAP8[dest + 1 >> 0] = HEAP8[src + 1 >> 0] | 0; //@line 4460
   HEAP8[dest + 2 >> 0] = HEAP8[src + 2 >> 0] | 0; //@line 4461
   HEAP8[dest + 3 >> 0] = HEAP8[src + 3 >> 0] | 0; //@line 4462
   dest = dest + 4 | 0; //@line 4463
   src = src + 4 | 0; //@line 4464
  }
 }
 while ((dest | 0) < (dest_end | 0)) {
  HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 4469
  dest = dest + 1 | 0; //@line 4470
  src = src + 1 | 0; //@line 4471
 }
 return ret | 0; //@line 4473
}
function _log10($0) {
 $0 = +$0;
 var $$0 = 0, $$0100 = 0, $$0101 = 0.0, $1 = 0, $15 = 0, $2 = 0, $21 = 0, $26 = 0, $28 = 0.0, $30 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $4 = 0, $50 = 0, $51 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $66 = 0.0, $71 = 0, label = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 62440
 $1 = HEAP32[tempDoublePtr >> 2] | 0; //@line 62440
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62441
 $4 = ($2 | 0) < 0; //@line 62443
 do {
  if ($4 | $2 >>> 0 < 1048576) {
   if (($1 | 0) == 0 & ($2 & 2147483647 | 0) == 0) {
    $$0101 = -1.0 / ($0 * $0); //@line 62454
    break;
   }
   if ($4) {
    $$0101 = ($0 - $0) / 0.0; //@line 62460
    break;
   } else {
    HEAPF64[tempDoublePtr >> 3] = $0 * 18014398509481984.0; //@line 62464
    $15 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62465
    $$0 = -1077; //@line 62466
    $$0100 = $15; //@line 62466
    $26 = HEAP32[tempDoublePtr >> 2] | 0; //@line 62466
    $71 = $15; //@line 62466
    label = 9; //@line 62467
    break;
   }
  } else {
   if ($2 >>> 0 > 2146435071) {
    $$0101 = $0; //@line 62473
   } else {
    if (($1 | 0) == 0 & 0 == 0 & ($2 | 0) == 1072693248) {
     $$0101 = 0.0; //@line 62481
    } else {
     $$0 = -1023; //@line 62483
     $$0100 = $2; //@line 62483
     $26 = $1; //@line 62483
     $71 = $2; //@line 62483
     label = 9; //@line 62484
    }
   }
  }
 } while (0);
 if ((label | 0) == 9) {
  $21 = $$0100 + 614242 | 0; //@line 62490
  HEAP32[tempDoublePtr >> 2] = $26; //@line 62495
  HEAP32[tempDoublePtr + 4 >> 2] = ($21 & 1048575) + 1072079006; //@line 62495
  $28 = +HEAPF64[tempDoublePtr >> 3] + -1.0; //@line 62496
  $30 = $28 * $28 * .5; //@line 62498
  $32 = $28 / ($28 + 2.0); //@line 62500
  $33 = $32 * $32; //@line 62501
  $34 = $33 * $33; //@line 62502
  HEAPF64[tempDoublePtr >> 3] = $28 - $30; //@line 62517
  $50 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62518
  HEAP32[tempDoublePtr >> 2] = 0; //@line 62519
  HEAP32[tempDoublePtr + 4 >> 2] = $50; //@line 62519
  $51 = +HEAPF64[tempDoublePtr >> 3]; //@line 62519
  $56 = $28 - $51 - $30 + $32 * ($30 + ($34 * ($34 * ($34 * .15313837699209373 + .22222198432149784) + .3999999999940942) + $33 * ($34 * ($34 * ($34 * .14798198605116586 + .1818357216161805) + .2857142874366239) + .6666666666666735))); //@line 62524
  $57 = $51 * .4342944818781689; //@line 62525
  $58 = +($$0 + ($21 >>> 20) | 0); //@line 62526
  $59 = $58 * .30102999566361177; //@line 62527
  $66 = $59 + $57; //@line 62534
  $$0101 = $66 + ($57 + ($59 - $66) + ($56 * .4342944818781689 + ($58 * 3.694239077158931e-13 + ($51 + $56) * 2.5082946711645275e-11))); //@line 62539
 }
 return +$$0101;
}
function __Z23rpc_message_recv_stringP13rpc_message_tPPc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$012$i$ph = 0, $$012$i19 = 0, $$014$i$ph = 0, $$014$i18 = 0, $$017 = 0, $$113$ph$i21 = 0, $$115$ph$i20 = 0, $14 = 0, $17 = 0, $2 = 0, $20 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 41865
 STACKTOP = STACKTOP + 16 | 0; //@line 41866
 $2 = sp; //@line 41867
 $$012$i$ph = 4; //@line 41868
 $$014$i$ph = $2; //@line 41868
 L1 : while (1) {
  while (1) {
   $4 = _recv(HEAP32[$0 >> 2] | 0, $$014$i$ph, $$012$i$ph, 0) | 0; //@line 41872
   if (($4 | 0) > 0) {
    break;
   }
   if (($4 | 0) != -1) {
    $$0 = -1001; //@line 41879
    label = 17; //@line 41880
    break L1;
   }
   if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
    $$0 = -1001; //@line 41887
    label = 17; //@line 41888
    break L1;
   }
  }
  $$012$i$ph = $$012$i$ph - $4 | 0; //@line 41892
  if (($$012$i$ph | 0) <= 0) {
   label = 7; //@line 41898
   break;
  } else {
   $$014$i$ph = $$014$i$ph + $4 | 0; //@line 41896
  }
 }
 if ((label | 0) == 7) {
  $14 = _ntohl(HEAP32[$2 >> 2] | 0) | 0; //@line 41904
  do {
   if (!$14) {
    $$017 = 0; //@line 41908
   } else {
    $17 = _malloc($14 + 1 | 0) | 0; //@line 41911
    if (!$17) {
     $$0 = -1002; //@line 41914
     STACKTOP = sp; //@line 41915
     return $$0 | 0; //@line 41915
    } else {
     $$012$i19 = $14; //@line 41917
     $$014$i18 = $17; //@line 41917
    }
    while (1) {
     $20 = _recv(HEAP32[$0 >> 2] | 0, $$014$i18, $$012$i19, 0) | 0; //@line 41921
     if (($20 | 0) > 0) {
      $$113$ph$i21 = $$012$i19 - $20 | 0; //@line 41926
      $$115$ph$i20 = $$014$i18 + $20 | 0; //@line 41926
     } else {
      if (($20 | 0) != -1) {
       break;
      }
      if ((HEAP32[(___errno_location() | 0) >> 2] | 0) == 4) {
       $$113$ph$i21 = $$012$i19; //@line 41936
       $$115$ph$i20 = $$014$i18; //@line 41936
      } else {
       break;
      }
     }
     if (($$113$ph$i21 | 0) > 0) {
      $$012$i19 = $$113$ph$i21; //@line 41943
      $$014$i18 = $$115$ph$i20; //@line 41943
     } else {
      label = 15; //@line 41945
      break;
     }
    }
    if ((label | 0) == 15) {
     HEAP8[$17 + $14 >> 0] = 0; //@line 41951
     $$017 = $17; //@line 41952
     break;
    }
    _free($17); //@line 41955
    $$0 = -1001; //@line 41956
    STACKTOP = sp; //@line 41957
    return $$0 | 0; //@line 41957
   }
  } while (0);
  HEAP32[$1 >> 2] = $$017; //@line 41960
  $$0 = 0; //@line 41961
  STACKTOP = sp; //@line 41962
  return $$0 | 0; //@line 41962
 } else if ((label | 0) == 17) {
  STACKTOP = sp; //@line 41965
  return $$0 | 0; //@line 41965
 }
 return 0; //@line 41967
}
function __Z11op_efc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit63 = 0, $$lobit64 = 0, $$lobit66 = 0, $$lobit67 = 0, $1 = 0, $10 = 0, $13 = 0, $18 = 0, $19 = 0, $22 = 0, $25 = 0, $27 = 0, $30 = 0, $35 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $48 = 0, $49 = 0, $50 = 0, $76 = 0, $77 = 0, $8 = 0;
 $1 = HEAP32[162769] | 0; //@line 23245
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 23248
 $8 = HEAPU8[$1 + 3 >> 0] | 0; //@line 23252
 $10 = $8 << 16 | $4 << 24; //@line 23254
 $13 = HEAPU8[$1 + 4 >> 0] | 0; //@line 23257
 $18 = HEAPU8[$1 + 5 >> 0] | 0; //@line 23262
 $19 = $10 | $13 << 8 | $18; //@line 23263
 $22 = HEAP32[651008 + ($4 >>> 4 << 2) >> 2] | 0; //@line 23266
 $25 = HEAP32[651008 + ($13 >>> 4 << 2) >> 2] | 0; //@line 23269
 $27 = 123608 + ($22 >>> 16 << 2) | 0; //@line 23271
 $30 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$27 >> 2] >> 2] & 127]($22) | 0; //@line 23274
 $35 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($25 >>> 16 << 2) >> 2] >> 2] & 127]($25) | 0; //@line 23279
 $38 = HEAP32[651008 + (($8 & 7) << 2) >> 2] | 0; //@line 23282
 $39 = $30 - $38 | 0; //@line 23283
 $$lobit63 = $30 >>> 31; //@line 23285
 $$lobit64 = $39 >>> 31; //@line 23286
 $40 = ($39 | 0) == 0; //@line 23287
 HEAP32[96442] = $40 & 1; //@line 23289
 HEAP32[96444] = ($38 >>> 31 | 0) != ($$lobit63 | 0) & ($$lobit64 | 0) != ($$lobit63 | 0) & 1; //@line 23294
 HEAP32[96441] = $30 >>> 0 < $38 >>> 0 & 1; //@line 23297
 HEAP32[96443] = $$lobit64; //@line 23298
 if ($40) {
  $48 = HEAP32[651008 + (($18 & 7) << 2) >> 2] | 0; //@line 23302
  $49 = $35 - $48 | 0; //@line 23303
  $$lobit66 = $35 >>> 31; //@line 23305
  $$lobit67 = $49 >>> 31; //@line 23306
  $50 = ($49 | 0) == 0; //@line 23307
  HEAP32[96442] = $50 & 1; //@line 23309
  HEAP32[96444] = ($48 >>> 31 | 0) != ($$lobit66 | 0) & ($$lobit67 | 0) != ($$lobit66 | 0) & 1; //@line 23314
  HEAP32[96441] = $35 >>> 0 < $48 >>> 0 & 1; //@line 23317
  HEAP32[96443] = $$lobit67; //@line 23318
  if ($50) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$27 >> 2] | 0) + 12 >> 2] & 31]($22, HEAP32[651008 + (($10 >>> 22 & 7) << 2) >> 2] | 0); //@line 23327
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$27 >> 2] | 0) + 12 >> 2] & 31]($22, HEAP32[651008 + (($19 >>> 6 & 7) << 2) >> 2] | 0); //@line 23335
   if (HEAP32[96442] | 0) {
    $76 = HEAP32[162769] | 0; //@line 23339
    $77 = $76 + 6 | 0; //@line 23340
    HEAP32[162769] = $77; //@line 23341
    return;
   }
  }
 }
 HEAP32[651008 + (($10 >>> 22 & 7) << 2) >> 2] = $30; //@line 23352
 HEAP32[651008 + (($19 >>> 6 & 7) << 2) >> 2] = $35; //@line 23353
 $76 = HEAP32[162769] | 0; //@line 23354
 $77 = $76 + 6 | 0; //@line 23355
 HEAP32[162769] = $77; //@line 23356
 return;
}
function __ZN8tinyxml211XMLDocumentC2EbNS_10WhitespaceE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $17 = 0, $22 = 0, $27 = 0, $3 = 0, $32 = 0, $4 = 0, $5 = 0;
 $3 = $1 & 1; //@line 41234
 $4 = $0 + 4 | 0; //@line 41235
 $5 = $4 + 4 | 0; //@line 41236
 HEAP32[$5 >> 2] = 0; //@line 41237
 HEAP32[$5 + 4 >> 2] = 0; //@line 41237
 HEAP32[$5 + 8 >> 2] = 0; //@line 41237
 HEAP32[$5 + 12 >> 2] = 0; //@line 41237
 HEAP32[$5 + 16 >> 2] = 0; //@line 41237
 HEAP32[$5 + 20 >> 2] = 0; //@line 41237
 HEAP32[$5 + 24 >> 2] = 0; //@line 41237
 HEAP32[$5 + 28 >> 2] = 0; //@line 41237
 HEAP32[$0 >> 2] = 2160; //@line 41238
 HEAP8[$0 + 44 >> 0] = 0; //@line 41240
 HEAP8[$0 + 45 >> 0] = $3; //@line 41242
 HEAP32[$0 + 48 >> 2] = 0; //@line 41244
 HEAP32[$0 + 52 >> 2] = $2; //@line 41246
 HEAP32[$0 + 56 >> 2] = 0; //@line 41248
 HEAP32[$0 + 60 >> 2] = 0; //@line 41250
 HEAP32[$0 + 64 >> 2] = 0; //@line 41252
 HEAP32[$0 + 68 >> 2] = 2336; //@line 41254
 HEAP32[$0 + 72 >> 2] = $0 + 76; //@line 41257
 HEAP32[$0 + 116 >> 2] = 10; //@line 41259
 $17 = $0 + 120 | 0; //@line 41260
 HEAP32[$17 >> 2] = 0; //@line 41261
 HEAP32[$17 + 4 >> 2] = 0; //@line 41261
 HEAP32[$17 + 8 >> 2] = 0; //@line 41261
 HEAP32[$17 + 12 >> 2] = 0; //@line 41261
 HEAP32[$17 + 16 >> 2] = 0; //@line 41261
 HEAP32[$17 + 20 >> 2] = 0; //@line 41261
 HEAP32[$0 + 144 >> 2] = 2304; //@line 41263
 HEAP32[$0 + 148 >> 2] = $0 + 152; //@line 41266
 HEAP32[$0 + 192 >> 2] = 10; //@line 41268
 $22 = $0 + 196 | 0; //@line 41269
 HEAP32[$22 >> 2] = 0; //@line 41270
 HEAP32[$22 + 4 >> 2] = 0; //@line 41270
 HEAP32[$22 + 8 >> 2] = 0; //@line 41270
 HEAP32[$22 + 12 >> 2] = 0; //@line 41270
 HEAP32[$22 + 16 >> 2] = 0; //@line 41270
 HEAP32[$22 + 20 >> 2] = 0; //@line 41270
 HEAP32[$0 + 220 >> 2] = 2272; //@line 41272
 HEAP32[$0 + 224 >> 2] = $0 + 228; //@line 41275
 HEAP32[$0 + 268 >> 2] = 10; //@line 41277
 $27 = $0 + 272 | 0; //@line 41278
 HEAP32[$27 >> 2] = 0; //@line 41279
 HEAP32[$27 + 4 >> 2] = 0; //@line 41279
 HEAP32[$27 + 8 >> 2] = 0; //@line 41279
 HEAP32[$27 + 12 >> 2] = 0; //@line 41279
 HEAP32[$27 + 16 >> 2] = 0; //@line 41279
 HEAP32[$27 + 20 >> 2] = 0; //@line 41279
 HEAP32[$0 + 296 >> 2] = 2240; //@line 41281
 HEAP32[$0 + 300 >> 2] = $0 + 304; //@line 41284
 HEAP32[$0 + 344 >> 2] = 10; //@line 41286
 $32 = $0 + 348 | 0; //@line 41287
 HEAP32[$32 >> 2] = 0; //@line 41288
 HEAP32[$32 + 4 >> 2] = 0; //@line 41288
 HEAP32[$32 + 8 >> 2] = 0; //@line 41288
 HEAP32[$32 + 12 >> 2] = 0; //@line 41288
 HEAP32[$32 + 16 >> 2] = 0; //@line 41288
 HEAP32[$32 + 20 >> 2] = 0; //@line 41288
 HEAP32[$4 >> 2] = $0; //@line 41289
 return;
}
function __Z9get_finfoPKcjjb($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0 = 0, $$04043 = 0, $10 = 0, $17 = 0, $23 = 0, $29 = 0, $35 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $58 = 0, $66 = 0, dest = 0, label = 0, stop = 0;
 $5 = 123608 + ($1 >>> 16 << 2) | 0; //@line 46467
 dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 24 >> 2] & 127]($1) | 0; //@line 46472
 stop = dest + 16 | 0; //@line 46472
 do {
  HEAP8[dest >> 0] = 0; //@line 46472
  dest = dest + 1 | 0; //@line 46472
 } while ((dest | 0) < (stop | 0));
 $10 = ($2 | 0) != 0; //@line 46473
 if ($10) {
  dest = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2) | 0; //@line 46481
  stop = dest + 16 | 0; //@line 46481
  do {
   HEAP8[dest >> 0] = 0; //@line 46481
   dest = dest + 1 | 0; //@line 46481
  } while ((dest | 0) < (stop | 0));
 }
 $17 = $1 + 8 | 0; //@line 46483
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($17, 256); //@line 46489
 $23 = $1 + 10 | 0; //@line 46490
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, -1); //@line 46496
 $29 = __ZL11open_helperPKcS0_i($0, 103798, 0) | 0; //@line 46497
 if (($29 | 0) > -1) {
  $35 = _read($29, FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 24 >> 2] & 127]($1) | 0, 16) | 0; //@line 46504
  if ($10) {
   $$0 = (_read($29, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2) | 0, 16) | 0) + $35 | 0; //@line 46514
  } else {
   $$0 = $35; //@line 46516
  }
  _close($29) | 0; //@line 46518
  if (($$0 | 0) > 15 | $3) {
   return;
  }
 } else {
  if ($3) {
   return;
  }
 }
 $44 = _strlen($0) | 0; //@line 46529
 $45 = $0 + $44 | 0; //@line 46530
 $$04043 = 0; //@line 46531
 $46 = 103805; //@line 46531
 while (1) {
  $47 = _strlen($46) | 0; //@line 46533
  if (($44 | 0) >= ($47 | 0)) {
   if (!(_strcmp($45 + (0 - $47) | 0, $46) | 0)) {
    break;
   }
  }
  $66 = $$04043 + 1 | 0; //@line 46544
  if (($66 | 0) == 57) {
   label = 13; //@line 46549
   break;
  } else {
   $$04043 = $66; //@line 46552
   $46 = HEAP32[4504 + ($66 * 12 | 0) >> 2] | 0; //@line 46552
  }
 }
 if ((label | 0) == 13) {
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($1, HEAP32[4504 + ($$04043 * 12 | 0) + 4 >> 2] | 0); //@line 46563
 $58 = $1 + 4 | 0; //@line 46564
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($58 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($58, HEAP32[4504 + ($$04043 * 12 | 0) + 8 >> 2] | 0); //@line 46572
 return;
}
function __Z9m68k_divljjtj($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $10 = 0, $12 = 0, $13 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $34 = 0, $37 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $55 = 0;
 if (!$1) {
  __Z9Exceptionij(5, $3); //@line 51830
  return;
 }
 $5 = $2 & 65535; //@line 51833
 $10 = ($5 & 1024 | 0) != 0; //@line 51838
 $12 = 651008 + (($5 >>> 12 & 7) << 2) | 0; //@line 51840
 $13 = HEAP32[$12 >> 2] | 0; //@line 51841
 if (!($5 & 2048)) {
  if ($10) {
   $46 = $13; //@line 51847
   $47 = HEAP32[651008 + (($5 & 7) << 2) >> 2] | 0; //@line 51847
  } else {
   $46 = $13; //@line 51849
   $47 = 0; //@line 51849
  }
  $48 = ___udivdi3($46 | 0, $47 | 0, $1 | 0, 0) | 0; //@line 51851
  $49 = tempRet0; //@line 51852
  if ($49 >>> 0 > 0 | ($49 | 0) == 0 & $48 >>> 0 > 4294967295) {
   HEAP32[96444] = 1; //@line 51859
   HEAP32[96443] = 1; //@line 51860
   HEAP32[96441] = 0; //@line 51861
   return;
  } else {
   $55 = ___uremdi3($46 | 0, $47 | 0, $1 | 0, 0) | 0; //@line 51864
   HEAP32[96444] = 0; //@line 51866
   HEAP32[96441] = 0; //@line 51867
   HEAP32[96442] = ($48 | 0) == 0 & 1; //@line 51870
   HEAP32[96443] = $48 >>> 31; //@line 51872
   HEAP32[651008 + (($5 & 7) << 2) >> 2] = $55; //@line 51875
   HEAP32[$12 >> 2] = $48; //@line 51876
   return;
  }
 } else {
  if ($10) {
   $21 = $13; //@line 51886
   $22 = HEAP32[651008 + (($5 & 7) << 2) >> 2] | 0; //@line 51886
  } else {
   $21 = $13; //@line 51888
   $22 = (($13 | 0) < 0) << 31 >> 31; //@line 51888
  }
  $20 = (($1 | 0) < 0) << 31 >> 31; //@line 51891
  $23 = ___remdi3($21 | 0, $22 | 0, $1 | 0, $20 | 0) | 0; //@line 51892
  $24 = tempRet0; //@line 51893
  $25 = ___divdi3($21 | 0, $22 | 0, $1 | 0, $20 | 0) | 0; //@line 51894
  $27 = _i64Add($25 | 0, tempRet0 | 0, -2147483648, -1) | 0; //@line 51896
  $28 = tempRet0; //@line 51897
  if ($28 >>> 0 < 4294967295 | ($28 | 0) == -1 & $27 >>> 0 < 0) {
   HEAP32[96444] = 1; //@line 51904
   HEAP32[96443] = 1; //@line 51905
   HEAP32[96441] = 0; //@line 51906
   return;
  } else {
   $34 = _bitshift64Lshr($21 | 0, $22 | 0, 63) | 0; //@line 51910
   $37 = _i64Subtract(0, 0, $23 | 0, $24 | 0) | 0; //@line 51913
   HEAP32[96444] = 0; //@line 51916
   HEAP32[96441] = 0; //@line 51917
   HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 51920
   HEAP32[96443] = $25 >>> 31; //@line 51922
   HEAP32[651008 + (($5 & 7) << 2) >> 2] = ($23 >>> 31 | 0) == ($34 | 0) ? $23 : $37; //@line 51925
   HEAP32[$12 >> 2] = $25; //@line 51926
   return;
  }
 }
}
function __Z11m68k_emulopj($0) {
 $0 = $0 | 0;
 var $1 = 0, $34 = 0, $35 = 0, $scevgep = 0, sp = 0;
 sp = STACKTOP; //@line 52068
 STACKTOP = STACKTOP + 80 | 0; //@line 52069
 $1 = sp; //@line 52070
 HEAP32[$1 >> 2] = HEAP32[162752]; //@line 52071
 HEAP32[$1 + 4 >> 2] = HEAP32[162753]; //@line 52071
 HEAP32[$1 + 8 >> 2] = HEAP32[162754]; //@line 52071
 HEAP32[$1 + 12 >> 2] = HEAP32[162755]; //@line 52071
 HEAP32[$1 + 16 >> 2] = HEAP32[162756]; //@line 52071
 HEAP32[$1 + 20 >> 2] = HEAP32[162757]; //@line 52071
 HEAP32[$1 + 24 >> 2] = HEAP32[162758]; //@line 52071
 HEAP32[$1 + 28 >> 2] = HEAP32[162759]; //@line 52071
 $scevgep = $1 + 32 | 0; //@line 52072
 HEAP32[$scevgep >> 2] = HEAP32[162760]; //@line 52073
 HEAP32[$scevgep + 4 >> 2] = HEAP32[162761]; //@line 52073
 HEAP32[$scevgep + 8 >> 2] = HEAP32[162762]; //@line 52073
 HEAP32[$scevgep + 12 >> 2] = HEAP32[162763]; //@line 52073
 HEAP32[$scevgep + 16 >> 2] = HEAP32[162764]; //@line 52073
 HEAP32[$scevgep + 20 >> 2] = HEAP32[162765]; //@line 52073
 HEAP32[$scevgep + 24 >> 2] = HEAP32[162766]; //@line 52073
 HEAP32[$scevgep + 28 >> 2] = HEAP32[162767]; //@line 52073
 $34 = (HEAP8[651119] << 14 | HEAP8[651118] << 15 | HEAP8[651120] << 13 | HEAP8[651121] << 12 | HEAP32[162772] << 8 | HEAP32[96445] << 4 | HEAP32[96443] << 3 | HEAP32[96442] << 2 | HEAP32[96444] << 1 | HEAP32[96441]) & 65535; //@line 52106
 HEAP16[325558] = $34; //@line 52107
 $35 = $1 + 64 | 0; //@line 52108
 HEAP16[$35 >> 1] = $34; //@line 52109
 __Z6EmulOptP13M68kRegisters($0 & 65535, $1); //@line 52111
 HEAP32[162752] = HEAP32[$1 >> 2]; //@line 52113
 HEAP32[162760] = HEAP32[$scevgep >> 2]; //@line 52115
 HEAP32[162753] = HEAP32[$1 + 4 >> 2]; //@line 52118
 HEAP32[162761] = HEAP32[$1 + 36 >> 2]; //@line 52121
 HEAP32[162754] = HEAP32[$1 + 8 >> 2]; //@line 52124
 HEAP32[162762] = HEAP32[$1 + 40 >> 2]; //@line 52127
 HEAP32[162755] = HEAP32[$1 + 12 >> 2]; //@line 52130
 HEAP32[162763] = HEAP32[$1 + 44 >> 2]; //@line 52133
 HEAP32[162756] = HEAP32[$1 + 16 >> 2]; //@line 52136
 HEAP32[162764] = HEAP32[$1 + 48 >> 2]; //@line 52139
 HEAP32[162757] = HEAP32[$1 + 20 >> 2]; //@line 52142
 HEAP32[162765] = HEAP32[$1 + 52 >> 2]; //@line 52145
 HEAP32[162758] = HEAP32[$1 + 24 >> 2]; //@line 52148
 HEAP32[162766] = HEAP32[$1 + 56 >> 2]; //@line 52151
 HEAP32[162759] = HEAP32[$1 + 28 >> 2]; //@line 52154
 HEAP32[162767] = HEAP32[$1 + 60 >> 2]; //@line 52157
 HEAP16[325558] = HEAP16[$35 >> 1] | 0; //@line 52159
 __Z10MakeFromSRv(); //@line 52160
 STACKTOP = sp; //@line 52161
 return;
}
function __Z12op_edfb_0_ffj($0) {
 $0 = $0 | 0;
 var $$046$lcssa = 0, $$04648 = 0, $$049 = 0, $1 = 0, $10 = 0, $14 = 0, $21 = 0, $23 = 0, $24 = 0, $27 = 0, $38 = 0, $39 = 0, $4 = 0, $41 = 0, $45 = 0, $50 = 0, $51 = 0, $59 = 0, $65 = 0, $66 = 0, $67 = 0, $74 = 0, $78 = 0, $79 = 0, $80 = 0, $9 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 46716
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 46719
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 46724
 $10 = $1 + 4 | 0; //@line 46725
 HEAP32[162769] = $10; //@line 46726
 $14 = (HEAP32[162768] | 0) + $10 - (HEAP32[162770] | 0) | 0; //@line 46731
 $21 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 46738
 HEAP32[162769] = $1 + 6; //@line 46740
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 46741
 $sext = $9 << 16; //@line 46742
 $24 = $sext >> 16; //@line 46743
 $27 = $sext >> 22; //@line 46746
 if (!($24 & 2048)) {
  $41 = $27 & 31; //@line 46749
 } else {
  $41 = HEAP32[651008 + (($27 & 7) << 2) >> 2] | 0; //@line 46754
 }
 if (!($24 & 32)) {
  $38 = $24; //@line 46759
 } else {
  $38 = HEAP32[651008 + (($24 & 7) << 2) >> 2] | 0; //@line 46764
 }
 $39 = $38 + 31 & 31; //@line 46767
 $45 = ($41 >> 31 & -536870912 | $41 >> 3) + $23 | 0; //@line 46772
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 46777
 $51 = $45 + 4 | 0; //@line 46778
 $59 = $41 & 7; //@line 46786
 $65 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($51) | 0) & 255) >>> (8 - $59 | 0) | $50 << $59) >>> ($39 ^ 31); //@line 46792
 $66 = 1 << $39; //@line 46793
 $67 = $65 & $66; //@line 46794
 HEAP32[96443] = ($67 | 0) != 0 & 1; //@line 46797
 HEAP32[96442] = ($65 | 0) == 0 & 1; //@line 46800
 HEAP32[96444] = 0; //@line 46801
 HEAP32[96441] = 0; //@line 46802
 if (!$67) {
  $$04648 = $41; //@line 46805
  $$049 = $66; //@line 46805
 } else {
  $$046$lcssa = $41; //@line 46807
  $78 = $4 >>> 4; //@line 46808
  $79 = $78 & 7; //@line 46809
  $80 = 651008 + ($79 << 2) | 0; //@line 46810
  HEAP32[$80 >> 2] = $$046$lcssa; //@line 46811
  return;
 }
 while (1) {
  $$049 = $$049 >>> 1; //@line 46815
  $74 = $$04648 + 1 | 0; //@line 46816
  if (!(($$049 | 0) != 0 & ($$049 & $65 | 0) == 0)) {
   $$046$lcssa = $74; //@line 46824
   break;
  } else {
   $$04648 = $74; //@line 46822
  }
 }
 $78 = $4 >>> 4; //@line 46828
 $79 = $78 & 7; //@line 46829
 $80 = 651008 + ($79 << 2) | 0; //@line 46830
 HEAP32[$80 >> 2] = $$046$lcssa; //@line 46831
 return;
}
function __Z16CDROMMountVolumePv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$023$i = 0, $$sroa$04$020 = 0, $1 = 0, $12 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $28 = 0, $32 = 0, $36 = 0, $38 = 0, $7 = 0, label = 0;
 $1 = HEAP32[28493] | 0; //@line 19847
 $2 = HEAP32[28494] | 0; //@line 19848
 if (($1 | 0) == ($2 | 0)) {
  $$0 = 0; //@line 19851
  return $$0 | 0; //@line 19852
 } else {
  $$sroa$04$020 = $1; //@line 19854
 }
 while (1) {
  if ((HEAP32[$$sroa$04$020 + 4 >> 2] | 0) == ($0 | 0)) {
   break;
  }
  $7 = $$sroa$04$020 + 840 | 0; //@line 19863
  if (($7 | 0) == ($2 | 0)) {
   $$0 = 0; //@line 19866
   label = 12; //@line 19867
   break;
  } else {
   $$sroa$04$020 = $7; //@line 19870
  }
 }
 if ((label | 0) == 12) {
  return $$0 | 0; //@line 19874
 }
 if (!(__Z17SysIsDiskInsertedPv($0) | 0)) {
  $$0 = 1; //@line 19878
  return $$0 | 0; //@line 19879
 }
 $12 = (HEAP32[$$sroa$04$020 + 836 >> 2] | 0) + 3 | 0; //@line 19883
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($12, 1); //@line 19889
 _memset($$sroa$04$020 + 22 | 0, 0, 804) | 0; //@line 19891
 $19 = $$sroa$04$020 + 826 | 0; //@line 19892
 HEAP8[$19 >> 0] = 0; //@line 19893
 $20 = $$sroa$04$020 + 827 | 0; //@line 19894
 HEAP8[$20 >> 0] = 0; //@line 19895
 $21 = $$sroa$04$020 + 828 | 0; //@line 19896
 HEAP8[$21 >> 0] = 0; //@line 19897
 $$023$i = 4; //@line 19898
 while (1) {
  if ((HEAP8[($$023$i | 2) + ($$sroa$04$020 + 22) >> 0] | 0) == -86) {
   label = 7; //@line 19905
   break;
  }
  $38 = $$023$i + 8 | 0; //@line 19908
  if (($38 | 0) < 804) {
   $$023$i = $38; //@line 19911
  } else {
   break;
  }
 }
 if ((label | 0) == 7) {
  $28 = HEAP8[$$023$i + 5 + ($$sroa$04$020 + 22) >> 0] | 0; //@line 19919
  HEAP8[$19 >> 0] = $28; //@line 19920
  HEAP8[$$sroa$04$020 + 829 >> 0] = $28; //@line 19922
  $32 = HEAP8[$$023$i + 6 + ($$sroa$04$020 + 22) >> 0] | 0; //@line 19925
  HEAP8[$20 >> 0] = $32; //@line 19926
  HEAP8[$$sroa$04$020 + 830 >> 0] = $32; //@line 19928
  $36 = HEAP8[$$023$i + 7 + ($$sroa$04$020 + 22) >> 0] | 0; //@line 19931
  HEAP8[$21 >> 0] = $36; //@line 19932
  HEAP8[$$sroa$04$020 + 831 >> 0] = $36; //@line 19934
 }
 __ZL18find_hfs_partitionR16cdrom_drive_info($$sroa$04$020); //@line 19936
 if (!(HEAP32[$$sroa$04$020 + 16 >> 2] | 0)) {
  if (!(HEAP8[$$sroa$04$020 + 21 >> 0] | 0)) {
   $$0 = 1; //@line 19945
   return $$0 | 0; //@line 19946
  }
 }
 HEAP8[$$sroa$04$020 + 20 >> 0] = 1; //@line 19950
 $$0 = 1; //@line 19951
 return $$0 | 0; //@line 19952
}
function __Z14TimerInterruptv() {
 var $$021 = 0, $0 = 0, $1 = 0, $10 = 0, $12 = 0, $2 = 0, $20 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $35 = 0, $36 = 0, $4 = 0, $46 = 0, $50 = 0, $55 = 0, $9 = 0, $tmpcast$byval_copy = 0, $tmpcast19$byval_copy = 0, sp = 0;
 sp = STACKTOP; //@line 13421
 STACKTOP = STACKTOP + 112 | 0; //@line 13422
 $tmpcast19$byval_copy = sp + 32 | 0; //@line 13423
 $tmpcast$byval_copy = sp + 24 | 0; //@line 13424
 $0 = sp + 16 | 0; //@line 13425
 $1 = sp + 8 | 0; //@line 13426
 $2 = sp; //@line 13427
 __Z18timer_current_timeR7timeval($0); //@line 13428
 $3 = $tmpcast19$byval_copy + 32 | 0; //@line 13429
 $4 = $tmpcast19$byval_copy + 36 | 0; //@line 13430
 $$021 = 0; //@line 13431
 do {
  if (HEAP8[112848 + ($$021 << 4) + 12 >> 0] | 0) {
   $9 = HEAP32[112848 + ($$021 << 4) >> 2] | 0; //@line 13438
   $10 = $9 + 4 | 0; //@line 13439
   $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 13441
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0) & 32768 | 0) {
    $20 = 112848 + ($$021 << 4) + 4 | 0; //@line 13450
    $25 = HEAP32[$20 + 4 >> 2] | 0; //@line 13455
    $26 = $1; //@line 13456
    HEAP32[$26 >> 2] = HEAP32[$20 >> 2]; //@line 13458
    HEAP32[$26 + 4 >> 2] = $25; //@line 13461
    $30 = $0; //@line 13462
    $35 = HEAP32[$30 + 4 >> 2] | 0; //@line 13467
    $36 = $2; //@line 13468
    HEAP32[$36 >> 2] = HEAP32[$30 >> 2]; //@line 13470
    HEAP32[$36 + 4 >> 2] = $35; //@line 13473
    HEAP32[$tmpcast$byval_copy >> 2] = HEAP32[$1 >> 2]; //@line 13474
    HEAP32[$tmpcast$byval_copy + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 13474
    HEAP32[$tmpcast19$byval_copy >> 2] = HEAP32[$2 >> 2]; //@line 13475
    HEAP32[$tmpcast19$byval_copy + 4 >> 2] = HEAP32[$2 + 4 >> 2]; //@line 13475
    if ((__Z14timer_cmp_time7timevalS_($tmpcast$byval_copy, $tmpcast19$byval_copy) | 0) < 0) {
     $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0) & 32767; //@line 13483
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $46); //@line 13487
     $50 = $9 + 6 | 0; //@line 13488
     $55 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($50 >>> 16 << 2) >> 2] >> 2] & 127]($50) | 0; //@line 13493
     if ($55 | 0) {
      HEAP32[$3 >> 2] = $55; //@line 13496
      HEAP32[$4 >> 2] = $9; //@line 13497
      _Execute68k($55, $tmpcast19$byval_copy); //@line 13498
     }
    }
   }
  }
  $$021 = $$021 + 1 | 0; //@line 13503
 } while (($$021 | 0) != 64);
 STACKTOP = sp; //@line 13511
 return;
}
function __Z12op_edf0_0_ffj($0) {
 $0 = $0 | 0;
 var $$045$lcssa = 0, $$04547 = 0, $$048 = 0, $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $65 = 0, $66 = 0, $73 = 0, $77 = 0, $78 = 0, $79 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 46203
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 46206
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 46211
 $11 = $2 + 4 | 0; //@line 46212
 HEAP32[162769] = $11; //@line 46213
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46215
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 46222
 HEAP32[162769] = $2 + 6; //@line 46224
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 46225
 $sext = $10 << 16; //@line 46226
 $23 = $sext >> 16; //@line 46227
 $26 = $sext >> 22; //@line 46230
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 46233
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 46238
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 46243
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 46248
 }
 $38 = $37 + 31 & 31; //@line 46251
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 46256
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 46261
 $50 = $44 + 4 | 0; //@line 46262
 $58 = $40 & 7; //@line 46270
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 46276
 $65 = 1 << $38; //@line 46277
 $66 = $64 & $65; //@line 46278
 HEAP32[96443] = ($66 | 0) != 0 & 1; //@line 46281
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 46284
 HEAP32[96444] = 0; //@line 46285
 HEAP32[96441] = 0; //@line 46286
 if (!$66) {
  $$04547 = $40; //@line 46289
  $$048 = $65; //@line 46289
 } else {
  $$045$lcssa = $40; //@line 46291
  $77 = $5 >>> 4; //@line 46292
  $78 = $77 & 7; //@line 46293
  $79 = 651008 + ($78 << 2) | 0; //@line 46294
  HEAP32[$79 >> 2] = $$045$lcssa; //@line 46295
  return;
 }
 while (1) {
  $$048 = $$048 >>> 1; //@line 46299
  $73 = $$04547 + 1 | 0; //@line 46300
  if (!(($$048 | 0) != 0 & ($$048 & $64 | 0) == 0)) {
   $$045$lcssa = $73; //@line 46308
   break;
  } else {
   $$04547 = $73; //@line 46306
  }
 }
 $77 = $5 >>> 4; //@line 46312
 $78 = $77 & 7; //@line 46313
 $79 = 651008 + ($78 << 2) | 0; //@line 46314
 HEAP32[$79 >> 2] = $$045$lcssa; //@line 46315
 return;
}
function _socket($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$017 = 0, $12 = 0, $3 = 0, $30 = 0, $4 = 0, $vararg_buffer = 0, $vararg_buffer11 = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, sp = 0;
 sp = STACKTOP; //@line 1850
 STACKTOP = STACKTOP + 96 | 0; //@line 1851
 $vararg_buffer11 = sp + 32 | 0; //@line 1852
 $vararg_buffer6 = sp + 16 | 0; //@line 1853
 $vararg_buffer2 = sp + 8 | 0; //@line 1854
 $vararg_buffer = sp; //@line 1855
 $3 = sp + 72 | 0; //@line 1856
 $4 = sp + 48 | 0; //@line 1857
 HEAP32[$3 >> 2] = $0; //@line 1858
 HEAP32[$3 + 4 >> 2] = $1; //@line 1860
 HEAP32[$3 + 8 >> 2] = $2; //@line 1862
 HEAP32[$3 + 12 >> 2] = 0; //@line 1864
 HEAP32[$3 + 16 >> 2] = 0; //@line 1866
 HEAP32[$3 + 20 >> 2] = 0; //@line 1868
 HEAP32[$vararg_buffer >> 2] = 1; //@line 1870
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 1872
 $12 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 1874
 do {
  if (($12 | 0) < 0) {
   if ((HEAP32[(___errno_location() | 0) >> 2] | 0) == 22) {
    if (!($1 & 526336)) {
     $$017 = $12; //@line 1885
     break;
    }
   } else {
    if (($1 & 526336 | 0) == 0 | (HEAP32[(___errno_location() | 0) >> 2] | 0) != 93) {
     $$017 = $12; //@line 1896
     break;
    }
   }
   HEAP32[$4 >> 2] = $0; //@line 1900
   HEAP32[$4 + 4 >> 2] = $1 & -526337; //@line 1903
   HEAP32[$4 + 8 >> 2] = $2; //@line 1905
   HEAP32[$4 + 12 >> 2] = 0; //@line 1907
   HEAP32[$4 + 16 >> 2] = 0; //@line 1909
   HEAP32[$4 + 20 >> 2] = 0; //@line 1911
   HEAP32[$vararg_buffer2 >> 2] = 1; //@line 1913
   HEAP32[$vararg_buffer2 + 4 >> 2] = $4; //@line 1915
   $30 = ___syscall_ret(___syscall102(102, $vararg_buffer2 | 0) | 0) | 0; //@line 1917
   if (($30 | 0) < 0) {
    $$017 = $30; //@line 1920
   } else {
    if ($1 & 524288 | 0) {
     HEAP32[$vararg_buffer6 >> 2] = $30; //@line 1925
     HEAP32[$vararg_buffer6 + 4 >> 2] = 2; //@line 1927
     HEAP32[$vararg_buffer6 + 8 >> 2] = 1; //@line 1929
     ___syscall221(221, $vararg_buffer6 | 0) | 0; //@line 1930
    }
    if (!($1 & 2048)) {
     $$017 = $30; //@line 1935
    } else {
     HEAP32[$vararg_buffer11 >> 2] = $30; //@line 1937
     HEAP32[$vararg_buffer11 + 4 >> 2] = 4; //@line 1939
     HEAP32[$vararg_buffer11 + 8 >> 2] = 2048; //@line 1941
     ___syscall221(221, $vararg_buffer11 | 0) | 0; //@line 1942
     $$017 = $30; //@line 1943
    }
   }
  } else {
   $$017 = $12; //@line 1947
  }
 } while (0);
 STACKTOP = sp; //@line 1950
 return $$017 | 0; //@line 1950
}
function __Z12op_edfa_0_ffj($0) {
 $0 = $0 | 0;
 var $$044$lcssa = 0, $$04447 = 0, $$048 = 0, $1 = 0, $22 = 0, $25 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0, $47 = 0, $52 = 0, $53 = 0, $61 = 0, $67 = 0, $68 = 0, $69 = 0, $76 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $sext45 = 0;
 $1 = HEAP32[162769] | 0; //@line 46584
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 46587
 $sext45 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 46606
 $22 = $sext45 >> 16; //@line 46607
 $25 = $sext45 >> 22; //@line 46610
 if (!($22 & 2048)) {
  $39 = $25 & 31; //@line 46613
 } else {
  $39 = HEAP32[651008 + (($25 & 7) << 2) >> 2] | 0; //@line 46618
 }
 if (!($22 & 32)) {
  $36 = $22; //@line 46623
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 46628
 }
 $37 = $36 + 31 & 31; //@line 46631
 $47 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) + ($39 >> 31 & -536870912 | $39 >> 3) | 0; //@line 46640
 $52 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($47 >>> 16 << 2) >> 2] >> 2] & 127]($47) | 0; //@line 46645
 $53 = $47 + 4 | 0; //@line 46646
 $61 = $39 & 7; //@line 46654
 $67 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($53) | 0) & 255) >>> (8 - $61 | 0) | $52 << $61) >>> ($37 ^ 31); //@line 46660
 $68 = 1 << $37; //@line 46661
 $69 = $67 & $68; //@line 46662
 HEAP32[96443] = ($69 | 0) != 0 & 1; //@line 46665
 HEAP32[96442] = ($67 | 0) == 0 & 1; //@line 46668
 HEAP32[96444] = 0; //@line 46669
 HEAP32[96441] = 0; //@line 46670
 if (!$69) {
  $$04447 = $39; //@line 46673
  $$048 = $68; //@line 46673
 } else {
  $$044$lcssa = $39; //@line 46675
  $80 = $4 >>> 4; //@line 46676
  $81 = $80 & 7; //@line 46677
  $82 = 651008 + ($81 << 2) | 0; //@line 46678
  HEAP32[$82 >> 2] = $$044$lcssa; //@line 46679
  $83 = HEAP32[162769] | 0; //@line 46680
  $84 = $83 + 6 | 0; //@line 46681
  HEAP32[162769] = $84; //@line 46682
  return;
 }
 while (1) {
  $$048 = $$048 >>> 1; //@line 46686
  $76 = $$04447 + 1 | 0; //@line 46687
  if (!(($$048 | 0) != 0 & ($$048 & $67 | 0) == 0)) {
   $$044$lcssa = $76; //@line 46695
   break;
  } else {
   $$04447 = $76; //@line 46693
  }
 }
 $80 = $4 >>> 4; //@line 46699
 $81 = $80 & 7; //@line 46700
 $82 = 651008 + ($81 << 2) | 0; //@line 46701
 HEAP32[$82 >> 2] = $$044$lcssa; //@line 46702
 $83 = HEAP32[162769] | 0; //@line 46703
 $84 = $83 + 6 | 0; //@line 46704
 HEAP32[162769] = $84; //@line 46705
 return;
}
function __Z12op_4e73_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink45 = 0, $10 = 0, $12 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0, $35 = 0, label = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 355
  return;
 }
 L3 : while (1) {
  $3 = HEAP32[162767] | 0; //@line 359
  $10 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0) & 65535; //@line 366
  $12 = (HEAP32[162767] | 0) + 2 | 0; //@line 368
  HEAP32[162767] = $12; //@line 369
  $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 374
  $19 = (HEAP32[162767] | 0) + 4 | 0; //@line 376
  HEAP32[162767] = $19; //@line 377
  $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 383
  $26 = HEAP32[162767] | 0; //@line 384
  HEAP32[162767] = $26 + 2; //@line 386
  switch ($25 >>> 12 & 15) {
  case 0:
   {
    break L3;
    break;
   }
  case 3:
  case 2:
   {
    label = 6; //@line 396
    break L3;
    break;
   }
  case 7:
   {
    label = 7; //@line 401
    break L3;
    break;
   }
  case 8:
   {
    label = 8; //@line 406
    break L3;
    break;
   }
  case 9:
   {
    label = 9; //@line 411
    break L3;
    break;
   }
  case 10:
   {
    label = 10; //@line 416
    break L3;
    break;
   }
  case 11:
   {
    $$sink45 = 86; //@line 421
    label = 11; //@line 422
    break L3;
    break;
   }
  case 1:
   {
    break;
   }
  default:
   {
    label = 4; //@line 430
    break L3;
   }
  }
  HEAP16[325558] = $10; //@line 434
  __Z10MakeFromSRv(); //@line 435
 }
 if ((label | 0) == 4) {
  __Z9Exceptionij(14, 0); //@line 438
  return;
 } else if ((label | 0) == 6) {
  $$sink45 = 6; //@line 442
  label = 11; //@line 443
 } else if ((label | 0) == 7) {
  $$sink45 = 54; //@line 446
  label = 11; //@line 447
 } else if ((label | 0) == 8) {
  $$sink45 = 52; //@line 450
  label = 11; //@line 451
 } else if ((label | 0) == 9) {
  $$sink45 = 14; //@line 454
  label = 11; //@line 455
 } else if ((label | 0) == 10) {
  $$sink45 = 26; //@line 458
  label = 11; //@line 459
 }
 if ((label | 0) == 11) {
  HEAP32[162767] = $$sink45 + $26; //@line 463
 }
 HEAP16[325558] = $10; //@line 465
 __Z10MakeFromSRv(); //@line 466
 $35 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($17) | 0; //@line 472
 HEAP32[162770] = $35; //@line 473
 HEAP32[162769] = $35; //@line 474
 HEAP32[162768] = $17; //@line 475
 return;
}
function __Z15DiskMountVolumePv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre$phiZ2D = 0, $$sroa$04$026 = 0, $1 = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $23 = 0, $37 = 0, $38 = 0, $4 = 0, $40 = 0, $42 = 0, $49 = 0, $7 = 0, label = 0;
 $1 = HEAP32[28489] | 0; //@line 18382
 $2 = HEAP32[28490] | 0; //@line 18383
 if (($1 | 0) == ($2 | 0)) {
  $$0 = 0; //@line 18386
  return $$0 | 0; //@line 18387
 } else {
  $$sroa$04$026 = $1; //@line 18389
 }
 while (1) {
  $4 = $$sroa$04$026 + 4 | 0; //@line 18392
  if ((HEAP32[$4 >> 2] | 0) == ($0 | 0)) {
   break;
  }
  $7 = $$sroa$04$026 + 24 | 0; //@line 18398
  if (($7 | 0) == ($2 | 0)) {
   $$0 = 0; //@line 18401
   label = 9; //@line 18402
   break;
  } else {
   $$sroa$04$026 = $7; //@line 18405
  }
 }
 if ((label | 0) == 9) {
  return $$0 | 0; //@line 18409
 }
 if (!(__Z17SysIsDiskInsertedPv($0) | 0)) {
  $$0 = 1; //@line 18413
  return $$0 | 0; //@line 18414
 }
 $12 = $$sroa$04$026 + 17 | 0; //@line 18418
 HEAP8[$12 >> 0] = (__Z13SysIsReadOnlyPv(HEAP32[$4 >> 2] | 0) | 0) & 1; //@line 18420
 $14 = $$sroa$04$026 + 20 | 0; //@line 18421
 $16 = (HEAP32[$14 >> 2] | 0) + 3 | 0; //@line 18423
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, 1); //@line 18429
 $23 = (HEAP32[$14 >> 2] | 0) + 2 | 0; //@line 18431
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, HEAP8[$12 >> 0] | 0 ? 255 : 0); //@line 18440
 __ZL18find_hfs_partitionR15disk_drive_info($$sroa$04$026); //@line 18441
 if (!(HEAP32[$$sroa$04$026 + 8 >> 2] | 0)) {
  $37 = (__Z14SysGetFileSizePv(HEAP32[$4 >> 2] | 0) | 0) / 512 | 0; //@line 18448
  $38 = $$sroa$04$026 + 12 | 0; //@line 18449
  HEAP32[$38 >> 2] = $37; //@line 18450
  $$pre$phiZ2D = $38; //@line 18451
  $42 = $37; //@line 18451
 } else {
  $$phi$trans$insert = $$sroa$04$026 + 12 | 0; //@line 18453
  $$pre$phiZ2D = $$phi$trans$insert; //@line 18455
  $42 = HEAP32[$$phi$trans$insert >> 2] | 0; //@line 18455
 }
 $40 = (HEAP32[$14 >> 2] | 0) + 18 | 0; //@line 18458
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($40, $42 & 65535); //@line 18465
 $49 = (HEAP32[$14 >> 2] | 0) + 20 | 0; //@line 18467
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($49 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($49, (HEAP32[$$pre$phiZ2D >> 2] | 0) >>> 16); //@line 18475
 HEAP8[$$sroa$04$026 + 16 >> 0] = 1; //@line 18477
 $$0 = 1; //@line 18478
 return $$0 | 0; //@line 18479
}
function __Z12op_edf9_0_ffj($0) {
 $0 = $0 | 0;
 var $$041$lcssa = 0, $$04143 = 0, $$044 = 0, $1 = 0, $28 = 0, $31 = 0, $4 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $54 = 0, $55 = 0, $63 = 0, $69 = 0, $70 = 0, $71 = 0, $78 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 46451
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 46454
 $sext = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 46478
 $28 = $sext >> 16; //@line 46479
 $31 = $sext >> 22; //@line 46482
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 46485
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 46490
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 46495
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 46500
 }
 $43 = $42 + 31 & 31; //@line 46503
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 46508
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($49 >>> 16 << 2) >> 2] >> 2] & 127]($49) | 0; //@line 46513
 $55 = $49 + 4 | 0; //@line 46514
 $63 = $45 & 7; //@line 46522
 $69 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255) >>> (8 - $63 | 0) | $54 << $63) >>> ($43 ^ 31); //@line 46528
 $70 = 1 << $43; //@line 46529
 $71 = $69 & $70; //@line 46530
 HEAP32[96443] = ($71 | 0) != 0 & 1; //@line 46533
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 46536
 HEAP32[96444] = 0; //@line 46537
 HEAP32[96441] = 0; //@line 46538
 if (!$71) {
  $$04143 = $45; //@line 46541
  $$044 = $70; //@line 46541
 } else {
  $$041$lcssa = $45; //@line 46543
  $82 = $4 >>> 4; //@line 46544
  $83 = $82 & 7; //@line 46545
  $84 = 651008 + ($83 << 2) | 0; //@line 46546
  HEAP32[$84 >> 2] = $$041$lcssa; //@line 46547
  $85 = HEAP32[162769] | 0; //@line 46548
  $86 = $85 + 8 | 0; //@line 46549
  HEAP32[162769] = $86; //@line 46550
  return;
 }
 while (1) {
  $$044 = $$044 >>> 1; //@line 46554
  $78 = $$04143 + 1 | 0; //@line 46555
  if (!(($$044 | 0) != 0 & ($$044 & $69 | 0) == 0)) {
   $$041$lcssa = $78; //@line 46563
   break;
  } else {
   $$04143 = $78; //@line 46561
  }
 }
 $82 = $4 >>> 4; //@line 46567
 $83 = $82 & 7; //@line 46568
 $84 = 651008 + ($83 << 2) | 0; //@line 46569
 HEAP32[$84 >> 2] = $$041$lcssa; //@line 46570
 $85 = HEAP32[162769] | 0; //@line 46571
 $86 = $85 + 8 | 0; //@line 46572
 HEAP32[162769] = $86; //@line 46573
 return;
}
function __Z12op_ede8_0_ffj($0) {
 $0 = $0 | 0;
 var $$045$lcssa = 0, $$04548 = 0, $$049 = 0, $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $65 = 0, $66 = 0, $73 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $sext46 = 0;
 $2 = HEAP32[162769] | 0; //@line 46074
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 46077
 $sext46 = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 46096
 $23 = $sext46 >> 16; //@line 46097
 $26 = $sext46 >> 22; //@line 46100
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 46103
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 46108
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 46113
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 46118
 }
 $38 = $37 + 31 & 31; //@line 46121
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 46126
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 46131
 $50 = $44 + 4 | 0; //@line 46132
 $58 = $40 & 7; //@line 46140
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 46146
 $65 = 1 << $38; //@line 46147
 $66 = $64 & $65; //@line 46148
 HEAP32[96443] = ($66 | 0) != 0 & 1; //@line 46151
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 46154
 HEAP32[96444] = 0; //@line 46155
 HEAP32[96441] = 0; //@line 46156
 if (!$66) {
  $$04548 = $40; //@line 46159
  $$049 = $65; //@line 46159
 } else {
  $$045$lcssa = $40; //@line 46161
  $77 = $5 >>> 4; //@line 46162
  $78 = $77 & 7; //@line 46163
  $79 = 651008 + ($78 << 2) | 0; //@line 46164
  HEAP32[$79 >> 2] = $$045$lcssa; //@line 46165
  $80 = HEAP32[162769] | 0; //@line 46166
  $81 = $80 + 6 | 0; //@line 46167
  HEAP32[162769] = $81; //@line 46168
  return;
 }
 while (1) {
  $$049 = $$049 >>> 1; //@line 46172
  $73 = $$04548 + 1 | 0; //@line 46173
  if (!(($$049 | 0) != 0 & ($$049 & $64 | 0) == 0)) {
   $$045$lcssa = $73; //@line 46181
   break;
  } else {
   $$04548 = $73; //@line 46179
  }
 }
 $77 = $5 >>> 4; //@line 46185
 $78 = $77 & 7; //@line 46186
 $79 = 651008 + ($78 << 2) | 0; //@line 46187
 HEAP32[$79 >> 2] = $$045$lcssa; //@line 46188
 $80 = HEAP32[162769] | 0; //@line 46189
 $81 = $80 + 6 | 0; //@line 46190
 HEAP32[162769] = $81; //@line 46191
 return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$037$off038 = 0, $$037$off039 = 0, $10 = 0, $14 = 0, $15 = 0, $19 = 0, $22 = 0, $23 = 0, $24 = 0, $31 = 0, $41 = 0, label = 0;
 do {
  if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, $4) | 0) {
   __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi(0, $1, $2, $3); //@line 4007
  } else {
   $10 = $0 + 8 | 0; //@line 4011
   if (!(__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 >> 2] | 0, $4) | 0)) {
    $41 = HEAP32[$10 >> 2] | 0; //@line 4013
    FUNCTION_TABLE_viiiii[HEAP32[(HEAP32[$41 >> 2] | 0) + 24 >> 2] & 3]($41, $1, $2, $3, $4); //@line 4017
    break;
   }
   $14 = $1 + 32 | 0; //@line 4023
   if ((HEAP32[$1 + 16 >> 2] | 0) != ($2 | 0)) {
    $15 = $1 + 20 | 0; //@line 4025
    if ((HEAP32[$15 >> 2] | 0) != ($2 | 0)) {
     HEAP32[$14 >> 2] = $3; //@line 4029
     $19 = $1 + 44 | 0; //@line 4030
     if ((HEAP32[$19 >> 2] | 0) == 4) {
      break;
     }
     $22 = $1 + 52 | 0; //@line 4036
     HEAP8[$22 >> 0] = 0; //@line 4037
     $23 = $1 + 53 | 0; //@line 4038
     HEAP8[$23 >> 0] = 0; //@line 4039
     $24 = HEAP32[$10 >> 2] | 0; //@line 4040
     FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[$24 >> 2] | 0) + 20 >> 2] & 3]($24, $1, $2, $2, 1, $4); //@line 4044
     if (!(HEAP8[$23 >> 0] | 0)) {
      $$037$off038 = 4; //@line 4048
      label = 11; //@line 4049
     } else {
      if (!(HEAP8[$22 >> 0] | 0)) {
       $$037$off038 = 3; //@line 4054
       label = 11; //@line 4055
      } else {
       $$037$off039 = 3; //@line 4057
      }
     }
     if ((label | 0) == 11) {
      HEAP32[$15 >> 2] = $2; //@line 4061
      $31 = $1 + 40 | 0; //@line 4062
      HEAP32[$31 >> 2] = (HEAP32[$31 >> 2] | 0) + 1; //@line 4065
      if ((HEAP32[$1 + 36 >> 2] | 0) == 1) {
       if ((HEAP32[$1 + 24 >> 2] | 0) == 2) {
        HEAP8[$1 + 54 >> 0] = 1; //@line 4075
        $$037$off039 = $$037$off038; //@line 4076
       } else {
        $$037$off039 = $$037$off038; //@line 4078
       }
      } else {
       $$037$off039 = $$037$off038; //@line 4081
      }
     }
     HEAP32[$19 >> 2] = $$037$off039; //@line 4084
     break;
    }
   }
   if (($3 | 0) == 1) {
    HEAP32[$14 >> 2] = 1; //@line 4090
   }
  }
 } while (0);
 return;
}
function __Z12op_edf8_0_ffj($0) {
 $0 = $0 | 0;
 var $$041$lcssa = 0, $$04144 = 0, $$045 = 0, $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $45 = 0, $46 = 0, $54 = 0, $60 = 0, $61 = 0, $62 = 0, $69 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $sext42 = 0;
 $1 = HEAP32[162769] | 0; //@line 46326
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 46329
 $sext42 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 46345
 $19 = $sext42 >> 16; //@line 46346
 $22 = $sext42 >> 22; //@line 46349
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 46352
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 46357
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 46362
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 46367
 }
 $34 = $33 + 31 & 31; //@line 46370
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 46375
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($40 >>> 16 << 2) >> 2] >> 2] & 127]($40) | 0; //@line 46380
 $46 = $40 + 4 | 0; //@line 46381
 $54 = $36 & 7; //@line 46389
 $60 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255) >>> (8 - $54 | 0) | $45 << $54) >>> ($34 ^ 31); //@line 46395
 $61 = 1 << $34; //@line 46396
 $62 = $60 & $61; //@line 46397
 HEAP32[96443] = ($62 | 0) != 0 & 1; //@line 46400
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 46403
 HEAP32[96444] = 0; //@line 46404
 HEAP32[96441] = 0; //@line 46405
 if (!$62) {
  $$04144 = $36; //@line 46408
  $$045 = $61; //@line 46408
 } else {
  $$041$lcssa = $36; //@line 46410
  $73 = $4 >>> 4; //@line 46411
  $74 = $73 & 7; //@line 46412
  $75 = 651008 + ($74 << 2) | 0; //@line 46413
  HEAP32[$75 >> 2] = $$041$lcssa; //@line 46414
  $76 = HEAP32[162769] | 0; //@line 46415
  $77 = $76 + 6 | 0; //@line 46416
  HEAP32[162769] = $77; //@line 46417
  return;
 }
 while (1) {
  $$045 = $$045 >>> 1; //@line 46421
  $69 = $$04144 + 1 | 0; //@line 46422
  if (!(($$045 | 0) != 0 & ($$045 & $60 | 0) == 0)) {
   $$041$lcssa = $69; //@line 46430
   break;
  } else {
   $$04144 = $69; //@line 46428
  }
 }
 $73 = $4 >>> 4; //@line 46434
 $74 = $73 & 7; //@line 46435
 $75 = 651008 + ($74 << 2) | 0; //@line 46436
 HEAP32[$75 >> 2] = $$041$lcssa; //@line 46437
 $76 = HEAP32[162769] | 0; //@line 46438
 $77 = $76 + 6 | 0; //@line 46439
 HEAP32[162769] = $77; //@line 46440
 return;
}
function __Z12op_edd0_0_ffj($0) {
 $0 = $0 | 0;
 var $$045$lcssa = 0, $$04547 = 0, $$048 = 0, $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $39 = 0, $40 = 0, $48 = 0, $5 = 0, $54 = 0, $55 = 0, $56 = 0, $63 = 0, $67 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 45956
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 45959
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 45967
 $13 = $sext >> 16; //@line 45968
 $16 = $sext >> 22; //@line 45971
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 45974
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 45979
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 45984
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 45989
 }
 $28 = $27 + 31 & 31; //@line 45992
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 45997
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($34 >>> 16 << 2) >> 2] >> 2] & 127]($34) | 0; //@line 46002
 $40 = $34 + 4 | 0; //@line 46003
 $48 = $30 & 7; //@line 46011
 $54 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255) >>> (8 - $48 | 0) | $39 << $48) >>> ($28 ^ 31); //@line 46017
 $55 = 1 << $28; //@line 46018
 $56 = $54 & $55; //@line 46019
 HEAP32[96443] = ($56 | 0) != 0 & 1; //@line 46022
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 46025
 HEAP32[96444] = 0; //@line 46026
 HEAP32[96441] = 0; //@line 46027
 if (!$56) {
  $$04547 = $30; //@line 46030
  $$048 = $55; //@line 46030
 } else {
  $$045$lcssa = $30; //@line 46032
  $67 = $5 >>> 4; //@line 46033
  $68 = $67 & 7; //@line 46034
  $69 = 651008 + ($68 << 2) | 0; //@line 46035
  HEAP32[$69 >> 2] = $$045$lcssa; //@line 46036
  $70 = HEAP32[162769] | 0; //@line 46037
  $71 = $70 + 4 | 0; //@line 46038
  HEAP32[162769] = $71; //@line 46039
  return;
 }
 while (1) {
  $$048 = $$048 >>> 1; //@line 46043
  $63 = $$04547 + 1 | 0; //@line 46044
  if (!(($$048 | 0) != 0 & ($$048 & $54 | 0) == 0)) {
   $$045$lcssa = $63; //@line 46052
   break;
  } else {
   $$04547 = $63; //@line 46050
  }
 }
 $67 = $5 >>> 4; //@line 46056
 $68 = $67 & 7; //@line 46057
 $69 = 651008 + ($68 << 2) | 0; //@line 46058
 HEAP32[$69 >> 2] = $$045$lcssa; //@line 46059
 $70 = HEAP32[162769] | 0; //@line 46060
 $71 = $70 + 4 | 0; //@line 46061
 HEAP32[162769] = $71; //@line 46062
 return;
}
function __ZN8tinyxml211XMLDocument8LoadFileEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$pre$phi$i$iZ2D = 0, $11 = 0, $13 = 0, $16 = 0, $19 = 0, $2 = 0, $23 = 0, $3 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $38 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $2 = $0 + 24 | 0; //@line 41299
 $3 = HEAP32[$2 >> 2] | 0; //@line 41300
 if (!$3) {
  $$pre$phi$i$iZ2D = $0 + 28 | 0; //@line 41304
 } else {
  $5 = $0 + 28 | 0; //@line 41306
  $7 = $3; //@line 41307
  do {
   $6 = $7 + 36 | 0; //@line 41309
   $8 = HEAP32[$6 >> 2] | 0; //@line 41310
   HEAP32[$2 >> 2] = $8; //@line 41311
   $11 = $7 + 32 | 0; //@line 41314
   if ((HEAP32[$5 >> 2] | 0) == ($7 | 0)) {
    $13 = HEAP32[$11 >> 2] | 0; //@line 41317
    HEAP32[$5 >> 2] = $13; //@line 41318
    $16 = $13; //@line 41320
   } else {
    $16 = HEAP32[$11 >> 2] | 0; //@line 41323
   }
   if (!$16) {
    $19 = $8; //@line 41327
   } else {
    HEAP32[$16 + 36 >> 2] = $8; //@line 41330
    $19 = HEAP32[$6 >> 2] | 0; //@line 41332
   }
   if ($19 | 0) {
    HEAP32[$19 + 32 >> 2] = $16; //@line 41337
   }
   HEAP32[$7 + 8 >> 2] = 0; //@line 41340
   $23 = HEAP32[$7 + 40 >> 2] | 0; //@line 41342
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$7 >> 2] | 0) + 64 >> 2] & 4095]($7); //@line 41346
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($23, $7); //@line 41350
   $7 = HEAP32[$2 >> 2] | 0; //@line 41351
  } while (($7 | 0) != 0);
  $$pre$phi$i$iZ2D = $5; //@line 41354
 }
 HEAP32[$$pre$phi$i$iZ2D >> 2] = 0; //@line 41361
 HEAP32[$2 >> 2] = 0; //@line 41362
 $32 = $0 + 48 | 0; //@line 41363
 HEAP32[$32 >> 2] = 0; //@line 41364
 $33 = $0 + 56 | 0; //@line 41365
 HEAP32[$33 >> 2] = 0; //@line 41366
 $34 = $0 + 60 | 0; //@line 41367
 HEAP32[$34 >> 2] = 0; //@line 41368
 $35 = $0 + 64 | 0; //@line 41369
 $36 = HEAP32[$35 >> 2] | 0; //@line 41370
 if ($36 | 0) {
  __ZdaPv($36); //@line 41373
 }
 HEAP32[$35 >> 2] = 0; //@line 41375
 $38 = _fopen($1, 97702) | 0; //@line 41376
 if (!$38) {
  HEAP32[$32 >> 2] = 3; //@line 41379
  HEAP32[$33 >> 2] = $1; //@line 41380
  HEAP32[$34 >> 2] = 0; //@line 41381
  $$0 = 3; //@line 41382
  return $$0 | 0; //@line 41383
 } else {
  __ZN8tinyxml211XMLDocument8LoadFileEP8_IO_FILE($0, $38) | 0; //@line 41385
  _fclose($38) | 0; //@line 41386
  $$0 = HEAP32[$32 >> 2] | 0; //@line 41388
  return $$0 | 0; //@line 41389
 }
 return 0; //@line 41391
}
function _vfprintf($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$ = 0, $$0 = 0, $$1 = 0, $13 = 0, $14 = 0, $19 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $29 = 0, $3 = 0, $35 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, dest = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 56229
 STACKTOP = STACKTOP + 224 | 0; //@line 56230
 $3 = sp + 120 | 0; //@line 56231
 $4 = sp + 80 | 0; //@line 56232
 $5 = sp; //@line 56233
 $6 = sp + 136 | 0; //@line 56234
 dest = $4; //@line 56235
 stop = dest + 40 | 0; //@line 56235
 do {
  HEAP32[dest >> 2] = 0; //@line 56235
  dest = dest + 4 | 0; //@line 56235
 } while ((dest | 0) < (stop | 0));
 HEAP32[$3 >> 2] = HEAP32[$2 >> 2]; //@line 56237
 if ((_printf_core(0, $1, $3, $5, $4) | 0) < 0) {
  $$0 = -1; //@line 56241
 } else {
  if ((HEAP32[$0 + 76 >> 2] | 0) > -1) {
   $40 = ___lockfile($0) | 0; //@line 56248
  } else {
   $40 = 0; //@line 56250
  }
  $13 = HEAP32[$0 >> 2] | 0; //@line 56252
  $14 = $13 & 32; //@line 56253
  if ((HEAP8[$0 + 74 >> 0] | 0) < 1) {
   HEAP32[$0 >> 2] = $13 & -33; //@line 56259
  }
  $19 = $0 + 48 | 0; //@line 56261
  if (!(HEAP32[$19 >> 2] | 0)) {
   $23 = $0 + 44 | 0; //@line 56265
   $24 = HEAP32[$23 >> 2] | 0; //@line 56266
   HEAP32[$23 >> 2] = $6; //@line 56267
   $25 = $0 + 28 | 0; //@line 56268
   HEAP32[$25 >> 2] = $6; //@line 56269
   $26 = $0 + 20 | 0; //@line 56270
   HEAP32[$26 >> 2] = $6; //@line 56271
   HEAP32[$19 >> 2] = 80; //@line 56272
   $28 = $0 + 16 | 0; //@line 56274
   HEAP32[$28 >> 2] = $6 + 80; //@line 56275
   $29 = _printf_core($0, $1, $3, $5, $4) | 0; //@line 56276
   if (!$24) {
    $$1 = $29; //@line 56279
   } else {
    FUNCTION_TABLE_iiii[HEAP32[$0 + 36 >> 2] & 15]($0, 0, 0) | 0; //@line 56283
    $$ = (HEAP32[$26 >> 2] | 0) == 0 ? -1 : $29; //@line 56286
    HEAP32[$23 >> 2] = $24; //@line 56287
    HEAP32[$19 >> 2] = 0; //@line 56288
    HEAP32[$28 >> 2] = 0; //@line 56289
    HEAP32[$25 >> 2] = 0; //@line 56290
    HEAP32[$26 >> 2] = 0; //@line 56291
    $$1 = $$; //@line 56292
   }
  } else {
   $$1 = _printf_core($0, $1, $3, $5, $4) | 0; //@line 56296
  }
  $35 = HEAP32[$0 >> 2] | 0; //@line 56298
  HEAP32[$0 >> 2] = $35 | $14; //@line 56303
  if ($40 | 0) {
   ___unlockfile($0); //@line 56306
  }
  $$0 = ($35 & 32 | 0) == 0 ? $$1 : -1; //@line 56308
 }
 STACKTOP = sp; //@line 56310
 return $$0 | 0; //@line 56310
}
function __Z15get_disp_ea_020jj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$ = 0, $$$2 = 0, $$1 = 0, $$135 = 0, $$2 = 0, $$4 = 0, $$sink = 0, $$sink44 = 0, $11 = 0, $19 = 0, $26 = 0, $30 = 0, $47 = 0, $5 = 0, $50 = 0, $51 = 0, $58 = 0, $61 = 0, $78 = 0, $81 = 0, $92 = 0;
 $5 = HEAP32[651008 + (($1 >>> 12 & 15) << 2) >> 2] | 0; //@line 51116
 $11 = (($1 & 2048 | 0) == 0 ? $5 << 16 >> 16 : $5) << ($1 >>> 9 & 3); //@line 51124
 if (!($1 & 256)) {
  $$sink = ($1 << 24 >> 24) + $0 | 0; //@line 51131
  $$sink44 = $11; //@line 51131
  $92 = $$sink + $$sink44 | 0; //@line 51132
  return $92 | 0; //@line 51133
 }
 $$ = ($1 & 128 | 0) == 0 ? $0 : 0; //@line 51137
 $$135 = ($1 & 64 | 0) == 0 ? $11 : 0; //@line 51140
 switch ($1 & 48) {
 case 32:
  {
   $19 = HEAP32[162769] | 0; //@line 51146
   $26 = (HEAPU8[$19 >> 0] | 0) << 8 | (HEAPU8[$19 + 1 >> 0] | 0); //@line 51153
   HEAP32[162769] = $19 + 2; //@line 51155
   $$2 = ($26 << 16 >> 16) + $$ | 0; //@line 51159
   break;
  }
 case 48:
  {
   $30 = HEAP32[162769] | 0; //@line 51163
   $47 = (HEAPU8[$30 + 1 >> 0] | 0) << 16 | (HEAPU8[$30 >> 0] | 0) << 24 | (HEAPU8[$30 + 2 >> 0] | 0) << 8 | (HEAPU8[$30 + 3 >> 0] | 0); //@line 51180
   HEAP32[162769] = $30 + 4; //@line 51182
   $$2 = $47 + $$ | 0; //@line 51184
   break;
  }
 default:
  {
   $$2 = $$; //@line 51188
  }
 }
 $50 = $1 & 3; //@line 51191
 switch ($1 & 3) {
 case 2:
  {
   $51 = HEAP32[162769] | 0; //@line 51196
   $58 = (HEAPU8[$51 >> 0] | 0) << 8 | (HEAPU8[$51 + 1 >> 0] | 0); //@line 51203
   HEAP32[162769] = $51 + 2; //@line 51205
   $$1 = $58 << 16 >> 16; //@line 51208
   break;
  }
 case 3:
  {
   $61 = HEAP32[162769] | 0; //@line 51212
   $78 = (HEAPU8[$61 + 1 >> 0] | 0) << 16 | (HEAPU8[$61 >> 0] | 0) << 24 | (HEAPU8[$61 + 2 >> 0] | 0) << 8 | (HEAPU8[$61 + 3 >> 0] | 0); //@line 51229
   HEAP32[162769] = $61 + 4; //@line 51231
   $$1 = $78; //@line 51232
   break;
  }
 default:
  {
   $$1 = 0; //@line 51236
  }
 }
 $81 = ($1 & 4 | 0) == 0; //@line 51240
 $$$2 = $$2 + ($81 ? $$135 : 0) | 0; //@line 51242
 if (!$50) {
  $$4 = $$$2; //@line 51245
 } else {
  $$4 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$$2 >>> 16 << 2) >> 2] >> 2] & 127]($$$2) | 0; //@line 51252
 }
 $$sink = $$4 + ($81 ? 0 : $$135) | 0; //@line 51256
 $$sink44 = $$1; //@line 51256
 $92 = $$sink + $$sink44 | 0; //@line 51257
 return $92 | 0; //@line 51258
}
function ___mo_lookup($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$090 = 0, $$094 = 0, $$4 = 0, $10 = 0, $13 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $31 = 0, $35 = 0, $4 = 0, $44 = 0, $46 = 0, $49 = 0, $53 = 0, $63 = 0, $7 = 0;
 $4 = (HEAP32[$0 >> 2] | 0) + 1794895138 | 0; //@line 59042
 $7 = _swapc(HEAP32[$0 + 8 >> 2] | 0, $4) | 0; //@line 59045
 $10 = _swapc(HEAP32[$0 + 12 >> 2] | 0, $4) | 0; //@line 59048
 $13 = _swapc(HEAP32[$0 + 16 >> 2] | 0, $4) | 0; //@line 59051
 L1 : do {
  if ($7 >>> 0 < $1 >>> 2 >>> 0) {
   $17 = $1 - ($7 << 2) | 0; //@line 59057
   if ($10 >>> 0 < $17 >>> 0 & $13 >>> 0 < $17 >>> 0) {
    if (!(($13 | $10) & 3)) {
     $23 = $10 >>> 2; //@line 59066
     $24 = $13 >>> 2; //@line 59067
     $$090 = 0; //@line 59068
     $$094 = $7; //@line 59068
     while (1) {
      $25 = $$094 >>> 1; //@line 59070
      $26 = $$090 + $25 | 0; //@line 59071
      $27 = $26 << 1; //@line 59072
      $28 = $27 + $23 | 0; //@line 59073
      $31 = _swapc(HEAP32[$0 + ($28 << 2) >> 2] | 0, $4) | 0; //@line 59076
      $35 = _swapc(HEAP32[$0 + ($28 + 1 << 2) >> 2] | 0, $4) | 0; //@line 59080
      if (!($35 >>> 0 < $1 >>> 0 & $31 >>> 0 < ($1 - $35 | 0) >>> 0)) {
       $$4 = 0; //@line 59086
       break L1;
      }
      if (HEAP8[$0 + ($35 + $31) >> 0] | 0) {
       $$4 = 0; //@line 59094
       break L1;
      }
      $44 = _strcmp($2, $0 + $35 | 0) | 0; //@line 59098
      if (!$44) {
       break;
      }
      $63 = ($44 | 0) < 0; //@line 59104
      if (($$094 | 0) == 1) {
       $$4 = 0; //@line 59109
       break L1;
      } else {
       $$090 = $63 ? $$090 : $26; //@line 59112
       $$094 = $63 ? $25 : $$094 - $25 | 0; //@line 59112
      }
     }
     $46 = $27 + $24 | 0; //@line 59115
     $49 = _swapc(HEAP32[$0 + ($46 << 2) >> 2] | 0, $4) | 0; //@line 59118
     $53 = _swapc(HEAP32[$0 + ($46 + 1 << 2) >> 2] | 0, $4) | 0; //@line 59122
     if ($53 >>> 0 < $1 >>> 0 & $49 >>> 0 < ($1 - $53 | 0) >>> 0) {
      $$4 = (HEAP8[$0 + ($53 + $49) >> 0] | 0) == 0 ? $0 + $53 | 0 : 0; //@line 59134
     } else {
      $$4 = 0; //@line 59136
     }
    } else {
     $$4 = 0; //@line 59139
    }
   } else {
    $$4 = 0; //@line 59142
   }
  } else {
   $$4 = 0; //@line 59145
  }
 } while (0);
 return $$4 | 0; //@line 59148
}
function _log1p($0) {
 $0 = +$0;
 var $$082 = 0.0, $$1 = 0.0, $$184 = 0.0, $$186 = 0.0, $$2 = 0.0, $14 = 0.0, $17 = 0, $19 = 0, $2 = 0, $21 = 0, $30 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $9 = 0, label = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 62284
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62285
 do {
  if (($2 | 0) < 0 | $2 >>> 0 < 1071284858) {
   if ($2 >>> 0 > 3220176895) {
    if ($0 == -1.0) {
     $$082 = -inf; //@line 62295
     break;
    }
    $$082 = ($0 - $0) / 0.0; //@line 62300
    break;
   } else {
    $9 = _bitshift64Shl($2 | 0, 0, 1) | 0; //@line 62303
    if ($9 >>> 0 < 2034237440) {
     $$082 = $0; //@line 62307
     break;
    }
    if ($2 >>> 0 < 3218259653) {
     $$1 = 0.0; //@line 62312
     $$184 = $0; //@line 62312
     $$2 = 0.0; //@line 62312
     label = 11; //@line 62313
     break;
    } else {
     label = 8; //@line 62316
     break;
    }
   }
  } else {
   if ($2 >>> 0 > 2146435071) {
    $$082 = $0; //@line 62323
   } else {
    label = 8; //@line 62325
   }
  }
 } while (0);
 if ((label | 0) == 8) {
  $14 = $0 + 1.0; //@line 62330
  HEAPF64[tempDoublePtr >> 3] = $14; //@line 62331
  $17 = (HEAP32[tempDoublePtr + 4 >> 2] | 0) + 614242 | 0; //@line 62333
  $19 = ($17 >>> 20) + -1023 | 0; //@line 62335
  if (($19 | 0) < 54) {
   $21 = ($19 | 0) > 1; //@line 62338
   $$186 = (($21 ? 1.0 : $0) - ($14 + ($21 ? -$0 : -1.0))) / $14; //@line 62345
  } else {
   $$186 = 0.0; //@line 62347
  }
  HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2]; //@line 62351
  HEAP32[tempDoublePtr + 4 >> 2] = ($17 & 1048575) + 1072079006; //@line 62351
  $$1 = +($19 | 0); //@line 62354
  $$184 = +HEAPF64[tempDoublePtr >> 3] + -1.0; //@line 62354
  $$2 = $$186; //@line 62354
  label = 11; //@line 62355
 }
 if ((label | 0) == 11) {
  $30 = $$184 * $$184 * .5; //@line 62359
  $32 = $$184 / ($$184 + 2.0); //@line 62361
  $33 = $32 * $32; //@line 62362
  $34 = $33 * $33; //@line 62363
  $$082 = $$1 * .6931471803691238 + ($$184 + ($$2 + $$1 * 1.9082149292705877e-10 + $32 * ($30 + ($34 * ($34 * ($34 * .15313837699209373 + .22222198432149784) + .3999999999940942) + $33 * ($34 * ($34 * ($34 * .14798198605116586 + .1818357216161805) + .2857142874366239) + .6666666666666735))) - $30)); //@line 62386
 }
 return +$$082;
}
function __Z12op_eff9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $101 = 0, $102 = 0, $28 = 0, $31 = 0, $4 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $51 = 0, $54 = 0, $55 = 0, $57 = 0, $61 = 0, $62 = 0, $63 = 0, $69 = 0, $75 = 0, $80 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 48141
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 48144
 $sext = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 48168
 $28 = $sext >> 16; //@line 48169
 $31 = $sext >> 22; //@line 48172
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 48175
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 48180
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 48185
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 48190
 }
 $43 = $42 + 31 & 31; //@line 48193
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 48198
 $51 = 123608 + ($49 >>> 16 << 2) | 0; //@line 48200
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$51 >> 2] >> 2] & 127]($49) | 0; //@line 48203
 $55 = $49 + 4 | 0; //@line 48204
 $57 = 123608 + ($55 >>> 16 << 2) | 0; //@line 48206
 $61 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$57 >> 2] | 0) + 8 >> 2] & 127]($55) | 0; //@line 48210
 $62 = $45 & 7; //@line 48211
 $63 = 8 - $62 | 0; //@line 48212
 HEAP32[96444] = 0; //@line 48215
 HEAP32[96441] = 0; //@line 48216
 $69 = HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] | 0; //@line 48220
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 48224
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 48227
 $75 = $69 << ($43 ^ 31); //@line 48228
 $80 = $62 + 1 + $43 | 0; //@line 48233
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] & 31]($49, ($80 >>> 0 > 31 ? 0 : -1 >>> $80 & $54) | $54 & -16777216 << $63 | $75 >>> $62); //@line 48243
 if ($80 >>> 0 <= 32) {
  $101 = HEAP32[162769] | 0; //@line 48246
  $102 = $101 + 8 | 0; //@line 48247
  HEAP32[162769] = $102; //@line 48248
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$57 >> 2] | 0) + 20 >> 2] & 31]($55, $75 << $63 | $61 & 255 & 255 >>> ($62 + -31 + $43 | 0)); //@line 48261
 $101 = HEAP32[162769] | 0; //@line 48262
 $102 = $101 + 8 | 0; //@line 48263
 HEAP32[162769] = $102; //@line 48264
 return;
}
function __Z12op_eff0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $5 = 0, $50 = 0, $52 = 0, $56 = 0, $57 = 0, $58 = 0, $64 = 0, $70 = 0, $75 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 47890
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 47893
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 47898
 $11 = $2 + 4 | 0; //@line 47899
 HEAP32[162769] = $11; //@line 47900
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47902
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 47909
 HEAP32[162769] = $2 + 6; //@line 47911
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 47912
 $sext = $10 << 16; //@line 47913
 $23 = $sext >> 16; //@line 47914
 $26 = $sext >> 22; //@line 47917
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 47920
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 47925
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 47930
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 47935
 }
 $38 = $37 + 31 & 31; //@line 47938
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 47943
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 47945
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 47948
 $50 = $44 + 4 | 0; //@line 47949
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 47951
 $56 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0; //@line 47955
 $57 = $40 & 7; //@line 47956
 $58 = 8 - $57 | 0; //@line 47957
 HEAP32[96444] = 0; //@line 47960
 HEAP32[96441] = 0; //@line 47961
 $64 = HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] | 0; //@line 47965
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 47969
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 47972
 $70 = $64 << ($38 ^ 31); //@line 47973
 $75 = $57 + 1 + $38 | 0; //@line 47978
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($75 >>> 0 > 31 ? 0 : -1 >>> $75 & $49) | $49 & -16777216 << $58 | $70 >>> $57); //@line 47988
 if ($75 >>> 0 <= 32) {
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $70 << $58 | $56 & 255 & 255 >>> ($57 + -31 + $38 | 0)); //@line 48003
 return;
}
function __Z12op_eaf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $102 = 0, $103 = 0, $28 = 0, $31 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $51 = 0, $54 = 0, $55 = 0, $57 = 0, $62 = 0, $63 = 0, $65 = 0, $68 = 0, $69 = 0, $77 = 0, $82 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 44256
 $sext = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 44283
 $28 = $sext >> 16; //@line 44284
 $31 = $sext >> 22; //@line 44287
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 44290
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 44295
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 44300
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 44305
 }
 $43 = $42 + 31 & 31; //@line 44308
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 44313
 $51 = 123608 + ($49 >>> 16 << 2) | 0; //@line 44315
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$51 >> 2] >> 2] & 127]($49) | 0; //@line 44318
 $55 = $49 + 4 | 0; //@line 44319
 $57 = 123608 + ($55 >>> 16 << 2) | 0; //@line 44321
 $62 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$57 >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255; //@line 44326
 $63 = $45 & 7; //@line 44327
 $65 = 8 - $63 | 0; //@line 44329
 $68 = $43 ^ 31; //@line 44332
 $69 = ($62 >>> $65 | $54 << $63) >>> $68; //@line 44333
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 44338
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 44341
 HEAP32[96444] = 0; //@line 44342
 HEAP32[96441] = 0; //@line 44343
 $77 = ~$69 << $68; //@line 44345
 $82 = $63 + 1 + $43 | 0; //@line 44350
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] & 31]($49, ($82 >>> 0 > 31 ? 0 : -1 >>> $82 & $54) | $54 & -16777216 << $65 | $77 >>> $63); //@line 44360
 if ($82 >>> 0 <= 32) {
  $102 = HEAP32[162769] | 0; //@line 44363
  $103 = $102 + 8 | 0; //@line 44364
  HEAP32[162769] = $103; //@line 44365
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$57 >> 2] | 0) + 20 >> 2] & 31]($55, $77 << $65 | $62 & 255 >>> ($63 + -31 + $43 | 0)); //@line 44377
 $102 = HEAP32[162769] | 0; //@line 44378
 $103 = $102 + 8 | 0; //@line 44379
 HEAP32[162769] = $103; //@line 44380
 return;
}
function __Z12op_eaf0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $63 = 0, $64 = 0, $72 = 0, $77 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 44003
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 44011
 $11 = $2 + 4 | 0; //@line 44012
 HEAP32[162769] = $11; //@line 44013
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 44015
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 44022
 HEAP32[162769] = $2 + 6; //@line 44024
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 44025
 $sext = $10 << 16; //@line 44026
 $23 = $sext >> 16; //@line 44027
 $26 = $sext >> 22; //@line 44030
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 44033
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 44038
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 44043
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 44048
 }
 $38 = $37 + 31 & 31; //@line 44051
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 44056
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 44058
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 44061
 $50 = $44 + 4 | 0; //@line 44062
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 44064
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 44069
 $58 = $40 & 7; //@line 44070
 $60 = 8 - $58 | 0; //@line 44072
 $63 = $38 ^ 31; //@line 44075
 $64 = ($57 >>> $60 | $49 << $58) >>> $63; //@line 44076
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 44081
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 44084
 HEAP32[96444] = 0; //@line 44085
 HEAP32[96441] = 0; //@line 44086
 $72 = ~$64 << $63; //@line 44088
 $77 = $58 + 1 + $38 | 0; //@line 44093
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($77 >>> 0 > 31 ? 0 : -1 >>> $77 & $49) | $49 & -16777216 << $60 | $72 >>> $58); //@line 44103
 if ($77 >>> 0 <= 32) {
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $72 << $60 | $57 & 255 >>> ($58 + -31 + $38 | 0)); //@line 44117
 return;
}
function __Z12op_eef9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $101 = 0, $102 = 0, $28 = 0, $31 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $51 = 0, $54 = 0, $55 = 0, $57 = 0, $62 = 0, $63 = 0, $65 = 0, $68 = 0, $69 = 0, $76 = 0, $82 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 47423
 $sext = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 47450
 $28 = $sext >> 16; //@line 47451
 $31 = $sext >> 22; //@line 47454
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 47457
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 47462
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 47467
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 47472
 }
 $43 = $42 + 31 & 31; //@line 47475
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 47480
 $51 = 123608 + ($49 >>> 16 << 2) | 0; //@line 47482
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$51 >> 2] >> 2] & 127]($49) | 0; //@line 47485
 $55 = $49 + 4 | 0; //@line 47486
 $57 = 123608 + ($55 >>> 16 << 2) | 0; //@line 47488
 $62 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$57 >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255; //@line 47493
 $63 = $45 & 7; //@line 47494
 $65 = 8 - $63 | 0; //@line 47496
 $68 = $43 ^ 31; //@line 47499
 $69 = ($62 >>> $65 | $54 << $63) >>> $68; //@line 47500
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 47505
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 47508
 HEAP32[96444] = 0; //@line 47509
 HEAP32[96441] = 0; //@line 47510
 $76 = -1 << $68; //@line 47511
 $82 = $63 + 1 + $43 | 0; //@line 47517
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] & 31]($49, $76 >>> $63 | $54 & -16777216 << $65 | ($82 >>> 0 > 31 ? 0 : -1 >>> $82 & $54)); //@line 47526
 if ($82 >>> 0 <= 32) {
  $101 = HEAP32[162769] | 0; //@line 47529
  $102 = $101 + 8 | 0; //@line 47530
  HEAP32[162769] = $102; //@line 47531
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$57 >> 2] | 0) + 20 >> 2] & 31]($55, $62 & 255 >>> ($63 + -31 + $43 | 0) | $76 << $65); //@line 47543
 $101 = HEAP32[162769] | 0; //@line 47544
 $102 = $101 + 8 | 0; //@line 47545
 HEAP32[162769] = $102; //@line 47546
 return;
}
function __Z12op_eef0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $63 = 0, $64 = 0, $71 = 0, $77 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 47172
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 47180
 $11 = $2 + 4 | 0; //@line 47181
 HEAP32[162769] = $11; //@line 47182
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47184
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 47191
 HEAP32[162769] = $2 + 6; //@line 47193
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 47194
 $sext = $10 << 16; //@line 47195
 $23 = $sext >> 16; //@line 47196
 $26 = $sext >> 22; //@line 47199
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 47202
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 47207
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 47212
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 47217
 }
 $38 = $37 + 31 & 31; //@line 47220
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 47225
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 47227
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 47230
 $50 = $44 + 4 | 0; //@line 47231
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 47233
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 47238
 $58 = $40 & 7; //@line 47239
 $60 = 8 - $58 | 0; //@line 47241
 $63 = $38 ^ 31; //@line 47244
 $64 = ($57 >>> $60 | $49 << $58) >>> $63; //@line 47245
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 47250
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 47253
 HEAP32[96444] = 0; //@line 47254
 HEAP32[96441] = 0; //@line 47255
 $71 = -1 << $63; //@line 47256
 $77 = $58 + 1 + $38 | 0; //@line 47262
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, $71 >>> $58 | $49 & -16777216 << $60 | ($77 >>> 0 > 31 ? 0 : -1 >>> $77 & $49)); //@line 47271
 if ($77 >>> 0 <= 32) {
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $57 & 255 >>> ($58 + -31 + $38 | 0) | $71 << $60); //@line 47285
 return;
}
function __Z12op_efe8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $5 = 0, $50 = 0, $52 = 0, $56 = 0, $57 = 0, $58 = 0, $64 = 0, $70 = 0, $75 = 0, $96 = 0, $97 = 0, $sext61 = 0;
 $2 = HEAP32[162769] | 0; //@line 47760
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 47763
 $sext61 = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 47782
 $23 = $sext61 >> 16; //@line 47783
 $26 = $sext61 >> 22; //@line 47786
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 47789
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 47794
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 47799
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 47804
 }
 $38 = $37 + 31 & 31; //@line 47807
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 47812
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 47814
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 47817
 $50 = $44 + 4 | 0; //@line 47818
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 47820
 $56 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0; //@line 47824
 $57 = $40 & 7; //@line 47825
 $58 = 8 - $57 | 0; //@line 47826
 HEAP32[96444] = 0; //@line 47829
 HEAP32[96441] = 0; //@line 47830
 $64 = HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] | 0; //@line 47834
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 47838
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 47841
 $70 = $64 << ($38 ^ 31); //@line 47842
 $75 = $57 + 1 + $38 | 0; //@line 47847
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($75 >>> 0 > 31 ? 0 : -1 >>> $75 & $49) | $49 & -16777216 << $58 | $70 >>> $57); //@line 47857
 if ($75 >>> 0 <= 32) {
  $96 = HEAP32[162769] | 0; //@line 47860
  $97 = $96 + 6 | 0; //@line 47861
  HEAP32[162769] = $97; //@line 47862
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $70 << $58 | $56 & 255 & 255 >>> ($57 + -31 + $38 | 0)); //@line 47875
 $96 = HEAP32[162769] | 0; //@line 47876
 $97 = $96 + 6 | 0; //@line 47877
 HEAP32[162769] = $97; //@line 47878
 return;
}
function __ZNK8tinyxml214XMLDeclaration12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$019$lcssa$i = 0, $$019$lcssa$i34 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, label = 0;
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 40 >> 2] & 127]($1) | 0)) {
  $33 = 0; //@line 39947
  return $33 | 0; //@line 39948
 }
 $12 = __ZN8tinyxml27StrPair6GetStrEv((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 40 >> 2] & 127]($1) | 0) + 12 | 0) | 0; //@line 39955
 $14 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39957
 if (($12 | 0) == ($14 | 0)) {
  $33 = 1; //@line 39960
  return $33 | 0; //@line 39961
 }
 $16 = HEAP8[$12 >> 0] | 0; //@line 39963
 do {
  if (!($16 << 24 >> 24)) {
   $$019$lcssa$i34 = $14; //@line 39967
   label = 8; //@line 39968
  } else {
   $$01923$i = $14; //@line 39970
   $$02022$i = $12; //@line 39970
   $$024$i = 0; //@line 39970
   $21 = $16; //@line 39970
   while (1) {
    $18 = HEAP8[$$01923$i >> 0] | 0; //@line 39972
    if (!(($$024$i | 0) != 2147483647 & ($18 << 24 >> 24 ? $21 << 24 >> 24 == $18 << 24 >> 24 : 0))) {
     $$0$lcssa$i = $$024$i; //@line 39979
     $$019$lcssa$i = $$01923$i; //@line 39979
     $30 = $21; //@line 39979
     break;
    }
    $$02022$i = $$02022$i + 1 | 0; //@line 39982
    $24 = $$01923$i + 1 | 0; //@line 39983
    $25 = $$024$i + 1 | 0; //@line 39984
    $21 = HEAP8[$$02022$i >> 0] | 0; //@line 39985
    if (!($21 << 24 >> 24)) {
     $$0$lcssa$i = $25; //@line 39988
     $$019$lcssa$i = $24; //@line 39988
     $30 = 0; //@line 39988
     break;
    } else {
     $$01923$i = $24; //@line 39991
     $$024$i = $25; //@line 39991
    }
   }
   if (($$0$lcssa$i | 0) == 2147483647) {
    $33 = 1; //@line 39996
    return $33 | 0; //@line 39997
   } else {
    if (!($30 << 24 >> 24)) {
     $$019$lcssa$i34 = $$019$lcssa$i; //@line 40001
     label = 8; //@line 40002
     break;
    } else {
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 8) {
  if (!(HEAP8[$$019$lcssa$i34 >> 0] | 0)) {
   $33 = 1; //@line 40014
   return $33 | 0; //@line 40015
  }
 }
 $33 = 0; //@line 40018
 return $33 | 0; //@line 40019
}
function __Z12op_eae8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $63 = 0, $64 = 0, $72 = 0, $77 = 0, $97 = 0, $98 = 0, $sext58 = 0;
 $2 = HEAP32[162769] | 0; //@line 43872
 $sext58 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 43894
 $23 = $sext58 >> 16; //@line 43895
 $26 = $sext58 >> 22; //@line 43898
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 43901
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 43906
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 43911
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 43916
 }
 $38 = $37 + 31 & 31; //@line 43919
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 43924
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 43926
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 43929
 $50 = $44 + 4 | 0; //@line 43930
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 43932
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 43937
 $58 = $40 & 7; //@line 43938
 $60 = 8 - $58 | 0; //@line 43940
 $63 = $38 ^ 31; //@line 43943
 $64 = ($57 >>> $60 | $49 << $58) >>> $63; //@line 43944
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 43949
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 43952
 HEAP32[96444] = 0; //@line 43953
 HEAP32[96441] = 0; //@line 43954
 $72 = ~$64 << $63; //@line 43956
 $77 = $58 + 1 + $38 | 0; //@line 43961
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($77 >>> 0 > 31 ? 0 : -1 >>> $77 & $49) | $49 & -16777216 << $60 | $72 >>> $58); //@line 43971
 if ($77 >>> 0 <= 32) {
  $97 = HEAP32[162769] | 0; //@line 43974
  $98 = $97 + 6 | 0; //@line 43975
  HEAP32[162769] = $98; //@line 43976
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $72 << $60 | $57 & 255 >>> ($58 + -31 + $38 | 0)); //@line 43988
 $97 = HEAP32[162769] | 0; //@line 43989
 $98 = $97 + 6 | 0; //@line 43990
 HEAP32[162769] = $98; //@line 43991
 return;
}
function __ZNK8tinyxml210XMLUnknown12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$019$lcssa$i = 0, $$019$lcssa$i34 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, label = 0;
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 44 >> 2] & 127]($1) | 0)) {
  $33 = 0; //@line 39204
  return $33 | 0; //@line 39205
 }
 $12 = __ZN8tinyxml27StrPair6GetStrEv((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 44 >> 2] & 127]($1) | 0) + 12 | 0) | 0; //@line 39212
 $14 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39214
 if (($12 | 0) == ($14 | 0)) {
  $33 = 1; //@line 39217
  return $33 | 0; //@line 39218
 }
 $16 = HEAP8[$12 >> 0] | 0; //@line 39220
 do {
  if (!($16 << 24 >> 24)) {
   $$019$lcssa$i34 = $14; //@line 39224
   label = 8; //@line 39225
  } else {
   $$01923$i = $14; //@line 39227
   $$02022$i = $12; //@line 39227
   $$024$i = 0; //@line 39227
   $21 = $16; //@line 39227
   while (1) {
    $18 = HEAP8[$$01923$i >> 0] | 0; //@line 39229
    if (!(($$024$i | 0) != 2147483647 & ($18 << 24 >> 24 ? $21 << 24 >> 24 == $18 << 24 >> 24 : 0))) {
     $$0$lcssa$i = $$024$i; //@line 39236
     $$019$lcssa$i = $$01923$i; //@line 39236
     $30 = $21; //@line 39236
     break;
    }
    $$02022$i = $$02022$i + 1 | 0; //@line 39239
    $24 = $$01923$i + 1 | 0; //@line 39240
    $25 = $$024$i + 1 | 0; //@line 39241
    $21 = HEAP8[$$02022$i >> 0] | 0; //@line 39242
    if (!($21 << 24 >> 24)) {
     $$0$lcssa$i = $25; //@line 39245
     $$019$lcssa$i = $24; //@line 39245
     $30 = 0; //@line 39245
     break;
    } else {
     $$01923$i = $24; //@line 39248
     $$024$i = $25; //@line 39248
    }
   }
   if (($$0$lcssa$i | 0) == 2147483647) {
    $33 = 1; //@line 39253
    return $33 | 0; //@line 39254
   } else {
    if (!($30 << 24 >> 24)) {
     $$019$lcssa$i34 = $$019$lcssa$i; //@line 39258
     label = 8; //@line 39259
     break;
    } else {
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 8) {
  if (!(HEAP8[$$019$lcssa$i34 >> 0] | 0)) {
   $33 = 1; //@line 39271
   return $33 | 0; //@line 39272
  }
 }
 $33 = 0; //@line 39275
 return $33 | 0; //@line 39276
}
function __ZNK8tinyxml210XMLComment12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$019$lcssa$i = 0, $$019$lcssa$i34 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, label = 0;
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 32 >> 2] & 127]($1) | 0)) {
  $33 = 0; //@line 39724
  return $33 | 0; //@line 39725
 }
 $12 = __ZN8tinyxml27StrPair6GetStrEv((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 32 >> 2] & 127]($1) | 0) + 12 | 0) | 0; //@line 39732
 $14 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39734
 if (($12 | 0) == ($14 | 0)) {
  $33 = 1; //@line 39737
  return $33 | 0; //@line 39738
 }
 $16 = HEAP8[$12 >> 0] | 0; //@line 39740
 do {
  if (!($16 << 24 >> 24)) {
   $$019$lcssa$i34 = $14; //@line 39744
   label = 8; //@line 39745
  } else {
   $$01923$i = $14; //@line 39747
   $$02022$i = $12; //@line 39747
   $$024$i = 0; //@line 39747
   $21 = $16; //@line 39747
   while (1) {
    $18 = HEAP8[$$01923$i >> 0] | 0; //@line 39749
    if (!(($$024$i | 0) != 2147483647 & ($18 << 24 >> 24 ? $21 << 24 >> 24 == $18 << 24 >> 24 : 0))) {
     $$0$lcssa$i = $$024$i; //@line 39756
     $$019$lcssa$i = $$01923$i; //@line 39756
     $30 = $21; //@line 39756
     break;
    }
    $$02022$i = $$02022$i + 1 | 0; //@line 39759
    $24 = $$01923$i + 1 | 0; //@line 39760
    $25 = $$024$i + 1 | 0; //@line 39761
    $21 = HEAP8[$$02022$i >> 0] | 0; //@line 39762
    if (!($21 << 24 >> 24)) {
     $$0$lcssa$i = $25; //@line 39765
     $$019$lcssa$i = $24; //@line 39765
     $30 = 0; //@line 39765
     break;
    } else {
     $$01923$i = $24; //@line 39768
     $$024$i = $25; //@line 39768
    }
   }
   if (($$0$lcssa$i | 0) == 2147483647) {
    $33 = 1; //@line 39773
    return $33 | 0; //@line 39774
   } else {
    if (!($30 << 24 >> 24)) {
     $$019$lcssa$i34 = $$019$lcssa$i; //@line 39778
     label = 8; //@line 39779
     break;
    } else {
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 8) {
  if (!(HEAP8[$$019$lcssa$i34 >> 0] | 0)) {
   $33 = 1; //@line 39791
   return $33 | 0; //@line 39792
  }
 }
 $33 = 0; //@line 39795
 return $33 | 0; //@line 39796
}
function __Z12op_eee8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $63 = 0, $64 = 0, $71 = 0, $77 = 0, $96 = 0, $97 = 0, $sext57 = 0;
 $2 = HEAP32[162769] | 0; //@line 47042
 $sext57 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 47064
 $23 = $sext57 >> 16; //@line 47065
 $26 = $sext57 >> 22; //@line 47068
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 47071
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 47076
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 47081
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 47086
 }
 $38 = $37 + 31 & 31; //@line 47089
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 47094
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 47096
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 47099
 $50 = $44 + 4 | 0; //@line 47100
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 47102
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 47107
 $58 = $40 & 7; //@line 47108
 $60 = 8 - $58 | 0; //@line 47110
 $63 = $38 ^ 31; //@line 47113
 $64 = ($57 >>> $60 | $49 << $58) >>> $63; //@line 47114
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 47119
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 47122
 HEAP32[96444] = 0; //@line 47123
 HEAP32[96441] = 0; //@line 47124
 $71 = -1 << $63; //@line 47125
 $77 = $58 + 1 + $38 | 0; //@line 47131
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, $71 >>> $58 | $49 & -16777216 << $60 | ($77 >>> 0 > 31 ? 0 : -1 >>> $77 & $49)); //@line 47140
 if ($77 >>> 0 <= 32) {
  $96 = HEAP32[162769] | 0; //@line 47143
  $97 = $96 + 6 | 0; //@line 47144
  HEAP32[162769] = $97; //@line 47145
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $57 & 255 >>> ($58 + -31 + $38 | 0) | $71 << $60); //@line 47157
 $96 = HEAP32[162769] | 0; //@line 47158
 $97 = $96 + 6 | 0; //@line 47159
 HEAP32[162769] = $97; //@line 47160
 return;
}
function __ZNK8tinyxml27XMLText12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$lcssa$i = 0, $$019$lcssa$i = 0, $$019$lcssa$i34 = 0, $$01923$i = 0, $$02022$i = 0, $$024$i = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, label = 0;
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 28 >> 2] & 127]($1) | 0)) {
  $33 = 0; //@line 39426
  return $33 | 0; //@line 39427
 }
 $12 = __ZN8tinyxml27StrPair6GetStrEv((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$1 >> 2] | 0) + 28 >> 2] & 127]($1) | 0) + 12 | 0) | 0; //@line 39434
 $14 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39436
 if (($12 | 0) == ($14 | 0)) {
  $33 = 1; //@line 39439
  return $33 | 0; //@line 39440
 }
 $16 = HEAP8[$12 >> 0] | 0; //@line 39442
 do {
  if (!($16 << 24 >> 24)) {
   $$019$lcssa$i34 = $14; //@line 39446
   label = 8; //@line 39447
  } else {
   $$01923$i = $14; //@line 39449
   $$02022$i = $12; //@line 39449
   $$024$i = 0; //@line 39449
   $21 = $16; //@line 39449
   while (1) {
    $18 = HEAP8[$$01923$i >> 0] | 0; //@line 39451
    if (!(($$024$i | 0) != 2147483647 & ($18 << 24 >> 24 ? $21 << 24 >> 24 == $18 << 24 >> 24 : 0))) {
     $$0$lcssa$i = $$024$i; //@line 39458
     $$019$lcssa$i = $$01923$i; //@line 39458
     $30 = $21; //@line 39458
     break;
    }
    $$02022$i = $$02022$i + 1 | 0; //@line 39461
    $24 = $$01923$i + 1 | 0; //@line 39462
    $25 = $$024$i + 1 | 0; //@line 39463
    $21 = HEAP8[$$02022$i >> 0] | 0; //@line 39464
    if (!($21 << 24 >> 24)) {
     $$0$lcssa$i = $25; //@line 39467
     $$019$lcssa$i = $24; //@line 39467
     $30 = 0; //@line 39467
     break;
    } else {
     $$01923$i = $24; //@line 39470
     $$024$i = $25; //@line 39470
    }
   }
   if (($$0$lcssa$i | 0) == 2147483647) {
    $33 = 1; //@line 39475
    return $33 | 0; //@line 39476
   } else {
    if (!($30 << 24 >> 24)) {
     $$019$lcssa$i34 = $$019$lcssa$i; //@line 39480
     label = 8; //@line 39481
     break;
    } else {
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 8) {
  if (!(HEAP8[$$019$lcssa$i34 >> 0] | 0)) {
   $33 = 1; //@line 39493
   return $33 | 0; //@line 39494
  }
 }
 $33 = 0; //@line 39497
 return $33 | 0; //@line 39498
}
function __Z12op_eff8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $48 = 0, $52 = 0, $53 = 0, $54 = 0, $60 = 0, $66 = 0, $71 = 0, $92 = 0, $93 = 0, $sext57 = 0;
 $1 = HEAP32[162769] | 0; //@line 48014
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 48017
 $sext57 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 48033
 $19 = $sext57 >> 16; //@line 48034
 $22 = $sext57 >> 22; //@line 48037
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 48040
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 48045
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 48050
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 48055
 }
 $34 = $33 + 31 & 31; //@line 48058
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 48063
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 48065
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$42 >> 2] >> 2] & 127]($40) | 0; //@line 48068
 $46 = $40 + 4 | 0; //@line 48069
 $48 = 123608 + ($46 >>> 16 << 2) | 0; //@line 48071
 $52 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$48 >> 2] | 0) + 8 >> 2] & 127]($46) | 0; //@line 48075
 $53 = $36 & 7; //@line 48076
 $54 = 8 - $53 | 0; //@line 48077
 HEAP32[96444] = 0; //@line 48080
 HEAP32[96441] = 0; //@line 48081
 $60 = HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] | 0; //@line 48085
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 48089
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 48092
 $66 = $60 << ($34 ^ 31); //@line 48093
 $71 = $53 + 1 + $34 | 0; //@line 48098
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 12 >> 2] & 31]($40, ($71 >>> 0 > 31 ? 0 : -1 >>> $71 & $45) | $45 & -16777216 << $54 | $66 >>> $53); //@line 48108
 if ($71 >>> 0 <= 32) {
  $92 = HEAP32[162769] | 0; //@line 48111
  $93 = $92 + 6 | 0; //@line 48112
  HEAP32[162769] = $93; //@line 48113
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$48 >> 2] | 0) + 20 >> 2] & 31]($46, $66 << $54 | $52 & 255 & 255 >>> ($53 + -31 + $34 | 0)); //@line 48126
 $92 = HEAP32[162769] | 0; //@line 48127
 $93 = $92 + 6 | 0; //@line 48128
 HEAP32[162769] = $93; //@line 48129
 return;
}
function __Z12op_eaf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $48 = 0, $53 = 0, $54 = 0, $56 = 0, $59 = 0, $60 = 0, $68 = 0, $73 = 0, $93 = 0, $94 = 0, $sext54 = 0;
 $1 = HEAP32[162769] | 0; //@line 44128
 $sext54 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 44147
 $19 = $sext54 >> 16; //@line 44148
 $22 = $sext54 >> 22; //@line 44151
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 44154
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 44159
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 44164
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 44169
 }
 $34 = $33 + 31 & 31; //@line 44172
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 44177
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 44179
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$42 >> 2] >> 2] & 127]($40) | 0; //@line 44182
 $46 = $40 + 4 | 0; //@line 44183
 $48 = 123608 + ($46 >>> 16 << 2) | 0; //@line 44185
 $53 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$48 >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255; //@line 44190
 $54 = $36 & 7; //@line 44191
 $56 = 8 - $54 | 0; //@line 44193
 $59 = $34 ^ 31; //@line 44196
 $60 = ($53 >>> $56 | $45 << $54) >>> $59; //@line 44197
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 44202
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 44205
 HEAP32[96444] = 0; //@line 44206
 HEAP32[96441] = 0; //@line 44207
 $68 = ~$60 << $59; //@line 44209
 $73 = $54 + 1 + $34 | 0; //@line 44214
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 12 >> 2] & 31]($40, ($73 >>> 0 > 31 ? 0 : -1 >>> $73 & $45) | $45 & -16777216 << $56 | $68 >>> $54); //@line 44224
 if ($73 >>> 0 <= 32) {
  $93 = HEAP32[162769] | 0; //@line 44227
  $94 = $93 + 6 | 0; //@line 44228
  HEAP32[162769] = $94; //@line 44229
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$48 >> 2] | 0) + 20 >> 2] & 31]($46, $68 << $56 | $53 & 255 >>> ($54 + -31 + $34 | 0)); //@line 44241
 $93 = HEAP32[162769] | 0; //@line 44242
 $94 = $93 + 6 | 0; //@line 44243
 HEAP32[162769] = $94; //@line 44244
 return;
}
function __Z12op_eef8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $48 = 0, $53 = 0, $54 = 0, $56 = 0, $59 = 0, $60 = 0, $67 = 0, $73 = 0, $92 = 0, $93 = 0, $sext53 = 0;
 $1 = HEAP32[162769] | 0; //@line 47296
 $sext53 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 47315
 $19 = $sext53 >> 16; //@line 47316
 $22 = $sext53 >> 22; //@line 47319
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 47322
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 47327
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 47332
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 47337
 }
 $34 = $33 + 31 & 31; //@line 47340
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 47345
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 47347
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$42 >> 2] >> 2] & 127]($40) | 0; //@line 47350
 $46 = $40 + 4 | 0; //@line 47351
 $48 = 123608 + ($46 >>> 16 << 2) | 0; //@line 47353
 $53 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$48 >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255; //@line 47358
 $54 = $36 & 7; //@line 47359
 $56 = 8 - $54 | 0; //@line 47361
 $59 = $34 ^ 31; //@line 47364
 $60 = ($53 >>> $56 | $45 << $54) >>> $59; //@line 47365
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 47370
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 47373
 HEAP32[96444] = 0; //@line 47374
 HEAP32[96441] = 0; //@line 47375
 $67 = -1 << $59; //@line 47376
 $73 = $54 + 1 + $34 | 0; //@line 47382
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 12 >> 2] & 31]($40, $67 >>> $54 | $45 & -16777216 << $56 | ($73 >>> 0 > 31 ? 0 : -1 >>> $73 & $45)); //@line 47391
 if ($73 >>> 0 <= 32) {
  $92 = HEAP32[162769] | 0; //@line 47394
  $93 = $92 + 6 | 0; //@line 47395
  HEAP32[162769] = $93; //@line 47396
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$48 >> 2] | 0) + 20 >> 2] & 31]($46, $53 & 255 >>> ($54 + -31 + $34 | 0) | $67 << $56); //@line 47408
 $92 = HEAP32[162769] | 0; //@line 47409
 $93 = $92 + 6 | 0; //@line 47410
 HEAP32[162769] = $93; //@line 47411
 return;
}
function __Z12op_efd0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0, $39 = 0, $40 = 0, $42 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $54 = 0, $60 = 0, $65 = 0, $86 = 0, $87 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 47640
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 47643
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 47651
 $13 = $sext >> 16; //@line 47652
 $16 = $sext >> 22; //@line 47655
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 47658
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 47663
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 47668
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 47673
 }
 $28 = $27 + 31 & 31; //@line 47676
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 47681
 $36 = 123608 + ($34 >>> 16 << 2) | 0; //@line 47683
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$36 >> 2] >> 2] & 127]($34) | 0; //@line 47686
 $40 = $34 + 4 | 0; //@line 47687
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 47689
 $46 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0; //@line 47693
 $47 = $30 & 7; //@line 47694
 $48 = 8 - $47 | 0; //@line 47695
 HEAP32[96444] = 0; //@line 47698
 HEAP32[96441] = 0; //@line 47699
 $54 = HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] | 0; //@line 47703
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 47707
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 47710
 $60 = $54 << ($28 ^ 31); //@line 47711
 $65 = $47 + 1 + $28 | 0; //@line 47716
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$36 >> 2] | 0) + 12 >> 2] & 31]($34, ($65 >>> 0 > 31 ? 0 : -1 >>> $65 & $39) | $39 & -16777216 << $48 | $60 >>> $47); //@line 47726
 if ($65 >>> 0 <= 32) {
  $86 = HEAP32[162769] | 0; //@line 47729
  $87 = $86 + 4 | 0; //@line 47730
  HEAP32[162769] = $87; //@line 47731
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 20 >> 2] & 31]($40, $60 << $48 | $46 & 255 & 255 >>> ($47 + -31 + $28 | 0)); //@line 47744
 $86 = HEAP32[162769] | 0; //@line 47745
 $87 = $86 + 4 | 0; //@line 47746
 HEAP32[162769] = $87; //@line 47747
 return;
}
function __Z12op_ead0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0, $39 = 0, $40 = 0, $42 = 0, $47 = 0, $48 = 0, $50 = 0, $53 = 0, $54 = 0, $62 = 0, $67 = 0, $87 = 0, $88 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 43751
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 43762
 $13 = $sext >> 16; //@line 43763
 $16 = $sext >> 22; //@line 43766
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 43769
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 43774
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 43779
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 43784
 }
 $28 = $27 + 31 & 31; //@line 43787
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 43792
 $36 = 123608 + ($34 >>> 16 << 2) | 0; //@line 43794
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$36 >> 2] >> 2] & 127]($34) | 0; //@line 43797
 $40 = $34 + 4 | 0; //@line 43798
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 43800
 $47 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255; //@line 43805
 $48 = $30 & 7; //@line 43806
 $50 = 8 - $48 | 0; //@line 43808
 $53 = $28 ^ 31; //@line 43811
 $54 = ($47 >>> $50 | $39 << $48) >>> $53; //@line 43812
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 43817
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 43820
 HEAP32[96444] = 0; //@line 43821
 HEAP32[96441] = 0; //@line 43822
 $62 = ~$54 << $53; //@line 43824
 $67 = $48 + 1 + $28 | 0; //@line 43829
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$36 >> 2] | 0) + 12 >> 2] & 31]($34, ($67 >>> 0 > 31 ? 0 : -1 >>> $67 & $39) | $39 & -16777216 << $50 | $62 >>> $48); //@line 43839
 if ($67 >>> 0 <= 32) {
  $87 = HEAP32[162769] | 0; //@line 43842
  $88 = $87 + 4 | 0; //@line 43843
  HEAP32[162769] = $88; //@line 43844
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 20 >> 2] & 31]($40, $62 << $50 | $47 & 255 >>> ($48 + -31 + $28 | 0)); //@line 43856
 $87 = HEAP32[162769] | 0; //@line 43857
 $88 = $87 + 4 | 0; //@line 43858
 HEAP32[162769] = $88; //@line 43859
 return;
}
function __Z12op_eed0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0, $39 = 0, $40 = 0, $42 = 0, $47 = 0, $48 = 0, $50 = 0, $53 = 0, $54 = 0, $61 = 0, $67 = 0, $86 = 0, $87 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 46922
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 46933
 $13 = $sext >> 16; //@line 46934
 $16 = $sext >> 22; //@line 46937
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 46940
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 46945
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 46950
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 46955
 }
 $28 = $27 + 31 & 31; //@line 46958
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 46963
 $36 = 123608 + ($34 >>> 16 << 2) | 0; //@line 46965
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$36 >> 2] >> 2] & 127]($34) | 0; //@line 46968
 $40 = $34 + 4 | 0; //@line 46969
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 46971
 $47 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255; //@line 46976
 $48 = $30 & 7; //@line 46977
 $50 = 8 - $48 | 0; //@line 46979
 $53 = $28 ^ 31; //@line 46982
 $54 = ($47 >>> $50 | $39 << $48) >>> $53; //@line 46983
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 46988
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 46991
 HEAP32[96444] = 0; //@line 46992
 HEAP32[96441] = 0; //@line 46993
 $61 = -1 << $53; //@line 46994
 $67 = $48 + 1 + $28 | 0; //@line 47000
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$36 >> 2] | 0) + 12 >> 2] & 31]($34, $61 >>> $48 | $39 & -16777216 << $50 | ($67 >>> 0 > 31 ? 0 : -1 >>> $67 & $39)); //@line 47009
 if ($67 >>> 0 <= 32) {
  $86 = HEAP32[162769] | 0; //@line 47012
  $87 = $86 + 4 | 0; //@line 47013
  HEAP32[162769] = $87; //@line 47014
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 20 >> 2] & 31]($40, $47 & 255 >>> ($48 + -31 + $28 | 0) | $61 << $50); //@line 47026
 $86 = HEAP32[162769] | 0; //@line 47027
 $87 = $86 + 4 | 0; //@line 47028
 HEAP32[162769] = $87; //@line 47029
 return;
}
function __Z12op_ecf0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $64 = 0, $74 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 45492
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 45500
 $11 = $2 + 4 | 0; //@line 45501
 HEAP32[162769] = $11; //@line 45502
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 45504
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 45511
 HEAP32[162769] = $2 + 6; //@line 45513
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 45514
 $sext = $10 << 16; //@line 45515
 $23 = $sext >> 16; //@line 45516
 $26 = $sext >> 22; //@line 45519
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 45522
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 45527
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 45532
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 45537
 }
 $38 = $37 + 31 & 31; //@line 45540
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 45545
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 45547
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 45550
 $50 = $44 + 4 | 0; //@line 45551
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 45553
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 45558
 $58 = $40 & 7; //@line 45559
 $60 = 8 - $58 | 0; //@line 45561
 $64 = ($57 >>> $60 | $49 << $58) >>> ($38 ^ 31); //@line 45565
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 45570
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 45573
 HEAP32[96444] = 0; //@line 45574
 HEAP32[96441] = 0; //@line 45575
 $74 = $58 + 1 + $38 | 0; //@line 45579
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($74 >>> 0 > 31 ? 0 : -1 >>> $74 & $49) | $49 & -16777216 << $60); //@line 45588
 if ($74 >>> 0 <= 32) {
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $57 & 255 >>> ($58 + -31 + $38 | 0)); //@line 45600
 return;
}
function __Z9m68k_mulljjt($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$sink26$off0 = 0, $10 = 0, $11 = 0, $16 = 0, $17 = 0, $22 = 0, $26 = 0, $27 = 0, $3 = 0, $33 = 0, $34 = 0, $39 = 0, $9 = 0;
 $3 = $2 & 65535; //@line 51939
 $9 = ($3 & 1024 | 0) != 0; //@line 51945
 $10 = 651008 + (($3 >>> 12 & 7) << 2) | 0; //@line 51946
 $11 = HEAP32[$10 >> 2] | 0; //@line 51947
 HEAP32[96444] = 0; //@line 51948
 HEAP32[96441] = 0; //@line 51949
 if (!($3 & 2048)) {
  $33 = ___muldi3($11 | 0, 0, $1 | 0, 0) | 0; //@line 51951
  $34 = tempRet0; //@line 51952
  HEAP32[96442] = ($33 | 0) == 0 & ($34 | 0) == 0 & 1; //@line 51957
  $39 = _bitshift64Lshr($33 | 0, $34 | 0, 63) | 0; //@line 51958
  HEAP32[96443] = $39; //@line 51960
  if ($9) {
   HEAP32[651008 + (($3 & 7) << 2) >> 2] = $34; //@line 51964
   $$sink26$off0 = $33; //@line 51965
   HEAP32[$10 >> 2] = $$sink26$off0; //@line 51966
   return;
  }
  if (!($34 >>> 0 > 0 | ($34 | 0) == 0 & $33 >>> 0 > 4294967295)) {
   $$sink26$off0 = $33; //@line 51975
   HEAP32[$10 >> 2] = $$sink26$off0; //@line 51976
   return;
  }
  HEAP32[96444] = 1; //@line 51979
  $$sink26$off0 = $33; //@line 51980
  HEAP32[$10 >> 2] = $$sink26$off0; //@line 51981
  return;
 } else {
  $16 = ___muldi3($11 | 0, (($11 | 0) < 0) << 31 >> 31 | 0, $1 | 0, (($1 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 51988
  $17 = tempRet0; //@line 51989
  HEAP32[96442] = ($16 | 0) == 0 & ($17 | 0) == 0 & 1; //@line 51994
  $22 = _bitshift64Lshr($16 | 0, $17 | 0, 63) | 0; //@line 51995
  HEAP32[96443] = $22; //@line 51997
  if ($9) {
   HEAP32[651008 + (($3 & 7) << 2) >> 2] = $17; //@line 52001
   $$sink26$off0 = $16; //@line 52002
   HEAP32[$10 >> 2] = $$sink26$off0; //@line 52003
   return;
  }
  $26 = _i64Add($16 | 0, $17 | 0, -2147483648, -1) | 0; //@line 52006
  $27 = tempRet0; //@line 52007
  if (!($27 >>> 0 < 4294967295 | ($27 | 0) == -1 & $26 >>> 0 < 0)) {
   $$sink26$off0 = $16; //@line 52014
   HEAP32[$10 >> 2] = $$sink26$off0; //@line 52015
   return;
  }
  HEAP32[96444] = 1; //@line 52018
  $$sink26$off0 = $16; //@line 52019
  HEAP32[$10 >> 2] = $$sink26$off0; //@line 52020
  return;
 }
}
function __Z12op_ecf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $28 = 0, $31 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $51 = 0, $54 = 0, $55 = 0, $57 = 0, $62 = 0, $63 = 0, $65 = 0, $69 = 0, $79 = 0, $96 = 0, $97 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 45732
 $sext = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 45759
 $28 = $sext >> 16; //@line 45760
 $31 = $sext >> 22; //@line 45763
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 45766
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 45771
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 45776
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 45781
 }
 $43 = $42 + 31 & 31; //@line 45784
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 45789
 $51 = 123608 + ($49 >>> 16 << 2) | 0; //@line 45791
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$51 >> 2] >> 2] & 127]($49) | 0; //@line 45794
 $55 = $49 + 4 | 0; //@line 45795
 $57 = 123608 + ($55 >>> 16 << 2) | 0; //@line 45797
 $62 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$57 >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255; //@line 45802
 $63 = $45 & 7; //@line 45803
 $65 = 8 - $63 | 0; //@line 45805
 $69 = ($62 >>> $65 | $54 << $63) >>> ($43 ^ 31); //@line 45809
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 45814
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 45817
 HEAP32[96444] = 0; //@line 45818
 HEAP32[96441] = 0; //@line 45819
 $79 = $63 + 1 + $43 | 0; //@line 45823
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$51 >> 2] | 0) + 12 >> 2] & 31]($49, ($79 >>> 0 > 31 ? 0 : -1 >>> $79 & $54) | $54 & -16777216 << $65); //@line 45832
 if ($79 >>> 0 <= 32) {
  $96 = HEAP32[162769] | 0; //@line 45835
  $97 = $96 + 8 | 0; //@line 45836
  HEAP32[162769] = $97; //@line 45837
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$57 >> 2] | 0) + 20 >> 2] & 31]($55, $62 & 255 >>> ($63 + -31 + $43 | 0)); //@line 45847
 $96 = HEAP32[162769] | 0; //@line 45848
 $97 = $96 + 8 | 0; //@line 45849
 HEAP32[162769] = $97; //@line 45850
 return;
}
function __Z12op_ece8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $49 = 0, $50 = 0, $52 = 0, $57 = 0, $58 = 0, $60 = 0, $64 = 0, $74 = 0, $91 = 0, $92 = 0, $sext57 = 0;
 $2 = HEAP32[162769] | 0; //@line 45367
 $sext57 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 45389
 $23 = $sext57 >> 16; //@line 45390
 $26 = $sext57 >> 22; //@line 45393
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 45396
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 45401
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 45406
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 45411
 }
 $38 = $37 + 31 & 31; //@line 45414
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 45419
 $46 = 123608 + ($44 >>> 16 << 2) | 0; //@line 45421
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$46 >> 2] >> 2] & 127]($44) | 0; //@line 45424
 $50 = $44 + 4 | 0; //@line 45425
 $52 = 123608 + ($50 >>> 16 << 2) | 0; //@line 45427
 $57 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$52 >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255; //@line 45432
 $58 = $40 & 7; //@line 45433
 $60 = 8 - $58 | 0; //@line 45435
 $64 = ($57 >>> $60 | $49 << $58) >>> ($38 ^ 31); //@line 45439
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 45444
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 45447
 HEAP32[96444] = 0; //@line 45448
 HEAP32[96441] = 0; //@line 45449
 $74 = $58 + 1 + $38 | 0; //@line 45453
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$46 >> 2] | 0) + 12 >> 2] & 31]($44, ($74 >>> 0 > 31 ? 0 : -1 >>> $74 & $49) | $49 & -16777216 << $60); //@line 45462
 if ($74 >>> 0 <= 32) {
  $91 = HEAP32[162769] | 0; //@line 45465
  $92 = $91 + 6 | 0; //@line 45466
  HEAP32[162769] = $92; //@line 45467
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$52 >> 2] | 0) + 20 >> 2] & 31]($50, $57 & 255 >>> ($58 + -31 + $38 | 0)); //@line 45477
 $91 = HEAP32[162769] | 0; //@line 45478
 $92 = $91 + 6 | 0; //@line 45479
 HEAP32[162769] = $92; //@line 45480
 return;
}
function ___dynamic_cast($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $8 = 0, dest = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 3871
 STACKTOP = STACKTOP + 64 | 0; //@line 3872
 $4 = sp; //@line 3873
 $5 = HEAP32[$0 >> 2] | 0; //@line 3874
 $8 = $0 + (HEAP32[$5 + -8 >> 2] | 0) | 0; //@line 3877
 $10 = HEAP32[$5 + -4 >> 2] | 0; //@line 3879
 HEAP32[$4 >> 2] = $2; //@line 3880
 HEAP32[$4 + 4 >> 2] = $0; //@line 3882
 HEAP32[$4 + 8 >> 2] = $1; //@line 3884
 HEAP32[$4 + 12 >> 2] = $3; //@line 3886
 $14 = $4 + 16 | 0; //@line 3887
 $15 = $4 + 20 | 0; //@line 3888
 $16 = $4 + 24 | 0; //@line 3889
 $17 = $4 + 28 | 0; //@line 3890
 $18 = $4 + 32 | 0; //@line 3891
 $19 = $4 + 40 | 0; //@line 3892
 dest = $14; //@line 3893
 stop = dest + 36 | 0; //@line 3893
 do {
  HEAP32[dest >> 2] = 0; //@line 3893
  dest = dest + 4 | 0; //@line 3893
 } while ((dest | 0) < (stop | 0));
 HEAP16[$14 + 36 >> 1] = 0; //@line 3893
 HEAP8[$14 + 38 >> 0] = 0; //@line 3893
 L1 : do {
  if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($10, $2, 0) | 0) {
   HEAP32[$4 + 48 >> 2] = 1; //@line 3898
   FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[$10 >> 2] | 0) + 20 >> 2] & 3]($10, $4, $8, $8, 1, 0); //@line 3902
   $$0 = (HEAP32[$16 >> 2] | 0) == 1 ? $8 : 0; //@line 3906
  } else {
   FUNCTION_TABLE_viiiii[HEAP32[(HEAP32[$10 >> 2] | 0) + 24 >> 2] & 3]($10, $4, $8, 1, 0); //@line 3912
   switch (HEAP32[$4 + 36 >> 2] | 0) {
   case 0:
    {
     $$0 = (HEAP32[$19 >> 2] | 0) == 1 & (HEAP32[$17 >> 2] | 0) == 1 & (HEAP32[$18 >> 2] | 0) == 1 ? HEAP32[$15 >> 2] | 0 : 0; //@line 3926
     break L1;
     break;
    }
   case 1:
    {
     break;
    }
   default:
    {
     $$0 = 0; //@line 3934
     break L1;
    }
   }
   if ((HEAP32[$16 >> 2] | 0) != 1) {
    if (!((HEAP32[$19 >> 2] | 0) == 0 & (HEAP32[$17 >> 2] | 0) == 1 & (HEAP32[$18 >> 2] | 0) == 1)) {
     $$0 = 0; //@line 3950
     break;
    }
   }
   $$0 = HEAP32[$14 >> 2] | 0; //@line 3955
  }
 } while (0);
 STACKTOP = sp; //@line 3958
 return $$0 | 0; //@line 3958
}
function __Z12op_ecf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $48 = 0, $53 = 0, $54 = 0, $56 = 0, $60 = 0, $70 = 0, $87 = 0, $88 = 0, $sext53 = 0;
 $1 = HEAP32[162769] | 0; //@line 45611
 $sext53 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 45630
 $19 = $sext53 >> 16; //@line 45631
 $22 = $sext53 >> 22; //@line 45634
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 45637
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 45642
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 45647
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 45652
 }
 $34 = $33 + 31 & 31; //@line 45655
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 45660
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 45662
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$42 >> 2] >> 2] & 127]($40) | 0; //@line 45665
 $46 = $40 + 4 | 0; //@line 45666
 $48 = 123608 + ($46 >>> 16 << 2) | 0; //@line 45668
 $53 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$48 >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255; //@line 45673
 $54 = $36 & 7; //@line 45674
 $56 = 8 - $54 | 0; //@line 45676
 $60 = ($53 >>> $56 | $45 << $54) >>> ($34 ^ 31); //@line 45680
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 45685
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 45688
 HEAP32[96444] = 0; //@line 45689
 HEAP32[96441] = 0; //@line 45690
 $70 = $54 + 1 + $34 | 0; //@line 45694
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 12 >> 2] & 31]($40, ($70 >>> 0 > 31 ? 0 : -1 >>> $70 & $45) | $45 & -16777216 << $56); //@line 45703
 if ($70 >>> 0 <= 32) {
  $87 = HEAP32[162769] | 0; //@line 45706
  $88 = $87 + 6 | 0; //@line 45707
  HEAP32[162769] = $88; //@line 45708
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$48 >> 2] | 0) + 20 >> 2] & 31]($46, $53 & 255 >>> ($54 + -31 + $34 | 0)); //@line 45718
 $87 = HEAP32[162769] | 0; //@line 45719
 $88 = $87 + 6 | 0; //@line 45720
 HEAP32[162769] = $88; //@line 45721
 return;
}
function __ZL11open_helperPKcS0_i($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$ = 0, $$0$i = 0, $$1 = 0, $13 = 0, $20 = 0, $24 = 0, $28 = 0, $3 = 0, $31 = 0, $4 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 46582
 STACKTOP = STACKTOP + 2064 | 0; //@line 46583
 $vararg_buffer1 = sp + 1024 | 0; //@line 46584
 $vararg_buffer = sp; //@line 46585
 $3 = sp + 1032 | 0; //@line 46586
 HEAP8[$3 >> 0] = 0; //@line 46587
 $4 = _strrchr($0, 47) | 0; //@line 46588
 $$0$i = ($4 | 0) == 0 ? $0 : $4 + 1 | 0; //@line 46591
 $8 = $0; //@line 46593
 $9 = $$0$i - $8 | 0; //@line 46594
 _strncpy($3, $0, $9) | 0; //@line 46595
 HEAP8[$3 + $9 >> 0] = 0; //@line 46597
 _strncat($3, $1, 1023) | 0; //@line 46598
 _strncat($3, $$0$i, 1023) | 0; //@line 46599
 $$ = (($2 & 2097155) + -1 | 0) >>> 0 < 2 ? $2 | 64 : $2; //@line 46604
 HEAP32[$vararg_buffer >> 2] = 438; //@line 46605
 $13 = _open($3, $$, $vararg_buffer) | 0; //@line 46606
 if (($13 | 0) >= 0) {
  $$1 = $13; //@line 46609
  STACKTOP = sp; //@line 46610
  return $$1 | 0; //@line 46610
 }
 if (($$ & 64 | 0) == 0 | (HEAP32[(___errno_location() | 0) >> 2] | 0) != 2) {
  $$1 = $13; //@line 46619
  STACKTOP = sp; //@line 46620
  return $$1 | 0; //@line 46620
 }
 HEAP8[$vararg_buffer >> 0] = 0; //@line 46622
 $20 = _strrchr($0, 47) | 0; //@line 46623
 $24 = (($20 | 0) == 0 ? $0 : $20 + 1 | 0) - $8 | 0; //@line 46628
 _strncpy($vararg_buffer, $0, $24) | 0; //@line 46629
 HEAP8[$vararg_buffer + $24 >> 0] = 0; //@line 46631
 _strncat($vararg_buffer, $1, 1023) | 0; //@line 46632
 $28 = $vararg_buffer + ((_strlen($vararg_buffer) | 0) + -1) | 0; //@line 46635
 if ((HEAP8[$28 >> 0] | 0) == 47) {
  HEAP8[$28 >> 0] = 0; //@line 46639
 }
 $31 = _mkdir($vararg_buffer, 511) | 0; //@line 46641
 if (($31 | 0) < 0) {
  $$1 = $31; //@line 46644
  STACKTOP = sp; //@line 46645
  return $$1 | 0; //@line 46645
 }
 HEAP32[$vararg_buffer1 >> 2] = 438; //@line 46647
 $$1 = _open($3, $$, $vararg_buffer1) | 0; //@line 46649
 STACKTOP = sp; //@line 46650
 return $$1 | 0; //@line 46650
}
function __Z12op_48e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in28 = 0, $$024$in31 = 0, $$025$lcssa = 0, $$02530 = 0, $$1$lcssa = 0, $$127 = 0, $13 = 0, $14 = 0, $2 = 0, $27 = 0, $28 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 50986
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50988
 $5 = $4 & 255; //@line 50989
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50991
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 50992
 $9 = HEAP32[$8 >> 2] | 0; //@line 50993
 if (!($7 << 24 >> 24)) {
  $$025$lcssa = $9; //@line 50996
 } else {
  $$024$in31 = $7 & 255; //@line 50999
  $$02530 = $9; //@line 50999
  while (1) {
   $13 = $$02530 + -4 | 0; //@line 51001
   $14 = $$024$in31 & 65535; //@line 51002
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, HEAP32[651040 + (HEAP32[386816 + ($14 << 2) >> 2] << 2) >> 2] | 0); //@line 51012
   $$024$in31 = HEAP32[387840 + ($14 << 2) >> 2] | 0; //@line 51014
   if (!(($$024$in31 & 65535) << 16 >> 16)) {
    $$025$lcssa = $13; //@line 51018
    break;
   } else {
    $$02530 = $13; //@line 51021
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $$1$lcssa = $$025$lcssa; //@line 51027
  HEAP32[$8 >> 2] = $$1$lcssa; //@line 51028
  $41 = HEAP32[162769] | 0; //@line 51029
  $42 = $41 + 4 | 0; //@line 51030
  HEAP32[162769] = $42; //@line 51031
  return;
 } else {
  $$0$in28 = $5; //@line 51034
  $$127 = $$025$lcssa; //@line 51034
 }
 while (1) {
  $27 = $$127 + -4 | 0; //@line 51037
  $28 = $$0$in28 & 65535; //@line 51038
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($27, HEAP32[651008 + (HEAP32[386816 + ($28 << 2) >> 2] << 2) >> 2] | 0); //@line 51048
  $$0$in28 = HEAP32[387840 + ($28 << 2) >> 2] | 0; //@line 51050
  if (!(($$0$in28 & 65535) << 16 >> 16)) {
   $$1$lcssa = $27; //@line 51054
   break;
  } else {
   $$127 = $27; //@line 51057
  }
 }
 HEAP32[$8 >> 2] = $$1$lcssa; //@line 51060
 $41 = HEAP32[162769] | 0; //@line 51061
 $42 = $41 + 4 | 0; //@line 51062
 HEAP32[162769] = $42; //@line 51063
 return;
}
function __Z12op_48a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in28 = 0, $$024$in31 = 0, $$025$lcssa = 0, $$02530 = 0, $$1$lcssa = 0, $$127 = 0, $13 = 0, $14 = 0, $2 = 0, $27 = 0, $28 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 50421
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50423
 $5 = $4 & 255; //@line 50424
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50426
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 50427
 $9 = HEAP32[$8 >> 2] | 0; //@line 50428
 if (!($7 << 24 >> 24)) {
  $$025$lcssa = $9; //@line 50431
 } else {
  $$024$in31 = $7 & 255; //@line 50434
  $$02530 = $9; //@line 50434
  while (1) {
   $13 = $$02530 + -2 | 0; //@line 50436
   $14 = $$024$in31 & 65535; //@line 50437
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, HEAP32[651040 + (HEAP32[386816 + ($14 << 2) >> 2] << 2) >> 2] | 0); //@line 50447
   $$024$in31 = HEAP32[387840 + ($14 << 2) >> 2] | 0; //@line 50449
   if (!(($$024$in31 & 65535) << 16 >> 16)) {
    $$025$lcssa = $13; //@line 50453
    break;
   } else {
    $$02530 = $13; //@line 50456
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $$1$lcssa = $$025$lcssa; //@line 50462
  HEAP32[$8 >> 2] = $$1$lcssa; //@line 50463
  $41 = HEAP32[162769] | 0; //@line 50464
  $42 = $41 + 4 | 0; //@line 50465
  HEAP32[162769] = $42; //@line 50466
  return;
 } else {
  $$0$in28 = $5; //@line 50469
  $$127 = $$025$lcssa; //@line 50469
 }
 while (1) {
  $27 = $$127 + -2 | 0; //@line 50472
  $28 = $$0$in28 & 65535; //@line 50473
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($27, HEAP32[651008 + (HEAP32[386816 + ($28 << 2) >> 2] << 2) >> 2] | 0); //@line 50483
  $$0$in28 = HEAP32[387840 + ($28 << 2) >> 2] | 0; //@line 50485
  if (!(($$0$in28 & 65535) << 16 >> 16)) {
   $$1$lcssa = $27; //@line 50489
   break;
  } else {
   $$127 = $27; //@line 50492
  }
 }
 HEAP32[$8 >> 2] = $$1$lcssa; //@line 50495
 $41 = HEAP32[162769] | 0; //@line 50496
 $42 = $41 + 4 | 0; //@line 50497
 HEAP32[162769] = $42; //@line 50498
 return;
}
function __Z12op_ecd0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0, $39 = 0, $40 = 0, $42 = 0, $47 = 0, $48 = 0, $50 = 0, $54 = 0, $64 = 0, $81 = 0, $82 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 45253
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 45264
 $13 = $sext >> 16; //@line 45265
 $16 = $sext >> 22; //@line 45268
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 45271
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 45276
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 45281
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 45286
 }
 $28 = $27 + 31 & 31; //@line 45289
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 45294
 $36 = 123608 + ($34 >>> 16 << 2) | 0; //@line 45296
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$36 >> 2] >> 2] & 127]($34) | 0; //@line 45299
 $40 = $34 + 4 | 0; //@line 45300
 $42 = 123608 + ($40 >>> 16 << 2) | 0; //@line 45302
 $47 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$42 >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255; //@line 45307
 $48 = $30 & 7; //@line 45308
 $50 = 8 - $48 | 0; //@line 45310
 $54 = ($47 >>> $50 | $39 << $48) >>> ($28 ^ 31); //@line 45314
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 45319
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 45322
 HEAP32[96444] = 0; //@line 45323
 HEAP32[96441] = 0; //@line 45324
 $64 = $48 + 1 + $28 | 0; //@line 45328
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$36 >> 2] | 0) + 12 >> 2] & 31]($34, ($64 >>> 0 > 31 ? 0 : -1 >>> $64 & $39) | $39 & -16777216 << $50); //@line 45337
 if ($64 >>> 0 <= 32) {
  $81 = HEAP32[162769] | 0; //@line 45340
  $82 = $81 + 4 | 0; //@line 45341
  HEAP32[162769] = $82; //@line 45342
  return;
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$42 >> 2] | 0) + 20 >> 2] & 31]($40, $47 & 255 >>> ($48 + -31 + $28 | 0)); //@line 45352
 $81 = HEAP32[162769] | 0; //@line 45353
 $82 = $81 + 4 | 0; //@line 45354
 HEAP32[162769] = $82; //@line 45355
 return;
}
function __Z17rpc_method_invokeP16rpc_connection_tiz($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $$0 = 0, $12 = 0, $14 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0, $7 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 41975
 STACKTOP = STACKTOP + 1056 | 0; //@line 41976
 $2 = sp + 16 | 0; //@line 41977
 $3 = sp; //@line 41978
 if (!$0) {
  $$0 = -1003; //@line 41981
  STACKTOP = sp; //@line 41982
  return $$0 | 0; //@line 41982
 }
 if ((HEAP32[$0 >> 2] | 0) != 1) {
  $$0 = -1004; //@line 41987
  STACKTOP = sp; //@line 41988
  return $$0 | 0; //@line 41988
 }
 HEAP32[$2 >> 2] = HEAP32[$0 + 8 >> 2]; //@line 41992
 $7 = $2 + 4 | 0; //@line 41993
 $9 = $2 + 8 | 0; //@line 41995
 HEAP32[$9 >> 2] = _htonl(-3e3) | 0; //@line 41996
 HEAP32[$2 + 12 >> 2] = _htonl($1) | 0; //@line 41999
 HEAP32[$7 >> 2] = 8; //@line 42000
 HEAP32[$3 >> 2] = $varargs; //@line 42001
 $12 = __ZL21rpc_message_send_argsP13rpc_message_tPi($2, $3) | 0; //@line 42002
 if ($12 | 0) {
  $$0 = $12; //@line 42005
  STACKTOP = sp; //@line 42006
  return $$0 | 0; //@line 42006
 }
 $14 = _htonl(-3001) | 0; //@line 42008
 $15 = HEAP32[$7 >> 2] | 0; //@line 42009
 if (($15 + 4 | 0) >>> 0 > 1023) {
  $19 = (_send(HEAP32[$2 >> 2] | 0, $9, $15, 0) | 0) == ($15 | 0); //@line 42015
  HEAP32[$7 >> 2] = 0; //@line 42016
  if ($19) {
   $21 = 0; //@line 42018
  } else {
   $$0 = -1001; //@line 42020
   STACKTOP = sp; //@line 42021
   return $$0 | 0; //@line 42021
  }
 } else {
  $21 = $15; //@line 42024
 }
 $20 = $2 + 8 + $21 | 0; //@line 42026
 HEAP8[$20 >> 0] = $14; //@line 42027
 HEAP8[$20 + 1 >> 0] = $14 >> 8; //@line 42027
 HEAP8[$20 + 2 >> 0] = $14 >> 16; //@line 42027
 HEAP8[$20 + 3 >> 0] = $14 >> 24; //@line 42027
 $22 = $21 + 4 | 0; //@line 42028
 HEAP32[$7 >> 2] = $22; //@line 42029
 $24 = (_send(HEAP32[$2 >> 2] | 0, $9, $22, 0) | 0) == ($22 | 0); //@line 42032
 HEAP32[$7 >> 2] = 0; //@line 42033
 $$0 = $24 ? 0 : -1001; //@line 42035
 STACKTOP = sp; //@line 42036
 return $$0 | 0; //@line 42036
}
function ___shgetc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi34Z2D = 0, $$sink = 0, $1 = 0, $10 = 0, $12 = 0, $14 = 0, $17 = 0, $19 = 0, $2 = 0, $21 = 0, $26 = 0, $29 = 0, $34 = 0, $7 = 0, label = 0;
 $1 = $0 + 104 | 0; //@line 55514
 $2 = HEAP32[$1 >> 2] | 0; //@line 55515
 if (!$2) {
  label = 3; //@line 55518
 } else {
  if ((HEAP32[$0 + 108 >> 2] | 0) < ($2 | 0)) {
   label = 3; //@line 55524
  } else {
   label = 4; //@line 55526
  }
 }
 if ((label | 0) == 3) {
  $7 = ___uflow($0) | 0; //@line 55530
  if (($7 | 0) < 0) {
   label = 4; //@line 55533
  } else {
   $10 = HEAP32[$1 >> 2] | 0; //@line 55535
   $$phi$trans$insert = $0 + 8 | 0; //@line 55537
   if (!$10) {
    $$pre = HEAP32[$$phi$trans$insert >> 2] | 0; //@line 55539
    $$pre$phi34Z2D = $0 + 108 | 0; //@line 55543
    $$sink = $$pre; //@line 55543
    $26 = $$pre; //@line 55543
    $29 = HEAP32[$0 + 4 >> 2] | 0; //@line 55543
   } else {
    $12 = HEAP32[$$phi$trans$insert >> 2] | 0; //@line 55545
    $14 = HEAP32[$0 + 4 >> 2] | 0; //@line 55547
    $17 = $0 + 108 | 0; //@line 55550
    $19 = $10 - (HEAP32[$17 >> 2] | 0) | 0; //@line 55552
    $21 = $12; //@line 55554
    if (($12 - $14 | 0) < ($19 | 0)) {
     $$pre$phi34Z2D = $17; //@line 55556
     $$sink = $21; //@line 55556
     $26 = $21; //@line 55556
     $29 = $14; //@line 55556
    } else {
     $$pre$phi34Z2D = $17; //@line 55560
     $$sink = $14 + ($19 + -1) | 0; //@line 55560
     $26 = $21; //@line 55560
     $29 = $14; //@line 55560
    }
   }
   HEAP32[$0 + 100 >> 2] = $$sink; //@line 55564
   if ($26 | 0) {
    HEAP32[$$pre$phi34Z2D >> 2] = $26 + 1 - $29 + (HEAP32[$$pre$phi34Z2D >> 2] | 0); //@line 55573
   }
   $34 = $29 + -1 | 0; //@line 55575
   if ((HEAPU8[$34 >> 0] | 0 | 0) == ($7 | 0)) {
    $$0 = $7; //@line 55580
   } else {
    HEAP8[$34 >> 0] = $7; //@line 55583
    $$0 = $7; //@line 55584
   }
  }
 }
 if ((label | 0) == 4) {
  HEAP32[$0 + 100 >> 2] = 0; //@line 55590
  $$0 = -1; //@line 55591
 }
 return $$0 | 0; //@line 55593
}
function ___strchrnul($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$029$lcssa = 0, $$02936 = 0, $$030$lcssa = 0, $$03039 = 0, $$1 = 0, $10 = 0, $13 = 0, $17 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $31 = 0, $38 = 0, $39 = 0, $7 = 0;
 $2 = $1 & 255; //@line 61914
 L1 : do {
  if (!$2) {
   $$0 = $0 + (_strlen($0) | 0) | 0; //@line 61920
  } else {
   if (!($0 & 3)) {
    $$030$lcssa = $0; //@line 61926
   } else {
    $7 = $1 & 255; //@line 61928
    $$03039 = $0; //@line 61929
    while (1) {
     $10 = HEAP8[$$03039 >> 0] | 0; //@line 61931
     if ($10 << 24 >> 24 == 0 ? 1 : $10 << 24 >> 24 == $7 << 24 >> 24) {
      $$0 = $$03039; //@line 61936
      break L1;
     }
     $13 = $$03039 + 1 | 0; //@line 61939
     if (!($13 & 3)) {
      $$030$lcssa = $13; //@line 61944
      break;
     } else {
      $$03039 = $13; //@line 61947
     }
    }
   }
   $17 = Math_imul($2, 16843009) | 0; //@line 61951
   $18 = HEAP32[$$030$lcssa >> 2] | 0; //@line 61952
   L10 : do {
    if (!(($18 & -2139062144 ^ -2139062144) & $18 + -16843009)) {
     $$02936 = $$030$lcssa; //@line 61960
     $25 = $18; //@line 61960
     while (1) {
      $24 = $25 ^ $17; //@line 61962
      if (($24 & -2139062144 ^ -2139062144) & $24 + -16843009 | 0) {
       $$029$lcssa = $$02936; //@line 61969
       break L10;
      }
      $31 = $$02936 + 4 | 0; //@line 61972
      $25 = HEAP32[$31 >> 2] | 0; //@line 61973
      if (($25 & -2139062144 ^ -2139062144) & $25 + -16843009 | 0) {
       $$029$lcssa = $31; //@line 61982
       break;
      } else {
       $$02936 = $31; //@line 61980
      }
     }
    } else {
     $$029$lcssa = $$030$lcssa; //@line 61987
    }
   } while (0);
   $38 = $1 & 255; //@line 61990
   $$1 = $$029$lcssa; //@line 61991
   while (1) {
    $39 = HEAP8[$$1 >> 0] | 0; //@line 61993
    if ($39 << 24 >> 24 == 0 ? 1 : $39 << 24 >> 24 == $38 << 24 >> 24) {
     $$0 = $$1; //@line 61999
     break;
    } else {
     $$1 = $$1 + 1 | 0; //@line 62002
    }
   }
  }
 } while (0);
 return $$0 | 0; //@line 62007
}
function __ZN16SDL_monitor_desc10video_openEv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$sink = 0, $11 = 0, $13 = 0, $15 = 0, $2 = 0, $26 = 0, $27 = 0, $5 = 0, $7 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 44230
 STACKTOP = STACKTOP + 16 | 0; //@line 44231
 $vararg_buffer = sp; //@line 44232
 _puts(102453) | 0; //@line 44233
 $2 = HEAP32[$0 + 16 >> 2] | 0; //@line 44235
 _puts(102466) | 0; //@line 44236
 $5 = HEAP32[$2 + 4 >> 2] | 0; //@line 44239
 $7 = HEAP32[$2 + 8 >> 2] | 0; //@line 44241
 $11 = 1 << (HEAP32[$2 + 12 >> 2] & 15); //@line 44245
 HEAP32[$vararg_buffer >> 2] = HEAP32[$2 >> 2]; //@line 44246
 HEAP32[$vararg_buffer + 4 >> 2] = $5; //@line 44248
 HEAP32[$vararg_buffer + 8 >> 2] = $7; //@line 44250
 HEAP32[$vararg_buffer + 12 >> 2] = $11; //@line 44252
 _printf(102486, $vararg_buffer) | 0; //@line 44253
 if (!(HEAP32[30856] | 0)) {
  $13 = __ZnwjRKSt9nothrow_t(32, 660780) | 0; //@line 44257
  if (!$13) {
   $26 = 0; //@line 44260
  } else {
   __ZN13driver_windowC2ER16SDL_monitor_desc($13, $0); //@line 44262
   $26 = $13; //@line 44263
  }
  $$sink = $26; //@line 44265
 } else {
  $15 = __ZnwjRKSt9nothrow_t(20, 660780) | 0; //@line 44267
  if (!$15) {
   $27 = 0; //@line 44270
  } else {
   __ZN17driver_fullscreenC2ER16SDL_monitor_desc($15, $0); //@line 44272
   $27 = $15; //@line 44273
  }
  $$sink = $27; //@line 44275
 }
 HEAP32[30855] = $$sink; //@line 44277
 if (!$$sink) {
  $$0 = 0; //@line 44280
  STACKTOP = sp; //@line 44281
  return $$0 | 0; //@line 44281
 }
 if (!(HEAP8[$$sink + 12 >> 0] | 0)) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$$sink >> 2] | 0) + 4 >> 2] & 4095]($$sink); //@line 44290
  HEAP32[30855] = 0; //@line 44291
  $$0 = 0; //@line 44292
  STACKTOP = sp; //@line 44293
  return $$0 | 0; //@line 44293
 } else {
  HEAP32[30857] = (HEAP32[30856] | 0) == 1 ? 2 : 3; //@line 44298
  _SDL_mutexP(0) | 0; //@line 44299
  HEAP8[659472] = 1; //@line 44300
  $$0 = 1; //@line 44301
  STACKTOP = sp; //@line 44302
  return $$0 | 0; //@line 44302
 }
 return 0; //@line 44304
}
function __Z9ExtFSCommtjj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $11 = 0, $18 = 0, $23 = 0, $3 = 0, $30 = 0, $36 = 0, $43 = 0, $46 = 0, $52 = 0, $58 = 0;
 switch ($0 << 16 >> 16) {
 case 1:
  {
   $3 = $1 + 14 | 0; //@line 30015
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0) != 1) {
    $$0 = -5012; //@line 30024
    return $$0 | 0; //@line 30025
   }
   $11 = $1 + 6 | 0; //@line 30027
   if ((FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($11 >>> 16 << 2) >> 2] >> 2] & 127]($11) | 0) >>> 0 <= 255) {
    $$0 = -5012; //@line 30035
    return $$0 | 0; //@line 30036
   }
   $18 = $1 + 2 | 0; //@line 30038
   $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 30043
   _memcpy(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($23) | 0, 96710, 256) | 0; //@line 30050
   $30 = $1 + 10 | 0; //@line 30051
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, 256); //@line 30057
   $$0 = 0; //@line 30058
   return $$0 | 0; //@line 30059
  }
 case 2:
  {
   $36 = $1 + 22 | 0; //@line 30063
   $43 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($36) | 0) << 16 >> 16; //@line 30071
   $$0 = ($43 | 0) == (HEAP32[30849] | 0) ? 0 : -58; //@line 30075
   return $$0 | 0; //@line 30076
  }
 case 5:
  {
   $46 = $1 + 32 | 0; //@line 30080
   $52 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($46 >>> 16 << 2) >> 2] >> 2] & 127]($46) | 0) + 2 | 0; //@line 30086
   $58 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($52 >>> 16 << 2) >> 2] >> 2] & 127]($52) | 0) == 1650553705; //@line 30092
   $$0 = $58 ? 0 : -58; //@line 30094
   return $$0 | 0; //@line 30095
  }
 case 4:
 case 3:
 case 0:
  {
   $$0 = 0; //@line 30099
   return $$0 | 0; //@line 30100
  }
 default:
  {
   $$0 = -438; //@line 30104
   return $$0 | 0; //@line 30105
  }
 }
 return 0; //@line 30108
}
function __ZN8tinyxml27StrPair9ParseNameEPc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$015$lcssa$ph = 0, $$01516 = 0, $$pre$i$i = 0, $10 = 0, $14 = 0, $21 = 0, $3 = 0, $6 = 0, $7 = 0, label = 0;
 if (!$1) {
  $$0 = 0; //@line 38329
  return $$0 | 0; //@line 38330
 }
 $3 = HEAP8[$1 >> 0] | 0; //@line 38332
 if (!($3 << 24 >> 24)) {
  $$0 = 0; //@line 38335
  return $$0 | 0; //@line 38336
 } else {
  $$01516 = $1; //@line 38338
  $7 = $3; //@line 38338
 }
 L6 : while (1) {
  $6 = $7 << 24 >> 24 > -1; //@line 38342
  L8 : do {
   if (($$01516 | 0) == ($1 | 0)) {
    if ($6) {
     if (!(_isalpha($7 & 255) | 0)) {
      switch ($7 << 24 >> 24) {
      case 58:
      case 95:
       {
        break;
       }
      default:
       {
        $$0 = 0; //@line 38355
        label = 17; //@line 38356
        break L6;
       }
      }
     }
    }
   } else {
    if ($6) {
     $10 = $7 & 255; //@line 38364
     if (!(_isalpha($10) | 0)) {
      switch ($7 << 24 >> 24) {
      case 58:
      case 95:
       {
        break L8;
        break;
       }
      default:
       {}
      }
      if (!(($7 + -45 & 255) < 2 | ($10 + -48 | 0) >>> 0 < 10)) {
       $$015$lcssa$ph = $$01516; //@line 38382
       break L6;
      }
     }
    }
   }
  } while (0);
  $14 = $$01516 + 1 | 0; //@line 38389
  $7 = HEAP8[$14 >> 0] | 0; //@line 38390
  if (!($7 << 24 >> 24)) {
   $$015$lcssa$ph = $14; //@line 38393
   break;
  } else {
   $$01516 = $14; //@line 38396
  }
 }
 if ((label | 0) == 17) {
  return $$0 | 0; //@line 38400
 }
 if ($$015$lcssa$ph >>> 0 <= $1 >>> 0) {
  $$0 = 0; //@line 38404
  return $$0 | 0; //@line 38405
 }
 $$pre$i$i = $0 + 4 | 0; //@line 38410
 if (HEAP32[$0 >> 2] & 512 | 0) {
  $21 = HEAP32[$$pre$i$i >> 2] | 0; //@line 38412
  if ($21 | 0) {
   __ZdaPv($21); //@line 38415
  }
 }
 HEAP32[$$pre$i$i >> 2] = $1; //@line 38419
 HEAP32[$0 + 8 >> 2] = $$015$lcssa$ph; //@line 38420
 HEAP32[$0 >> 2] = 256; //@line 38421
 $$0 = $$015$lcssa$ph; //@line 38422
 return $$0 | 0; //@line 38423
}
function __Z12op_4c98_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02427 = 0, $$02529 = 0, $$030 = 0, $$1$lcssa = 0, $$128 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $37 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 53810
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 53812
 $5 = $4 & 255; //@line 53813
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 53815
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 53816
 $9 = HEAP32[$8 >> 2] | 0; //@line 53817
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $9; //@line 53820
 } else {
  $$02529 = $7 & 255; //@line 53823
  $$030 = $9; //@line 53823
  while (1) {
   $19 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$030 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$030) | 0) << 16 >> 16; //@line 53832
   HEAP32[651008 + (HEAP32[385792 + ($$02529 << 2) >> 2] << 2) >> 2] = $19; //@line 53836
   $23 = $$030 + 2 | 0; //@line 53837
   $$02529 = HEAP32[387840 + ($$02529 << 2) >> 2] | 0; //@line 53839
   if (!$$02529) {
    $$0$lcssa = $23; //@line 53842
    break;
   } else {
    $$030 = $23; //@line 53845
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $$1$lcssa = $$0$lcssa; //@line 53851
  HEAP32[$8 >> 2] = $$1$lcssa; //@line 53852
  $41 = HEAP32[162769] | 0; //@line 53853
  $42 = $41 + 4 | 0; //@line 53854
  HEAP32[162769] = $42; //@line 53855
  return;
 } else {
  $$02427 = $5; //@line 53858
  $$128 = $$0$lcssa; //@line 53858
 }
 while (1) {
  $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$128 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$128) | 0) << 16 >> 16; //@line 53868
  HEAP32[651040 + (HEAP32[385792 + ($$02427 << 2) >> 2] << 2) >> 2] = $33; //@line 53872
  $37 = $$128 + 2 | 0; //@line 53873
  $$02427 = HEAP32[387840 + ($$02427 << 2) >> 2] | 0; //@line 53875
  if (!$$02427) {
   $$1$lcssa = $37; //@line 53878
   break;
  } else {
   $$128 = $37; //@line 53881
  }
 }
 HEAP32[$8 >> 2] = $$1$lcssa; //@line 53884
 $41 = HEAP32[162769] | 0; //@line 53885
 $42 = $41 + 4 | 0; //@line 53886
 HEAP32[162769] = $42; //@line 53887
 return;
}
function __Z10MakeFromSRv() {
 var $$sink2$sink = 0, $0 = 0, $1 = 0, $11 = 0, $14 = 0, $2 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $35 = 0, $38 = 0, $41 = 0;
 $0 = HEAP8[651121] | 0; //@line 51326
 $1 = HEAP8[651120] | 0; //@line 51327
 $2 = HEAP16[325558] | 0; //@line 51328
 $3 = $2 & 65535; //@line 51329
 HEAP8[651118] = ($2 & 65535) >>> 15; //@line 51332
 HEAP8[651119] = $3 >>> 14 & 1; //@line 51336
 $11 = $3 >>> 13 & 1; //@line 51339
 HEAP8[651120] = $11; //@line 51340
 $14 = $3 >>> 12 & 1; //@line 51343
 HEAP8[651121] = $14; //@line 51344
 HEAP32[162772] = $3 >>> 8 & 7; //@line 51347
 HEAP32[96445] = $3 >>> 4 & 1; //@line 51350
 HEAP32[96443] = $3 >>> 3 & 1; //@line 51353
 HEAP32[96442] = $3 >>> 2 & 1; //@line 51356
 HEAP32[96444] = $3 >>> 1 & 1; //@line 51359
 HEAP32[96441] = $3 & 1; //@line 51361
 $28 = $1 << 24 >> 24 != $11 << 24 >> 24; //@line 51364
 do {
  if ((HEAP32[30880] | 0) > 1) {
   $29 = $1 << 24 >> 24 != 0; //@line 51367
   if (!$28) {
    if ($0 << 24 >> 24 == $14 << 24 >> 24 | $29 ^ 1) {
     break;
    }
    $35 = $0 << 24 >> 24 != 0; //@line 51375
    HEAP32[($35 ? 651112 : 651108) >> 2] = HEAP32[162767]; //@line 51378
    HEAP32[162767] = $35 ? HEAP32[162777] | 0 : HEAP32[162778] | 0; //@line 51382
    break;
   }
   $30 = HEAP32[162767] | 0; //@line 51385
   if ($29) {
    HEAP32[($0 << 24 >> 24 ? 651112 : 651108) >> 2] = $30; //@line 51389
    $$sink2$sink = 651104; //@line 51390
   } else {
    HEAP32[162776] = $30; //@line 51392
    $$sink2$sink = $14 << 24 >> 24 ? 651112 : 651108; //@line 51395
   }
   HEAP32[162767] = HEAP32[$$sink2$sink >> 2]; //@line 51398
  } else {
   if ($28) {
    $38 = $1 << 24 >> 24 != 0; //@line 51401
    HEAP32[($38 ? 651108 : 651104) >> 2] = HEAP32[162767]; //@line 51404
    HEAP32[162767] = $38 ? HEAP32[162776] | 0 : HEAP32[162777] | 0; //@line 51408
   }
  }
 } while (0);
 $41 = HEAP32[162771] | 0; //@line 51412
 HEAP32[162771] = (HEAP8[651119] | HEAP8[651118]) << 24 >> 24 ? $41 | 10 : $41 & -11 | 2; //@line 51421
 return;
}
function __Z12op_edc0_0_ffj($0) {
 $0 = $0 | 0;
 var $$031$lcssa = 0, $$03133 = 0, $$034 = 0, $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $30 = 0, $33 = 0, $34 = 0, $35 = 0, $42 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 45860
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 45863
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 45869
 $11 = $sext >> 16; //@line 45870
 $14 = $sext >> 22; //@line 45873
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 45876
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 45881
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 45886
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 45891
 }
 $26 = $25 + 31 & 31; //@line 45894
 $33 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << ($30 & 31) >>> ($26 ^ 31); //@line 45900
 $34 = 1 << $26; //@line 45901
 $35 = $33 & $34; //@line 45902
 HEAP32[96443] = ($35 | 0) != 0 & 1; //@line 45905
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 45908
 HEAP32[96444] = 0; //@line 45909
 HEAP32[96441] = 0; //@line 45910
 if (!$35) {
  $$03133 = $30; //@line 45913
  $$034 = $34; //@line 45913
 } else {
  $$031$lcssa = $30; //@line 45915
  $46 = $5 >>> 4; //@line 45916
  $47 = $46 & 7; //@line 45917
  $48 = 651008 + ($47 << 2) | 0; //@line 45918
  HEAP32[$48 >> 2] = $$031$lcssa; //@line 45919
  $49 = HEAP32[162769] | 0; //@line 45920
  $50 = $49 + 4 | 0; //@line 45921
  HEAP32[162769] = $50; //@line 45922
  return;
 }
 while (1) {
  $$034 = $$034 >>> 1; //@line 45926
  $42 = $$03133 + 1 | 0; //@line 45927
  if (!(($$034 | 0) != 0 & ($$034 & $33 | 0) == 0)) {
   $$031$lcssa = $42; //@line 45935
   break;
  } else {
   $$03133 = $42; //@line 45933
  }
 }
 $46 = $5 >>> 4; //@line 45939
 $47 = $46 & 7; //@line 45940
 $48 = 651008 + ($47 << 2) | 0; //@line 45941
 HEAP32[$48 >> 2] = $$031$lcssa; //@line 45942
 $49 = HEAP32[162769] | 0; //@line 45943
 $50 = $49 + 4 | 0; //@line 45944
 HEAP32[162769] = $50; //@line 45945
 return;
}
function __ZNK12monitor_desc17get_bytes_per_rowE11video_depthj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$016 = 0, $$sroa$010$019 = 0, $$sroa$07$014$i = 0, $16 = 0, $22 = 0, $4 = 0, $6 = 0, $7 = 0, label = 0;
 $4 = HEAP32[$0 + 8 >> 2] | 0; //@line 23576
 $6 = HEAP32[$0 + 4 >> 2] | 0; //@line 23578
 $7 = ($6 | 0) == ($4 | 0); //@line 23579
 L1 : do {
  if ($7) {
   $$016 = 0; //@line 23582
  } else {
   $$sroa$010$019 = $6; //@line 23584
   while (1) {
    if ((HEAP32[$$sroa$010$019 + 12 >> 2] | 0) == ($1 | 0)) {
     if ((HEAP32[$$sroa$010$019 + 8 >> 2] | 0) == ($2 | 0)) {
      label = 4; //@line 23594
      break;
     }
    }
    $16 = $$sroa$010$019 + 24 | 0; //@line 23598
    if (($16 | 0) == ($4 | 0)) {
     break;
    } else {
     $$sroa$010$019 = $16; //@line 23603
    }
   }
   if ((label | 0) == 4) {
    $$0 = HEAP32[$$sroa$010$019 + 16 >> 2] | 0; //@line 23609
    return $$0 | 0; //@line 23610
   }
   if ($7) {
    $$016 = 0; //@line 23613
   } else {
    $$sroa$07$014$i = $6; //@line 23615
    while (1) {
     if ((HEAP32[$$sroa$07$014$i + 8 >> 2] | 0) == ($2 | 0)) {
      break;
     }
     $22 = $$sroa$07$014$i + 24 | 0; //@line 23623
     if (($22 | 0) == ($4 | 0)) {
      $$016 = 0; //@line 23626
      break L1;
     } else {
      $$sroa$07$014$i = $22; //@line 23629
     }
    }
    $$016 = HEAP32[$$sroa$07$014$i >> 2] | 0; //@line 23633
   }
  }
 } while (0);
 switch ($1 | 0) {
 case 0:
  {
   $$0 = $$016 >>> 3; //@line 23640
   return $$0 | 0; //@line 23641
  }
 case 1:
  {
   $$0 = $$016 >>> 2; //@line 23646
   return $$0 | 0; //@line 23647
  }
 case 2:
  {
   $$0 = $$016 >>> 1; //@line 23652
   return $$0 | 0; //@line 23653
  }
 case 5:
  {
   $$0 = $$016 << 2; //@line 23658
   return $$0 | 0; //@line 23659
  }
 case 4:
  {
   $$0 = $$016 << 1; //@line 23664
   return $$0 | 0; //@line 23665
  }
 default:
  {
   $$0 = $$016; //@line 23669
   return $$0 | 0; //@line 23670
  }
 }
 return 0; //@line 23673
}
function ___fwritex($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$038 = 0, $$1 = 0, $$139 = 0, $$141 = 0, $$143 = 0, $10 = 0, $12 = 0, $14 = 0, $22 = 0, $28 = 0, $3 = 0, $31 = 0, $4 = 0, $9 = 0, label = 0;
 $3 = $2 + 16 | 0; //@line 59168
 $4 = HEAP32[$3 >> 2] | 0; //@line 59169
 if (!$4) {
  if (!(___towrite($2) | 0)) {
   $12 = HEAP32[$3 >> 2] | 0; //@line 59176
   label = 5; //@line 59177
  } else {
   $$1 = 0; //@line 59179
  }
 } else {
  $12 = $4; //@line 59183
  label = 5; //@line 59184
 }
 L5 : do {
  if ((label | 0) == 5) {
   $9 = $2 + 20 | 0; //@line 59188
   $10 = HEAP32[$9 >> 2] | 0; //@line 59189
   $14 = $10; //@line 59192
   if (($12 - $10 | 0) >>> 0 < $1 >>> 0) {
    $$1 = FUNCTION_TABLE_iiii[HEAP32[$2 + 36 >> 2] & 15]($2, $0, $1) | 0; //@line 59197
    break;
   }
   L10 : do {
    if ((HEAP8[$2 + 75 >> 0] | 0) > -1) {
     $$038 = $1; //@line 59205
     while (1) {
      if (!$$038) {
       $$139 = 0; //@line 59209
       $$141 = $0; //@line 59209
       $$143 = $1; //@line 59209
       $31 = $14; //@line 59209
       break L10;
      }
      $22 = $$038 + -1 | 0; //@line 59212
      if ((HEAP8[$0 + $22 >> 0] | 0) == 10) {
       break;
      } else {
       $$038 = $22; //@line 59219
      }
     }
     $28 = FUNCTION_TABLE_iiii[HEAP32[$2 + 36 >> 2] & 15]($2, $0, $$038) | 0; //@line 59224
     if ($28 >>> 0 < $$038 >>> 0) {
      $$1 = $28; //@line 59227
      break L5;
     }
     $$139 = $$038; //@line 59233
     $$141 = $0 + $$038 | 0; //@line 59233
     $$143 = $1 - $$038 | 0; //@line 59233
     $31 = HEAP32[$9 >> 2] | 0; //@line 59233
    } else {
     $$139 = 0; //@line 59235
     $$141 = $0; //@line 59235
     $$143 = $1; //@line 59235
     $31 = $14; //@line 59235
    }
   } while (0);
   _memcpy($31 | 0, $$141 | 0, $$143 | 0) | 0; //@line 59238
   HEAP32[$9 >> 2] = (HEAP32[$9 >> 2] | 0) + $$143; //@line 59241
   $$1 = $$139 + $$143 | 0; //@line 59243
  }
 } while (0);
 return $$1 | 0; //@line 59246
}
function _fread($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$ = 0, $$0 = 0, $$054$ph = 0, $$05460 = 0, $$056$ph = 0, $$05659 = 0, $$57 = 0, $10 = 0, $12 = 0, $18 = 0, $19 = 0, $21 = 0, $28 = 0, $32 = 0, $36 = 0, $39 = 0, $4 = 0, label = 0;
 $4 = Math_imul($2, $1) | 0; //@line 2584
 $$ = ($1 | 0) == 0 ? 0 : $2; //@line 2586
 if ((HEAP32[$3 + 76 >> 2] | 0) > -1) {
  $36 = ___lockfile($3) | 0; //@line 2592
 } else {
  $36 = 0; //@line 2594
 }
 $10 = $3 + 74 | 0; //@line 2596
 $12 = HEAP8[$10 >> 0] | 0; //@line 2598
 HEAP8[$10 >> 0] = $12 + 255 | $12; //@line 2602
 $18 = $3 + 4 | 0; //@line 2605
 $19 = HEAP32[$18 >> 2] | 0; //@line 2606
 $21 = (HEAP32[$3 + 8 >> 2] | 0) - $19 | 0; //@line 2608
 $$57 = $21 >>> 0 < $4 >>> 0 ? $21 : $4; //@line 2611
 if (($21 | 0) > 0) {
  _memcpy($0 | 0, $19 | 0, $$57 | 0) | 0; //@line 2615
  HEAP32[$18 >> 2] = $19 + $$57; //@line 2617
  $$054$ph = $4 - $$57 | 0; //@line 2618
  $$056$ph = $0 + $$57 | 0; //@line 2618
 } else {
  $$054$ph = $4; //@line 2620
  $$056$ph = $0; //@line 2620
 }
 L7 : do {
  if (!$$054$ph) {
   label = 13; //@line 2625
  } else {
   $28 = $3 + 32 | 0; //@line 2627
   $$05460 = $$054$ph; //@line 2628
   $$05659 = $$056$ph; //@line 2628
   while (1) {
    if (___toread($3) | 0) {
     break;
    }
    $32 = FUNCTION_TABLE_iiii[HEAP32[$28 >> 2] & 15]($3, $$05659, $$05460) | 0; //@line 2636
    if (($32 + 1 | 0) >>> 0 < 2) {
     break;
    }
    $39 = $$05460 - $32 | 0; //@line 2642
    if (!$39) {
     label = 13; //@line 2646
     break L7;
    } else {
     $$05460 = $39; //@line 2649
     $$05659 = $$05659 + $32 | 0; //@line 2649
    }
   }
   if ($36 | 0) {
    ___unlockfile($3); //@line 2654
   }
   $$0 = (($4 - $$05460 | 0) >>> 0) / ($1 >>> 0) | 0; //@line 2658
  }
 } while (0);
 if ((label | 0) == 13) {
  if (!$36) {
   $$0 = $$; //@line 2664
  } else {
   ___unlockfile($3); //@line 2666
   $$0 = $$; //@line 2667
  }
 }
 return $$0 | 0; //@line 2670
}
function __Z12op_4cd8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02426 = 0, $$02528 = 0, $$029 = 0, $$1$lcssa = 0, $$127 = 0, $17 = 0, $2 = 0, $21 = 0, $29 = 0, $33 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 54537
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 54539
 $5 = $4 & 255; //@line 54540
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 54542
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 54543
 $9 = HEAP32[$8 >> 2] | 0; //@line 54544
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $9; //@line 54547
 } else {
  $$02528 = $7 & 255; //@line 54550
  $$029 = $9; //@line 54550
  while (1) {
   $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] >> 2] & 127]($$029) | 0; //@line 54556
   HEAP32[651008 + (HEAP32[385792 + ($$02528 << 2) >> 2] << 2) >> 2] = $17; //@line 54560
   $21 = $$029 + 4 | 0; //@line 54561
   $$02528 = HEAP32[387840 + ($$02528 << 2) >> 2] | 0; //@line 54563
   if (!$$02528) {
    $$0$lcssa = $21; //@line 54566
    break;
   } else {
    $$029 = $21; //@line 54569
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $$1$lcssa = $$0$lcssa; //@line 54575
  HEAP32[$8 >> 2] = $$1$lcssa; //@line 54576
  $37 = HEAP32[162769] | 0; //@line 54577
  $38 = $37 + 4 | 0; //@line 54578
  HEAP32[162769] = $38; //@line 54579
  return;
 } else {
  $$02426 = $5; //@line 54582
  $$127 = $$0$lcssa; //@line 54582
 }
 while (1) {
  $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] >> 2] & 127]($$127) | 0; //@line 54589
  HEAP32[651040 + (HEAP32[385792 + ($$02426 << 2) >> 2] << 2) >> 2] = $29; //@line 54593
  $33 = $$127 + 4 | 0; //@line 54594
  $$02426 = HEAP32[387840 + ($$02426 << 2) >> 2] | 0; //@line 54596
  if (!$$02426) {
   $$1$lcssa = $33; //@line 54599
   break;
  } else {
   $$127 = $33; //@line 54602
  }
 }
 HEAP32[$8 >> 2] = $$1$lcssa; //@line 54605
 $37 = HEAP32[162769] | 0; //@line 54606
 $38 = $37 + 4 | 0; //@line 54607
 HEAP32[162769] = $38; //@line 54608
 return;
}
function __ZN17disk_sparsebundle9open_bandEib($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$1 = 0, $$2 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $18 = 0, $20 = 0, $26 = 0, $29 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, sp = 0;
 sp = STACKTOP; //@line 35973
 STACKTOP = STACKTOP + 4112 | 0; //@line 35974
 $vararg_buffer2 = sp + 8 | 0; //@line 35975
 $vararg_buffer = sp; //@line 35976
 $3 = sp + 12 | 0; //@line 35977
 $4 = $0 + 24 | 0; //@line 35978
 if ((HEAP32[$4 >> 2] | 0) == ($1 | 0)) {
  $$2 = 2; //@line 35982
  STACKTOP = sp; //@line 35983
  return $$2 | 0; //@line 35983
 }
 HEAP32[$vararg_buffer >> 2] = HEAP32[$0 + 20 >> 2]; //@line 35987
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 35989
 do {
  if ((_snprintf($3, 4096, 97244, $vararg_buffer) | 0) > 4095) {
   $$1 = 0; //@line 35994
  } else {
   $11 = $0 + 28 | 0; //@line 35996
   $12 = HEAP32[$11 >> 2] | 0; //@line 35997
   if (($12 | 0) != -1) {
    _close($12) | 0; //@line 36000
   }
   $14 = $0 + 32 | 0; //@line 36002
   HEAP32[$14 >> 2] = -1; //@line 36003
   HEAP32[$4 >> 2] = -1; //@line 36004
   $15 = $0 + 8 | 0; //@line 36005
   $18 = HEAP8[$15 >> 0] | 0 ? 0 : 2; //@line 36008
   HEAP32[$vararg_buffer2 >> 2] = 420; //@line 36011
   $20 = _open($3, $2 ? $18 | 64 : $18, $vararg_buffer2) | 0; //@line 36012
   HEAP32[$11 >> 2] = $20; //@line 36013
   if (($20 | 0) == -1) {
    if ($2) {
     $26 = 0; //@line 36017
    } else {
     $26 = (HEAP32[(___errno_location() | 0) >> 2] | 0) == 2; //@line 36022
    }
    $$1 = $26 & 1; //@line 36025
    break;
   }
   if (!(HEAP8[$15 >> 0] | 0)) {
    $29 = _lseek($20, 0, 2) | 0; //@line 36031
    HEAP32[$14 >> 2] = $29; //@line 36032
    if (($29 | 0) == -1) {
     HEAP32[$14 >> 2] = HEAP32[$0 + 12 >> 2]; //@line 36037
    }
   }
   HEAP32[$4 >> 2] = $1; //@line 36040
   $$1 = 2; //@line 36041
  }
 } while (0);
 $$2 = $$1; //@line 36044
 STACKTOP = sp; //@line 36045
 return $$2 | 0; //@line 36045
}
function __Z12op_f620_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $18 = 0, $2 = 0, $20 = 0, $28 = 0, $3 = 0, $36 = 0, $4 = 0, $44 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 $1 = $0 & 7; //@line 49674
 $2 = 651040 + ($1 << 2) | 0; //@line 49675
 $3 = HEAP32[$2 >> 2] | 0; //@line 49676
 $4 = $3 & -16; //@line 49677
 $10 = (HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0) >>> 4 & 7; //@line 49683
 $11 = 651040 + ($10 << 2) | 0; //@line 49684
 $12 = HEAP32[$11 >> 2] | 0; //@line 49685
 $13 = $12 & -16; //@line 49686
 $15 = 123608 + ($3 >>> 16 << 2) | 0; //@line 49688
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($4) | 0; //@line 49691
 $20 = 123608 + ($12 >>> 16 << 2) | 0; //@line 49693
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($13, $18); //@line 49697
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($4 | 4) | 0; //@line 49702
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($13 | 4, $28); //@line 49706
 $36 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($4 | 8) | 0; //@line 49711
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($13 | 8, $36); //@line 49715
 $44 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($4 | 12) | 0; //@line 49720
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($13 | 12, $44); //@line 49724
 if (($1 | 0) == ($10 | 0)) {
  $51 = HEAP32[$11 >> 2] | 0; //@line 49727
  $52 = $51 + 16 | 0; //@line 49728
  HEAP32[$11 >> 2] = $52; //@line 49729
  $53 = HEAP32[162769] | 0; //@line 49730
  $54 = $53 + 4 | 0; //@line 49731
  HEAP32[162769] = $54; //@line 49732
  return;
 }
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 16; //@line 49737
 $51 = HEAP32[$11 >> 2] | 0; //@line 49738
 $52 = $51 + 16 | 0; //@line 49739
 HEAP32[$11 >> 2] = $52; //@line 49740
 $53 = HEAP32[162769] | 0; //@line 49741
 $54 = $53 + 4 | 0; //@line 49742
 HEAP32[162769] = $54; //@line 49743
 return;
}
function __Z10Delay_usecj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $2 = 0, $20 = 0, $22 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $6 = 0, $9 = 0, label = 0, sp = 0, $27$looptemp = 0, $28$looptemp = 0;
 sp = STACKTOP; //@line 13713
 STACKTOP = STACKTOP + 16 | 0; //@line 13714
 $1 = sp + 8 | 0; //@line 13715
 $2 = sp; //@line 13716
 _gettimeofday($1 | 0, 0) | 0; //@line 13717
 $3 = HEAP32[$1 >> 2] | 0; //@line 13718
 $6 = ___muldi3($3 | 0, (($3 | 0) < 0) << 31 >> 31 | 0, 1e6, 0) | 0; //@line 13721
 $9 = HEAP32[$1 + 4 >> 2] | 0; //@line 13724
 $12 = _i64Add($6 | 0, tempRet0 | 0, $9 | 0, (($9 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 13727
 $14 = $1 + 4 | 0; //@line 13729
 $15 = $2 + 4 | 0; //@line 13730
 $$0 = $0; //@line 13731
 $27 = $12; //@line 13731
 $28 = tempRet0; //@line 13731
 while (1) {
  HEAP32[(___errno_location() | 0) >> 2] = 0; //@line 13734
  _gettimeofday($1 | 0, 0) | 0; //@line 13735
  $17 = HEAP32[$1 >> 2] | 0; //@line 13736
  $20 = ___muldi3($17 | 0, (($17 | 0) < 0) << 31 >> 31 | 0, 1e6, 0) | 0; //@line 13739
  $22 = HEAP32[$14 >> 2] | 0; //@line 13741
  $27$looptemp = $27;
  $27 = _i64Add($20 | 0, tempRet0 | 0, $22 | 0, (($22 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 13744
  $28$looptemp = $28;
  $28 = tempRet0; //@line 13745
  $29 = _i64Subtract($27 | 0, $28 | 0, $27$looptemp | 0, $28$looptemp | 0) | 0; //@line 13746
  $30 = tempRet0; //@line 13747
  if (!(0 > $30 >>> 0 | 0 == ($30 | 0) & $$0 >>> 0 > $29 >>> 0)) {
   label = 5; //@line 13754
   break;
  }
  $$0 = _i64Subtract($$0 | 0, 0, $29 | 0, $30 | 0) | 0; //@line 13757
  HEAP32[$2 >> 2] = 0; //@line 13759
  HEAP32[$15 >> 2] = $$0; //@line 13760
  if (!(_select(0, 0, 0, 0, $2) | 0)) {
   label = 5; //@line 13764
   break;
  }
  if ((HEAP32[(___errno_location() | 0) >> 2] | 0) != 4) {
   label = 5; //@line 13773
   break;
  }
 }
 if ((label | 0) == 5) {
  STACKTOP = sp; //@line 13778
  return;
 }
}
function __Z12op_48f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in23 = 0, $$019$in26 = 0, $$020$lcssa = 0, $$02025 = 0, $$122 = 0, $1 = 0, $24 = 0, $28 = 0, $3 = 0, $38 = 0, $4 = 0, $42 = 0, $56 = 0, $57 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 51347
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 51349
 $4 = $3 & 255; //@line 51350
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 51352
 $24 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 51370
 if (!($6 << 24 >> 24)) {
  $$020$lcssa = $24; //@line 51373
 } else {
  $$019$in26 = $6 & 255; //@line 51376
  $$02025 = $24; //@line 51376
  while (1) {
   $28 = $$019$in26 & 65535; //@line 51378
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02025 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02025, HEAP32[651008 + (HEAP32[385792 + ($28 << 2) >> 2] << 2) >> 2] | 0); //@line 51388
   $38 = $$02025 + 4 | 0; //@line 51389
   $$019$in26 = HEAP32[387840 + ($28 << 2) >> 2] | 0; //@line 51391
   if (!(($$019$in26 & 65535) << 16 >> 16)) {
    $$020$lcssa = $38; //@line 51395
    break;
   } else {
    $$02025 = $38; //@line 51398
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $56 = HEAP32[162769] | 0; //@line 51404
  $57 = $56 + 8 | 0; //@line 51405
  HEAP32[162769] = $57; //@line 51406
  return;
 } else {
  $$0$in23 = $4; //@line 51409
  $$122 = $$020$lcssa; //@line 51409
 }
 while (1) {
  $42 = $$0$in23 & 65535; //@line 51412
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$122, HEAP32[651040 + (HEAP32[385792 + ($42 << 2) >> 2] << 2) >> 2] | 0); //@line 51422
  $$0$in23 = HEAP32[387840 + ($42 << 2) >> 2] | 0; //@line 51425
  if (!(($$0$in23 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$122 = $$122 + 4 | 0; //@line 51431
  }
 }
 $56 = HEAP32[162769] | 0; //@line 51434
 $57 = $56 + 8 | 0; //@line 51435
 HEAP32[162769] = $57; //@line 51436
 return;
}
function __Z12op_48b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in23 = 0, $$019$in26 = 0, $$020$lcssa = 0, $$02025 = 0, $$122 = 0, $1 = 0, $24 = 0, $28 = 0, $3 = 0, $38 = 0, $4 = 0, $42 = 0, $56 = 0, $57 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 50782
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 50784
 $4 = $3 & 255; //@line 50785
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 50787
 $24 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 50805
 if (!($6 << 24 >> 24)) {
  $$020$lcssa = $24; //@line 50808
 } else {
  $$019$in26 = $6 & 255; //@line 50811
  $$02025 = $24; //@line 50811
  while (1) {
   $28 = $$019$in26 & 65535; //@line 50813
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02025 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02025, HEAP32[651008 + (HEAP32[385792 + ($28 << 2) >> 2] << 2) >> 2] | 0); //@line 50823
   $38 = $$02025 + 2 | 0; //@line 50824
   $$019$in26 = HEAP32[387840 + ($28 << 2) >> 2] | 0; //@line 50826
   if (!(($$019$in26 & 65535) << 16 >> 16)) {
    $$020$lcssa = $38; //@line 50830
    break;
   } else {
    $$02025 = $38; //@line 50833
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $56 = HEAP32[162769] | 0; //@line 50839
  $57 = $56 + 8 | 0; //@line 50840
  HEAP32[162769] = $57; //@line 50841
  return;
 } else {
  $$0$in23 = $4; //@line 50844
  $$122 = $$020$lcssa; //@line 50844
 }
 while (1) {
  $42 = $$0$in23 & 65535; //@line 50847
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$122, HEAP32[651040 + (HEAP32[385792 + ($42 << 2) >> 2] << 2) >> 2] | 0); //@line 50857
  $$0$in23 = HEAP32[387840 + ($42 << 2) >> 2] | 0; //@line 50860
  if (!(($$0$in23 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$122 = $$122 + 2 | 0; //@line 50866
  }
 }
 $56 = HEAP32[162769] | 0; //@line 50869
 $57 = $56 + 8 | 0; //@line 50870
 HEAP32[162769] = $57; //@line 50871
 return;
}
function __Z12op_48e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $37 = 0, $4 = 0, $5 = 0, $51 = 0, $52 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 51074
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 51076
 $5 = $4 & 255; //@line 51077
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 51079
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 51092
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $19; //@line 51095
 } else {
  $$023$in30 = $7 & 255; //@line 51098
  $$02429 = $19; //@line 51098
  while (1) {
   $23 = $$023$in30 & 65535; //@line 51100
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($23 << 2) >> 2] << 2) >> 2] | 0); //@line 51110
   $33 = $$02429 + 4 | 0; //@line 51111
   $$023$in30 = HEAP32[387840 + ($23 << 2) >> 2] | 0; //@line 51113
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $33; //@line 51117
    break;
   } else {
    $$02429 = $33; //@line 51120
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $51 = HEAP32[162769] | 0; //@line 51126
  $52 = $51 + 6 | 0; //@line 51127
  HEAP32[162769] = $52; //@line 51128
  return;
 } else {
  $$0$in27 = $5; //@line 51131
  $$126 = $$024$lcssa; //@line 51131
 }
 while (1) {
  $37 = $$0$in27 & 65535; //@line 51134
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($37 << 2) >> 2] << 2) >> 2] | 0); //@line 51144
  $$0$in27 = HEAP32[387840 + ($37 << 2) >> 2] | 0; //@line 51147
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 51153
  }
 }
 $51 = HEAP32[162769] | 0; //@line 51156
 $52 = $51 + 6 | 0; //@line 51157
 HEAP32[162769] = $52; //@line 51158
 return;
}
function __Z12op_48a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $37 = 0, $4 = 0, $5 = 0, $51 = 0, $52 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 50509
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50511
 $5 = $4 & 255; //@line 50512
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50514
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 50527
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $19; //@line 50530
 } else {
  $$023$in30 = $7 & 255; //@line 50533
  $$02429 = $19; //@line 50533
  while (1) {
   $23 = $$023$in30 & 65535; //@line 50535
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($23 << 2) >> 2] << 2) >> 2] | 0); //@line 50545
   $33 = $$02429 + 2 | 0; //@line 50546
   $$023$in30 = HEAP32[387840 + ($23 << 2) >> 2] | 0; //@line 50548
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $33; //@line 50552
    break;
   } else {
    $$02429 = $33; //@line 50555
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $51 = HEAP32[162769] | 0; //@line 50561
  $52 = $51 + 6 | 0; //@line 50562
  HEAP32[162769] = $52; //@line 50563
  return;
 } else {
  $$0$in27 = $5; //@line 50566
  $$126 = $$024$lcssa; //@line 50566
 }
 while (1) {
  $37 = $$0$in27 & 65535; //@line 50569
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($37 << 2) >> 2] << 2) >> 2] | 0); //@line 50579
  $$0$in27 = HEAP32[387840 + ($37 << 2) >> 2] | 0; //@line 50582
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 2 | 0; //@line 50588
  }
 }
 $51 = HEAP32[162769] | 0; //@line 50591
 $52 = $51 + 6 | 0; //@line 50592
 HEAP32[162769] = $52; //@line 50593
 return;
}
function __Z12op_8108_1_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $$neg = 0, $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $32 = 0, $34 = 0, $38 = 0, $4 = 0, $40 = 0, $44 = 0, $53 = 0, $8 = 0;
 $1 = $0 & 7; //@line 22480
 $3 = $0 >>> 9 & 7; //@line 22482
 $4 = 651040 + ($1 << 2) | 0; //@line 22483
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 22487
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 22493
 HEAP32[$4 >> 2] = $8; //@line 22494
 $15 = 651040 + ($3 << 2) | 0; //@line 22495
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 22499
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 22501
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 22505
 HEAP32[$15 >> 2] = $19; //@line 22506
 $26 = $25 << 24 >> 24; //@line 22508
 $28 = $14 << 24 >> 24; //@line 22511
 $32 = (HEAP32[96445] | 0) != 0; //@line 22515
 $$neg = $32 << 31 >> 31; //@line 22517
 $34 = ($26 & 15) - ($28 & 15) + $$neg | 0; //@line 22518
 $38 = $34 + (($26 & 240) - ($28 & 240)) | 0; //@line 22522
 $40 = ($34 & 240 | 0) == 0; //@line 22524
 $$ = $40 ? $38 : $38 + -6 | 0; //@line 22526
 $44 = ($26 & 255) - ($28 & 255) | 0; //@line 22529
 $$1$in = ($44 - ($32 & 1) & 256 | 0) == 0 ? $$ : $$ + 65440 | 0; //@line 22534
 $53 = ($$neg + $44 + ($40 ? 0 : 1018) & 768 | 0) != 0 & 1; //@line 22540
 HEAP32[96441] = $53; //@line 22541
 HEAP32[96445] = $53; //@line 22542
 HEAP32[96442] = ($$1$in & 255 | 0) == 0 & HEAP32[96442]; //@line 22548
 HEAP32[96443] = $$1$in >>> 7 & 1; //@line 22551
 HEAP32[96444] = ($38 & 128 | 0) != 0 & ($$1$in & 128 | 0) == 0 & 1; //@line 22559
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$1$in & 65535); //@line 22563
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 22566
 return;
}
function __Z12op_48f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $18 = 0, $2 = 0, $22 = 0, $32 = 0, $36 = 0, $4 = 0, $5 = 0, $50 = 0, $51 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 2882
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 2884
 $5 = $4 & 255; //@line 2885
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 2887
 $18 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 2898
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $18; //@line 2901
 } else {
  $$023$in30 = $7 & 255; //@line 2904
  $$02429 = $18; //@line 2904
  while (1) {
   $22 = $$023$in30 & 65535; //@line 2906
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($22 << 2) >> 2] << 2) >> 2] | 0); //@line 2916
   $32 = $$02429 + 4 | 0; //@line 2917
   $$023$in30 = HEAP32[387840 + ($22 << 2) >> 2] | 0; //@line 2919
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $32; //@line 2923
    break;
   } else {
    $$02429 = $32; //@line 2926
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $50 = HEAP32[162769] | 0; //@line 2932
  $51 = $50 + 6 | 0; //@line 2933
  HEAP32[162769] = $51; //@line 2934
  return;
 } else {
  $$0$in27 = $5; //@line 2937
  $$126 = $$024$lcssa; //@line 2937
 }
 while (1) {
  $36 = $$0$in27 & 65535; //@line 2940
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($36 << 2) >> 2] << 2) >> 2] | 0); //@line 2950
  $$0$in27 = HEAP32[387840 + ($36 << 2) >> 2] | 0; //@line 2953
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 2959
  }
 }
 $50 = HEAP32[162769] | 0; //@line 2962
 $51 = $50 + 6 | 0; //@line 2963
 HEAP32[162769] = $51; //@line 2964
 return;
}
function __Z12op_48b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $18 = 0, $2 = 0, $22 = 0, $32 = 0, $36 = 0, $4 = 0, $5 = 0, $50 = 0, $51 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 2790
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 2792
 $5 = $4 & 255; //@line 2793
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 2795
 $18 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 2806
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $18; //@line 2809
 } else {
  $$023$in30 = $7 & 255; //@line 2812
  $$02429 = $18; //@line 2812
  while (1) {
   $22 = $$023$in30 & 65535; //@line 2814
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($22 << 2) >> 2] << 2) >> 2] | 0); //@line 2824
   $32 = $$02429 + 2 | 0; //@line 2825
   $$023$in30 = HEAP32[387840 + ($22 << 2) >> 2] | 0; //@line 2827
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $32; //@line 2831
    break;
   } else {
    $$02429 = $32; //@line 2834
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $50 = HEAP32[162769] | 0; //@line 2840
  $51 = $50 + 6 | 0; //@line 2841
  HEAP32[162769] = $51; //@line 2842
  return;
 } else {
  $$0$in27 = $5; //@line 2845
  $$126 = $$024$lcssa; //@line 2845
 }
 while (1) {
  $36 = $$0$in27 & 65535; //@line 2848
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($36 << 2) >> 2] << 2) >> 2] | 0); //@line 2858
  $$0$in27 = HEAP32[387840 + ($36 << 2) >> 2] | 0; //@line 2861
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 2 | 0; //@line 2867
  }
 }
 $50 = HEAP32[162769] | 0; //@line 2870
 $51 = $50 + 6 | 0; //@line 2871
 HEAP32[162769] = $51; //@line 2872
 return;
}
function __Z12op_48f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in23 = 0, $$019$in26 = 0, $$020$lcssa = 0, $$02025 = 0, $$122 = 0, $1 = 0, $15 = 0, $19 = 0, $29 = 0, $3 = 0, $33 = 0, $4 = 0, $47 = 0, $48 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 51256
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 51258
 $4 = $3 & 255; //@line 51259
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 51261
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 51271
 if (!($6 << 24 >> 24)) {
  $$020$lcssa = $15; //@line 51274
 } else {
  $$019$in26 = $6 & 255; //@line 51277
  $$02025 = $15; //@line 51277
  while (1) {
   $19 = $$019$in26 & 65535; //@line 51279
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02025 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02025, HEAP32[651008 + (HEAP32[385792 + ($19 << 2) >> 2] << 2) >> 2] | 0); //@line 51289
   $29 = $$02025 + 4 | 0; //@line 51290
   $$019$in26 = HEAP32[387840 + ($19 << 2) >> 2] | 0; //@line 51292
   if (!(($$019$in26 & 65535) << 16 >> 16)) {
    $$020$lcssa = $29; //@line 51296
    break;
   } else {
    $$02025 = $29; //@line 51299
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $47 = HEAP32[162769] | 0; //@line 51305
  $48 = $47 + 6 | 0; //@line 51306
  HEAP32[162769] = $48; //@line 51307
  return;
 } else {
  $$0$in23 = $4; //@line 51310
  $$122 = $$020$lcssa; //@line 51310
 }
 while (1) {
  $33 = $$0$in23 & 65535; //@line 51313
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$122, HEAP32[651040 + (HEAP32[385792 + ($33 << 2) >> 2] << 2) >> 2] | 0); //@line 51323
  $$0$in23 = HEAP32[387840 + ($33 << 2) >> 2] | 0; //@line 51326
  if (!(($$0$in23 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$122 = $$122 + 4 | 0; //@line 51332
  }
 }
 $47 = HEAP32[162769] | 0; //@line 51335
 $48 = $47 + 6 | 0; //@line 51336
 HEAP32[162769] = $48; //@line 51337
 return;
}
function __Z12op_48b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in23 = 0, $$019$in26 = 0, $$020$lcssa = 0, $$02025 = 0, $$122 = 0, $1 = 0, $15 = 0, $19 = 0, $29 = 0, $3 = 0, $33 = 0, $4 = 0, $47 = 0, $48 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 50691
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 50693
 $4 = $3 & 255; //@line 50694
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 50696
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 50706
 if (!($6 << 24 >> 24)) {
  $$020$lcssa = $15; //@line 50709
 } else {
  $$019$in26 = $6 & 255; //@line 50712
  $$02025 = $15; //@line 50712
  while (1) {
   $19 = $$019$in26 & 65535; //@line 50714
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02025 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02025, HEAP32[651008 + (HEAP32[385792 + ($19 << 2) >> 2] << 2) >> 2] | 0); //@line 50724
   $29 = $$02025 + 2 | 0; //@line 50725
   $$019$in26 = HEAP32[387840 + ($19 << 2) >> 2] | 0; //@line 50727
   if (!(($$019$in26 & 65535) << 16 >> 16)) {
    $$020$lcssa = $29; //@line 50731
    break;
   } else {
    $$02025 = $29; //@line 50734
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $47 = HEAP32[162769] | 0; //@line 50740
  $48 = $47 + 6 | 0; //@line 50741
  HEAP32[162769] = $48; //@line 50742
  return;
 } else {
  $$0$in23 = $4; //@line 50745
  $$122 = $$020$lcssa; //@line 50745
 }
 while (1) {
  $33 = $$0$in23 & 65535; //@line 50748
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$122, HEAP32[651040 + (HEAP32[385792 + ($33 << 2) >> 2] << 2) >> 2] | 0); //@line 50758
  $$0$in23 = HEAP32[387840 + ($33 << 2) >> 2] | 0; //@line 50761
  if (!(($$0$in23 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$122 = $$122 + 2 | 0; //@line 50767
  }
 }
 $47 = HEAP32[162769] | 0; //@line 50770
 $48 = $47 + 6 | 0; //@line 50771
 HEAP32[162769] = $48; //@line 50772
 return;
}
function __ZNSt3__26vectorI15disk_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 18274
 $4 = HEAP32[$0 >> 2] | 0; //@line 18276
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 18277
 $6 = ($5 | 0) / 24 | 0; //@line 18278
 $7 = $6 + 1 | 0; //@line 18279
 if ($7 >>> 0 > 178956970) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 18282
 }
 $9 = $0 + 8 | 0; //@line 18285
 $12 = ((HEAP32[$9 >> 2] | 0) - $4 | 0) / 24 | 0; //@line 18288
 $14 = $12 << 1; //@line 18290
 $$sroa$speculated$$i = $12 >>> 0 < 89478485 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 178956970; //@line 18293
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 18297
  } else {
   if ($$sroa$speculated$$i >>> 0 > 178956970) {
    _abort(); //@line 18301
   } else {
    $21 = __Znwj($$sroa$speculated$$i * 24 | 0) | 0; //@line 18306
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 * 24 | 0) | 0; //@line 18311
 $23 = $21 + ($$sroa$speculated$$i * 24 | 0) | 0; //@line 18313
 HEAP32[$20 >> 2] = HEAP32[$1 >> 2]; //@line 18314
 HEAP32[$20 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 18314
 HEAP32[$20 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 18314
 HEAP32[$20 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 18314
 HEAP32[$20 + 16 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 18314
 HEAP32[$20 + 20 >> 2] = HEAP32[$1 + 20 >> 2]; //@line 18314
 $27 = $20 + ((($5 | 0) / -24 | 0) * 24 | 0) | 0; //@line 18318
 if (($5 | 0) > 0) {
  _memcpy($27 | 0, $4 | 0, $5 | 0) | 0; //@line 18323
 }
 HEAP32[$0 >> 2] = $27; //@line 18325
 HEAP32[$2 >> 2] = $20 + 24; //@line 18326
 HEAP32[$9 >> 2] = $23; //@line 18327
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 18333
 return;
}
function __Z12op_48f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $10 = 0, $17 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 51168
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 51170
 $5 = $4 & 255; //@line 51171
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 51173
 $8 = $2 + 4 | 0; //@line 51174
 HEAP32[162769] = $8; //@line 51175
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51177
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 51184
 HEAP32[162769] = $2 + 6; //@line 51186
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 51187
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $19; //@line 51190
 } else {
  $$023$in30 = $7 & 255; //@line 51193
  $$02429 = $19; //@line 51193
  while (1) {
   $23 = $$023$in30 & 65535; //@line 51195
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($23 << 2) >> 2] << 2) >> 2] | 0); //@line 51205
   $33 = $$02429 + 4 | 0; //@line 51206
   $$023$in30 = HEAP32[387840 + ($23 << 2) >> 2] | 0; //@line 51208
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $33; //@line 51212
    break;
   } else {
    $$02429 = $33; //@line 51215
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  return;
 } else {
  $$0$in27 = $5; //@line 51223
  $$126 = $$024$lcssa; //@line 51223
 }
 while (1) {
  $37 = $$0$in27 & 65535; //@line 51226
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($37 << 2) >> 2] << 2) >> 2] | 0); //@line 51236
  $$0$in27 = HEAP32[387840 + ($37 << 2) >> 2] | 0; //@line 51239
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 51245
  }
 }
 return;
}
function __Z12op_48b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $10 = 0, $17 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 50603
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50605
 $5 = $4 & 255; //@line 50606
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50608
 $8 = $2 + 4 | 0; //@line 50609
 HEAP32[162769] = $8; //@line 50610
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 50612
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 50619
 HEAP32[162769] = $2 + 6; //@line 50621
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 50622
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $19; //@line 50625
 } else {
  $$023$in30 = $7 & 255; //@line 50628
  $$02429 = $19; //@line 50628
  while (1) {
   $23 = $$023$in30 & 65535; //@line 50630
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($23 << 2) >> 2] << 2) >> 2] | 0); //@line 50640
   $33 = $$02429 + 2 | 0; //@line 50641
   $$023$in30 = HEAP32[387840 + ($23 << 2) >> 2] | 0; //@line 50643
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $33; //@line 50647
    break;
   } else {
    $$02429 = $33; //@line 50650
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  return;
 } else {
  $$0$in27 = $5; //@line 50658
  $$126 = $$024$lcssa; //@line 50658
 }
 while (1) {
  $37 = $$0$in27 & 65535; //@line 50661
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($37 << 2) >> 2] << 2) >> 2] | 0); //@line 50671
  $$0$in27 = HEAP32[387840 + ($37 << 2) >> 2] | 0; //@line 50674
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 2 | 0; //@line 50680
  }
 }
 return;
}
function __Z12op_4cba_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02226 = 0, $$02328 = 0, $$029 = 0, $$127 = 0, $1 = 0, $22 = 0, $3 = 0, $32 = 0, $36 = 0, $4 = 0, $46 = 0, $54 = 0, $55 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 54270
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54272
 $4 = $3 & 255; //@line 54273
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54275
 $22 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 54292
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $22; //@line 54295
 } else {
  $$02328 = $6 & 255; //@line 54298
  $$029 = $22; //@line 54298
  while (1) {
   $32 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$029) | 0) << 16 >> 16; //@line 54307
   HEAP32[651008 + (HEAP32[385792 + ($$02328 << 2) >> 2] << 2) >> 2] = $32; //@line 54311
   $36 = $$029 + 2 | 0; //@line 54312
   $$02328 = HEAP32[387840 + ($$02328 << 2) >> 2] | 0; //@line 54314
   if (!$$02328) {
    $$0$lcssa = $36; //@line 54317
    break;
   } else {
    $$029 = $36; //@line 54320
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $54 = HEAP32[162769] | 0; //@line 54326
  $55 = $54 + 6 | 0; //@line 54327
  HEAP32[162769] = $55; //@line 54328
  return;
 } else {
  $$02226 = $4; //@line 54331
  $$127 = $$0$lcssa; //@line 54331
 }
 while (1) {
  $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$127) | 0) << 16 >> 16; //@line 54341
  HEAP32[651040 + (HEAP32[385792 + ($$02226 << 2) >> 2] << 2) >> 2] = $46; //@line 54345
  $$02226 = HEAP32[387840 + ($$02226 << 2) >> 2] | 0; //@line 54348
  if (!$$02226) {
   break;
  } else {
   $$127 = $$127 + 2 | 0; //@line 54353
  }
 }
 $54 = HEAP32[162769] | 0; //@line 54356
 $55 = $54 + 6 | 0; //@line 54357
 HEAP32[162769] = $55; //@line 54358
 return;
}
function __ZNSt3__26vectorI10video_modeNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 45911
 $4 = HEAP32[$0 >> 2] | 0; //@line 45913
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 45914
 $6 = ($5 | 0) / 24 | 0; //@line 45915
 $7 = $6 + 1 | 0; //@line 45916
 if ($7 >>> 0 > 178956970) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 45919
 }
 $9 = $0 + 8 | 0; //@line 45922
 $12 = ((HEAP32[$9 >> 2] | 0) - $4 | 0) / 24 | 0; //@line 45925
 $14 = $12 << 1; //@line 45927
 $$sroa$speculated$$i = $12 >>> 0 < 89478485 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 178956970; //@line 45930
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 45934
  } else {
   if ($$sroa$speculated$$i >>> 0 > 178956970) {
    _abort(); //@line 45938
   } else {
    $21 = __Znwj($$sroa$speculated$$i * 24 | 0) | 0; //@line 45943
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 * 24 | 0) | 0; //@line 45948
 $23 = $21 + ($$sroa$speculated$$i * 24 | 0) | 0; //@line 45950
 HEAP32[$20 >> 2] = HEAP32[$1 >> 2]; //@line 45951
 HEAP32[$20 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 45951
 HEAP32[$20 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 45951
 HEAP32[$20 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 45951
 HEAP32[$20 + 16 >> 2] = HEAP32[$1 + 16 >> 2]; //@line 45951
 HEAP32[$20 + 20 >> 2] = HEAP32[$1 + 20 >> 2]; //@line 45951
 $27 = $20 + ((($5 | 0) / -24 | 0) * 24 | 0) | 0; //@line 45955
 if (($5 | 0) > 0) {
  _memcpy($27 | 0, $4 | 0, $5 | 0) | 0; //@line 45960
 }
 HEAP32[$0 >> 2] = $27; //@line 45962
 HEAP32[$2 >> 2] = $20 + 24; //@line 45963
 HEAP32[$9 >> 2] = $23; //@line 45964
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 45970
 return;
}
function __Z12op_4cb9_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$01922 = 0, $$02024 = 0, $$025 = 0, $$123 = 0, $1 = 0, $24 = 0, $3 = 0, $34 = 0, $38 = 0, $4 = 0, $48 = 0, $56 = 0, $57 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 54171
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54173
 $4 = $3 & 255; //@line 54174
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54176
 $24 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 54194
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $24; //@line 54197
 } else {
  $$02024 = $6 & 255; //@line 54200
  $$025 = $24; //@line 54200
  while (1) {
   $34 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$025 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$025) | 0) << 16 >> 16; //@line 54209
   HEAP32[651008 + (HEAP32[385792 + ($$02024 << 2) >> 2] << 2) >> 2] = $34; //@line 54213
   $38 = $$025 + 2 | 0; //@line 54214
   $$02024 = HEAP32[387840 + ($$02024 << 2) >> 2] | 0; //@line 54216
   if (!$$02024) {
    $$0$lcssa = $38; //@line 54219
    break;
   } else {
    $$025 = $38; //@line 54222
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $56 = HEAP32[162769] | 0; //@line 54228
  $57 = $56 + 8 | 0; //@line 54229
  HEAP32[162769] = $57; //@line 54230
  return;
 } else {
  $$01922 = $4; //@line 54233
  $$123 = $$0$lcssa; //@line 54233
 }
 while (1) {
  $48 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$123 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$123) | 0) << 16 >> 16; //@line 54243
  HEAP32[651040 + (HEAP32[385792 + ($$01922 << 2) >> 2] << 2) >> 2] = $48; //@line 54247
  $$01922 = HEAP32[387840 + ($$01922 << 2) >> 2] | 0; //@line 54250
  if (!$$01922) {
   break;
  } else {
   $$123 = $$123 + 2 | 0; //@line 54255
  }
 }
 $56 = HEAP32[162769] | 0; //@line 54258
 $57 = $56 + 8 | 0; //@line 54259
 HEAP32[162769] = $57; //@line 54260
 return;
}
function __Z12op_4ca8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02327 = 0, $$02429 = 0, $$030 = 0, $$128 = 0, $19 = 0, $2 = 0, $29 = 0, $33 = 0, $4 = 0, $43 = 0, $5 = 0, $51 = 0, $52 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53898
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 53900
 $5 = $4 & 255; //@line 53901
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 53903
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 53916
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $19; //@line 53919
 } else {
  $$02429 = $7 & 255; //@line 53922
  $$030 = $19; //@line 53922
  while (1) {
   $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$030 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$030) | 0) << 16 >> 16; //@line 53931
   HEAP32[651008 + (HEAP32[385792 + ($$02429 << 2) >> 2] << 2) >> 2] = $29; //@line 53935
   $33 = $$030 + 2 | 0; //@line 53936
   $$02429 = HEAP32[387840 + ($$02429 << 2) >> 2] | 0; //@line 53938
   if (!$$02429) {
    $$0$lcssa = $33; //@line 53941
    break;
   } else {
    $$030 = $33; //@line 53944
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $51 = HEAP32[162769] | 0; //@line 53950
  $52 = $51 + 6 | 0; //@line 53951
  HEAP32[162769] = $52; //@line 53952
  return;
 } else {
  $$02327 = $5; //@line 53955
  $$128 = $$0$lcssa; //@line 53955
 }
 while (1) {
  $43 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$128 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$128) | 0) << 16 >> 16; //@line 53965
  HEAP32[651040 + (HEAP32[385792 + ($$02327 << 2) >> 2] << 2) >> 2] = $43; //@line 53969
  $$02327 = HEAP32[387840 + ($$02327 << 2) >> 2] | 0; //@line 53972
  if (!$$02327) {
   break;
  } else {
   $$128 = $$128 + 2 | 0; //@line 53977
  }
 }
 $51 = HEAP32[162769] | 0; //@line 53980
 $52 = $51 + 6 | 0; //@line 53981
 HEAP32[162769] = $52; //@line 53982
 return;
}
function __Z12op_4cbb_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02429 = 0, $$02527 = 0, $$030 = 0, $$128 = 0, $1 = 0, $21 = 0, $3 = 0, $31 = 0, $35 = 0, $4 = 0, $45 = 0, $53 = 0, $54 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 3334
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 3336
 $4 = $3 & 255; //@line 3337
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 3339
 $21 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 3354
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $21; //@line 3357
 } else {
  $$02429 = $6 & 255; //@line 3360
  $$030 = $21; //@line 3360
  while (1) {
   $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$030 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$030) | 0) << 16 >> 16; //@line 3369
   HEAP32[651008 + (HEAP32[385792 + ($$02429 << 2) >> 2] << 2) >> 2] = $31; //@line 3373
   $35 = $$030 + 2 | 0; //@line 3374
   $$02429 = HEAP32[387840 + ($$02429 << 2) >> 2] | 0; //@line 3376
   if (!$$02429) {
    $$0$lcssa = $35; //@line 3379
    break;
   } else {
    $$030 = $35; //@line 3382
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $53 = HEAP32[162769] | 0; //@line 3388
  $54 = $53 + 6 | 0; //@line 3389
  HEAP32[162769] = $54; //@line 3390
  return;
 } else {
  $$02527 = $4; //@line 3393
  $$128 = $$0$lcssa; //@line 3393
 }
 while (1) {
  $45 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$128 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$128) | 0) << 16 >> 16; //@line 3403
  HEAP32[651040 + (HEAP32[385792 + ($$02527 << 2) >> 2] << 2) >> 2] = $45; //@line 3407
  $$02527 = HEAP32[387840 + ($$02527 << 2) >> 2] | 0; //@line 3410
  if (!$$02527) {
   break;
  } else {
   $$128 = $$128 + 2 | 0; //@line 3415
  }
 }
 $53 = HEAP32[162769] | 0; //@line 3418
 $54 = $53 + 6 | 0; //@line 3419
 HEAP32[162769] = $54; //@line 3420
 return;
}
function __Z12op_48d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $13 = 0, $2 = 0, $23 = 0, $27 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 50903
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50905
 $5 = $4 & 255; //@line 50906
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50908
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 50910
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $9; //@line 50913
 } else {
  $$023$in30 = $7 & 255; //@line 50916
  $$02429 = $9; //@line 50916
  while (1) {
   $13 = $$023$in30 & 65535; //@line 50918
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($13 << 2) >> 2] << 2) >> 2] | 0); //@line 50928
   $23 = $$02429 + 4 | 0; //@line 50929
   $$023$in30 = HEAP32[387840 + ($13 << 2) >> 2] | 0; //@line 50931
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $23; //@line 50935
    break;
   } else {
    $$02429 = $23; //@line 50938
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $41 = HEAP32[162769] | 0; //@line 50944
  $42 = $41 + 4 | 0; //@line 50945
  HEAP32[162769] = $42; //@line 50946
  return;
 } else {
  $$0$in27 = $5; //@line 50949
  $$126 = $$024$lcssa; //@line 50949
 }
 while (1) {
  $27 = $$0$in27 & 65535; //@line 50952
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($27 << 2) >> 2] << 2) >> 2] | 0); //@line 50962
  $$0$in27 = HEAP32[387840 + ($27 << 2) >> 2] | 0; //@line 50965
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 50971
  }
 }
 $41 = HEAP32[162769] | 0; //@line 50974
 $42 = $41 + 4 | 0; //@line 50975
 HEAP32[162769] = $42; //@line 50976
 return;
}
function __Z12op_4890_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$in27 = 0, $$023$in30 = 0, $$024$lcssa = 0, $$02429 = 0, $$126 = 0, $13 = 0, $2 = 0, $23 = 0, $27 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 50338
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 50340
 $5 = $4 & 255; //@line 50341
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 50343
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 50345
 if (!($7 << 24 >> 24)) {
  $$024$lcssa = $9; //@line 50348
 } else {
  $$023$in30 = $7 & 255; //@line 50351
  $$02429 = $9; //@line 50351
  while (1) {
   $13 = $$023$in30 & 65535; //@line 50353
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$02429 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$02429, HEAP32[651008 + (HEAP32[385792 + ($13 << 2) >> 2] << 2) >> 2] | 0); //@line 50363
   $23 = $$02429 + 2 | 0; //@line 50364
   $$023$in30 = HEAP32[387840 + ($13 << 2) >> 2] | 0; //@line 50366
   if (!(($$023$in30 & 65535) << 16 >> 16)) {
    $$024$lcssa = $23; //@line 50370
    break;
   } else {
    $$02429 = $23; //@line 50373
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $41 = HEAP32[162769] | 0; //@line 50379
  $42 = $41 + 4 | 0; //@line 50380
  HEAP32[162769] = $42; //@line 50381
  return;
 } else {
  $$0$in27 = $5; //@line 50384
  $$126 = $$024$lcssa; //@line 50384
 }
 while (1) {
  $27 = $$0$in27 & 65535; //@line 50387
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($$126, HEAP32[651040 + (HEAP32[385792 + ($27 << 2) >> 2] << 2) >> 2] | 0); //@line 50397
  $$0$in27 = HEAP32[387840 + ($27 << 2) >> 2] | 0; //@line 50400
  if (!(($$0$in27 & 65535) << 16 >> 16)) {
   break;
  } else {
   $$126 = $$126 + 2 | 0; //@line 50406
  }
 }
 $41 = HEAP32[162769] | 0; //@line 50409
 $42 = $41 + 4 | 0; //@line 50410
 HEAP32[162769] = $42; //@line 50411
 return;
}
function __Z12op_4cb0_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02326 = 0, $$02428 = 0, $$029 = 0, $$127 = 0, $18 = 0, $2 = 0, $28 = 0, $32 = 0, $4 = 0, $42 = 0, $5 = 0, $50 = 0, $51 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 3242
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 3244
 $5 = $4 & 255; //@line 3245
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 3247
 $18 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 3258
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $18; //@line 3261
 } else {
  $$02428 = $7 & 255; //@line 3264
  $$029 = $18; //@line 3264
  while (1) {
   $28 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$029) | 0) << 16 >> 16; //@line 3273
   HEAP32[651008 + (HEAP32[385792 + ($$02428 << 2) >> 2] << 2) >> 2] = $28; //@line 3277
   $32 = $$029 + 2 | 0; //@line 3278
   $$02428 = HEAP32[387840 + ($$02428 << 2) >> 2] | 0; //@line 3280
   if (!$$02428) {
    $$0$lcssa = $32; //@line 3283
    break;
   } else {
    $$029 = $32; //@line 3286
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $50 = HEAP32[162769] | 0; //@line 3292
  $51 = $50 + 6 | 0; //@line 3293
  HEAP32[162769] = $51; //@line 3294
  return;
 } else {
  $$02326 = $5; //@line 3297
  $$127 = $$0$lcssa; //@line 3297
 }
 while (1) {
  $42 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$127) | 0) << 16 >> 16; //@line 3307
  HEAP32[651040 + (HEAP32[385792 + ($$02326 << 2) >> 2] << 2) >> 2] = $42; //@line 3311
  $$02326 = HEAP32[387840 + ($$02326 << 2) >> 2] | 0; //@line 3314
  if (!$$02326) {
   break;
  } else {
   $$127 = $$127 + 2 | 0; //@line 3319
  }
 }
 $50 = HEAP32[162769] | 0; //@line 3322
 $51 = $50 + 6 | 0; //@line 3323
 HEAP32[162769] = $51; //@line 3324
 return;
}
function __Z12op_4cf9_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$01921 = 0, $$02023 = 0, $$024 = 0, $$122 = 0, $1 = 0, $24 = 0, $3 = 0, $32 = 0, $36 = 0, $4 = 0, $44 = 0, $52 = 0, $53 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 54872
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54874
 $4 = $3 & 255; //@line 54875
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54877
 $24 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 54895
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $24; //@line 54898
 } else {
  $$02023 = $6 & 255; //@line 54901
  $$024 = $24; //@line 54901
  while (1) {
   $32 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$024 >>> 16 << 2) >> 2] >> 2] & 127]($$024) | 0; //@line 54907
   HEAP32[651008 + (HEAP32[385792 + ($$02023 << 2) >> 2] << 2) >> 2] = $32; //@line 54911
   $36 = $$024 + 4 | 0; //@line 54912
   $$02023 = HEAP32[387840 + ($$02023 << 2) >> 2] | 0; //@line 54914
   if (!$$02023) {
    $$0$lcssa = $36; //@line 54917
    break;
   } else {
    $$024 = $36; //@line 54920
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $52 = HEAP32[162769] | 0; //@line 54926
  $53 = $52 + 8 | 0; //@line 54927
  HEAP32[162769] = $53; //@line 54928
  return;
 } else {
  $$01921 = $4; //@line 54931
  $$122 = $$0$lcssa; //@line 54931
 }
 while (1) {
  $44 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] >> 2] & 127]($$122) | 0; //@line 54938
  HEAP32[651040 + (HEAP32[385792 + ($$01921 << 2) >> 2] << 2) >> 2] = $44; //@line 54942
  $$01921 = HEAP32[387840 + ($$01921 << 2) >> 2] | 0; //@line 54945
  if (!$$01921) {
   break;
  } else {
   $$122 = $$122 + 4 | 0; //@line 54950
  }
 }
 $52 = HEAP32[162769] | 0; //@line 54953
 $53 = $52 + 8 | 0; //@line 54954
 HEAP32[162769] = $53; //@line 54955
 return;
}
function __Z12op_ebfb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $14 = 0, $21 = 0, $23 = 0, $24 = 0, $27 = 0, $38 = 0, $39 = 0, $4 = 0, $41 = 0, $45 = 0, $50 = 0, $51 = 0, $59 = 0, $65 = 0, $68 = 0, $9 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 45072
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 45075
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 45080
 $10 = $1 + 4 | 0; //@line 45081
 HEAP32[162769] = $10; //@line 45082
 $14 = (HEAP32[162768] | 0) + $10 - (HEAP32[162770] | 0) | 0; //@line 45087
 $21 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 45094
 HEAP32[162769] = $1 + 6; //@line 45096
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 45097
 $sext = $9 << 16; //@line 45098
 $24 = $sext >> 16; //@line 45099
 $27 = $sext >> 22; //@line 45102
 if (!($24 & 2048)) {
  $41 = $27 & 31; //@line 45105
 } else {
  $41 = HEAP32[651008 + (($27 & 7) << 2) >> 2] | 0; //@line 45110
 }
 if (!($24 & 32)) {
  $38 = $24; //@line 45115
 } else {
  $38 = HEAP32[651008 + (($24 & 7) << 2) >> 2] | 0; //@line 45120
 }
 $39 = $38 + 31 & 31; //@line 45123
 $45 = ($41 >> 31 & -536870912 | $41 >> 3) + $23 | 0; //@line 45128
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 45133
 $51 = $45 + 4 | 0; //@line 45134
 $59 = $41 & 7; //@line 45142
 $65 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($51) | 0) & 255) >>> (8 - $59 | 0) | $50 << $59) >>> ($39 ^ 31); //@line 45148
 $68 = ($65 & 1 << $39 | 0) != 0; //@line 45151
 HEAP32[96443] = $68 & 1; //@line 45153
 HEAP32[96442] = ($65 | 0) == 0 & 1; //@line 45156
 HEAP32[96444] = 0; //@line 45157
 HEAP32[96441] = 0; //@line 45158
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = ($68 ? -2 << $39 : 0) | $65; //@line 45165
 return;
}
function __Z12op_4cbb_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02429 = 0, $$02527 = 0, $$030 = 0, $$128 = 0, $1 = 0, $11 = 0, $18 = 0, $20 = 0, $3 = 0, $30 = 0, $34 = 0, $4 = 0, $44 = 0, $6 = 0, $7 = 0;
 $1 = HEAP32[162769] | 0; //@line 54368
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54370
 $4 = $3 & 255; //@line 54371
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54373
 $7 = $1 + 4 | 0; //@line 54374
 HEAP32[162769] = $7; //@line 54375
 $11 = (HEAP32[162768] | 0) + $7 - (HEAP32[162770] | 0) | 0; //@line 54380
 $18 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 54387
 HEAP32[162769] = $1 + 6; //@line 54389
 $20 = __Z15get_disp_ea_020jj($11, $18) | 0; //@line 54390
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $20; //@line 54393
 } else {
  $$02429 = $6 & 255; //@line 54396
  $$030 = $20; //@line 54396
  while (1) {
   $30 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$030 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$030) | 0) << 16 >> 16; //@line 54405
   HEAP32[651008 + (HEAP32[385792 + ($$02429 << 2) >> 2] << 2) >> 2] = $30; //@line 54409
   $34 = $$030 + 2 | 0; //@line 54410
   $$02429 = HEAP32[387840 + ($$02429 << 2) >> 2] | 0; //@line 54412
   if (!$$02429) {
    $$0$lcssa = $34; //@line 54415
    break;
   } else {
    $$030 = $34; //@line 54418
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  return;
 } else {
  $$02527 = $4; //@line 54426
  $$128 = $$0$lcssa; //@line 54426
 }
 while (1) {
  $44 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$128 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$128) | 0) << 16 >> 16; //@line 54436
  HEAP32[651040 + (HEAP32[385792 + ($$02527 << 2) >> 2] << 2) >> 2] = $44; //@line 54440
  $$02527 = HEAP32[387840 + ($$02527 << 2) >> 2] | 0; //@line 54443
  if (!$$02527) {
   break;
  } else {
   $$128 = $$128 + 2 | 0; //@line 54448
  }
 }
 return;
}
function __Z12op_4ce8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02325 = 0, $$02427 = 0, $$028 = 0, $$126 = 0, $19 = 0, $2 = 0, $27 = 0, $31 = 0, $39 = 0, $4 = 0, $47 = 0, $48 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 54618
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 54620
 $5 = $4 & 255; //@line 54621
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 54623
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 54636
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $19; //@line 54639
 } else {
  $$02427 = $7 & 255; //@line 54642
  $$028 = $19; //@line 54642
  while (1) {
   $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$028 >>> 16 << 2) >> 2] >> 2] & 127]($$028) | 0; //@line 54648
   HEAP32[651008 + (HEAP32[385792 + ($$02427 << 2) >> 2] << 2) >> 2] = $27; //@line 54652
   $31 = $$028 + 4 | 0; //@line 54653
   $$02427 = HEAP32[387840 + ($$02427 << 2) >> 2] | 0; //@line 54655
   if (!$$02427) {
    $$0$lcssa = $31; //@line 54658
    break;
   } else {
    $$028 = $31; //@line 54661
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $47 = HEAP32[162769] | 0; //@line 54667
  $48 = $47 + 6 | 0; //@line 54668
  HEAP32[162769] = $48; //@line 54669
  return;
 } else {
  $$02325 = $5; //@line 54672
  $$126 = $$0$lcssa; //@line 54672
 }
 while (1) {
  $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] >> 2] & 127]($$126) | 0; //@line 54679
  HEAP32[651040 + (HEAP32[385792 + ($$02325 << 2) >> 2] << 2) >> 2] = $39; //@line 54683
  $$02325 = HEAP32[387840 + ($$02325 << 2) >> 2] | 0; //@line 54686
  if (!$$02325) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 54691
  }
 }
 $47 = HEAP32[162769] | 0; //@line 54694
 $48 = $47 + 6 | 0; //@line 54695
 HEAP32[162769] = $48; //@line 54696
 return;
}
function __Z12op_4cb8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$01923 = 0, $$02025 = 0, $$026 = 0, $$124 = 0, $1 = 0, $15 = 0, $25 = 0, $29 = 0, $3 = 0, $39 = 0, $4 = 0, $47 = 0, $48 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 54080
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54082
 $4 = $3 & 255; //@line 54083
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54085
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 54095
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $15; //@line 54098
 } else {
  $$02025 = $6 & 255; //@line 54101
  $$026 = $15; //@line 54101
  while (1) {
   $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$026 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$026) | 0) << 16 >> 16; //@line 54110
   HEAP32[651008 + (HEAP32[385792 + ($$02025 << 2) >> 2] << 2) >> 2] = $25; //@line 54114
   $29 = $$026 + 2 | 0; //@line 54115
   $$02025 = HEAP32[387840 + ($$02025 << 2) >> 2] | 0; //@line 54117
   if (!$$02025) {
    $$0$lcssa = $29; //@line 54120
    break;
   } else {
    $$026 = $29; //@line 54123
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $47 = HEAP32[162769] | 0; //@line 54129
  $48 = $47 + 6 | 0; //@line 54130
  HEAP32[162769] = $48; //@line 54131
  return;
 } else {
  $$01923 = $4; //@line 54134
  $$124 = $$0$lcssa; //@line 54134
 }
 while (1) {
  $39 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$124 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$124) | 0) << 16 >> 16; //@line 54144
  HEAP32[651040 + (HEAP32[385792 + ($$01923 << 2) >> 2] << 2) >> 2] = $39; //@line 54148
  $$01923 = HEAP32[387840 + ($$01923 << 2) >> 2] | 0; //@line 54151
  if (!$$01923) {
   break;
  } else {
   $$124 = $$124 + 2 | 0; //@line 54156
  }
 }
 $47 = HEAP32[162769] | 0; //@line 54159
 $48 = $47 + 6 | 0; //@line 54160
 HEAP32[162769] = $48; //@line 54161
 return;
}
function __Z12op_81f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $$cast = 0, $16 = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $31 = 0, $32 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext45$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 17200
 $5 = HEAP32[162769] | 0; //@line 17201
 $6 = HEAP32[162770] | 0; //@line 17202
 $$cast = $5; //@line 17203
 $7 = $$cast + 2 | 0; //@line 17204
 HEAP32[162769] = $7; //@line 17205
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 17207
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 17214
 HEAP32[162769] = $$cast + 4; //@line 17216
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 17217
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 17223
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17224
 $26 = HEAP32[$25 >> 2] | 0; //@line 17225
 $27 = $24 << 16 >> 16; //@line 17227
 if (!$27) {
  HEAP32[96444] = 0; //@line 17232
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 17233
  return;
 }
 $31 = ($26 | 0) / ($27 | 0) | 0; //@line 17236
 $32 = ($26 | 0) % ($27 | 0) | 0; //@line 17237
 if (($31 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17241
  HEAP32[96443] = 1; //@line 17242
  HEAP32[96441] = 0; //@line 17243
  return;
 } else {
  $$043 = ($32 >>> 15 & 1 | 0) == ($26 >>> 31 | 0) ? $32 : 0 - $32 | 0; //@line 17251
  $sext45$mask = $31 & 65535; //@line 17252
  $38 = ($sext45$mask | 0) == 0 & 1; //@line 17254
  HEAP32[96441] = 0; //@line 17255
  HEAP32[96442] = 0; //@line 17255
  HEAP32[96443] = 0; //@line 17255
  HEAP32[96444] = 0; //@line 17255
  HEAP32[96442] = $38; //@line 17256
  HEAP32[96443] = $31 >>> 15 & 1; //@line 17259
  HEAP32[$25 >> 2] = $$043 << 16 | $sext45$mask; //@line 17262
  return;
 }
}
function __Z12op_4cfb_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02428 = 0, $$02526 = 0, $$029 = 0, $$127 = 0, $1 = 0, $21 = 0, $29 = 0, $3 = 0, $33 = 0, $4 = 0, $41 = 0, $49 = 0, $50 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 3515
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 3517
 $4 = $3 & 255; //@line 3518
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 3520
 $21 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 3535
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $21; //@line 3538
 } else {
  $$02428 = $6 & 255; //@line 3541
  $$029 = $21; //@line 3541
  while (1) {
   $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] >> 2] & 127]($$029) | 0; //@line 3547
   HEAP32[651008 + (HEAP32[385792 + ($$02428 << 2) >> 2] << 2) >> 2] = $29; //@line 3551
   $33 = $$029 + 4 | 0; //@line 3552
   $$02428 = HEAP32[387840 + ($$02428 << 2) >> 2] | 0; //@line 3554
   if (!$$02428) {
    $$0$lcssa = $33; //@line 3557
    break;
   } else {
    $$029 = $33; //@line 3560
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $49 = HEAP32[162769] | 0; //@line 3566
  $50 = $49 + 6 | 0; //@line 3567
  HEAP32[162769] = $50; //@line 3568
  return;
 } else {
  $$02526 = $4; //@line 3571
  $$127 = $$0$lcssa; //@line 3571
 }
 while (1) {
  $41 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] >> 2] & 127]($$127) | 0; //@line 3578
  HEAP32[651040 + (HEAP32[385792 + ($$02526 << 2) >> 2] << 2) >> 2] = $41; //@line 3582
  $$02526 = HEAP32[387840 + ($$02526 << 2) >> 2] | 0; //@line 3585
  if (!$$02526) {
   break;
  } else {
   $$127 = $$127 + 4 | 0; //@line 3590
  }
 }
 $49 = HEAP32[162769] | 0; //@line 3593
 $50 = $49 + 6 | 0; //@line 3594
 HEAP32[162769] = $50; //@line 3595
 return;
}
function __Z12op_ebf0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $67 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 44657
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 44660
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 44665
 $11 = $2 + 4 | 0; //@line 44666
 HEAP32[162769] = $11; //@line 44667
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 44669
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 44676
 HEAP32[162769] = $2 + 6; //@line 44678
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 44679
 $sext = $10 << 16; //@line 44680
 $23 = $sext >> 16; //@line 44681
 $26 = $sext >> 22; //@line 44684
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 44687
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 44692
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 44697
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 44702
 }
 $38 = $37 + 31 & 31; //@line 44705
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 44710
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 44715
 $50 = $44 + 4 | 0; //@line 44716
 $58 = $40 & 7; //@line 44724
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 44730
 $67 = ($64 & 1 << $38 | 0) != 0; //@line 44733
 HEAP32[96443] = $67 & 1; //@line 44735
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 44738
 HEAP32[96444] = 0; //@line 44739
 HEAP32[96441] = 0; //@line 44740
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = ($67 ? -2 << $38 : 0) | $64; //@line 44747
 return;
}
function __Z12op_4cb0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02326 = 0, $$02428 = 0, $$029 = 0, $$127 = 0, $10 = 0, $17 = 0, $19 = 0, $2 = 0, $29 = 0, $33 = 0, $4 = 0, $43 = 0, $5 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 53992
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 53994
 $5 = $4 & 255; //@line 53995
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 53997
 $8 = $2 + 4 | 0; //@line 53998
 HEAP32[162769] = $8; //@line 53999
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 54001
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 54008
 HEAP32[162769] = $2 + 6; //@line 54010
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 54011
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $19; //@line 54014
 } else {
  $$02428 = $7 & 255; //@line 54017
  $$029 = $19; //@line 54017
  while (1) {
   $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$029) | 0) << 16 >> 16; //@line 54026
   HEAP32[651008 + (HEAP32[385792 + ($$02428 << 2) >> 2] << 2) >> 2] = $29; //@line 54030
   $33 = $$029 + 2 | 0; //@line 54031
   $$02428 = HEAP32[387840 + ($$02428 << 2) >> 2] | 0; //@line 54033
   if (!$$02428) {
    $$0$lcssa = $33; //@line 54036
    break;
   } else {
    $$029 = $33; //@line 54039
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  return;
 } else {
  $$02326 = $5; //@line 54047
  $$127 = $$0$lcssa; //@line 54047
 }
 while (1) {
  $43 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$127) | 0) << 16 >> 16; //@line 54057
  HEAP32[651040 + (HEAP32[385792 + ($$02326 << 2) >> 2] << 2) >> 2] = $43; //@line 54061
  $$02326 = HEAP32[387840 + ($$02326 << 2) >> 2] | 0; //@line 54064
  if (!$$02326) {
   break;
  } else {
   $$127 = $$127 + 2 | 0; //@line 54069
  }
 }
 return;
}
function __ZN17disk_sparsebundle5writeEPvij($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$$041$us$i = 0, $$036$us$i = 0, $$037$us$i = 0, $$039$us$i = 0, $$041$us$i = 0, $$053$us$i = 0, $$2$i = 0, $$sroa$speculated$us$i = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $4 = 0, $7 = 0, label = 0;
 $4 = $0 + 12 | 0; //@line 35844
 if (!$3) {
  $$2$i = 0; //@line 35847
  return $$2$i | 0; //@line 35848
 }
 $7 = $0 + 16 | 0; //@line 35852
 $$036$us$i = $2; //@line 35853
 $$037$us$i = $1; //@line 35853
 $$039$us$i = ($2 | 0) / (HEAP32[$4 >> 2] | 0) | 0; //@line 35853
 $$041$us$i = 0; //@line 35853
 $$053$us$i = $3; //@line 35853
 while (1) {
  if (($$036$us$i | 0) >= (HEAP32[$7 >> 2] | 0)) {
   $$2$i = $$041$us$i; //@line 35858
   label = 5; //@line 35859
   break;
  }
  $10 = HEAP32[$4 >> 2] | 0; //@line 35862
  $11 = ($$036$us$i | 0) % ($10 | 0) | 0; //@line 35863
  $12 = $10 - $11 | 0; //@line 35864
  $$sroa$speculated$us$i = $$053$us$i >>> 0 < $12 >>> 0 ? $$053$us$i : $12; //@line 35866
  $14 = __ZN17disk_sparsebundle10band_writeEPcijj($0, $$037$us$i, $$039$us$i, $11, $$sroa$speculated$us$i) | 0; //@line 35867
  $$$041$us$i = (($14 | 0) > 0 ? $14 : 0) + $$041$us$i | 0; //@line 35870
  $$053$us$i = $$053$us$i - $$sroa$speculated$us$i | 0; //@line 35874
  if (!($14 >>> 0 >= $$sroa$speculated$us$i >>> 0 & ($$053$us$i | 0) != 0)) {
   $$2$i = $$$041$us$i; //@line 35881
   label = 5; //@line 35882
   break;
  } else {
   $$036$us$i = $$sroa$speculated$us$i + $$036$us$i | 0; //@line 35879
   $$037$us$i = $$037$us$i + $$sroa$speculated$us$i | 0; //@line 35879
   $$039$us$i = $$039$us$i + 1 | 0; //@line 35879
   $$041$us$i = $$$041$us$i; //@line 35879
  }
 }
 if ((label | 0) == 5) {
  return $$2$i | 0; //@line 35887
 }
 return 0; //@line 35889
}
function _vsnprintf($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$$015 = 0, $$0 = 0, $$014 = 0, $$015 = 0, $11 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $4 = 0, $5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 56169
 STACKTOP = STACKTOP + 128 | 0; //@line 56170
 $4 = sp + 124 | 0; //@line 56171
 $5 = sp; //@line 56172
 dest = $5; //@line 56173
 src = 88656; //@line 56173
 stop = dest + 124 | 0; //@line 56173
 do {
  HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 56173
  dest = dest + 4 | 0; //@line 56173
  src = src + 4 | 0; //@line 56173
 } while ((dest | 0) < (stop | 0));
 if (($1 + -1 | 0) >>> 0 > 2147483646) {
  if (!$1) {
   $$014 = $4; //@line 56179
   $$015 = 1; //@line 56179
   label = 4; //@line 56180
  } else {
   HEAP32[(___errno_location() | 0) >> 2] = 75; //@line 56183
   $$0 = -1; //@line 56184
  }
 } else {
  $$014 = $0; //@line 56187
  $$015 = $1; //@line 56187
  label = 4; //@line 56188
 }
 if ((label | 0) == 4) {
  $11 = -2 - $$014 | 0; //@line 56192
  $$$015 = $$015 >>> 0 > $11 >>> 0 ? $11 : $$015; //@line 56194
  HEAP32[$5 + 48 >> 2] = $$$015; //@line 56196
  $14 = $5 + 20 | 0; //@line 56197
  HEAP32[$14 >> 2] = $$014; //@line 56198
  HEAP32[$5 + 44 >> 2] = $$014; //@line 56200
  $16 = $$014 + $$$015 | 0; //@line 56201
  $17 = $5 + 16 | 0; //@line 56202
  HEAP32[$17 >> 2] = $16; //@line 56203
  HEAP32[$5 + 28 >> 2] = $16; //@line 56205
  $19 = _vfprintf($5, $2, $3) | 0; //@line 56206
  if (!$$$015) {
   $$0 = $19; //@line 56209
  } else {
   $21 = HEAP32[$14 >> 2] | 0; //@line 56211
   HEAP8[$21 + ((($21 | 0) == (HEAP32[$17 >> 2] | 0)) << 31 >> 31) >> 0] = 0; //@line 56216
   $$0 = $19; //@line 56217
  }
 }
 STACKTOP = sp; //@line 56220
 return $$0 | 0; //@line 56220
}
function __Z18PrefsReplaceStringPKcS0_i($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, $$017$i = 0, $$1$i = 0, $$sink$i = 0, $14 = 0, $18 = 0, $19 = 0, $21 = 0, $26 = 0, $28 = 0;
 $$01416$i = HEAP32[28198] | 0; //@line 751
 L1 : do {
  if ($$01416$i | 0) {
   $$01418$i = $$01416$i; //@line 755
   $$017$i = 0; //@line 755
   while (1) {
    if (!(HEAP32[$$01418$i + 8 >> 2] | 0)) {
     if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
      if (($$017$i | 0) == ($2 | 0)) {
       break;
      }
      $$1$i = $$017$i + 1 | 0; //@line 771
     } else {
      $$1$i = $$017$i; //@line 773
     }
    } else {
     $$1$i = $$017$i; //@line 776
    }
    $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 778
    if (!$$014$i) {
     break L1;
    } else {
     $$01418$i = $$014$i; //@line 783
     $$017$i = $$1$i; //@line 783
    }
   }
   $14 = $$01418$i + 12 | 0; //@line 786
   _free(HEAP32[$14 >> 2] | 0); //@line 788
   HEAP32[$14 >> 2] = ___strdup($1) | 0; //@line 790
   return;
  }
 } while (0);
 $18 = (_strlen($1) | 0) + 1 | 0; //@line 795
 $19 = _malloc($18) | 0; //@line 796
 if (!$19) {
  return;
 }
 _memcpy($19 | 0, $1 | 0, $18 | 0) | 0; //@line 801
 $21 = __Znwj(16) | 0; //@line 802
 HEAP32[$21 >> 2] = 0; //@line 803
 HEAP32[$21 + 4 >> 2] = ___strdup($0) | 0; //@line 806
 HEAP32[$21 + 8 >> 2] = 0; //@line 808
 HEAP32[$21 + 12 >> 2] = $19; //@line 810
 $26 = HEAP32[28198] | 0; //@line 811
 if (!$26) {
  $$sink$i = 112792; //@line 814
 } else {
  $$0$i = $26; //@line 816
  while (1) {
   $28 = HEAP32[$$0$i >> 2] | 0; //@line 818
   if (!$28) {
    break;
   } else {
    $$0$i = $28; //@line 823
   }
  }
  $$sink$i = $$0$i; //@line 826
 }
 HEAP32[$$sink$i >> 2] = $21; //@line 828
 return;
}
function __Z12op_8108_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $$neg = 0, $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $32 = 0, $34 = 0, $38 = 0, $4 = 0, $40 = 0, $44 = 0, $53 = 0, $8 = 0;
 $1 = $0 & 7; //@line 15672
 $3 = $0 >>> 9 & 7; //@line 15674
 $4 = 651040 + ($1 << 2) | 0; //@line 15675
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 15679
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 15685
 HEAP32[$4 >> 2] = $8; //@line 15686
 $15 = 651040 + ($3 << 2) | 0; //@line 15687
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 15691
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 15693
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 15697
 HEAP32[$15 >> 2] = $19; //@line 15698
 $26 = $25 << 24 >> 24; //@line 15700
 $28 = $14 << 24 >> 24; //@line 15703
 $32 = (HEAP32[96445] | 0) != 0; //@line 15707
 $$neg = $32 << 31 >> 31; //@line 15709
 $34 = ($26 & 15) - ($28 & 15) + $$neg | 0; //@line 15710
 $38 = $34 + (($26 & 240) - ($28 & 240)) | 0; //@line 15714
 $40 = ($34 & 240 | 0) == 0; //@line 15716
 $$ = $40 ? $38 : $38 + -6 | 0; //@line 15718
 $44 = ($26 & 255) - ($28 & 255) | 0; //@line 15721
 $$1$in = ($44 - ($32 & 1) & 256 | 0) == 0 ? $$ : $$ + 65440 | 0; //@line 15726
 $53 = ($$neg + $44 + ($40 ? 0 : 1018) & 768 | 0) != 0 & 1; //@line 15732
 HEAP32[96441] = $53; //@line 15733
 HEAP32[96445] = $53; //@line 15734
 HEAP32[96442] = ($$1$in & 255 | 0) == 0 & HEAP32[96442]; //@line 15740
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$1$in & 65535); //@line 15745
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15748
 return;
}
function __ZN17disk_sparsebundle4readEPvij($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$$041$us$i = 0, $$036$us$i = 0, $$037$us$i = 0, $$039$us$i = 0, $$041$us$i = 0, $$053$us$i = 0, $$2$i = 0, $$sroa$speculated$us$i = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $4 = 0, $7 = 0, label = 0;
 $4 = $0 + 12 | 0; //@line 35789
 if (!$3) {
  $$2$i = 0; //@line 35792
  return $$2$i | 0; //@line 35793
 }
 $7 = $0 + 16 | 0; //@line 35797
 $$036$us$i = $2; //@line 35798
 $$037$us$i = $1; //@line 35798
 $$039$us$i = ($2 | 0) / (HEAP32[$4 >> 2] | 0) | 0; //@line 35798
 $$041$us$i = 0; //@line 35798
 $$053$us$i = $3; //@line 35798
 while (1) {
  if (($$036$us$i | 0) >= (HEAP32[$7 >> 2] | 0)) {
   $$2$i = $$041$us$i; //@line 35803
   label = 5; //@line 35804
   break;
  }
  $10 = HEAP32[$4 >> 2] | 0; //@line 35807
  $11 = ($$036$us$i | 0) % ($10 | 0) | 0; //@line 35808
  $12 = $10 - $11 | 0; //@line 35809
  $$sroa$speculated$us$i = $$053$us$i >>> 0 < $12 >>> 0 ? $$053$us$i : $12; //@line 35811
  $14 = __ZN17disk_sparsebundle9band_readEPcijj($0, $$037$us$i, $$039$us$i, $11, $$sroa$speculated$us$i) | 0; //@line 35812
  $$$041$us$i = (($14 | 0) > 0 ? $14 : 0) + $$041$us$i | 0; //@line 35815
  $$053$us$i = $$053$us$i - $$sroa$speculated$us$i | 0; //@line 35819
  if (!($14 >>> 0 >= $$sroa$speculated$us$i >>> 0 & ($$053$us$i | 0) != 0)) {
   $$2$i = $$$041$us$i; //@line 35826
   label = 5; //@line 35827
   break;
  } else {
   $$036$us$i = $$sroa$speculated$us$i + $$036$us$i | 0; //@line 35824
   $$037$us$i = $$037$us$i + $$sroa$speculated$us$i | 0; //@line 35824
   $$039$us$i = $$039$us$i + 1 | 0; //@line 35824
   $$041$us$i = $$$041$us$i; //@line 35824
  }
 }
 if ((label | 0) == 5) {
  return $$2$i | 0; //@line 35832
 }
 return 0; //@line 35834
}
function __Z12op_4cf0_3_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02325 = 0, $$02427 = 0, $$028 = 0, $$126 = 0, $18 = 0, $2 = 0, $26 = 0, $30 = 0, $38 = 0, $4 = 0, $46 = 0, $47 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 3430
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 3432
 $5 = $4 & 255; //@line 3433
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 3435
 $18 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 3446
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $18; //@line 3449
 } else {
  $$02427 = $7 & 255; //@line 3452
  $$028 = $18; //@line 3452
  while (1) {
   $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$028 >>> 16 << 2) >> 2] >> 2] & 127]($$028) | 0; //@line 3458
   HEAP32[651008 + (HEAP32[385792 + ($$02427 << 2) >> 2] << 2) >> 2] = $26; //@line 3462
   $30 = $$028 + 4 | 0; //@line 3463
   $$02427 = HEAP32[387840 + ($$02427 << 2) >> 2] | 0; //@line 3465
   if (!$$02427) {
    $$0$lcssa = $30; //@line 3468
    break;
   } else {
    $$028 = $30; //@line 3471
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $46 = HEAP32[162769] | 0; //@line 3477
  $47 = $46 + 6 | 0; //@line 3478
  HEAP32[162769] = $47; //@line 3479
  return;
 } else {
  $$02325 = $5; //@line 3482
  $$126 = $$0$lcssa; //@line 3482
 }
 while (1) {
  $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] >> 2] & 127]($$126) | 0; //@line 3489
  HEAP32[651040 + (HEAP32[385792 + ($$02325 << 2) >> 2] << 2) >> 2] = $38; //@line 3493
  $$02325 = HEAP32[387840 + ($$02325 << 2) >> 2] | 0; //@line 3496
  if (!$$02325) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 3501
  }
 }
 $46 = HEAP32[162769] | 0; //@line 3504
 $47 = $46 + 6 | 0; //@line 3505
 HEAP32[162769] = $47; //@line 3506
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0, $1, $2, $3, $4, $5, $6, $7) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 $6 = $6 | 0;
 $7 = $7 | 0;
 var $$sroa$speculated = 0, $16 = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $38 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 3286
 STACKTOP = STACKTOP + 16 | 0; //@line 3287
 $8 = sp; //@line 3288
 if ((-18 - $1 | 0) >>> 0 < $2 >>> 0) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0); //@line 3292
 }
 if ((HEAP8[$0 + 11 >> 0] | 0) < 0) {
  $25 = HEAP32[$0 >> 2] | 0; //@line 3300
 } else {
  $25 = $0; //@line 3302
 }
 if ($1 >>> 0 < 2147483623) {
  $16 = $2 + $1 | 0; //@line 3306
  $17 = $1 << 1; //@line 3307
  $$sroa$speculated = $16 >>> 0 < $17 >>> 0 ? $17 : $16; //@line 3309
  $22 = $$sroa$speculated >>> 0 < 11 ? 11 : $$sroa$speculated + 16 & -16; //@line 3314
 } else {
  $22 = -17; //@line 3316
 }
 $23 = __Znwj($22) | 0; //@line 3318
 if ($4 | 0) {
  __ZNSt3__211char_traitsIcE4copyEPcPKcj($23, $25, $4) | 0; //@line 3321
 }
 if ($6 | 0) {
  __ZNSt3__211char_traitsIcE4copyEPcPKcj($23 + $4 | 0, $7, $6) | 0; //@line 3326
 }
 $28 = $3 - $5 | 0; //@line 3328
 $29 = $28 - $4 | 0; //@line 3329
 if ($29 | 0) {
  __ZNSt3__211char_traitsIcE4copyEPcPKcj($23 + $4 + $6 | 0, $25 + $4 + $5 | 0, $29) | 0; //@line 3336
 }
 if (($1 | 0) != 10) {
  __ZdlPv($25); //@line 3340
 }
 HEAP32[$0 >> 2] = $23; //@line 3342
 HEAP32[$0 + 8 >> 2] = $22 | -2147483648; //@line 3345
 $38 = $28 + $6 | 0; //@line 3346
 HEAP32[$0 + 4 >> 2] = $38; //@line 3348
 HEAP8[$8 >> 0] = 0; //@line 3350
 __ZNSt3__211char_traitsIcE6assignERcRKc($23 + $38 | 0, $8); //@line 3351
 STACKTOP = sp; //@line 3352
 return;
}
function __Z8fpu_initb($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $21 = 0, $22 = 0, $32 = 0, $33 = 0, $43 = 0, $44 = 0, $54 = 0, $55 = 0, $65 = 0, $66 = 0, $76 = 0, $77 = 0, $87 = 0, $88 = 0;
 if (!(HEAP8[659739] | 0)) {
  HEAP8[659739] = 1; //@line 4451
 }
 HEAP8[112776] = $0 & 1; //@line 4453
 HEAP32[28193] = 0; //@line 4454
 HEAP32[28187] = 0; //@line 4455
 HEAP32[28188] = 0; //@line 4456
 HEAP32[28191] = 0; //@line 4457
 HEAP32[28192] = 0; //@line 4458
 HEAP32[28190] = 0; //@line 4459
 HEAPF64[14092] = 1.0; //@line 4460
 $10 = HEAP32[28169] | 2147483647; //@line 4467
 $11 = 112672; //@line 4468
 HEAP32[$11 >> 2] = -1; //@line 4470
 HEAP32[$11 + 4 >> 2] = $10; //@line 4473
 $21 = HEAP32[28171] | 2147483647; //@line 4480
 $22 = 112680; //@line 4481
 HEAP32[$22 >> 2] = -1; //@line 4483
 HEAP32[$22 + 4 >> 2] = $21; //@line 4486
 $32 = HEAP32[28173] | 2147483647; //@line 4493
 $33 = 112688; //@line 4494
 HEAP32[$33 >> 2] = -1; //@line 4496
 HEAP32[$33 + 4 >> 2] = $32; //@line 4499
 $43 = HEAP32[28175] | 2147483647; //@line 4506
 $44 = 112696; //@line 4507
 HEAP32[$44 >> 2] = -1; //@line 4509
 HEAP32[$44 + 4 >> 2] = $43; //@line 4512
 $54 = HEAP32[28177] | 2147483647; //@line 4519
 $55 = 112704; //@line 4520
 HEAP32[$55 >> 2] = -1; //@line 4522
 HEAP32[$55 + 4 >> 2] = $54; //@line 4525
 $65 = HEAP32[28179] | 2147483647; //@line 4532
 $66 = 112712; //@line 4533
 HEAP32[$66 >> 2] = -1; //@line 4535
 HEAP32[$66 + 4 >> 2] = $65; //@line 4538
 $76 = HEAP32[28181] | 2147483647; //@line 4545
 $77 = 112720; //@line 4546
 HEAP32[$77 >> 2] = -1; //@line 4548
 HEAP32[$77 + 4 >> 2] = $76; //@line 4551
 $87 = HEAP32[28183] | 2147483647; //@line 4558
 $88 = 112728; //@line 4559
 HEAP32[$88 >> 2] = -1; //@line 4561
 HEAP32[$88 + 4 >> 2] = $87; //@line 4564
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$018 = 0, $$019 = 0, $$pn = 0, $17 = 0, $18 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 3499
 STACKTOP = STACKTOP + 16 | 0; //@line 3500
 $2 = sp; //@line 3501
 $3 = sp + 1 | 0; //@line 3502
 HEAP8[$2 >> 0] = $1; //@line 3503
 $4 = $0 + 11 | 0; //@line 3504
 $5 = HEAP8[$4 >> 0] | 0; //@line 3505
 $6 = $5 << 24 >> 24 < 0; //@line 3506
 if ($6) {
  $$018 = HEAP32[$0 + 4 >> 2] | 0; //@line 3514
  $$019 = (HEAP32[$0 + 8 >> 2] & 2147483647) + -1 | 0; //@line 3514
 } else {
  $$018 = $5 & 255; //@line 3517
  $$019 = 10; //@line 3517
 }
 if (($$018 | 0) == ($$019 | 0)) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0, $$019, 1, $$019, $$019, 0, 0); //@line 3521
  $17 = $$019 + 1 | 0; //@line 3524
  if ((HEAP8[$4 >> 0] | 0) < 0) {
   $23 = $17; //@line 3526
   label = 8; //@line 3527
  } else {
   $20 = $17; //@line 3529
   label = 7; //@line 3530
  }
 } else {
  $18 = $$018 + 1 | 0; //@line 3533
  if ($6) {
   $23 = $18; //@line 3535
   label = 8; //@line 3536
  } else {
   $20 = $18; //@line 3538
   label = 7; //@line 3539
  }
 }
 if ((label | 0) == 7) {
  HEAP8[$4 >> 0] = $20; //@line 3544
  $$pn = $0; //@line 3545
 } else if ((label | 0) == 8) {
  $21 = HEAP32[$0 >> 2] | 0; //@line 3548
  HEAP32[$0 + 4 >> 2] = $23; //@line 3550
  $$pn = $21; //@line 3551
 }
 $$0 = $$pn + $$018 | 0; //@line 3553
 __ZNSt3__211char_traitsIcE6assignERcRKc($$0, $2); //@line 3554
 HEAP8[$3 >> 0] = 0; //@line 3556
 __ZNSt3__211char_traitsIcE6assignERcRKc($$0 + 1 | 0, $3); //@line 3557
 STACKTOP = sp; //@line 3558
 return;
}
function __Z12op_4c90_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02326 = 0, $$02428 = 0, $$029 = 0, $$127 = 0, $19 = 0, $2 = 0, $23 = 0, $33 = 0, $4 = 0, $41 = 0, $42 = 0, $5 = 0, $7 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 53727
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 53729
 $5 = $4 & 255; //@line 53730
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 53732
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 53734
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $9; //@line 53737
 } else {
  $$02428 = $7 & 255; //@line 53740
  $$029 = $9; //@line 53740
  while (1) {
   $19 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$029) | 0) << 16 >> 16; //@line 53749
   HEAP32[651008 + (HEAP32[385792 + ($$02428 << 2) >> 2] << 2) >> 2] = $19; //@line 53753
   $23 = $$029 + 2 | 0; //@line 53754
   $$02428 = HEAP32[387840 + ($$02428 << 2) >> 2] | 0; //@line 53756
   if (!$$02428) {
    $$0$lcssa = $23; //@line 53759
    break;
   } else {
    $$029 = $23; //@line 53762
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $41 = HEAP32[162769] | 0; //@line 53768
  $42 = $41 + 4 | 0; //@line 53769
  HEAP32[162769] = $42; //@line 53770
  return;
 } else {
  $$02326 = $5; //@line 53773
  $$127 = $$0$lcssa; //@line 53773
 }
 while (1) {
  $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($$127) | 0) << 16 >> 16; //@line 53783
  HEAP32[651040 + (HEAP32[385792 + ($$02326 << 2) >> 2] << 2) >> 2] = $33; //@line 53787
  $$02326 = HEAP32[387840 + ($$02326 << 2) >> 2] | 0; //@line 53790
  if (!$$02326) {
   break;
  } else {
   $$127 = $$127 + 2 | 0; //@line 53795
  }
 }
 $41 = HEAP32[162769] | 0; //@line 53798
 $42 = $41 + 4 | 0; //@line 53799
 HEAP32[162769] = $42; //@line 53800
 return;
}
function __Z11op_ad8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $4 = 0, $46 = 0, $47 = 0, $7 = 0, $8 = 0, $9 = 0, $sext41$lobit = 0, $sext43$lobit = 0;
 $1 = $0 & 7; //@line 18291
 $2 = HEAP32[162769] | 0; //@line 18292
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 18294
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 18297
 $8 = 651040 + ($1 << 2) | 0; //@line 18298
 $9 = HEAP32[$8 >> 2] | 0; //@line 18299
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 18301
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 18305
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 18310
 $21 = $15 << 24 >> 24; //@line 18313
 $22 = 651008 + (($7 & 7) << 2) | 0; //@line 18314
 $23 = HEAP32[$22 >> 2] | 0; //@line 18315
 $24 = $21 - $23 | 0; //@line 18316
 $sext41$lobit = $15 >>> 7 & 1; //@line 18320
 $sext43$lobit = $24 >>> 7 & 1; //@line 18322
 $28 = ($24 & 255 | 0) == 0; //@line 18324
 HEAP32[96442] = $28 & 1; //@line 18326
 HEAP32[96444] = ($23 >>> 7 & 1 | 0) != ($sext41$lobit | 0) & ($sext43$lobit | 0) != ($sext41$lobit | 0) & 1; //@line 18331
 HEAP32[96441] = ($23 & 255) >>> 0 > ($15 & 255) >>> 0 & 1; //@line 18336
 HEAP32[96443] = $sext43$lobit; //@line 18337
 if ($28) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 18349
  $46 = HEAP32[162769] | 0; //@line 18350
  $47 = $46 + 4 | 0; //@line 18351
  HEAP32[162769] = $47; //@line 18352
  return;
 } else {
  HEAP32[$22 >> 2] = $21; //@line 18355
  $46 = HEAP32[162769] | 0; //@line 18356
  $47 = $46 + 4 | 0; //@line 18357
  HEAP32[162769] = $47; //@line 18358
  return;
 }
}
function __Z12op_4cf8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$01921 = 0, $$02023 = 0, $$024 = 0, $$122 = 0, $1 = 0, $15 = 0, $23 = 0, $27 = 0, $3 = 0, $35 = 0, $4 = 0, $43 = 0, $44 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 54788
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 54790
 $4 = $3 & 255; //@line 54791
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 54793
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 54803
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $15; //@line 54806
 } else {
  $$02023 = $6 & 255; //@line 54809
  $$024 = $15; //@line 54809
  while (1) {
   $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$024 >>> 16 << 2) >> 2] >> 2] & 127]($$024) | 0; //@line 54815
   HEAP32[651008 + (HEAP32[385792 + ($$02023 << 2) >> 2] << 2) >> 2] = $23; //@line 54819
   $27 = $$024 + 4 | 0; //@line 54820
   $$02023 = HEAP32[387840 + ($$02023 << 2) >> 2] | 0; //@line 54822
   if (!$$02023) {
    $$0$lcssa = $27; //@line 54825
    break;
   } else {
    $$024 = $27; //@line 54828
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $43 = HEAP32[162769] | 0; //@line 54834
  $44 = $43 + 6 | 0; //@line 54835
  HEAP32[162769] = $44; //@line 54836
  return;
 } else {
  $$01921 = $4; //@line 54839
  $$122 = $$0$lcssa; //@line 54839
 }
 while (1) {
  $35 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$122 >>> 16 << 2) >> 2] >> 2] & 127]($$122) | 0; //@line 54846
  HEAP32[651040 + (HEAP32[385792 + ($$01921 << 2) >> 2] << 2) >> 2] = $35; //@line 54850
  $$01921 = HEAP32[387840 + ($$01921 << 2) >> 2] | 0; //@line 54853
  if (!$$01921) {
   break;
  } else {
   $$122 = $$122 + 4 | 0; //@line 54858
  }
 }
 $43 = HEAP32[162769] | 0; //@line 54861
 $44 = $43 + 6 | 0; //@line 54862
 HEAP32[162769] = $44; //@line 54863
 return;
}
function __Z11op_ae0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $27 = 0, $4 = 0, $45 = 0, $46 = 0, $7 = 0, $8 = 0, $sext42$lobit = 0, $sext44$lobit = 0;
 $1 = $0 & 7; //@line 18368
 $2 = HEAP32[162769] | 0; //@line 18369
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 18371
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 18374
 $8 = 651040 + ($1 << 2) | 0; //@line 18375
 $12 = (HEAP32[$8 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 18379
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 18381
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 18385
 HEAP32[$8 >> 2] = $12; //@line 18386
 $20 = $18 << 24 >> 24; //@line 18389
 $21 = 651008 + (($7 & 7) << 2) | 0; //@line 18390
 $22 = HEAP32[$21 >> 2] | 0; //@line 18391
 $23 = $20 - $22 | 0; //@line 18392
 $sext42$lobit = $18 >>> 7 & 1; //@line 18396
 $sext44$lobit = $23 >>> 7 & 1; //@line 18398
 $27 = ($23 & 255 | 0) == 0; //@line 18400
 HEAP32[96442] = $27 & 1; //@line 18402
 HEAP32[96444] = ($22 >>> 7 & 1 | 0) != ($sext42$lobit | 0) & ($sext44$lobit | 0) != ($sext42$lobit | 0) & 1; //@line 18407
 HEAP32[96441] = ($22 & 255) >>> 0 > ($18 & 255) >>> 0 & 1; //@line 18412
 HEAP32[96443] = $sext44$lobit; //@line 18413
 if ($27) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 18425
  $45 = HEAP32[162769] | 0; //@line 18426
  $46 = $45 + 4 | 0; //@line 18427
  HEAP32[162769] = $46; //@line 18428
  return;
 } else {
  HEAP32[$21 >> 2] = $20; //@line 18431
  $45 = HEAP32[162769] | 0; //@line 18432
  $46 = $45 + 4 | 0; //@line 18433
  HEAP32[162769] = $46; //@line 18434
  return;
 }
}
function __Z12op_e9fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $14 = 0, $21 = 0, $23 = 0, $24 = 0, $27 = 0, $38 = 0, $39 = 0, $4 = 0, $41 = 0, $45 = 0, $50 = 0, $51 = 0, $59 = 0, $65 = 0, $9 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 43569
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 43572
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 43577
 $10 = $1 + 4 | 0; //@line 43578
 HEAP32[162769] = $10; //@line 43579
 $14 = (HEAP32[162768] | 0) + $10 - (HEAP32[162770] | 0) | 0; //@line 43584
 $21 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 43591
 HEAP32[162769] = $1 + 6; //@line 43593
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 43594
 $sext = $9 << 16; //@line 43595
 $24 = $sext >> 16; //@line 43596
 $27 = $sext >> 22; //@line 43599
 if (!($24 & 2048)) {
  $41 = $27 & 31; //@line 43602
 } else {
  $41 = HEAP32[651008 + (($27 & 7) << 2) >> 2] | 0; //@line 43607
 }
 if (!($24 & 32)) {
  $38 = $24; //@line 43612
 } else {
  $38 = HEAP32[651008 + (($24 & 7) << 2) >> 2] | 0; //@line 43617
 }
 $39 = $38 + 31 & 31; //@line 43620
 $45 = ($41 >> 31 & -536870912 | $41 >> 3) + $23 | 0; //@line 43625
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 43630
 $51 = $45 + 4 | 0; //@line 43631
 $59 = $41 & 7; //@line 43639
 $65 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($51) | 0) & 255) >>> (8 - $59 | 0) | $50 << $59) >>> ($39 ^ 31); //@line 43645
 HEAP32[96443] = ($65 & 1 << $39 | 0) != 0 & 1; //@line 43650
 HEAP32[96442] = ($65 | 0) == 0 & 1; //@line 43653
 HEAP32[96444] = 0; //@line 43654
 HEAP32[96441] = 0; //@line 43655
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = $65; //@line 43659
 return;
}
function __Z12op_4cf0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02325 = 0, $$02427 = 0, $$028 = 0, $$126 = 0, $10 = 0, $17 = 0, $19 = 0, $2 = 0, $27 = 0, $31 = 0, $39 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 54706
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 54708
 $5 = $4 & 255; //@line 54709
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 54711
 $8 = $2 + 4 | 0; //@line 54712
 HEAP32[162769] = $8; //@line 54713
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 54715
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 54722
 HEAP32[162769] = $2 + 6; //@line 54724
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 54725
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $19; //@line 54728
 } else {
  $$02427 = $7 & 255; //@line 54731
  $$028 = $19; //@line 54731
  while (1) {
   $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$028 >>> 16 << 2) >> 2] >> 2] & 127]($$028) | 0; //@line 54737
   HEAP32[651008 + (HEAP32[385792 + ($$02427 << 2) >> 2] << 2) >> 2] = $27; //@line 54741
   $31 = $$028 + 4 | 0; //@line 54742
   $$02427 = HEAP32[387840 + ($$02427 << 2) >> 2] | 0; //@line 54744
   if (!$$02427) {
    $$0$lcssa = $31; //@line 54747
    break;
   } else {
    $$028 = $31; //@line 54750
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  return;
 } else {
  $$02325 = $5; //@line 54758
  $$126 = $$0$lcssa; //@line 54758
 }
 while (1) {
  $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] >> 2] & 127]($$126) | 0; //@line 54765
  HEAP32[651040 + (HEAP32[385792 + ($$02325 << 2) >> 2] << 2) >> 2] = $39; //@line 54769
  $$02325 = HEAP32[387840 + ($$02325 << 2) >> 2] | 0; //@line 54772
  if (!$$02325) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 54777
  }
 }
 return;
}
function __Z12op_81fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $31 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $sext44$mask = 0;
 $3 = HEAP32[162768] | 0; //@line 17503
 $4 = HEAP32[162769] | 0; //@line 17504
 $5 = HEAP32[162770] | 0; //@line 17505
 $$cast = $4; //@line 17506
 $6 = $$cast + 2 | 0; //@line 17507
 HEAP32[162769] = $6; //@line 17508
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 17518
 HEAP32[162769] = $$cast + 4; //@line 17520
 $17 = __Z15get_disp_ea_020jj($3 - $5 + $6 | 0, $15) | 0; //@line 17521
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 17527
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17528
 $25 = HEAP32[$24 >> 2] | 0; //@line 17529
 $26 = $23 << 16 >> 16; //@line 17531
 if (!$26) {
  HEAP32[96444] = 0; //@line 17536
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 17537
  return;
 }
 $30 = ($25 | 0) / ($26 | 0) | 0; //@line 17540
 $31 = ($25 | 0) % ($26 | 0) | 0; //@line 17541
 if (($30 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17545
  HEAP32[96443] = 1; //@line 17546
  HEAP32[96441] = 0; //@line 17547
  return;
 } else {
  $$042 = ($31 >>> 15 & 1 | 0) == ($25 >>> 31 | 0) ? $31 : 0 - $31 | 0; //@line 17555
  $sext44$mask = $30 & 65535; //@line 17556
  $37 = ($sext44$mask | 0) == 0 & 1; //@line 17558
  HEAP32[96441] = 0; //@line 17559
  HEAP32[96442] = 0; //@line 17559
  HEAP32[96443] = 0; //@line 17559
  HEAP32[96444] = 0; //@line 17559
  HEAP32[96442] = $37; //@line 17560
  HEAP32[96443] = $30 >>> 15 & 1; //@line 17563
  HEAP32[$24 >> 2] = $$042 << 16 | $sext44$mask; //@line 17566
  return;
 }
}
function __Z12op_e9f0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 43167
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 43170
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 43175
 $11 = $2 + 4 | 0; //@line 43176
 HEAP32[162769] = $11; //@line 43177
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 43179
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 43186
 HEAP32[162769] = $2 + 6; //@line 43188
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 43189
 $sext = $10 << 16; //@line 43190
 $23 = $sext >> 16; //@line 43191
 $26 = $sext >> 22; //@line 43194
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 43197
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 43202
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 43207
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 43212
 }
 $38 = $37 + 31 & 31; //@line 43215
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 43220
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 43225
 $50 = $44 + 4 | 0; //@line 43226
 $58 = $40 & 7; //@line 43234
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 43240
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 43245
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 43248
 HEAP32[96444] = 0; //@line 43249
 HEAP32[96441] = 0; //@line 43250
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = $64; //@line 43254
 return;
}
function __Z12op_4cfa_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02224 = 0, $$02326 = 0, $$027 = 0, $$125 = 0, $1 = 0, $22 = 0, $3 = 0, $30 = 0, $34 = 0, $4 = 0, $42 = 0, $50 = 0, $51 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 6
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 8
 $4 = $3 & 255; //@line 9
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 11
 $22 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 28
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $22; //@line 31
 } else {
  $$02326 = $6 & 255; //@line 34
  $$027 = $22; //@line 34
  while (1) {
   $30 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$027 >>> 16 << 2) >> 2] >> 2] & 127]($$027) | 0; //@line 40
   HEAP32[651008 + (HEAP32[385792 + ($$02326 << 2) >> 2] << 2) >> 2] = $30; //@line 44
   $34 = $$027 + 4 | 0; //@line 45
   $$02326 = HEAP32[387840 + ($$02326 << 2) >> 2] | 0; //@line 47
   if (!$$02326) {
    $$0$lcssa = $34; //@line 50
    break;
   } else {
    $$027 = $34; //@line 53
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  $50 = HEAP32[162769] | 0; //@line 59
  $51 = $50 + 6 | 0; //@line 60
  HEAP32[162769] = $51; //@line 61
  return;
 } else {
  $$02224 = $4; //@line 64
  $$125 = $$0$lcssa; //@line 64
 }
 while (1) {
  $42 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$125 >>> 16 << 2) >> 2] >> 2] & 127]($$125) | 0; //@line 71
  HEAP32[651040 + (HEAP32[385792 + ($$02224 << 2) >> 2] << 2) >> 2] = $42; //@line 75
  $$02224 = HEAP32[387840 + ($$02224 << 2) >> 2] | 0; //@line 78
  if (!$$02224) {
   break;
  } else {
   $$125 = $$125 + 4 | 0; //@line 83
  }
 }
 $50 = HEAP32[162769] | 0; //@line 86
 $51 = $50 + 6 | 0; //@line 87
 HEAP32[162769] = $51; //@line 88
 return;
}
function __Z11op_cf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $24 = 0, $26 = 0, $3 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $39 = 0, $57 = 0, $58 = 0, $6 = 0, $sext37$lobit = 0, $sext39$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 20907
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 20909
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 20912
 $15 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 20921
 $24 = $15 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 20930
 $26 = 123608 + ($15 >>> 16 << 2) | 0; //@line 20932
 $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$26 >> 2] | 0) + 4 >> 2] & 127]($24) | 0; //@line 20936
 $32 = $30 << 16 >> 16; //@line 20939
 $33 = 651008 + (($6 & 7) << 2) | 0; //@line 20940
 $34 = HEAP32[$33 >> 2] | 0; //@line 20941
 $35 = $32 - $34 | 0; //@line 20942
 $sext37$lobit = $30 >>> 15 & 1; //@line 20946
 $sext39$lobit = $35 >>> 15 & 1; //@line 20948
 $39 = ($35 & 65535 | 0) == 0; //@line 20950
 HEAP32[96442] = $39 & 1; //@line 20952
 HEAP32[96444] = ($34 >>> 15 & 1 | 0) != ($sext37$lobit | 0) & ($sext39$lobit | 0) != ($sext37$lobit | 0) & 1; //@line 20957
 HEAP32[96441] = ($34 & 65535) >>> 0 > ($30 & 65535) >>> 0 & 1; //@line 20962
 HEAP32[96443] = $sext39$lobit; //@line 20963
 if ($39) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$26 >> 2] | 0) + 16 >> 2] & 31]($24, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 20975
  $57 = HEAP32[162769] | 0; //@line 20976
  $58 = $57 + 8 | 0; //@line 20977
  HEAP32[162769] = $58; //@line 20978
  return;
 } else {
  HEAP32[$33 >> 2] = $32; //@line 20981
  $57 = HEAP32[162769] | 0; //@line 20982
  $58 = $57 + 8 | 0; //@line 20983
  HEAP32[162769] = $58; //@line 20984
  return;
 }
}
function __Z8DiskInitv() {
 var $0 = 0, $10 = 0, $12 = 0, $15 = 0, $19 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 18216
 STACKTOP = STACKTOP + 32 | 0; //@line 18217
 $0 = sp; //@line 18218
 if (!(__Z15PrefsFindStringPKci(94530, 0) | 0)) {}
 $3 = __Z15PrefsFindStringPKci(94530, 0) | 0; //@line 18223
 if (!$3) {
  STACKTOP = sp; //@line 18226
  return;
 }
 $5 = $0 + 4 | 0; //@line 18228
 $6 = $0 + 17 | 0; //@line 18229
 $7 = $0 + 20 | 0; //@line 18230
 $15 = 1; //@line 18231
 $9 = $3; //@line 18231
 while (1) {
  $10 = (HEAP8[$9 >> 0] | 0) == 42; //@line 18234
  $12 = __Z8Sys_openPKcb($10 ? $9 + 1 | 0 : $9, $10) | 0; //@line 18237
  if ($12 | 0) {
   $19 = (__Z13SysIsReadOnlyPv($12) | 0) & 1; //@line 18241
   HEAP32[$0 >> 2] = 0; //@line 18242
   HEAP32[$5 >> 2] = $12; //@line 18243
   HEAP8[$6 >> 0] = $19; //@line 18244
   HEAP32[$7 >> 2] = 0; //@line 18245
   $20 = HEAP32[28490] | 0; //@line 18246
   if (($20 | 0) == (HEAP32[28491] | 0)) {
    __ZNSt3__26vectorI15disk_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(113956, $0); //@line 18250
   } else {
    HEAP32[$20 >> 2] = HEAP32[$0 >> 2]; //@line 18252
    HEAP32[$20 + 4 >> 2] = HEAP32[$0 + 4 >> 2]; //@line 18252
    HEAP32[$20 + 8 >> 2] = HEAP32[$0 + 8 >> 2]; //@line 18252
    HEAP32[$20 + 12 >> 2] = HEAP32[$0 + 12 >> 2]; //@line 18252
    HEAP32[$20 + 16 >> 2] = HEAP32[$0 + 16 >> 2]; //@line 18252
    HEAP32[$20 + 20 >> 2] = HEAP32[$0 + 20 >> 2]; //@line 18252
    HEAP32[28490] = $20 + 24; //@line 18254
   }
  }
  $9 = __Z15PrefsFindStringPKci(94530, $15) | 0; //@line 18258
  if (!$9) {
   break;
  } else {
   $15 = $15 + 1 | 0; //@line 18263
  }
 }
 STACKTOP = sp; //@line 18266
 return;
}
function __Z11op_af9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $24 = 0, $26 = 0, $3 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $39 = 0, $57 = 0, $58 = 0, $6 = 0, $sext35$lobit = 0, $sext37$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 18686
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 18688
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 18691
 $15 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 18700
 $24 = $15 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 18709
 $26 = 123608 + ($15 >>> 16 << 2) | 0; //@line 18711
 $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$26 >> 2] | 0) + 8 >> 2] & 127]($24) | 0; //@line 18715
 $32 = $30 << 24 >> 24; //@line 18718
 $33 = 651008 + (($6 & 7) << 2) | 0; //@line 18719
 $34 = HEAP32[$33 >> 2] | 0; //@line 18720
 $35 = $32 - $34 | 0; //@line 18721
 $sext35$lobit = $30 >>> 7 & 1; //@line 18725
 $sext37$lobit = $35 >>> 7 & 1; //@line 18727
 $39 = ($35 & 255 | 0) == 0; //@line 18729
 HEAP32[96442] = $39 & 1; //@line 18731
 HEAP32[96444] = ($34 >>> 7 & 1 | 0) != ($sext35$lobit | 0) & ($sext37$lobit | 0) != ($sext35$lobit | 0) & 1; //@line 18736
 HEAP32[96441] = ($34 & 255) >>> 0 > ($30 & 255) >>> 0 & 1; //@line 18741
 HEAP32[96443] = $sext37$lobit; //@line 18742
 if ($39) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$26 >> 2] | 0) + 20 >> 2] & 31]($24, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 18754
  $57 = HEAP32[162769] | 0; //@line 18755
  $58 = $57 + 8 | 0; //@line 18756
  HEAP32[162769] = $58; //@line 18757
  return;
 } else {
  HEAP32[$33 >> 2] = $32; //@line 18760
  $57 = HEAP32[162769] | 0; //@line 18761
  $58 = $57 + 8 | 0; //@line 18762
  HEAP32[162769] = $58; //@line 18763
  return;
 }
}
function __Z12op_80f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $32 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext$mask = 0, $sext$mask39 = 0;
 $4 = HEAP32[162768] | 0; //@line 15218
 $5 = HEAP32[162769] | 0; //@line 15219
 $6 = HEAP32[162770] | 0; //@line 15220
 $$cast = $5; //@line 15221
 $7 = $$cast + 2 | 0; //@line 15222
 HEAP32[162769] = $7; //@line 15223
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15225
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 15232
 HEAP32[162769] = $$cast + 4; //@line 15234
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 15235
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 15241
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15242
 $26 = HEAP32[$25 >> 2] | 0; //@line 15243
 $sext$mask = $24 & 65535; //@line 15244
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 15249
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 15250
  return;
 }
 $30 = ($26 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15253
 if ($30 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15256
  HEAP32[96443] = 1; //@line 15257
  HEAP32[96441] = 0; //@line 15258
  return;
 } else {
  $32 = ($26 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15261
  $sext$mask39 = $30 & 65535; //@line 15262
  $34 = ($sext$mask39 | 0) == 0 & 1; //@line 15264
  HEAP32[96441] = 0; //@line 15265
  HEAP32[96442] = 0; //@line 15265
  HEAP32[96443] = 0; //@line 15265
  HEAP32[96444] = 0; //@line 15265
  HEAP32[96442] = $34; //@line 15266
  HEAP32[96443] = $30 >>> 15 & 1; //@line 15269
  HEAP32[$25 >> 2] = $32 << 16 | $sext$mask39; //@line 15272
  return;
 }
}
function __Z12op_c108_1_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $34 = 0, $38 = 0, $4 = 0, $42 = 0, $43 = 0, $8 = 0;
 $1 = $0 & 7; //@line 35229
 $3 = $0 >>> 9 & 7; //@line 35231
 $4 = 651040 + ($1 << 2) | 0; //@line 35232
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 35236
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 35242
 HEAP32[$4 >> 2] = $8; //@line 35243
 $15 = 651040 + ($3 << 2) | 0; //@line 35244
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 35248
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 35250
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 35254
 HEAP32[$15 >> 2] = $19; //@line 35255
 $26 = $14 << 24 >> 24; //@line 35257
 $28 = $25 << 24 >> 24; //@line 35260
 $34 = ($28 & 15) + ($26 & 15) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 35266
 $38 = ($28 & 240) + ($26 & 240) + $34 | 0; //@line 35270
 $$ = $34 >>> 0 > 9 ? $38 + 6 | 0 : $38; //@line 35273
 $42 = ($$ & 1008) >>> 0 > 144; //@line 35275
 $43 = $42 & 1; //@line 35276
 $$1$in = $42 ? ($$ & 65535) + 96 | 0 : $$; //@line 35279
 HEAP32[96441] = $43; //@line 35280
 HEAP32[96445] = $43; //@line 35281
 HEAP32[96442] = ($$1$in & 255 | 0) == 0 & HEAP32[96442]; //@line 35287
 HEAP32[96443] = $$1$in >>> 7 & 1; //@line 35290
 HEAP32[96444] = ($38 & 128 | 0) == 0 & ($$1$in & 128 | 0) != 0 & 1; //@line 35298
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$1$in & 65535); //@line 35302
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35305
 return;
}
function __Z12op_4cd0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02325 = 0, $$02427 = 0, $$028 = 0, $$126 = 0, $17 = 0, $2 = 0, $21 = 0, $29 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $7 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 54460
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 54462
 $5 = $4 & 255; //@line 54463
 $7 = HEAP8[$2 + 3 >> 0] | 0; //@line 54465
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 54467
 if (!($7 << 24 >> 24)) {
  $$0$lcssa = $9; //@line 54470
 } else {
  $$02427 = $7 & 255; //@line 54473
  $$028 = $9; //@line 54473
  while (1) {
   $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$028 >>> 16 << 2) >> 2] >> 2] & 127]($$028) | 0; //@line 54479
   HEAP32[651008 + (HEAP32[385792 + ($$02427 << 2) >> 2] << 2) >> 2] = $17; //@line 54483
   $21 = $$028 + 4 | 0; //@line 54484
   $$02427 = HEAP32[387840 + ($$02427 << 2) >> 2] | 0; //@line 54486
   if (!$$02427) {
    $$0$lcssa = $21; //@line 54489
    break;
   } else {
    $$028 = $21; //@line 54492
   }
  }
 }
 if (!($4 << 24 >> 24)) {
  $37 = HEAP32[162769] | 0; //@line 54498
  $38 = $37 + 4 | 0; //@line 54499
  HEAP32[162769] = $38; //@line 54500
  return;
 } else {
  $$02325 = $5; //@line 54503
  $$126 = $$0$lcssa; //@line 54503
 }
 while (1) {
  $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$126 >>> 16 << 2) >> 2] >> 2] & 127]($$126) | 0; //@line 54510
  HEAP32[651040 + (HEAP32[385792 + ($$02325 << 2) >> 2] << 2) >> 2] = $29; //@line 54514
  $$02325 = HEAP32[387840 + ($$02325 << 2) >> 2] | 0; //@line 54517
  if (!$$02325) {
   break;
  } else {
   $$126 = $$126 + 4 | 0; //@line 54522
  }
 }
 $37 = HEAP32[162769] | 0; //@line 54525
 $38 = $37 + 4 | 0; //@line 54526
 HEAP32[162769] = $38; //@line 54527
 return;
}
function __Z9fpu_resetv() {
 var $19 = 0, $20 = 0, $30 = 0, $31 = 0, $41 = 0, $42 = 0, $52 = 0, $53 = 0, $63 = 0, $64 = 0, $74 = 0, $75 = 0, $8 = 0, $85 = 0, $86 = 0, $9 = 0;
 if (!(HEAP8[659739] | 0)) {
  HEAP8[659739] = 1; //@line 4582
 }
 HEAP32[28187] = 0; //@line 4584
 HEAP32[28188] = 0; //@line 4585
 HEAP32[28190] = 0; //@line 4586
 HEAP32[28191] = 0; //@line 4586
 HEAP32[28192] = 0; //@line 4586
 HEAP32[28193] = 0; //@line 4586
 HEAPF64[14092] = 1.0; //@line 4587
 $8 = HEAP32[28169] | 2147483647; //@line 4594
 $9 = 112672; //@line 4595
 HEAP32[$9 >> 2] = -1; //@line 4597
 HEAP32[$9 + 4 >> 2] = $8; //@line 4600
 $19 = HEAP32[28171] | 2147483647; //@line 4607
 $20 = 112680; //@line 4608
 HEAP32[$20 >> 2] = -1; //@line 4610
 HEAP32[$20 + 4 >> 2] = $19; //@line 4613
 $30 = HEAP32[28173] | 2147483647; //@line 4620
 $31 = 112688; //@line 4621
 HEAP32[$31 >> 2] = -1; //@line 4623
 HEAP32[$31 + 4 >> 2] = $30; //@line 4626
 $41 = HEAP32[28175] | 2147483647; //@line 4633
 $42 = 112696; //@line 4634
 HEAP32[$42 >> 2] = -1; //@line 4636
 HEAP32[$42 + 4 >> 2] = $41; //@line 4639
 $52 = HEAP32[28177] | 2147483647; //@line 4646
 $53 = 112704; //@line 4647
 HEAP32[$53 >> 2] = -1; //@line 4649
 HEAP32[$53 + 4 >> 2] = $52; //@line 4652
 $63 = HEAP32[28179] | 2147483647; //@line 4659
 $64 = 112712; //@line 4660
 HEAP32[$64 >> 2] = -1; //@line 4662
 HEAP32[$64 + 4 >> 2] = $63; //@line 4665
 $74 = HEAP32[28181] | 2147483647; //@line 4672
 $75 = 112720; //@line 4673
 HEAP32[$75 >> 2] = -1; //@line 4675
 HEAP32[$75 + 4 >> 2] = $74; //@line 4678
 $85 = HEAP32[28183] | 2147483647; //@line 4685
 $86 = 112728; //@line 4686
 HEAP32[$86 >> 2] = -1; //@line 4688
 HEAP32[$86 + 4 >> 2] = $85; //@line 4691
 return;
}
function __Z12op_4cfb_0_ffj($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$02428 = 0, $$02526 = 0, $$029 = 0, $$127 = 0, $1 = 0, $11 = 0, $18 = 0, $20 = 0, $28 = 0, $3 = 0, $32 = 0, $4 = 0, $40 = 0, $6 = 0, $7 = 0;
 $1 = HEAP32[162769] | 0; //@line 97
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 99
 $4 = $3 & 255; //@line 100
 $6 = HEAP8[$1 + 3 >> 0] | 0; //@line 102
 $7 = $1 + 4 | 0; //@line 103
 HEAP32[162769] = $7; //@line 104
 $11 = (HEAP32[162768] | 0) + $7 - (HEAP32[162770] | 0) | 0; //@line 109
 $18 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 116
 HEAP32[162769] = $1 + 6; //@line 118
 $20 = __Z15get_disp_ea_020jj($11, $18) | 0; //@line 119
 if (!($6 << 24 >> 24)) {
  $$0$lcssa = $20; //@line 122
 } else {
  $$02428 = $6 & 255; //@line 125
  $$029 = $20; //@line 125
  while (1) {
   $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$029 >>> 16 << 2) >> 2] >> 2] & 127]($$029) | 0; //@line 131
   HEAP32[651008 + (HEAP32[385792 + ($$02428 << 2) >> 2] << 2) >> 2] = $28; //@line 135
   $32 = $$029 + 4 | 0; //@line 136
   $$02428 = HEAP32[387840 + ($$02428 << 2) >> 2] | 0; //@line 138
   if (!$$02428) {
    $$0$lcssa = $32; //@line 141
    break;
   } else {
    $$029 = $32; //@line 144
   }
  }
 }
 if (!($3 << 24 >> 24)) {
  return;
 } else {
  $$02526 = $4; //@line 152
  $$127 = $$0$lcssa; //@line 152
 }
 while (1) {
  $40 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$127 >>> 16 << 2) >> 2] >> 2] & 127]($$127) | 0; //@line 159
  HEAP32[651040 + (HEAP32[385792 + ($$02526 << 2) >> 2] << 2) >> 2] = $40; //@line 163
  $$02526 = HEAP32[387840 + ($$02526 << 2) >> 2] | 0; //@line 166
  if (!$$02526) {
   break;
  } else {
   $$127 = $$127 + 4 | 0; //@line 171
  }
 }
 return;
}
function __Z11op_cd8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $26 = 0, $4 = 0, $44 = 0, $45 = 0, $7 = 0, $8 = 0, $9 = 0, $sext42$lobit = 0, $sext44$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 20517
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 20519
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 20522
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 20523
 $9 = HEAP32[$8 >> 2] | 0; //@line 20524
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 20526
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 4 >> 2] & 127]($9) | 0; //@line 20530
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 2; //@line 20533
 $19 = $15 << 16 >> 16; //@line 20536
 $20 = 651008 + (($7 & 7) << 2) | 0; //@line 20537
 $21 = HEAP32[$20 >> 2] | 0; //@line 20538
 $22 = $19 - $21 | 0; //@line 20539
 $sext42$lobit = $15 >>> 15 & 1; //@line 20543
 $sext44$lobit = $22 >>> 15 & 1; //@line 20545
 $26 = ($22 & 65535 | 0) == 0; //@line 20547
 HEAP32[96442] = $26 & 1; //@line 20549
 HEAP32[96444] = ($21 >>> 15 & 1 | 0) != ($sext42$lobit | 0) & ($sext44$lobit | 0) != ($sext42$lobit | 0) & 1; //@line 20554
 HEAP32[96441] = ($21 & 65535) >>> 0 > ($15 & 65535) >>> 0 & 1; //@line 20559
 HEAP32[96443] = $sext44$lobit; //@line 20560
 if ($26) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 16 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 20572
  $44 = HEAP32[162769] | 0; //@line 20573
  $45 = $44 + 4 | 0; //@line 20574
  HEAP32[162769] = $45; //@line 20575
  return;
 } else {
  HEAP32[$20 >> 2] = $19; //@line 20578
  $44 = HEAP32[162769] | 0; //@line 20579
  $45 = $44 + 4 | 0; //@line 20580
  HEAP32[162769] = $45; //@line 20581
  return;
 }
}
function __Z11op_ce0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $25 = 0, $4 = 0, $43 = 0, $44 = 0, $7 = 0, $8 = 0, $sext43$lobit = 0, $sext45$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 20592
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 20594
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 20597
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 20598
 $10 = (HEAP32[$8 >> 2] | 0) + -2 | 0; //@line 20600
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 20602
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 20606
 HEAP32[$8 >> 2] = $10; //@line 20607
 $18 = $16 << 16 >> 16; //@line 20610
 $19 = 651008 + (($7 & 7) << 2) | 0; //@line 20611
 $20 = HEAP32[$19 >> 2] | 0; //@line 20612
 $21 = $18 - $20 | 0; //@line 20613
 $sext43$lobit = $16 >>> 15 & 1; //@line 20617
 $sext45$lobit = $21 >>> 15 & 1; //@line 20619
 $25 = ($21 & 65535 | 0) == 0; //@line 20621
 HEAP32[96442] = $25 & 1; //@line 20623
 HEAP32[96444] = ($20 >>> 15 & 1 | 0) != ($sext43$lobit | 0) & ($sext45$lobit | 0) != ($sext43$lobit | 0) & 1; //@line 20628
 HEAP32[96441] = ($20 & 65535) >>> 0 > ($16 & 65535) >>> 0 & 1; //@line 20633
 HEAP32[96443] = $sext45$lobit; //@line 20634
 if ($25) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 20646
  $43 = HEAP32[162769] | 0; //@line 20647
  $44 = $43 + 4 | 0; //@line 20648
  HEAP32[162769] = $44; //@line 20649
  return;
 } else {
  HEAP32[$19 >> 2] = $18; //@line 20652
  $43 = HEAP32[162769] | 0; //@line 20653
  $44 = $43 + 4 | 0; //@line 20654
  HEAP32[162769] = $44; //@line 20655
  return;
 }
}
function __ZNSt3__26vectorI15sony_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $11 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 17126
 $4 = HEAP32[$0 >> 2] | 0; //@line 17128
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 17129
 $6 = $5 >> 4; //@line 17130
 $7 = $6 + 1 | 0; //@line 17131
 if ($7 >>> 0 > 268435455) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 17134
 }
 $9 = $0 + 8 | 0; //@line 17137
 $11 = (HEAP32[$9 >> 2] | 0) - $4 | 0; //@line 17139
 $14 = $11 >> 3; //@line 17142
 $$sroa$speculated$$i = $11 >> 4 >>> 0 < 134217727 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 268435455; //@line 17145
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 17149
  } else {
   if ($$sroa$speculated$$i >>> 0 > 268435455) {
    _abort(); //@line 17153
   } else {
    $21 = __Znwj($$sroa$speculated$$i << 4) | 0; //@line 17158
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 << 4) | 0; //@line 17163
 $23 = $21 + ($$sroa$speculated$$i << 4) | 0; //@line 17165
 HEAP32[$20 >> 2] = HEAP32[$1 >> 2]; //@line 17166
 HEAP32[$20 + 4 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 17166
 HEAP32[$20 + 8 >> 2] = HEAP32[$1 + 8 >> 2]; //@line 17166
 HEAP32[$20 + 12 >> 2] = HEAP32[$1 + 12 >> 2]; //@line 17166
 $27 = $20 + (0 - $6 << 4) | 0; //@line 17170
 if (($5 | 0) > 0) {
  _memcpy($27 | 0, $4 | 0, $5 | 0) | 0; //@line 17175
 }
 HEAP32[$0 >> 2] = $27; //@line 17177
 HEAP32[$2 >> 2] = $20 + 16; //@line 17178
 HEAP32[$9 >> 2] = $23; //@line 17179
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 17185
 return;
}
function __Z11op_ce8_0_ffj($0) {
 $0 = $0 | 0;
 var $19 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $34 = 0, $4 = 0, $52 = 0, $53 = 0, $7 = 0, $sext42$lobit = 0, $sext44$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 20667
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 20669
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 20672
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 20685
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 20687
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 20691
 $27 = $25 << 16 >> 16; //@line 20694
 $28 = 651008 + (($7 & 7) << 2) | 0; //@line 20695
 $29 = HEAP32[$28 >> 2] | 0; //@line 20696
 $30 = $27 - $29 | 0; //@line 20697
 $sext42$lobit = $25 >>> 15 & 1; //@line 20701
 $sext44$lobit = $30 >>> 15 & 1; //@line 20703
 $34 = ($30 & 65535 | 0) == 0; //@line 20705
 HEAP32[96442] = $34 & 1; //@line 20707
 HEAP32[96444] = ($29 >>> 15 & 1 | 0) != ($sext42$lobit | 0) & ($sext44$lobit | 0) != ($sext42$lobit | 0) & 1; //@line 20712
 HEAP32[96441] = ($29 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 20717
 HEAP32[96443] = $sext44$lobit; //@line 20718
 if ($34) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 20730
  $52 = HEAP32[162769] | 0; //@line 20731
  $53 = $52 + 6 | 0; //@line 20732
  HEAP32[162769] = $53; //@line 20733
  return;
 } else {
  HEAP32[$28 >> 2] = $27; //@line 20736
  $52 = HEAP32[162769] | 0; //@line 20737
  $53 = $52 + 6 | 0; //@line 20738
  HEAP32[162769] = $53; //@line 20739
  return;
 }
}
function __ZN17disk_sparsebundle10band_writeEPcijj($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$ = 0, $$1 = 0, $$sroa$speculated30 = 0, $$sroa$speculated39 = 0, $11 = 0, $15 = 0, $19 = 0, $20 = 0, $26 = 0, $28 = 0, $29 = 0, $6 = 0, $storemerge = 0, $storemerge$lcssa = 0;
 $storemerge = $4; //@line 35908
 while (1) {
  if (!$storemerge) {
   $storemerge$lcssa = 0; //@line 35912
   break;
  }
  $6 = $storemerge + -1 | 0; //@line 35915
  if (!(HEAP8[$1 + $6 >> 0] | 0)) {
   $storemerge = $6; //@line 35920
  } else {
   $storemerge$lcssa = $storemerge; //@line 35922
   break;
  }
 }
 $11 = __ZN17disk_sparsebundle9open_bandEib($0, $2, ($storemerge$lcssa | 0) != 0) | 0; //@line 35927
 if (($11 | 0) != 2) {
  $$1 = ($11 | 0) == 1 ? $4 : -1; //@line 35932
  return $$1 | 0; //@line 35933
 }
 $15 = $0 + 28 | 0; //@line 35935
 if ((_lseek(HEAP32[$15 >> 2] | 0, $3, 0) | 0) == -1) {
  $$1 = -1; //@line 35940
  return $$1 | 0; //@line 35941
 }
 $19 = $0 + 32 | 0; //@line 35943
 $20 = HEAP32[$19 >> 2] | 0; //@line 35944
 $$ = $20 >>> 0 > $3 >>> 0 ? $20 - $3 | 0 : 0; //@line 35947
 $$sroa$speculated39 = $$ >>> 0 > $4 >>> 0 ? $4 : $$; //@line 35949
 $$sroa$speculated30 = $storemerge$lcssa >>> 0 < $$sroa$speculated39 >>> 0 ? $$sroa$speculated39 : $storemerge$lcssa; //@line 35951
 $26 = _write(HEAP32[$15 >> 2] | 0, $1, $$sroa$speculated30) | 0; //@line 35953
 $28 = $26 + $3 | 0; //@line 35955
 if (($26 | 0) > -1) {
  $29 = HEAP32[$19 >> 2] | 0; //@line 35957
  HEAP32[$19 >> 2] = ($29 | 0) < ($28 | 0) ? $28 : $29; //@line 35960
 }
 $$1 = $26 >>> 0 < $$sroa$speculated30 >>> 0 ? $26 : $4; //@line 35964
 return $$1 | 0; //@line 35965
}
function __Z11op_ae8_0_ffj($0) {
 $0 = $0 | 0;
 var $19 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $34 = 0, $4 = 0, $52 = 0, $53 = 0, $7 = 0, $sext40$lobit = 0, $sext42$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 18446
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 18448
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 18451
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 18464
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 18466
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 18470
 $27 = $25 << 24 >> 24; //@line 18473
 $28 = 651008 + (($7 & 7) << 2) | 0; //@line 18474
 $29 = HEAP32[$28 >> 2] | 0; //@line 18475
 $30 = $27 - $29 | 0; //@line 18476
 $sext40$lobit = $25 >>> 7 & 1; //@line 18480
 $sext42$lobit = $30 >>> 7 & 1; //@line 18482
 $34 = ($30 & 255 | 0) == 0; //@line 18484
 HEAP32[96442] = $34 & 1; //@line 18486
 HEAP32[96444] = ($29 >>> 7 & 1 | 0) != ($sext40$lobit | 0) & ($sext42$lobit | 0) != ($sext40$lobit | 0) & 1; //@line 18491
 HEAP32[96441] = ($29 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 18496
 HEAP32[96443] = $sext42$lobit; //@line 18497
 if ($34) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 18509
  $52 = HEAP32[162769] | 0; //@line 18510
  $53 = $52 + 6 | 0; //@line 18511
  HEAP32[162769] = $53; //@line 18512
  return;
 } else {
  HEAP32[$28 >> 2] = $27; //@line 18515
  $52 = HEAP32[162769] | 0; //@line 18516
  $53 = $52 + 6 | 0; //@line 18517
  HEAP32[162769] = $53; //@line 18518
  return;
 }
}
function __Z12op_81f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$039 = 0, $$cast = 0, $14 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $34 = 0, $38 = 0, $39 = 0, $4 = 0, $45 = 0, $5 = 0, $sext41$mask = 0;
 $3 = HEAP32[162768] | 0; //@line 17347
 $4 = HEAP32[162769] | 0; //@line 17348
 $5 = HEAP32[162770] | 0; //@line 17349
 $$cast = $4; //@line 17350
 $14 = (HEAPU8[$$cast + 3 >> 0] | 0) << 16 | (HEAPU8[$$cast + 2 >> 0] | 0) << 24; //@line 17359
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14 | (HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) | 0; //@line 17374
 $30 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17375
 $31 = HEAP32[$30 >> 2] | 0; //@line 17376
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17379
 $34 = $29 << 16 >> 16; //@line 17381
 if (!$34) {
  HEAP32[96444] = 0; //@line 17386
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 17387
  return;
 }
 $38 = ($31 | 0) / ($34 | 0) | 0; //@line 17390
 $39 = ($31 | 0) % ($34 | 0) | 0; //@line 17391
 if (($38 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17395
  HEAP32[96443] = 1; //@line 17396
  HEAP32[96441] = 0; //@line 17397
  return;
 } else {
  $$039 = ($39 >>> 15 & 1 | 0) == ($31 >>> 31 | 0) ? $39 : 0 - $39 | 0; //@line 17405
  $sext41$mask = $38 & 65535; //@line 17406
  $45 = ($sext41$mask | 0) == 0 & 1; //@line 17408
  HEAP32[96441] = 0; //@line 17409
  HEAP32[96442] = 0; //@line 17409
  HEAP32[96443] = 0; //@line 17409
  HEAP32[96444] = 0; //@line 17409
  HEAP32[96442] = $45; //@line 17410
  HEAP32[96443] = $38 >>> 15 & 1; //@line 17413
  HEAP32[$30 >> 2] = $$039 << 16 | $sext41$mask; //@line 17416
  return;
 }
}
function __Z12op_81f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $32 = 0, $33 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $sext45$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 23556
 $5 = HEAP32[162769] | 0; //@line 23557
 $6 = HEAP32[162770] | 0; //@line 23558
 $$cast = $5; //@line 23561
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23570
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23576
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23577
 $25 = HEAP32[$24 >> 2] | 0; //@line 23578
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23581
 $28 = $23 << 16 >> 16; //@line 23583
 if (!$28) {
  HEAP32[96444] = 0; //@line 23588
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 23589
  return;
 }
 $32 = ($25 | 0) / ($28 | 0) | 0; //@line 23592
 $33 = ($25 | 0) % ($28 | 0) | 0; //@line 23593
 if (($32 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 23597
  HEAP32[96443] = 1; //@line 23598
  HEAP32[96441] = 0; //@line 23599
  return;
 } else {
  $$043 = ($33 >>> 15 & 1 | 0) == ($25 >>> 31 | 0) ? $33 : 0 - $33 | 0; //@line 23607
  $sext45$mask = $32 & 65535; //@line 23608
  $39 = ($sext45$mask | 0) == 0 & 1; //@line 23610
  HEAP32[96441] = 0; //@line 23611
  HEAP32[96442] = 0; //@line 23611
  HEAP32[96443] = 0; //@line 23611
  HEAP32[96444] = 0; //@line 23611
  HEAP32[96442] = $39; //@line 23612
  HEAP32[96443] = $32 >>> 15 & 1; //@line 23615
  HEAP32[$24 >> 2] = $$043 << 16 | $sext45$mask; //@line 23618
  return;
 }
}
function __Z12op_81e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $33 = 0, $34 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $sext46$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 17123
 $5 = HEAP32[162769] | 0; //@line 17124
 $6 = HEAP32[162770] | 0; //@line 17125
 $$cast = $5; //@line 17128
 $18 = (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 17139
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 17145
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17146
 $26 = HEAP32[$25 >> 2] | 0; //@line 17147
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 17150
 $29 = $24 << 16 >> 16; //@line 17152
 if (!$29) {
  HEAP32[96444] = 0; //@line 17157
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 17158
  return;
 }
 $33 = ($26 | 0) / ($29 | 0) | 0; //@line 17161
 $34 = ($26 | 0) % ($29 | 0) | 0; //@line 17162
 if (($33 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17166
  HEAP32[96443] = 1; //@line 17167
  HEAP32[96441] = 0; //@line 17168
  return;
 } else {
  $$043 = ($34 >>> 15 & 1 | 0) == ($26 >>> 31 | 0) ? $34 : 0 - $34 | 0; //@line 17176
  $sext46$mask = $33 & 65535; //@line 17177
  $40 = ($sext46$mask | 0) == 0 & 1; //@line 17179
  HEAP32[96441] = 0; //@line 17180
  HEAP32[96442] = 0; //@line 17180
  HEAP32[96443] = 0; //@line 17180
  HEAP32[96444] = 0; //@line 17180
  HEAP32[96442] = $40; //@line 17181
  HEAP32[96443] = $33 >>> 15 & 1; //@line 17184
  HEAP32[$25 >> 2] = $$043 << 16 | $sext46$mask; //@line 17187
  return;
 }
}
function __Z12op_80fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $3 = 0, $31 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $sext$mask = 0, $sext$mask38 = 0;
 $3 = HEAP32[162768] | 0; //@line 15489
 $4 = HEAP32[162769] | 0; //@line 15490
 $5 = HEAP32[162770] | 0; //@line 15491
 $$cast = $4; //@line 15492
 $6 = $$cast + 2 | 0; //@line 15493
 HEAP32[162769] = $6; //@line 15494
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 15504
 HEAP32[162769] = $$cast + 4; //@line 15506
 $17 = __Z15get_disp_ea_020jj($3 - $5 + $6 | 0, $15) | 0; //@line 15507
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 15513
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15514
 $25 = HEAP32[$24 >> 2] | 0; //@line 15515
 $sext$mask = $23 & 65535; //@line 15516
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 15521
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 15522
  return;
 }
 $29 = ($25 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15525
 if ($29 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15528
  HEAP32[96443] = 1; //@line 15529
  HEAP32[96441] = 0; //@line 15530
  return;
 } else {
  $31 = ($25 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15533
  $sext$mask38 = $29 & 65535; //@line 15534
  $33 = ($sext$mask38 | 0) == 0 & 1; //@line 15536
  HEAP32[96441] = 0; //@line 15537
  HEAP32[96442] = 0; //@line 15537
  HEAP32[96443] = 0; //@line 15537
  HEAP32[96444] = 0; //@line 15537
  HEAP32[96442] = $33; //@line 15538
  HEAP32[96443] = $29 >>> 15 & 1; //@line 15541
  HEAP32[$24 >> 2] = $31 << 16 | $sext$mask38; //@line 15544
  return;
 }
}
function __ZNK8tinyxml27XMLText12ShallowCloneEPNS_11XMLDocumentE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$pre$i$i$i$i = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0;
 if (!$1) {
  $$0 = HEAP32[$0 + 4 >> 2] | 0; //@line 39377
 } else {
  $$0 = $1; //@line 39379
 }
 $6 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39382
 $7 = $$0 + 220 | 0; //@line 39383
 $8 = __ZN8tinyxml28MemPoolTILi48EE5AllocEv($7) | 0; //@line 39384
 HEAP32[$8 + 4 >> 2] = $$0; //@line 39386
 $10 = $8 + 8 | 0; //@line 39387
 HEAP32[$10 >> 2] = 0; //@line 39388
 HEAP32[$10 + 4 >> 2] = 0; //@line 39388
 HEAP32[$10 + 8 >> 2] = 0; //@line 39388
 HEAP32[$10 + 12 >> 2] = 0; //@line 39388
 HEAP32[$10 + 16 >> 2] = 0; //@line 39388
 HEAP32[$10 + 20 >> 2] = 0; //@line 39388
 HEAP32[$10 + 24 >> 2] = 0; //@line 39388
 HEAP32[$10 + 28 >> 2] = 0; //@line 39388
 HEAP32[$8 >> 2] = 1904; //@line 39389
 $11 = $8 + 44 | 0; //@line 39390
 HEAP8[$11 >> 0] = 0; //@line 39391
 HEAP32[$8 + 40 >> 2] = $7; //@line 39393
 $13 = $8 + 12 | 0; //@line 39394
 $$pre$i$i$i$i = $8 + 16 | 0; //@line 39395
 HEAP32[$13 >> 2] = 0; //@line 39396
 HEAP32[$$pre$i$i$i$i >> 2] = 0; //@line 39397
 $14 = $8 + 20 | 0; //@line 39398
 HEAP32[$14 >> 2] = 0; //@line 39399
 $15 = _strlen($6) | 0; //@line 39400
 $16 = $15 + 1 | 0; //@line 39401
 $17 = __Znaj($16) | 0; //@line 39402
 HEAP32[$$pre$i$i$i$i >> 2] = $17; //@line 39403
 _memcpy($17 | 0, $6 | 0, $16 | 0) | 0; //@line 39404
 HEAP32[$14 >> 2] = $17 + $15; //@line 39406
 HEAP32[$13 >> 2] = 512; //@line 39407
 HEAP8[$11 >> 0] = HEAP8[$0 + 44 >> 0] | 0; //@line 39410
 return $8 | 0; //@line 39411
}
function __Z12op_e8fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $14 = 0, $21 = 0, $23 = 0, $24 = 0, $27 = 0, $38 = 0, $39 = 0, $41 = 0, $45 = 0, $50 = 0, $51 = 0, $59 = 0, $65 = 0, $9 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 42814
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 42822
 $10 = $1 + 4 | 0; //@line 42823
 HEAP32[162769] = $10; //@line 42824
 $14 = (HEAP32[162768] | 0) + $10 - (HEAP32[162770] | 0) | 0; //@line 42829
 $21 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 42836
 HEAP32[162769] = $1 + 6; //@line 42838
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 42839
 $sext = $9 << 16; //@line 42840
 $24 = $sext >> 16; //@line 42841
 $27 = $sext >> 22; //@line 42844
 if (!($24 & 2048)) {
  $41 = $27 & 31; //@line 42847
 } else {
  $41 = HEAP32[651008 + (($27 & 7) << 2) >> 2] | 0; //@line 42852
 }
 if (!($24 & 32)) {
  $38 = $24; //@line 42857
 } else {
  $38 = HEAP32[651008 + (($24 & 7) << 2) >> 2] | 0; //@line 42862
 }
 $39 = $38 + 31 & 31; //@line 42865
 $45 = ($41 >> 31 & -536870912 | $41 >> 3) + $23 | 0; //@line 42870
 $50 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45) | 0; //@line 42875
 $51 = $45 + 4 | 0; //@line 42876
 $59 = $41 & 7; //@line 42884
 $65 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($51 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($51) | 0) & 255) >>> (8 - $59 | 0) | $50 << $59) >>> ($39 ^ 31); //@line 42890
 HEAP32[96443] = ($65 & 1 << $39 | 0) != 0 & 1; //@line 42895
 HEAP32[96442] = ($65 | 0) == 0 & 1; //@line 42898
 HEAP32[96444] = 0; //@line 42899
 HEAP32[96441] = 0; //@line 42900
 return;
}
function __Z8SonyInitv() {
 var $0 = 0, $10 = 0, $12 = 0, $15 = 0, $19 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 17067
 STACKTOP = STACKTOP + 16 | 0; //@line 17068
 $0 = sp; //@line 17069
 if (!(__Z15PrefsFindStringPKci(94198, 0) | 0)) {
  __Z17SysAddFloppyPrefsv(); //@line 17073
 }
 $3 = __Z15PrefsFindStringPKci(94198, 0) | 0; //@line 17075
 if (!$3) {
  STACKTOP = sp; //@line 17078
  return;
 }
 $5 = $0 + 4 | 0; //@line 17080
 $6 = $0 + 9 | 0; //@line 17081
 $7 = $0 + 12 | 0; //@line 17082
 $15 = 1; //@line 17083
 $9 = $3; //@line 17083
 while (1) {
  $10 = (HEAP8[$9 >> 0] | 0) == 42; //@line 17086
  $12 = __Z8Sys_openPKcb($10 ? $9 + 1 | 0 : $9, $10) | 0; //@line 17089
  if ($12 | 0) {
   $19 = (__Z13SysIsReadOnlyPv($12) | 0) & 1; //@line 17093
   HEAP32[$0 >> 2] = 0; //@line 17094
   HEAP32[$5 >> 2] = $12; //@line 17095
   HEAP8[$6 >> 0] = $19; //@line 17096
   HEAP32[$7 >> 2] = 0; //@line 17097
   $20 = HEAP32[28486] | 0; //@line 17098
   if (($20 | 0) == (HEAP32[28487] | 0)) {
    __ZNSt3__26vectorI15sony_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(113940, $0); //@line 17102
   } else {
    HEAP32[$20 >> 2] = HEAP32[$0 >> 2]; //@line 17104
    HEAP32[$20 + 4 >> 2] = HEAP32[$0 + 4 >> 2]; //@line 17104
    HEAP32[$20 + 8 >> 2] = HEAP32[$0 + 8 >> 2]; //@line 17104
    HEAP32[$20 + 12 >> 2] = HEAP32[$0 + 12 >> 2]; //@line 17104
    HEAP32[28486] = $20 + 16; //@line 17106
   }
  }
  $9 = __Z15PrefsFindStringPKci(94198, $15) | 0; //@line 17110
  if (!$9) {
   break;
  } else {
   $15 = $15 + 1 | 0; //@line 17115
  }
 }
 STACKTOP = sp; //@line 17118
 return;
}
function __Z11op_cf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $48 = 0, $49 = 0, $6 = 0, $sext38$lobit = 0, $sext40$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 20827
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 20829
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 20832
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 20842
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 20844
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 20848
 $23 = $21 << 16 >> 16; //@line 20851
 $24 = 651008 + (($6 & 7) << 2) | 0; //@line 20852
 $25 = HEAP32[$24 >> 2] | 0; //@line 20853
 $26 = $23 - $25 | 0; //@line 20854
 $sext38$lobit = $21 >>> 15 & 1; //@line 20858
 $sext40$lobit = $26 >>> 15 & 1; //@line 20860
 $30 = ($26 & 65535 | 0) == 0; //@line 20862
 HEAP32[96442] = $30 & 1; //@line 20864
 HEAP32[96444] = ($25 >>> 15 & 1 | 0) != ($sext38$lobit | 0) & ($sext40$lobit | 0) != ($sext38$lobit | 0) & 1; //@line 20869
 HEAP32[96441] = ($25 & 65535) >>> 0 > ($21 & 65535) >>> 0 & 1; //@line 20874
 HEAP32[96443] = $sext40$lobit; //@line 20875
 if ($30) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 16 >> 2] & 31]($15, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 20887
  $48 = HEAP32[162769] | 0; //@line 20888
  $49 = $48 + 6 | 0; //@line 20889
  HEAP32[162769] = $49; //@line 20890
  return;
 } else {
  HEAP32[$24 >> 2] = $23; //@line 20893
  $48 = HEAP32[162769] | 0; //@line 20894
  $49 = $48 + 6 | 0; //@line 20895
  HEAP32[162769] = $49; //@line 20896
  return;
 }
}
function __Z12op_e8f0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $50 = 0, $58 = 0, $64 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 42430
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 42438
 $11 = $2 + 4 | 0; //@line 42439
 HEAP32[162769] = $11; //@line 42440
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42442
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 42449
 HEAP32[162769] = $2 + 6; //@line 42451
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 42452
 $sext = $10 << 16; //@line 42453
 $23 = $sext >> 16; //@line 42454
 $26 = $sext >> 22; //@line 42457
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 42460
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 42465
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 42470
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 42475
 }
 $38 = $37 + 31 & 31; //@line 42478
 $44 = ($40 >> 31 & -536870912 | $40 >> 3) + $22 | 0; //@line 42483
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 42488
 $50 = $44 + 4 | 0; //@line 42489
 $58 = $40 & 7; //@line 42497
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 42503
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 42508
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 42511
 HEAP32[96444] = 0; //@line 42512
 HEAP32[96441] = 0; //@line 42513
 return;
}
function __Z12SerialStatusjji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $10 = 0, $13 = 0, $17 = 0, $23 = 0, $29 = 0, $3 = 0, $35 = 0;
 $3 = $0 + 26 | 0; //@line 14843
 $10 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0) & 65535; //@line 14850
 $13 = HEAP32[113900 + ($2 >> 1 << 2) >> 2] | 0; //@line 14853
 if (!(HEAP8[$13 + 4 >> 0] | 0)) {
  $$0 = -28; //@line 14858
  return $$0 | 0; //@line 14859
 }
 L4 : do {
  if ($10 << 16 >> 16 < 9) {
   switch ($10 << 16 >> 16) {
   case -32768:
    {
     break;
    }
   default:
    {
     break L4;
    }
   }
   $23 = $0 + 28 | 0; //@line 14872
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, 9); //@line 14878
   $29 = $0 + 32 | 0; //@line 14879
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, 6551); //@line 14885
   $35 = $0 + 34 | 0; //@line 14886
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, 1558); //@line 14892
   $$0 = 0; //@line 14893
   return $$0 | 0; //@line 14894
  } else {
   switch ($10 << 16 >> 16) {
   case 9:
    {
     break;
    }
   default:
    {
     break L4;
    }
   }
   $17 = $0 + 28 | 0; //@line 14904
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, 9); //@line 14910
   $$0 = 0; //@line 14911
   return $$0 | 0; //@line 14912
  }
 } while (0);
 $$0 = FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[$13 >> 2] | 0) + 24 >> 2] & 7]($13, $0, $1, $10) | 0; //@line 14919
 return $$0 | 0; //@line 14920
}
function _memset(ptr, value, num) {
 ptr = ptr | 0;
 value = value | 0;
 num = num | 0;
 var end = 0, aligned_end = 0, block_aligned_end = 0, value4 = 0;
 end = ptr + num | 0; //@line 4543
 value = value & 255; //@line 4545
 if ((num | 0) >= 67) {
  while (ptr & 3) {
   HEAP8[ptr >> 0] = value; //@line 4548
   ptr = ptr + 1 | 0; //@line 4549
  }
  aligned_end = end & -4 | 0; //@line 4552
  block_aligned_end = aligned_end - 64 | 0; //@line 4553
  value4 = value | value << 8 | value << 16 | value << 24; //@line 4554
  while ((ptr | 0) <= (block_aligned_end | 0)) {
   HEAP32[ptr >> 2] = value4; //@line 4557
   HEAP32[ptr + 4 >> 2] = value4; //@line 4558
   HEAP32[ptr + 8 >> 2] = value4; //@line 4559
   HEAP32[ptr + 12 >> 2] = value4; //@line 4560
   HEAP32[ptr + 16 >> 2] = value4; //@line 4561
   HEAP32[ptr + 20 >> 2] = value4; //@line 4562
   HEAP32[ptr + 24 >> 2] = value4; //@line 4563
   HEAP32[ptr + 28 >> 2] = value4; //@line 4564
   HEAP32[ptr + 32 >> 2] = value4; //@line 4565
   HEAP32[ptr + 36 >> 2] = value4; //@line 4566
   HEAP32[ptr + 40 >> 2] = value4; //@line 4567
   HEAP32[ptr + 44 >> 2] = value4; //@line 4568
   HEAP32[ptr + 48 >> 2] = value4; //@line 4569
   HEAP32[ptr + 52 >> 2] = value4; //@line 4570
   HEAP32[ptr + 56 >> 2] = value4; //@line 4571
   HEAP32[ptr + 60 >> 2] = value4; //@line 4572
   ptr = ptr + 64 | 0; //@line 4573
  }
  while ((ptr | 0) < (aligned_end | 0)) {
   HEAP32[ptr >> 2] = value4; //@line 4577
   ptr = ptr + 4 | 0; //@line 4578
  }
 }
 while ((ptr | 0) < (end | 0)) {
  HEAP8[ptr >> 0] = value; //@line 4583
  ptr = ptr + 1 | 0; //@line 4584
 }
 return end - num | 0; //@line 4586
}
function ___stdio_read($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $11 = 0, $18 = 0, $24 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 54763
 STACKTOP = STACKTOP + 32 | 0; //@line 54764
 $vararg_buffer = sp; //@line 54765
 $3 = sp + 16 | 0; //@line 54766
 HEAP32[$3 >> 2] = $1; //@line 54767
 $4 = $3 + 4 | 0; //@line 54768
 $5 = $0 + 48 | 0; //@line 54769
 $6 = HEAP32[$5 >> 2] | 0; //@line 54770
 HEAP32[$4 >> 2] = $2 - (($6 | 0) != 0 & 1); //@line 54774
 $11 = $0 + 44 | 0; //@line 54776
 HEAP32[$3 + 8 >> 2] = HEAP32[$11 >> 2]; //@line 54778
 HEAP32[$3 + 12 >> 2] = $6; //@line 54780
 HEAP32[$vararg_buffer >> 2] = HEAP32[$0 + 60 >> 2]; //@line 54784
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 54786
 HEAP32[$vararg_buffer + 8 >> 2] = 2; //@line 54788
 $18 = ___syscall_ret(___syscall145(145, $vararg_buffer | 0) | 0) | 0; //@line 54790
 if (($18 | 0) < 1) {
  HEAP32[$0 >> 2] = HEAP32[$0 >> 2] | $18 & 48 ^ 16; //@line 54797
  $$0 = $18; //@line 54798
 } else {
  $24 = HEAP32[$4 >> 2] | 0; //@line 54800
  if ($18 >>> 0 > $24 >>> 0) {
   $27 = HEAP32[$11 >> 2] | 0; //@line 54804
   $28 = $0 + 4 | 0; //@line 54805
   HEAP32[$28 >> 2] = $27; //@line 54806
   HEAP32[$0 + 8 >> 2] = $27 + ($18 - $24); //@line 54809
   if (!(HEAP32[$5 >> 2] | 0)) {
    $$0 = $2; //@line 54813
   } else {
    HEAP32[$28 >> 2] = $27 + 1; //@line 54816
    HEAP8[$1 + ($2 + -1) >> 0] = HEAP8[$27 >> 0] | 0; //@line 54820
    $$0 = $2; //@line 54821
   }
  } else {
   $$0 = $18; //@line 54824
  }
 }
 STACKTOP = sp; //@line 54827
 return $$0 | 0; //@line 54827
}
function __Z11op_cf0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $34 = 0, $4 = 0, $7 = 0, $8 = 0, $sext41$lobit = 0, $sext43$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 20750
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 20752
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 20755
 $8 = $2 + 4 | 0; //@line 20756
 HEAP32[162769] = $8; //@line 20757
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20759
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 20766
 HEAP32[162769] = $2 + 6; //@line 20768
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 20769
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 20771
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 20775
 $27 = $25 << 16 >> 16; //@line 20778
 $28 = 651008 + (($7 & 7) << 2) | 0; //@line 20779
 $29 = HEAP32[$28 >> 2] | 0; //@line 20780
 $30 = $27 - $29 | 0; //@line 20781
 $sext41$lobit = $25 >>> 15 & 1; //@line 20785
 $sext43$lobit = $30 >>> 15 & 1; //@line 20787
 $34 = ($30 & 65535 | 0) == 0; //@line 20789
 HEAP32[96442] = $34 & 1; //@line 20791
 HEAP32[96444] = ($29 >>> 15 & 1 | 0) != ($sext41$lobit | 0) & ($sext43$lobit | 0) != ($sext41$lobit | 0) & 1; //@line 20796
 HEAP32[96441] = ($29 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 20801
 HEAP32[96443] = $sext43$lobit; //@line 20802
 if ($34) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 20814
  return;
 } else {
  HEAP32[$28 >> 2] = $27; //@line 20817
  return;
 }
}
function __Z11op_af8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $48 = 0, $49 = 0, $6 = 0, $sext36$lobit = 0, $sext38$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 18606
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 18608
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 18611
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 18621
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 18623
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 18627
 $23 = $21 << 24 >> 24; //@line 18630
 $24 = 651008 + (($6 & 7) << 2) | 0; //@line 18631
 $25 = HEAP32[$24 >> 2] | 0; //@line 18632
 $26 = $23 - $25 | 0; //@line 18633
 $sext36$lobit = $21 >>> 7 & 1; //@line 18637
 $sext38$lobit = $26 >>> 7 & 1; //@line 18639
 $30 = ($26 & 255 | 0) == 0; //@line 18641
 HEAP32[96442] = $30 & 1; //@line 18643
 HEAP32[96444] = ($25 >>> 7 & 1 | 0) != ($sext36$lobit | 0) & ($sext38$lobit | 0) != ($sext36$lobit | 0) & 1; //@line 18648
 HEAP32[96441] = ($25 & 255) >>> 0 > ($21 & 255) >>> 0 & 1; //@line 18653
 HEAP32[96443] = $sext38$lobit; //@line 18654
 if ($30) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 18666
  $48 = HEAP32[162769] | 0; //@line 18667
  $49 = $48 + 6 | 0; //@line 18668
  HEAP32[162769] = $49; //@line 18669
  return;
 } else {
  HEAP32[$24 >> 2] = $23; //@line 18672
  $48 = HEAP32[162769] | 0; //@line 18673
  $49 = $48 + 6 | 0; //@line 18674
  HEAP32[162769] = $49; //@line 18675
  return;
 }
}
function __ZN8tinyxml210XMLElement9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$014 = 0, $$03$i = 0, $10 = 0, $17 = 0, $23 = 0, $3 = 0, $6 = 0, $9 = 0;
 $3 = HEAP8[$1 >> 0] | 0; //@line 38169
 L1 : do {
  if ($3 << 24 >> 24 > -1) {
   $$03$i = $1; //@line 38173
   $6 = $3; //@line 38173
   while (1) {
    if (!(_isspace($6 & 255) | 0)) {
     break;
    }
    $9 = $$03$i + 1 | 0; //@line 38181
    $10 = HEAP8[$9 >> 0] | 0; //@line 38182
    if ($10 << 24 >> 24 > -1) {
     $$03$i = $9; //@line 38185
     $6 = $10; //@line 38185
    } else {
     $$014 = $9; //@line 38187
     break L1;
    }
   }
   if (!$$03$i) {
    $$0 = 0; //@line 38193
    return $$0 | 0; //@line 38194
   }
   if ($6 << 24 >> 24 == 47) {
    HEAP32[$0 + 44 >> 2] = 2; //@line 38199
    $$014 = $$03$i + 1 | 0; //@line 38201
   } else {
    $$014 = $$03$i; //@line 38203
   }
  } else {
   $$014 = $1; //@line 38206
  }
 } while (0);
 $17 = __ZN8tinyxml27StrPair9ParseNameEPc($0 + 12 | 0, $$014) | 0; //@line 38210
 if ((HEAP32[$0 + 16 >> 2] | 0) == (HEAP32[$0 + 20 >> 2] | 0)) {
  $$0 = 0; //@line 38217
  return $$0 | 0; //@line 38218
 }
 $23 = __ZN8tinyxml210XMLElement15ParseAttributesEPc($0, $17) | 0; //@line 38220
 if (!$23) {
  $$0 = 0; //@line 38223
  return $$0 | 0; //@line 38224
 }
 if (!(HEAP8[$23 >> 0] | 0)) {
  $$0 = $23; //@line 38229
  return $$0 | 0; //@line 38230
 }
 if (HEAP32[$0 + 44 >> 2] | 0) {
  $$0 = $23; //@line 38236
  return $$0 | 0; //@line 38237
 }
 $$0 = __ZN8tinyxml27XMLNode9ParseDeepEPcPNS_7StrPairE($0, $23, $2) | 0; //@line 38240
 return $$0 | 0; //@line 38241
}
function __Z12op_81d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$044 = 0, $14 = 0, $17 = 0, $18 = 0, $21 = 0, $25 = 0, $26 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $sext46$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 16988
 $5 = HEAP32[162769] | 0; //@line 16989
 $6 = HEAP32[162770] | 0; //@line 16990
 $7 = 651040 + (($0 & 7) << 2) | 0; //@line 16991
 $8 = HEAP32[$7 >> 2] | 0; //@line 16992
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 16998
 HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 2; //@line 17001
 $17 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17002
 $18 = HEAP32[$17 >> 2] | 0; //@line 17003
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17006
 $21 = $14 << 16 >> 16; //@line 17008
 if (!$21) {
  HEAP32[96444] = 0; //@line 17013
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 17014
  return;
 }
 $25 = ($18 | 0) / ($21 | 0) | 0; //@line 17017
 $26 = ($18 | 0) % ($21 | 0) | 0; //@line 17018
 if (($25 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17022
  HEAP32[96443] = 1; //@line 17023
  HEAP32[96441] = 0; //@line 17024
  return;
 } else {
  $$044 = ($26 >>> 15 & 1 | 0) == ($18 >>> 31 | 0) ? $26 : 0 - $26 | 0; //@line 17032
  $sext46$mask = $25 & 65535; //@line 17033
  $32 = ($sext46$mask | 0) == 0 & 1; //@line 17035
  HEAP32[96441] = 0; //@line 17036
  HEAP32[96442] = 0; //@line 17036
  HEAP32[96443] = 0; //@line 17036
  HEAP32[96444] = 0; //@line 17036
  HEAP32[96442] = $32; //@line 17037
  HEAP32[96443] = $25 >>> 15 & 1; //@line 17040
  HEAP32[$17 >> 2] = $$044 << 16 | $sext46$mask; //@line 17043
  return;
 }
}
function __Z11op_af0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $34 = 0, $4 = 0, $7 = 0, $8 = 0, $sext39$lobit = 0, $sext41$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 18529
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 18531
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 18534
 $8 = $2 + 4 | 0; //@line 18535
 HEAP32[162769] = $8; //@line 18536
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18538
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 18545
 HEAP32[162769] = $2 + 6; //@line 18547
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 18548
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 18550
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 18554
 $27 = $25 << 24 >> 24; //@line 18557
 $28 = 651008 + (($7 & 7) << 2) | 0; //@line 18558
 $29 = HEAP32[$28 >> 2] | 0; //@line 18559
 $30 = $27 - $29 | 0; //@line 18560
 $sext39$lobit = $25 >>> 7 & 1; //@line 18564
 $sext41$lobit = $30 >>> 7 & 1; //@line 18566
 $34 = ($30 & 255 | 0) == 0; //@line 18568
 HEAP32[96442] = $34 & 1; //@line 18570
 HEAP32[96444] = ($29 >>> 7 & 1 | 0) != ($sext39$lobit | 0) & ($sext41$lobit | 0) != ($sext39$lobit | 0) & 1; //@line 18575
 HEAP32[96441] = ($29 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 18580
 HEAP32[96443] = $sext41$lobit; //@line 18581
 if ($34) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 18593
  return;
 } else {
  HEAP32[$28 >> 2] = $27; //@line 18596
  return;
 }
}
function __Z12op_81e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$045 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $24 = 0, $25 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext47$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 17056
 $5 = HEAP32[162769] | 0; //@line 17057
 $6 = HEAP32[162770] | 0; //@line 17058
 $7 = 651040 + (($0 & 7) << 2) | 0; //@line 17059
 $9 = (HEAP32[$7 >> 2] | 0) + -2 | 0; //@line 17061
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($9) | 0; //@line 17067
 HEAP32[$7 >> 2] = $9; //@line 17068
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17069
 $17 = HEAP32[$16 >> 2] | 0; //@line 17070
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17073
 $20 = $15 << 16 >> 16; //@line 17075
 if (!$20) {
  HEAP32[96444] = 0; //@line 17080
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 17081
  return;
 }
 $24 = ($17 | 0) / ($20 | 0) | 0; //@line 17084
 $25 = ($17 | 0) % ($20 | 0) | 0; //@line 17085
 if (($24 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17089
  HEAP32[96443] = 1; //@line 17090
  HEAP32[96441] = 0; //@line 17091
  return;
 } else {
  $$045 = ($25 >>> 15 & 1 | 0) == ($17 >>> 31 | 0) ? $25 : 0 - $25 | 0; //@line 17099
  $sext47$mask = $24 & 65535; //@line 17100
  $31 = ($sext47$mask | 0) == 0 & 1; //@line 17102
  HEAP32[96441] = 0; //@line 17103
  HEAP32[96442] = 0; //@line 17103
  HEAP32[96443] = 0; //@line 17103
  HEAP32[96444] = 0; //@line 17103
  HEAP32[96442] = $31; //@line 17104
  HEAP32[96443] = $24 >>> 15 & 1; //@line 17107
  HEAP32[$16 >> 2] = $$045 << 16 | $sext47$mask; //@line 17110
  return;
 }
}
function __Z12op_81f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$039 = 0, $$cast = 0, $14 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $29 = 0, $3 = 0, $30 = 0, $36 = 0, $4 = 0, $5 = 0, $sext42$mask = 0;
 $3 = HEAP32[162768] | 0; //@line 17274
 $4 = HEAP32[162769] | 0; //@line 17275
 $5 = HEAP32[162770] | 0; //@line 17276
 $$cast = $4; //@line 17277
 $14 = ((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16; //@line 17287
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 17293
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17294
 $22 = HEAP32[$21 >> 2] | 0; //@line 17295
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 17298
 $25 = $20 << 16 >> 16; //@line 17300
 if (!$25) {
  HEAP32[96444] = 0; //@line 17305
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 17306
  return;
 }
 $29 = ($22 | 0) / ($25 | 0) | 0; //@line 17309
 $30 = ($22 | 0) % ($25 | 0) | 0; //@line 17310
 if (($29 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17314
  HEAP32[96443] = 1; //@line 17315
  HEAP32[96441] = 0; //@line 17316
  return;
 } else {
  $$039 = ($30 >>> 15 & 1 | 0) == ($22 >>> 31 | 0) ? $30 : 0 - $30 | 0; //@line 17324
  $sext42$mask = $29 & 65535; //@line 17325
  $36 = ($sext42$mask | 0) == 0 & 1; //@line 17327
  HEAP32[96441] = 0; //@line 17328
  HEAP32[96442] = 0; //@line 17328
  HEAP32[96443] = 0; //@line 17328
  HEAP32[96444] = 0; //@line 17328
  HEAP32[96442] = $36; //@line 17329
  HEAP32[96443] = $29 >>> 15 & 1; //@line 17332
  HEAP32[$21 >> 2] = $$039 << 16 | $sext42$mask; //@line 17335
  return;
 }
}
function __Z12op_81fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $30 = 0, $31 = 0, $37 = 0, $4 = 0, $7 = 0, $sext44$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 23631
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 23634
 $$cast = $4; //@line 23636
 $17 = __Z15get_disp_ea_000jj($7 + 2 | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23645
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23651
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23652
 $25 = HEAP32[$24 >> 2] | 0; //@line 23653
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23656
 $28 = $23 << 16 >> 16; //@line 23658
 if (!$28) {
  HEAP32[96444] = 0; //@line 23661
  __Z9Exceptionij(5, $7); //@line 23662
  return;
 }
 $30 = ($25 | 0) / ($28 | 0) | 0; //@line 23665
 $31 = ($25 | 0) % ($28 | 0) | 0; //@line 23666
 if (($30 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 23670
  HEAP32[96443] = 1; //@line 23671
  HEAP32[96441] = 0; //@line 23672
  return;
 } else {
  $$042 = ($31 >>> 15 & 1 | 0) == ($25 >>> 31 | 0) ? $31 : 0 - $31 | 0; //@line 23680
  $sext44$mask = $30 & 65535; //@line 23681
  $37 = ($sext44$mask | 0) == 0 & 1; //@line 23683
  HEAP32[96441] = 0; //@line 23684
  HEAP32[96442] = 0; //@line 23684
  HEAP32[96443] = 0; //@line 23684
  HEAP32[96444] = 0; //@line 23684
  HEAP32[96442] = $37; //@line 23685
  HEAP32[96443] = $30 >>> 15 & 1; //@line 23688
  HEAP32[$24 >> 2] = $$042 << 16 | $sext44$mask; //@line 23691
  return;
 }
}
function __Z12op_ebfa_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $22 = 0, $25 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0, $47 = 0, $52 = 0, $53 = 0, $61 = 0, $67 = 0, $70 = 0, $sext39 = 0;
 $1 = HEAP32[162769] | 0; //@line 44965
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 44968
 $sext39 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 44987
 $22 = $sext39 >> 16; //@line 44988
 $25 = $sext39 >> 22; //@line 44991
 if (!($22 & 2048)) {
  $39 = $25 & 31; //@line 44994
 } else {
  $39 = HEAP32[651008 + (($25 & 7) << 2) >> 2] | 0; //@line 44999
 }
 if (!($22 & 32)) {
  $36 = $22; //@line 45004
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 45009
 }
 $37 = $36 + 31 & 31; //@line 45012
 $47 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) + ($39 >> 31 & -536870912 | $39 >> 3) | 0; //@line 45021
 $52 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($47 >>> 16 << 2) >> 2] >> 2] & 127]($47) | 0; //@line 45026
 $53 = $47 + 4 | 0; //@line 45027
 $61 = $39 & 7; //@line 45035
 $67 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($53) | 0) & 255) >>> (8 - $61 | 0) | $52 << $61) >>> ($37 ^ 31); //@line 45041
 $70 = ($67 & 1 << $37 | 0) != 0; //@line 45044
 HEAP32[96443] = $70 & 1; //@line 45046
 HEAP32[96442] = ($67 | 0) == 0 & 1; //@line 45049
 HEAP32[96444] = 0; //@line 45050
 HEAP32[96441] = 0; //@line 45051
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = ($70 ? -2 << $37 : 0) | $67; //@line 45058
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45061
 return;
}
function __Z11op_cd0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $24 = 0, $4 = 0, $42 = 0, $43 = 0, $7 = 0, $9 = 0, $sext41$lobit = 0, $sext43$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 20445
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 20447
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 20450
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20452
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 20454
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 4 >> 2] & 127]($9) | 0; //@line 20458
 $17 = $15 << 16 >> 16; //@line 20461
 $18 = 651008 + (($7 & 7) << 2) | 0; //@line 20462
 $19 = HEAP32[$18 >> 2] | 0; //@line 20463
 $20 = $17 - $19 | 0; //@line 20464
 $sext41$lobit = $15 >>> 15 & 1; //@line 20468
 $sext43$lobit = $20 >>> 15 & 1; //@line 20470
 $24 = ($20 & 65535 | 0) == 0; //@line 20472
 HEAP32[96442] = $24 & 1; //@line 20474
 HEAP32[96444] = ($19 >>> 15 & 1 | 0) != ($sext41$lobit | 0) & ($sext43$lobit | 0) != ($sext41$lobit | 0) & 1; //@line 20479
 HEAP32[96441] = ($19 & 65535) >>> 0 > ($15 & 65535) >>> 0 & 1; //@line 20484
 HEAP32[96443] = $sext43$lobit; //@line 20485
 if ($24) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 16 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 20497
  $42 = HEAP32[162769] | 0; //@line 20498
  $43 = $42 + 4 | 0; //@line 20499
  HEAP32[162769] = $43; //@line 20500
  return;
 } else {
  HEAP32[$18 >> 2] = $17; //@line 20503
  $42 = HEAP32[162769] | 0; //@line 20504
  $43 = $42 + 4 | 0; //@line 20505
  HEAP32[162769] = $43; //@line 20506
  return;
 }
}
function __Z12op_81fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$040 = 0, $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $31 = 0, $32 = 0, $38 = 0, $4 = 0, $7 = 0, $sext43$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 17429
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 17432
 $$cast = $4; //@line 17434
 $18 = $7 + 2 + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 17445
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 17451
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17452
 $26 = HEAP32[$25 >> 2] | 0; //@line 17453
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 17456
 $29 = $24 << 16 >> 16; //@line 17458
 if (!$29) {
  HEAP32[96444] = 0; //@line 17461
  __Z9Exceptionij(5, $7); //@line 17462
  return;
 }
 $31 = ($26 | 0) / ($29 | 0) | 0; //@line 17465
 $32 = ($26 | 0) % ($29 | 0) | 0; //@line 17466
 if (($31 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17470
  HEAP32[96443] = 1; //@line 17471
  HEAP32[96441] = 0; //@line 17472
  return;
 } else {
  $$040 = ($32 >>> 15 & 1 | 0) == ($26 >>> 31 | 0) ? $32 : 0 - $32 | 0; //@line 17480
  $sext43$mask = $31 & 65535; //@line 17481
  $38 = ($sext43$mask | 0) == 0 & 1; //@line 17483
  HEAP32[96441] = 0; //@line 17484
  HEAP32[96442] = 0; //@line 17484
  HEAP32[96443] = 0; //@line 17484
  HEAP32[96444] = 0; //@line 17484
  HEAP32[96442] = $38; //@line 17485
  HEAP32[96443] = $31 >>> 15 & 1; //@line 17488
  HEAP32[$25 >> 2] = $$040 << 16 | $sext43$mask; //@line 17491
  return;
 }
}
function __Z12op_9108_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $3 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $8 = 0, $sext46$lobit = 0;
 $1 = $0 & 7; //@line 19949
 $3 = $0 >>> 9 & 7; //@line 19951
 $4 = 651040 + ($1 << 2) | 0; //@line 19952
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 19956
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 19962
 HEAP32[$4 >> 2] = $8; //@line 19963
 $15 = 651040 + ($3 << 2) | 0; //@line 19964
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 19968
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 19970
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 19974
 HEAP32[$15 >> 2] = $19; //@line 19975
 $31 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) + (($25 << 24 >> 24) - ($14 << 24 >> 24)) | 0; //@line 19984
 $32 = $14 >>> 7; //@line 19985
 $33 = $25 >>> 7; //@line 19987
 $34 = $31 >>> 7; //@line 19989
 $sext46$lobit = $34 & 1; //@line 19990
 $36 = $sext46$lobit ^ $33 & 1; //@line 19992
 HEAP32[96444] = $36 & ($33 ^ $32); //@line 19994
 $40 = $36 & ($34 ^ $32) ^ $32 & 1; //@line 19997
 HEAP32[96441] = $40; //@line 19998
 HEAP32[96445] = $40; //@line 19999
 HEAP32[96442] = ($31 & 255 | 0) == 0 & HEAP32[96442]; //@line 20005
 HEAP32[96443] = $sext46$lobit; //@line 20006
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $31); //@line 20010
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20013
 return;
}
function __Z11op_ef9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $1 = 0, $15 = 0, $24 = 0, $26 = 0, $29 = 0, $3 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $50 = 0, $51 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 23165
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 23167
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 23170
 $15 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 23179
 $24 = $15 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 23188
 $26 = 123608 + ($15 >>> 16 << 2) | 0; //@line 23190
 $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$26 >> 2] >> 2] & 127]($24) | 0; //@line 23193
 $31 = 651008 + (($6 & 7) << 2) | 0; //@line 23195
 $32 = HEAP32[$31 >> 2] | 0; //@line 23196
 $33 = $29 - $32 | 0; //@line 23197
 $$lobit37 = $29 >>> 31; //@line 23199
 $$lobit38 = $33 >>> 31; //@line 23200
 $34 = ($33 | 0) == 0; //@line 23201
 HEAP32[96442] = $34 & 1; //@line 23203
 HEAP32[96444] = ($32 >>> 31 | 0) != ($$lobit37 | 0) & ($$lobit38 | 0) != ($$lobit37 | 0) & 1; //@line 23208
 HEAP32[96441] = $29 >>> 0 < $32 >>> 0 & 1; //@line 23211
 HEAP32[96443] = $$lobit38; //@line 23212
 if ($34) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$26 >> 2] | 0) + 12 >> 2] & 31]($24, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 23224
  $50 = HEAP32[162769] | 0; //@line 23225
  $51 = $50 + 8 | 0; //@line 23226
  HEAP32[162769] = $51; //@line 23227
  return;
 } else {
  HEAP32[$31 >> 2] = $29; //@line 23230
  $50 = HEAP32[162769] | 0; //@line 23231
  $51 = $50 + 8 | 0; //@line 23232
  HEAP32[162769] = $51; //@line 23233
  return;
 }
}
function __Z12op_80f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $14 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $37 = 0, $39 = 0, $4 = 0, $41 = 0, $5 = 0, $sext$mask = 0, $sext$mask35 = 0;
 $3 = HEAP32[162768] | 0; //@line 15349
 $4 = HEAP32[162769] | 0; //@line 15350
 $5 = HEAP32[162770] | 0; //@line 15351
 $$cast = $4; //@line 15352
 $14 = (HEAPU8[$$cast + 3 >> 0] | 0) << 16 | (HEAPU8[$$cast + 2 >> 0] | 0) << 24; //@line 15361
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14 | (HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) | 0; //@line 15376
 $30 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15377
 $31 = HEAP32[$30 >> 2] | 0; //@line 15378
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15381
 $sext$mask = $29 & 65535; //@line 15382
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 15387
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 15388
  return;
 }
 $37 = ($31 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15391
 if ($37 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15394
  HEAP32[96443] = 1; //@line 15395
  HEAP32[96441] = 0; //@line 15396
  return;
 } else {
  $39 = ($31 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15399
  $sext$mask35 = $37 & 65535; //@line 15400
  $41 = ($sext$mask35 | 0) == 0 & 1; //@line 15402
  HEAP32[96441] = 0; //@line 15403
  HEAP32[96442] = 0; //@line 15403
  HEAP32[96443] = 0; //@line 15403
  HEAP32[96444] = 0; //@line 15403
  HEAP32[96442] = $41; //@line 15404
  HEAP32[96443] = $37 >>> 15 & 1; //@line 15407
  HEAP32[$30 >> 2] = $39 << 16 | $sext$mask35; //@line 15410
  return;
 }
}
function __Z12op_80e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $32 = 0, $34 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $sext39$mask = 0, $sext40$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 15149
 $5 = HEAP32[162769] | 0; //@line 15150
 $6 = HEAP32[162770] | 0; //@line 15151
 $$cast = $5; //@line 15154
 $18 = (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 15165
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 15171
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15172
 $26 = HEAP32[$25 >> 2] | 0; //@line 15173
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15176
 $sext39$mask = $24 & 65535; //@line 15177
 if (!$sext39$mask) {
  HEAP32[96444] = 0; //@line 15182
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 15183
  return;
 }
 $32 = ($26 >>> 0) / ($sext39$mask >>> 0) | 0; //@line 15186
 if ($32 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15189
  HEAP32[96443] = 1; //@line 15190
  HEAP32[96441] = 0; //@line 15191
  return;
 } else {
  $34 = ($26 >>> 0) % ($sext39$mask >>> 0) | 0; //@line 15194
  $sext40$mask = $32 & 65535; //@line 15195
  $36 = ($sext40$mask | 0) == 0 & 1; //@line 15197
  HEAP32[96441] = 0; //@line 15198
  HEAP32[96442] = 0; //@line 15198
  HEAP32[96443] = 0; //@line 15198
  HEAP32[96444] = 0; //@line 15198
  HEAP32[96442] = $36; //@line 15199
  HEAP32[96443] = $32 >>> 15 & 1; //@line 15202
  HEAP32[$25 >> 2] = $34 << 16 | $sext40$mask; //@line 15205
  return;
 }
}
function __Z12op_ebf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $28 = 0, $31 = 0, $4 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $54 = 0, $55 = 0, $63 = 0, $69 = 0, $72 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 44857
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 44860
 $sext = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 44884
 $28 = $sext >> 16; //@line 44885
 $31 = $sext >> 22; //@line 44888
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 44891
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 44896
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 44901
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 44906
 }
 $43 = $42 + 31 & 31; //@line 44909
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 44914
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($49 >>> 16 << 2) >> 2] >> 2] & 127]($49) | 0; //@line 44919
 $55 = $49 + 4 | 0; //@line 44920
 $63 = $45 & 7; //@line 44928
 $69 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255) >>> (8 - $63 | 0) | $54 << $63) >>> ($43 ^ 31); //@line 44934
 $72 = ($69 & 1 << $43 | 0) != 0; //@line 44937
 HEAP32[96443] = $72 & 1; //@line 44939
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 44942
 HEAP32[96444] = 0; //@line 44943
 HEAP32[96441] = 0; //@line 44944
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = ($72 ? -2 << $43 : 0) | $69; //@line 44951
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 44954
 return;
}
function __Z12op_ebe8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $67 = 0, $sext40 = 0;
 $2 = HEAP32[162769] | 0; //@line 44554
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 44557
 $sext40 = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 44576
 $23 = $sext40 >> 16; //@line 44577
 $26 = $sext40 >> 22; //@line 44580
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 44583
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 44588
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 44593
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 44598
 }
 $38 = $37 + 31 & 31; //@line 44601
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 44606
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 44611
 $50 = $44 + 4 | 0; //@line 44612
 $58 = $40 & 7; //@line 44620
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 44626
 $67 = ($64 & 1 << $38 | 0) != 0; //@line 44629
 HEAP32[96443] = $67 & 1; //@line 44631
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 44634
 HEAP32[96444] = 0; //@line 44635
 HEAP32[96441] = 0; //@line 44636
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = ($67 ? -2 << $38 : 0) | $64; //@line 44643
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 44646
 return;
}
function __Z9fpuop_sccjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $11 = 0, $17 = 0, $2 = 0, $21 = 0, $34 = 0, $4 = 0, $40 = 0, $41 = 0, sp = 0;
 sp = STACKTOP; //@line 55528
 STACKTOP = STACKTOP + 16 | 0; //@line 55529
 $2 = sp; //@line 55530
 $4 = __ZL8fpp_condi($1 & 63) | 0; //@line 55532
 if (($4 | 0) == -1) {
  $11 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 55540
  $17 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($11) | 0; //@line 55546
  HEAP32[162770] = $17; //@line 55547
  HEAP32[162769] = $17; //@line 55548
  HEAP32[162768] = $11; //@line 55549
  __Z7op_illgj($0); //@line 55550
  STACKTOP = sp; //@line 55551
  return;
 }
 if (!($0 & 56)) {
  $21 = 651008 + (($0 & 7) << 2) | 0; //@line 55557
  HEAP32[$21 >> 2] = HEAP32[$21 >> 2] & -256 | ($4 | 0 ? 255 : 0); //@line 55563
  STACKTOP = sp; //@line 55564
  return;
 }
 if (!(__ZL9get_fp_adjPj($0, $2) | 0)) {
  $34 = (HEAP32[162768] | 0) + -4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 55574
  $40 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($34) | 0; //@line 55580
  HEAP32[162770] = $40; //@line 55581
  HEAP32[162769] = $40; //@line 55582
  HEAP32[162768] = $34; //@line 55583
  __Z7op_illgj($0); //@line 55584
  STACKTOP = sp; //@line 55585
  return;
 } else {
  $41 = HEAP32[$2 >> 2] | 0; //@line 55587
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($41, $4 | 0 ? 255 : 0); //@line 55595
  STACKTOP = sp; //@line 55596
  return;
 }
}
function __Z11op_ad0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $24 = 0, $4 = 0, $42 = 0, $43 = 0, $7 = 0, $9 = 0, $sext39$lobit = 0, $sext41$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 18220
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 18222
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 18225
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18227
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 18229
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 18233
 $17 = $15 << 24 >> 24; //@line 18236
 $18 = 651008 + (($7 & 7) << 2) | 0; //@line 18237
 $19 = HEAP32[$18 >> 2] | 0; //@line 18238
 $20 = $17 - $19 | 0; //@line 18239
 $sext39$lobit = $15 >>> 7 & 1; //@line 18243
 $sext41$lobit = $20 >>> 7 & 1; //@line 18245
 $24 = ($20 & 255 | 0) == 0; //@line 18247
 HEAP32[96442] = $24 & 1; //@line 18249
 HEAP32[96444] = ($19 >>> 7 & 1 | 0) != ($sext39$lobit | 0) & ($sext41$lobit | 0) != ($sext39$lobit | 0) & 1; //@line 18254
 HEAP32[96441] = ($19 & 255) >>> 0 > ($15 & 255) >>> 0 & 1; //@line 18259
 HEAP32[96443] = $sext41$lobit; //@line 18260
 if ($24) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 18272
  $42 = HEAP32[162769] | 0; //@line 18273
  $43 = $42 + 4 | 0; //@line 18274
  HEAP32[162769] = $43; //@line 18275
  return;
 } else {
  HEAP32[$18 >> 2] = $17; //@line 18278
  $42 = HEAP32[162769] | 0; //@line 18279
  $43 = $42 + 4 | 0; //@line 18280
  HEAP32[162769] = $43; //@line 18281
  return;
 }
}
function __Z12op_80f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $31 = 0, $33 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $sext$mask = 0, $sext$mask39 = 0;
 $4 = HEAP32[162768] | 0; //@line 23287
 $5 = HEAP32[162769] | 0; //@line 23288
 $6 = HEAP32[162770] | 0; //@line 23289
 $$cast = $5; //@line 23292
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23301
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23307
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23308
 $25 = HEAP32[$24 >> 2] | 0; //@line 23309
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23312
 $sext$mask = $23 & 65535; //@line 23313
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 23318
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 23319
  return;
 }
 $31 = ($25 >>> 0) / ($sext$mask >>> 0) | 0; //@line 23322
 if ($31 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 23325
  HEAP32[96443] = 1; //@line 23326
  HEAP32[96441] = 0; //@line 23327
  return;
 } else {
  $33 = ($25 >>> 0) % ($sext$mask >>> 0) | 0; //@line 23330
  $sext$mask39 = $31 & 65535; //@line 23331
  $35 = ($sext$mask39 | 0) == 0 & 1; //@line 23333
  HEAP32[96441] = 0; //@line 23334
  HEAP32[96442] = 0; //@line 23334
  HEAP32[96443] = 0; //@line 23334
  HEAP32[96444] = 0; //@line 23334
  HEAP32[96442] = $35; //@line 23335
  HEAP32[96443] = $31 >>> 15 & 1; //@line 23338
  HEAP32[$24 >> 2] = $33 << 16 | $sext$mask39; //@line 23341
  return;
 }
}
function _strncmp($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$01824 = 0, $$01926$in = 0, $$020 = 0, $$025 = 0, $$lcssa = 0, $$lcssa22 = 0, $10 = 0, $13 = 0, $17 = 0, $20 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 if (!$2) {
  $$020 = 0; //@line 56097
 } else {
  $4 = HEAP8[$0 >> 0] | 0; //@line 56099
  $5 = $4 & 255; //@line 56100
  $7 = HEAP8[$1 >> 0] | 0; //@line 56102
  $8 = $7 & 255; //@line 56103
  L3 : do {
   if (!($4 << 24 >> 24)) {
    $$lcssa = $8; //@line 56106
    $$lcssa22 = $5; //@line 56106
   } else {
    $$01824 = $0; //@line 56108
    $$01926$in = $2; //@line 56108
    $$025 = $1; //@line 56108
    $10 = $7; //@line 56108
    $13 = $4; //@line 56108
    $22 = $8; //@line 56108
    $23 = $5; //@line 56108
    while (1) {
     $$01926$in = $$01926$in + -1 | 0; //@line 56110
     if (!($13 << 24 >> 24 == $10 << 24 >> 24 & (($$01926$in | 0) != 0 & $10 << 24 >> 24 != 0))) {
      $$lcssa = $22; //@line 56117
      $$lcssa22 = $23; //@line 56117
      break L3;
     }
     $$01824 = $$01824 + 1 | 0; //@line 56120
     $$025 = $$025 + 1 | 0; //@line 56121
     $13 = HEAP8[$$01824 >> 0] | 0; //@line 56122
     $17 = $13 & 255; //@line 56123
     $10 = HEAP8[$$025 >> 0] | 0; //@line 56125
     $20 = $10 & 255; //@line 56126
     if (!($13 << 24 >> 24)) {
      $$lcssa = $20; //@line 56128
      $$lcssa22 = $17; //@line 56128
      break;
     } else {
      $22 = $20; //@line 56131
      $23 = $17; //@line 56131
     }
    }
   }
  } while (0);
  $$020 = $$lcssa22 - $$lcssa | 0; //@line 56137
 }
 return $$020 | 0; //@line 56139
}
function __Z12op_d108_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $3 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $4 = 0, $41 = 0, $8 = 0, $sext46$lobit = 0;
 $1 = $0 & 7; //@line 33571
 $3 = $0 >>> 9 & 7; //@line 33573
 $4 = 651040 + ($1 << 2) | 0; //@line 33574
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 33578
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 33584
 HEAP32[$4 >> 2] = $8; //@line 33585
 $15 = 651040 + ($3 << 2) | 0; //@line 33586
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 33590
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 33592
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 33596
 HEAP32[$15 >> 2] = $19; //@line 33597
 $32 = ($25 << 24 >> 24) + ($14 << 24 >> 24) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 33606
 $33 = $14 >>> 7; //@line 33607
 $34 = $25 >>> 7; //@line 33609
 $35 = $32 >>> 7; //@line 33611
 $sext46$lobit = $35 & 1; //@line 33612
 $37 = $sext46$lobit ^ $34 & 1; //@line 33614
 HEAP32[96444] = $37 & ($35 ^ $33); //@line 33616
 $41 = $37 & ($34 ^ $33) ^ $33 & 1; //@line 33619
 HEAP32[96441] = $41; //@line 33620
 HEAP32[96445] = $41; //@line 33621
 HEAP32[96442] = ($32 & 255 | 0) == 0 & HEAP32[96442]; //@line 33627
 HEAP32[96443] = $sext46$lobit; //@line 33628
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $32); //@line 33632
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33635
 return;
}
function _fflush($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$02325 = 0, $$02327 = 0, $$024$lcssa = 0, $$02426 = 0, $$1 = 0, $26 = 0, $29 = 0, $7 = 0, $phitmp = 0;
 do {
  if (!$0) {
   if (!(HEAP32[22163] | 0)) {
    $29 = 0; //@line 309
   } else {
    $29 = _fflush(HEAP32[22163] | 0) | 0; //@line 313
   }
   $$02325 = HEAP32[(___ofl_lock() | 0) >> 2] | 0; //@line 316
   if (!$$02325) {
    $$024$lcssa = $29; //@line 319
   } else {
    $$02327 = $$02325; //@line 321
    $$02426 = $29; //@line 321
    while (1) {
     if ((HEAP32[$$02327 + 76 >> 2] | 0) > -1) {
      $26 = ___lockfile($$02327) | 0; //@line 328
     } else {
      $26 = 0; //@line 330
     }
     if ((HEAP32[$$02327 + 20 >> 2] | 0) >>> 0 > (HEAP32[$$02327 + 28 >> 2] | 0) >>> 0) {
      $$1 = ___fflush_unlocked($$02327) | 0 | $$02426; //@line 340
     } else {
      $$1 = $$02426; //@line 342
     }
     if ($26 | 0) {
      ___unlockfile($$02327); //@line 346
     }
     $$02327 = HEAP32[$$02327 + 56 >> 2] | 0; //@line 349
     if (!$$02327) {
      $$024$lcssa = $$1; //@line 352
      break;
     } else {
      $$02426 = $$1; //@line 355
     }
    }
   }
   ___ofl_unlock(); //@line 359
   $$0 = $$024$lcssa; //@line 360
  } else {
   if ((HEAP32[$0 + 76 >> 2] | 0) <= -1) {
    $$0 = ___fflush_unlocked($0) | 0; //@line 367
    break;
   }
   $phitmp = (___lockfile($0) | 0) == 0; //@line 371
   $7 = ___fflush_unlocked($0) | 0; //@line 372
   if ($phitmp) {
    $$0 = $7; //@line 374
   } else {
    ___unlockfile($0); //@line 376
    $$0 = $7; //@line 377
   }
  }
 } while (0);
 return $$0 | 0; //@line 381
}
function __ZNK8tinyxml214XMLDeclaration12ShallowCloneEPNS_11XMLDocumentE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$pre$i$i$i$i = 0, $10 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $6 = 0, $7 = 0, $8 = 0;
 if (!$1) {
  $$0 = HEAP32[$0 + 4 >> 2] | 0; //@line 39901
 } else {
  $$0 = $1; //@line 39903
 }
 $6 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39906
 $7 = $$0 + 296 | 0; //@line 39907
 $8 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($7) | 0; //@line 39908
 HEAP32[$8 + 4 >> 2] = $$0; //@line 39910
 $10 = $8 + 8 | 0; //@line 39911
 HEAP32[$10 >> 2] = 0; //@line 39912
 HEAP32[$10 + 4 >> 2] = 0; //@line 39912
 HEAP32[$10 + 8 >> 2] = 0; //@line 39912
 HEAP32[$10 + 12 >> 2] = 0; //@line 39912
 HEAP32[$10 + 16 >> 2] = 0; //@line 39912
 HEAP32[$10 + 20 >> 2] = 0; //@line 39912
 HEAP32[$10 + 24 >> 2] = 0; //@line 39912
 HEAP32[$10 + 28 >> 2] = 0; //@line 39912
 HEAP32[$8 >> 2] = 1744; //@line 39913
 HEAP32[$8 + 40 >> 2] = $7; //@line 39915
 $13 = $6 | 0 ? $6 : 97462; //@line 39917
 $14 = $8 + 12 | 0; //@line 39918
 $$pre$i$i$i$i = $8 + 16 | 0; //@line 39919
 HEAP32[$14 >> 2] = 0; //@line 39920
 HEAP32[$$pre$i$i$i$i >> 2] = 0; //@line 39921
 $15 = $8 + 20 | 0; //@line 39922
 HEAP32[$15 >> 2] = 0; //@line 39923
 $16 = _strlen($13) | 0; //@line 39924
 $17 = $16 + 1 | 0; //@line 39925
 $18 = __Znaj($17) | 0; //@line 39926
 HEAP32[$$pre$i$i$i$i >> 2] = $18; //@line 39927
 _memcpy($18 | 0, $13 | 0, $17 | 0) | 0; //@line 39928
 HEAP32[$15 >> 2] = $18 + $16; //@line 39930
 HEAP32[$14 >> 2] = 512; //@line 39931
 return $8 | 0; //@line 39932
}
function __Z12op_c108_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $1 = 0, $14 = 0, $15 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $34 = 0, $38 = 0, $4 = 0, $42 = 0, $43 = 0, $8 = 0;
 $1 = $0 & 7; //@line 29732
 $3 = $0 >>> 9 & 7; //@line 29734
 $4 = 651040 + ($1 << 2) | 0; //@line 29735
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 29739
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 29745
 HEAP32[$4 >> 2] = $8; //@line 29746
 $15 = 651040 + ($3 << 2) | 0; //@line 29747
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 29751
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 29753
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 29757
 HEAP32[$15 >> 2] = $19; //@line 29758
 $26 = $14 << 24 >> 24; //@line 29760
 $28 = $25 << 24 >> 24; //@line 29763
 $34 = ($28 & 15) + ($26 & 15) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 29769
 $38 = ($28 & 240) + ($26 & 240) + $34 | 0; //@line 29773
 $$ = $34 >>> 0 > 9 ? $38 + 6 | 0 : $38; //@line 29776
 $42 = ($$ & 1008) >>> 0 > 144; //@line 29778
 $43 = $42 & 1; //@line 29779
 $$1$in = $42 ? ($$ & 65535) + 96 | 0 : $$; //@line 29782
 HEAP32[96441] = $43; //@line 29783
 HEAP32[96445] = $43; //@line 29784
 HEAP32[96442] = ($$1$in & 255 | 0) == 0 & HEAP32[96442]; //@line 29790
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$1$in & 65535); //@line 29795
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29798
 return;
}
function __Z11op_e70_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $17 = 0, $24 = 0, $26 = 0, $33 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $50 = 0, $52 = 0, $54 = 0, $7 = 0, $9 = 0;
 $1 = $0 & 7; //@line 22019
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22023
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 22026
 $5 = $4 + 2 | 0; //@line 22027
 $7 = HEAPU8[$5 >> 0] | 0; //@line 22029
 $9 = $7 << 24 >> 16; //@line 22031
 if ($9 & 2048 | 0) {
  $14 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 22037
  $15 = $4 + 4 | 0; //@line 22038
  HEAP32[162769] = $15; //@line 22039
  $17 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 22041
  $24 = HEAPU8[$15 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]; //@line 22048
  HEAP32[162769] = $4 + 6; //@line 22050
  $26 = __Z15get_disp_ea_020jj($17, $24) | 0; //@line 22051
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $14); //@line 22057
  return;
 }
 $33 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 22061
 $40 = HEAPU8[$4 >> 0] << 8 | HEAPU8[$4 + 1 >> 0]; //@line 22068
 HEAP32[162769] = $5; //@line 22069
 $41 = __Z15get_disp_ea_020jj($33, $40) | 0; //@line 22070
 $50 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($41) | 0) << 16 >> 16; //@line 22080
 $52 = $7 >>> 4 & 7; //@line 22082
 if (!($9 & 32768)) {
  $54 = 651008 + ($52 << 2) | 0; //@line 22084
  HEAP32[$54 >> 2] = HEAP32[$54 >> 2] & -65536 | $50 & 65535; //@line 22089
  return;
 } else {
  HEAP32[651040 + ($52 << 2) >> 2] = $50; //@line 22093
  return;
 }
}
function __Z11op_e30_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $17 = 0, $24 = 0, $26 = 0, $33 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $50 = 0, $52 = 0, $54 = 0, $7 = 0, $9 = 0;
 $1 = $0 & 7; //@line 21450
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21454
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 21457
 $5 = $4 + 2 | 0; //@line 21458
 $7 = HEAPU8[$5 >> 0] | 0; //@line 21460
 $9 = $7 << 24 >> 16; //@line 21462
 if ($9 & 2048 | 0) {
  $14 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 21468
  $15 = $4 + 4 | 0; //@line 21469
  HEAP32[162769] = $15; //@line 21470
  $17 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 21472
  $24 = HEAPU8[$15 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]; //@line 21479
  HEAP32[162769] = $4 + 6; //@line 21481
  $26 = __Z15get_disp_ea_020jj($17, $24) | 0; //@line 21482
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $14); //@line 21488
  return;
 }
 $33 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 21492
 $40 = HEAPU8[$4 >> 0] << 8 | HEAPU8[$4 + 1 >> 0]; //@line 21499
 HEAP32[162769] = $5; //@line 21500
 $41 = __Z15get_disp_ea_020jj($33, $40) | 0; //@line 21501
 $50 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($41) | 0) << 24 >> 24; //@line 21511
 $52 = $7 >>> 4 & 7; //@line 21513
 if (!($9 & 32768)) {
  $54 = 651008 + ($52 << 2) | 0; //@line 21515
  HEAP32[$54 >> 2] = HEAP32[$54 >> 2] & -256 | $50 & 255; //@line 21520
  return;
 } else {
  HEAP32[651040 + ($52 << 2) >> 2] = $50; //@line 21524
  return;
 }
}
function __Z11op_ed8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit42 = 0, $$lobit43 = 0, $11 = 0, $14 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $37 = 0, $38 = 0, $4 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 22822
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 22824
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 22827
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 22828
 $9 = HEAP32[$8 >> 2] | 0; //@line 22829
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 22831
 $14 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$11 >> 2] >> 2] & 127]($9) | 0; //@line 22834
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 4; //@line 22837
 $18 = 651008 + (($7 & 7) << 2) | 0; //@line 22839
 $19 = HEAP32[$18 >> 2] | 0; //@line 22840
 $20 = $14 - $19 | 0; //@line 22841
 $$lobit42 = $14 >>> 31; //@line 22843
 $$lobit43 = $20 >>> 31; //@line 22844
 $21 = ($20 | 0) == 0; //@line 22845
 HEAP32[96442] = $21 & 1; //@line 22847
 HEAP32[96444] = ($19 >>> 31 | 0) != ($$lobit42 | 0) & ($$lobit43 | 0) != ($$lobit42 | 0) & 1; //@line 22852
 HEAP32[96441] = $14 >>> 0 < $19 >>> 0 & 1; //@line 22855
 HEAP32[96443] = $$lobit43; //@line 22856
 if ($21) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 12 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 22868
  $37 = HEAP32[162769] | 0; //@line 22869
  $38 = $37 + 4 | 0; //@line 22870
  HEAP32[162769] = $38; //@line 22871
  return;
 } else {
  HEAP32[$18 >> 2] = $14; //@line 22874
  $37 = HEAP32[162769] | 0; //@line 22875
  $38 = $37 + 4 | 0; //@line 22876
  HEAP32[162769] = $38; //@line 22877
  return;
 }
}
function __Z11op_2f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $11 = 0, $13 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $3 = 0, $33 = 0, $34 = 0, $41 = 0, $54 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 9803
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 9806
 $$cast = $3; //@line 9807
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 9810
 $11 = $$cast + 4 | 0; //@line 9812
 HEAP32[162769] = $11; //@line 9813
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9815
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 9822
 HEAP32[162769] = $$cast + 6; //@line 9824
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 9825
 $23 = $9 << 24 >> 16; //@line 9826
 $26 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 9829
 $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($22) | 0) << 16 >> 16; //@line 9837
 $34 = $22 + 2 | 0; //@line 9838
 $41 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($34) | 0) << 16 >> 16; //@line 9846
 $$042 = ($23 & 32768 | 0) == 0 ? $26 << 16 >> 16 : $26; //@line 9851
 HEAP32[96442] = (($33 | 0) == ($$042 | 0) | ($41 | 0) == ($$042 | 0)) & 1; //@line 9856
 if (($33 | 0) > ($41 | 0)) {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 9862
 } else {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 9867
 }
 HEAP32[96441] = $54 & 1; //@line 9870
 if (!(($23 & 2048 | 0) != 0 & $54)) {
  return;
 }
 __Z9Exceptionij(6, $6); //@line 9877
 return;
}
function __Z10op_f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $11 = 0, $13 = 0, $20 = 0, $22 = 0, $23 = 0, $26 = 0, $3 = 0, $33 = 0, $34 = 0, $41 = 0, $54 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 6069
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 6072
 $$cast = $3; //@line 6073
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 6076
 $11 = $$cast + 4 | 0; //@line 6078
 HEAP32[162769] = $11; //@line 6079
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6081
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 6088
 HEAP32[162769] = $$cast + 6; //@line 6090
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 6091
 $23 = $9 << 24 >> 16; //@line 6092
 $26 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 6095
 $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($22) | 0) << 24 >> 24; //@line 6103
 $34 = $22 + 1 | 0; //@line 6104
 $41 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($34) | 0) << 24 >> 24; //@line 6112
 $$042 = ($23 & 32768 | 0) == 0 ? $26 << 24 >> 24 : $26; //@line 6117
 HEAP32[96442] = (($33 | 0) == ($$042 | 0) | ($41 | 0) == ($$042 | 0)) & 1; //@line 6122
 if (($33 | 0) > ($41 | 0)) {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 6128
 } else {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 6133
 }
 HEAP32[96441] = $54 & 1; //@line 6136
 if (!(($23 & 2048 | 0) != 0 & $54)) {
  return;
 }
 __Z9Exceptionij(6, $6); //@line 6143
 return;
}
function __Z11op_ee0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit43 = 0, $$lobit44 = 0, $10 = 0, $12 = 0, $15 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $36 = 0, $37 = 0, $4 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 22888
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 22890
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 22893
 $8 = 651040 + (($0 & 7) << 2) | 0; //@line 22894
 $10 = (HEAP32[$8 >> 2] | 0) + -4 | 0; //@line 22896
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 22898
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$12 >> 2] >> 2] & 127]($10) | 0; //@line 22901
 HEAP32[$8 >> 2] = $10; //@line 22902
 $17 = 651008 + (($7 & 7) << 2) | 0; //@line 22904
 $18 = HEAP32[$17 >> 2] | 0; //@line 22905
 $19 = $15 - $18 | 0; //@line 22906
 $$lobit43 = $15 >>> 31; //@line 22908
 $$lobit44 = $19 >>> 31; //@line 22909
 $20 = ($19 | 0) == 0; //@line 22910
 HEAP32[96442] = $20 & 1; //@line 22912
 HEAP32[96444] = ($18 >>> 31 | 0) != ($$lobit43 | 0) & ($$lobit44 | 0) != ($$lobit43 | 0) & 1; //@line 22917
 HEAP32[96441] = $15 >>> 0 < $18 >>> 0 & 1; //@line 22920
 HEAP32[96443] = $$lobit44; //@line 22921
 if ($20) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 12 >> 2] & 31]($10, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 22933
  $36 = HEAP32[162769] | 0; //@line 22934
  $37 = $36 + 4 | 0; //@line 22935
  HEAP32[162769] = $37; //@line 22936
  return;
 } else {
  HEAP32[$17 >> 2] = $15; //@line 22939
  $36 = HEAP32[162769] | 0; //@line 22940
  $37 = $36 + 4 | 0; //@line 22941
  HEAP32[162769] = $37; //@line 22942
  return;
 }
}
function __Z11op_ee8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit42 = 0, $$lobit43 = 0, $19 = 0, $2 = 0, $21 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $4 = 0, $45 = 0, $46 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 22953
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 22955
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 22958
 $19 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 22971
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 22973
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$21 >> 2] >> 2] & 127]($19) | 0; //@line 22976
 $26 = 651008 + (($7 & 7) << 2) | 0; //@line 22978
 $27 = HEAP32[$26 >> 2] | 0; //@line 22979
 $28 = $24 - $27 | 0; //@line 22980
 $$lobit42 = $24 >>> 31; //@line 22982
 $$lobit43 = $28 >>> 31; //@line 22983
 $29 = ($28 | 0) == 0; //@line 22984
 HEAP32[96442] = $29 & 1; //@line 22986
 HEAP32[96444] = ($27 >>> 31 | 0) != ($$lobit42 | 0) & ($$lobit43 | 0) != ($$lobit42 | 0) & 1; //@line 22991
 HEAP32[96441] = $24 >>> 0 < $27 >>> 0 & 1; //@line 22994
 HEAP32[96443] = $$lobit43; //@line 22995
 if ($29) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 12 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 23007
  $45 = HEAP32[162769] | 0; //@line 23008
  $46 = $45 + 6 | 0; //@line 23009
  HEAP32[162769] = $46; //@line 23010
  return;
 } else {
  HEAP32[$26 >> 2] = $24; //@line 23013
  $45 = HEAP32[162769] | 0; //@line 23014
  $46 = $45 + 6 | 0; //@line 23015
  HEAP32[162769] = $46; //@line 23016
  return;
 }
}
function __Z11op_2fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $$cast = 0, $1 = 0, $10 = 0, $19 = 0, $2 = 0, $21 = 0, $22 = 0, $25 = 0, $3 = 0, $32 = 0, $33 = 0, $40 = 0, $53 = 0, $8 = 0;
 $1 = HEAP32[162768] | 0; //@line 10152
 $2 = HEAP32[162769] | 0; //@line 10153
 $3 = HEAP32[162770] | 0; //@line 10154
 $$cast = $2; //@line 10157
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 10160
 $10 = $$cast + 4 | 0; //@line 10162
 HEAP32[162769] = $10; //@line 10163
 $19 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 10173
 HEAP32[162769] = $$cast + 6; //@line 10175
 $21 = __Z15get_disp_ea_020jj($1 + $10 - $3 | 0, $19) | 0; //@line 10176
 $22 = $8 << 24 >> 16; //@line 10177
 $25 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 10180
 $32 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($21) | 0) << 16 >> 16; //@line 10188
 $33 = $21 + 2 | 0; //@line 10189
 $40 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($33) | 0) << 16 >> 16; //@line 10197
 $$043 = ($22 & 32768 | 0) == 0 ? $25 << 16 >> 16 : $25; //@line 10202
 HEAP32[96442] = (($32 | 0) == ($$043 | 0) | ($40 | 0) == ($$043 | 0)) & 1; //@line 10207
 if (($32 | 0) > ($40 | 0)) {
  $53 = ($$043 | 0) < ($32 | 0) | ($$043 | 0) > ($40 | 0); //@line 10213
 } else {
  $53 = ($$043 | 0) < ($32 | 0) | ($$043 | 0) > ($40 | 0); //@line 10218
 }
 HEAP32[96441] = $53 & 1; //@line 10221
 if (!(($22 & 2048 | 0) != 0 & $53)) {
  return;
 }
 __Z9Exceptionij(6, $2 + $1 - $3 | 0); //@line 10228
 return;
}
function __Z12op_ebf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $45 = 0, $46 = 0, $54 = 0, $60 = 0, $63 = 0, $sext36 = 0;
 $1 = HEAP32[162769] | 0; //@line 44757
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 44760
 $sext36 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 44776
 $19 = $sext36 >> 16; //@line 44777
 $22 = $sext36 >> 22; //@line 44780
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 44783
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 44788
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 44793
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 44798
 }
 $34 = $33 + 31 & 31; //@line 44801
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 44806
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($40 >>> 16 << 2) >> 2] >> 2] & 127]($40) | 0; //@line 44811
 $46 = $40 + 4 | 0; //@line 44812
 $54 = $36 & 7; //@line 44820
 $60 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255) >>> (8 - $54 | 0) | $45 << $54) >>> ($34 ^ 31); //@line 44826
 $63 = ($60 & 1 << $34 | 0) != 0; //@line 44829
 HEAP32[96443] = $63 & 1; //@line 44831
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 44834
 HEAP32[96444] = 0; //@line 44835
 HEAP32[96441] = 0; //@line 44836
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = ($63 ? -2 << $34 : 0) | $60; //@line 44843
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 44846
 return;
}
function __ZN12monitor_desc11driver_openEv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $11 = 0, $15 = 0, $19 = 0, $24 = 0, $scevgep$i = 0, sp = 0;
 sp = STACKTOP; //@line 24344
 STACKTOP = STACKTOP + 80 | 0; //@line 24345
 $1 = sp; //@line 24346
 if ((HEAP32[$0 + 4 >> 2] | 0) == (HEAP32[$0 + 8 >> 2] | 0)) {
  _fwrite(96320, 50, 1, HEAP32[22038] | 0) | 0; //@line 24354
 }
 HEAP8[$0 + 793 >> 0] = 0; //@line 24357
 HEAP8[$0 + 794 >> 0] = 0; //@line 24359
 $11 = HEAP32[$0 + 16 >> 2] | 0; //@line 24361
 $15 = HEAP16[$0 + 824 + (HEAP32[$11 + 12 >> 2] << 1) >> 1] | 0; //@line 24365
 HEAP16[$0 + 812 >> 1] = $15; //@line 24367
 HEAP16[$0 + 804 >> 1] = $15; //@line 24369
 $19 = HEAP32[$11 + 8 >> 2] | 0; //@line 24371
 HEAP32[$0 + 816 >> 2] = $19; //@line 24373
 HEAP32[$0 + 808 >> 2] = $19; //@line 24375
 HEAP8[$0 + 795 >> 0] = 0; //@line 24377
 HEAP32[$1 >> 2] = 56; //@line 24378
 _Execute68kTrap(-22754, $1); //@line 24379
 $24 = HEAP32[$1 + 32 >> 2] | 0; //@line 24381
 if (!$24) {
  $$0 = -108; //@line 24384
  STACKTOP = sp; //@line 24385
  return $$0 | 0; //@line 24385
 }
 HEAP32[$0 + 820 >> 2] = $24; //@line 24388
 HEAP32[$0 + 796 >> 2] = 0; //@line 24390
 HEAP32[$0 + 800 >> 2] = 0; //@line 24392
 __ZN12monitor_desc15set_gamma_tableEj($0, 0) | 0; //@line 24393
 $scevgep$i = $0 + 25 | 0; //@line 24394
 _memset($scevgep$i | 0, 127, 768) | 0; //@line 24395
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[$0 >> 2] | 0) + 12 >> 2] & 7]($0, $scevgep$i, 256); //@line 24399
 $$0 = 0; //@line 24400
 STACKTOP = sp; //@line 24401
 return $$0 | 0; //@line 24401
}
function __Z12op_80d8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $17 = 0, $18 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $sext$mask = 0, $sext$mask40 = 0;
 $4 = HEAP32[162768] | 0; //@line 15031
 $5 = HEAP32[162769] | 0; //@line 15032
 $6 = HEAP32[162770] | 0; //@line 15033
 $7 = 651040 + (($0 & 7) << 2) | 0; //@line 15034
 $8 = HEAP32[$7 >> 2] | 0; //@line 15035
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 15041
 HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 2; //@line 15044
 $17 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15045
 $18 = HEAP32[$17 >> 2] | 0; //@line 15046
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15049
 $sext$mask = $14 & 65535; //@line 15050
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 15055
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 15056
  return;
 }
 $24 = ($18 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15059
 if ($24 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15062
  HEAP32[96443] = 1; //@line 15063
  HEAP32[96441] = 0; //@line 15064
  return;
 } else {
  $26 = ($18 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15067
  $sext$mask40 = $24 & 65535; //@line 15068
  $28 = ($sext$mask40 | 0) == 0 & 1; //@line 15070
  HEAP32[96441] = 0; //@line 15071
  HEAP32[96442] = 0; //@line 15071
  HEAP32[96443] = 0; //@line 15071
  HEAP32[96444] = 0; //@line 15071
  HEAP32[96442] = $28; //@line 15072
  HEAP32[96443] = $24 >>> 15 & 1; //@line 15075
  HEAP32[$17 >> 2] = $26 << 16 | $sext$mask40; //@line 15078
  return;
 }
}
function __Z12op_e9fa_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $22 = 0, $25 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0, $47 = 0, $52 = 0, $53 = 0, $61 = 0, $67 = 0, $sext36 = 0;
 $1 = HEAP32[162769] | 0; //@line 43466
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 43469
 $sext36 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 43488
 $22 = $sext36 >> 16; //@line 43489
 $25 = $sext36 >> 22; //@line 43492
 if (!($22 & 2048)) {
  $39 = $25 & 31; //@line 43495
 } else {
  $39 = HEAP32[651008 + (($25 & 7) << 2) >> 2] | 0; //@line 43500
 }
 if (!($22 & 32)) {
  $36 = $22; //@line 43505
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 43510
 }
 $37 = $36 + 31 & 31; //@line 43513
 $47 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) + ($39 >> 31 & -536870912 | $39 >> 3) | 0; //@line 43522
 $52 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($47 >>> 16 << 2) >> 2] >> 2] & 127]($47) | 0; //@line 43527
 $53 = $47 + 4 | 0; //@line 43528
 $61 = $39 & 7; //@line 43536
 $67 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($53) | 0) & 255) >>> (8 - $61 | 0) | $52 << $61) >>> ($37 ^ 31); //@line 43542
 HEAP32[96443] = ($67 & 1 << $37 | 0) != 0 & 1; //@line 43547
 HEAP32[96442] = ($67 | 0) == 0 & 1; //@line 43550
 HEAP32[96444] = 0; //@line 43551
 HEAP32[96441] = 0; //@line 43552
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = $67; //@line 43556
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43559
 return;
}
function __Z12op_80f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $14 = 0, $20 = 0, $21 = 0, $22 = 0, $28 = 0, $3 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext35$mask = 0, $sext36$mask = 0;
 $3 = HEAP32[162768] | 0; //@line 15284
 $4 = HEAP32[162769] | 0; //@line 15285
 $5 = HEAP32[162770] | 0; //@line 15286
 $$cast = $4; //@line 15287
 $14 = ((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16; //@line 15297
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 15303
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15304
 $22 = HEAP32[$21 >> 2] | 0; //@line 15305
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15308
 $sext35$mask = $20 & 65535; //@line 15309
 if (!$sext35$mask) {
  HEAP32[96444] = 0; //@line 15314
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 15315
  return;
 }
 $28 = ($22 >>> 0) / ($sext35$mask >>> 0) | 0; //@line 15318
 if ($28 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15321
  HEAP32[96443] = 1; //@line 15322
  HEAP32[96441] = 0; //@line 15323
  return;
 } else {
  $30 = ($22 >>> 0) % ($sext35$mask >>> 0) | 0; //@line 15326
  $sext36$mask = $28 & 65535; //@line 15327
  $32 = ($sext36$mask | 0) == 0 & 1; //@line 15329
  HEAP32[96441] = 0; //@line 15330
  HEAP32[96442] = 0; //@line 15330
  HEAP32[96443] = 0; //@line 15330
  HEAP32[96444] = 0; //@line 15330
  HEAP32[96442] = $32; //@line 15331
  HEAP32[96443] = $28 >>> 15 & 1; //@line 15334
  HEAP32[$21 >> 2] = $30 << 16 | $sext36$mask; //@line 15337
  return;
 }
}
function __Z12op_e9f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $28 = 0, $31 = 0, $4 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $54 = 0, $55 = 0, $63 = 0, $69 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 43361
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 43364
 $sext = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 43388
 $28 = $sext >> 16; //@line 43389
 $31 = $sext >> 22; //@line 43392
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 43395
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 43400
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 43405
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 43410
 }
 $43 = $42 + 31 & 31; //@line 43413
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 43418
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($49 >>> 16 << 2) >> 2] >> 2] & 127]($49) | 0; //@line 43423
 $55 = $49 + 4 | 0; //@line 43424
 $63 = $45 & 7; //@line 43432
 $69 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255) >>> (8 - $63 | 0) | $54 << $63) >>> ($43 ^ 31); //@line 43438
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 43443
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 43446
 HEAP32[96444] = 0; //@line 43447
 HEAP32[96441] = 0; //@line 43448
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = $69; //@line 43452
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 43455
 return;
}
function __Z12op_e9e8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $5 = 0, $50 = 0, $58 = 0, $64 = 0, $sext37 = 0;
 $2 = HEAP32[162769] | 0; //@line 43067
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 43070
 $sext37 = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 43089
 $23 = $sext37 >> 16; //@line 43090
 $26 = $sext37 >> 22; //@line 43093
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 43096
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 43101
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 43106
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 43111
 }
 $38 = $37 + 31 & 31; //@line 43114
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 43119
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 43124
 $50 = $44 + 4 | 0; //@line 43125
 $58 = $40 & 7; //@line 43133
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 43139
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 43144
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 43147
 HEAP32[96444] = 0; //@line 43148
 HEAP32[96441] = 0; //@line 43149
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = $64; //@line 43153
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43156
 return;
}
function __Z12op_80e0_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $17 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext$mask = 0, $sext$mask41 = 0;
 $4 = HEAP32[162768] | 0; //@line 15090
 $5 = HEAP32[162769] | 0; //@line 15091
 $6 = HEAP32[162770] | 0; //@line 15092
 $7 = 651040 + (($0 & 7) << 2) | 0; //@line 15093
 $9 = (HEAP32[$7 >> 2] | 0) + -2 | 0; //@line 15095
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($9) | 0; //@line 15101
 HEAP32[$7 >> 2] = $9; //@line 15102
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15103
 $17 = HEAP32[$16 >> 2] | 0; //@line 15104
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15107
 $sext$mask = $15 & 65535; //@line 15108
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 15113
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 15114
  return;
 }
 $23 = ($17 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15117
 if ($23 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15120
  HEAP32[96443] = 1; //@line 15121
  HEAP32[96441] = 0; //@line 15122
  return;
 } else {
  $25 = ($17 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15125
  $sext$mask41 = $23 & 65535; //@line 15126
  $27 = ($sext$mask41 | 0) == 0 & 1; //@line 15128
  HEAP32[96441] = 0; //@line 15129
  HEAP32[96442] = 0; //@line 15129
  HEAP32[96443] = 0; //@line 15129
  HEAP32[96444] = 0; //@line 15129
  HEAP32[96442] = $27; //@line 15130
  HEAP32[96443] = $23 >>> 15 & 1; //@line 15133
  HEAP32[$16 >> 2] = $25 << 16 | $sext$mask41; //@line 15136
  return;
 }
}
function __Z10op_fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $$cast = 0, $1 = 0, $10 = 0, $19 = 0, $2 = 0, $21 = 0, $22 = 0, $25 = 0, $3 = 0, $32 = 0, $33 = 0, $40 = 0, $53 = 0, $8 = 0;
 $1 = HEAP32[162768] | 0; //@line 6418
 $2 = HEAP32[162769] | 0; //@line 6419
 $3 = HEAP32[162770] | 0; //@line 6420
 $$cast = $2; //@line 6423
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 6426
 $10 = $$cast + 4 | 0; //@line 6428
 HEAP32[162769] = $10; //@line 6429
 $19 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 6439
 HEAP32[162769] = $$cast + 6; //@line 6441
 $21 = __Z15get_disp_ea_020jj($1 + $10 - $3 | 0, $19) | 0; //@line 6442
 $22 = $8 << 24 >> 16; //@line 6443
 $25 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 6446
 $32 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($21) | 0) << 24 >> 24; //@line 6454
 $33 = $21 + 1 | 0; //@line 6455
 $40 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($33) | 0) << 24 >> 24; //@line 6463
 $$043 = ($22 & 32768 | 0) == 0 ? $25 << 24 >> 24 : $25; //@line 6468
 HEAP32[96442] = (($32 | 0) == ($$043 | 0) | ($40 | 0) == ($$043 | 0)) & 1; //@line 6473
 if (($32 | 0) > ($40 | 0)) {
  $53 = ($$043 | 0) < ($32 | 0) | ($$043 | 0) > ($40 | 0); //@line 6479
 } else {
  $53 = ($$043 | 0) < ($32 | 0) | ($$043 | 0) > ($40 | 0); //@line 6484
 }
 HEAP32[96441] = $53 & 1; //@line 6487
 if (!(($22 & 2048 | 0) != 0 & $53)) {
  return;
 }
 __Z9Exceptionij(6, $2 + $1 - $3 | 0); //@line 6494
 return;
}
function __Z12op_80fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $33 = 0, $4 = 0, $7 = 0, $sext$mask = 0, $sext$mask38 = 0;
 $4 = HEAP32[162769] | 0; //@line 23354
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 23357
 $$cast = $4; //@line 23359
 $17 = __Z15get_disp_ea_000jj($7 + 2 | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23368
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23374
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23375
 $25 = HEAP32[$24 >> 2] | 0; //@line 23376
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23379
 $sext$mask = $23 & 65535; //@line 23380
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 23383
  __Z9Exceptionij(5, $7); //@line 23384
  return;
 }
 $29 = ($25 >>> 0) / ($sext$mask >>> 0) | 0; //@line 23387
 if ($29 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 23390
  HEAP32[96443] = 1; //@line 23391
  HEAP32[96441] = 0; //@line 23392
  return;
 } else {
  $31 = ($25 >>> 0) % ($sext$mask >>> 0) | 0; //@line 23395
  $sext$mask38 = $29 & 65535; //@line 23396
  $33 = ($sext$mask38 | 0) == 0 & 1; //@line 23398
  HEAP32[96441] = 0; //@line 23399
  HEAP32[96442] = 0; //@line 23399
  HEAP32[96443] = 0; //@line 23399
  HEAP32[96444] = 0; //@line 23399
  HEAP32[96442] = $33; //@line 23400
  HEAP32[96443] = $29 >>> 15 & 1; //@line 23403
  HEAP32[$24 >> 2] = $31 << 16 | $sext$mask38; //@line 23406
  return;
 }
}
function __Z12op_80fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $32 = 0, $34 = 0, $4 = 0, $7 = 0, $sext36$mask = 0, $sext37$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 15423
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 15426
 $$cast = $4; //@line 15428
 $18 = $7 + 2 + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 15439
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 15445
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15446
 $26 = HEAP32[$25 >> 2] | 0; //@line 15447
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15450
 $sext36$mask = $24 & 65535; //@line 15451
 if (!$sext36$mask) {
  HEAP32[96444] = 0; //@line 15454
  __Z9Exceptionij(5, $7); //@line 15455
  return;
 }
 $30 = ($26 >>> 0) / ($sext36$mask >>> 0) | 0; //@line 15458
 if ($30 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15461
  HEAP32[96443] = 1; //@line 15462
  HEAP32[96441] = 0; //@line 15463
  return;
 } else {
  $32 = ($26 >>> 0) % ($sext36$mask >>> 0) | 0; //@line 15466
  $sext37$mask = $30 & 65535; //@line 15467
  $34 = ($sext37$mask | 0) == 0 & 1; //@line 15469
  HEAP32[96441] = 0; //@line 15470
  HEAP32[96442] = 0; //@line 15470
  HEAP32[96443] = 0; //@line 15470
  HEAP32[96444] = 0; //@line 15470
  HEAP32[96442] = $34; //@line 15471
  HEAP32[96443] = $30 >>> 15 & 1; //@line 15474
  HEAP32[$25 >> 2] = $32 << 16 | $sext37$mask; //@line 15477
  return;
 }
}
function __Z12op_81d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$043 = 0, $14 = 0, $15 = 0, $16 = 0, $19 = 0, $23 = 0, $24 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $sext45$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 16923
 $5 = HEAP32[162769] | 0; //@line 16924
 $6 = HEAP32[162770] | 0; //@line 16925
 $8 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16927
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 16933
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 16934
 $16 = HEAP32[$15 >> 2] | 0; //@line 16935
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16938
 $19 = $14 << 16 >> 16; //@line 16940
 if (!$19) {
  HEAP32[96444] = 0; //@line 16945
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 16946
  return;
 }
 $23 = ($16 | 0) / ($19 | 0) | 0; //@line 16949
 $24 = ($16 | 0) % ($19 | 0) | 0; //@line 16950
 if (($23 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 16954
  HEAP32[96443] = 1; //@line 16955
  HEAP32[96441] = 0; //@line 16956
  return;
 } else {
  $$043 = ($24 >>> 15 & 1 | 0) == ($16 >>> 31 | 0) ? $24 : 0 - $24 | 0; //@line 16964
  $sext45$mask = $23 & 65535; //@line 16965
  $30 = ($sext45$mask | 0) == 0 & 1; //@line 16967
  HEAP32[96441] = 0; //@line 16968
  HEAP32[96442] = 0; //@line 16968
  HEAP32[96443] = 0; //@line 16968
  HEAP32[96444] = 0; //@line 16968
  HEAP32[96442] = $30; //@line 16969
  HEAP32[96443] = $23 >>> 15 & 1; //@line 16972
  HEAP32[$15 >> 2] = $$043 << 16 | $sext45$mask; //@line 16975
  return;
 }
}
function __ZNK8tinyxml210XMLUnknown12ShallowCloneEPNS_11XMLDocumentE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$pre$i$i$i$i = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0;
 if (!$1) {
  $$0 = HEAP32[$0 + 4 >> 2] | 0; //@line 39160
 } else {
  $$0 = $1; //@line 39162
 }
 $6 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39165
 $7 = $$0 + 296 | 0; //@line 39166
 $8 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($7) | 0; //@line 39167
 HEAP32[$8 + 4 >> 2] = $$0; //@line 39169
 $10 = $8 + 8 | 0; //@line 39170
 HEAP32[$10 >> 2] = 0; //@line 39171
 HEAP32[$10 + 4 >> 2] = 0; //@line 39171
 HEAP32[$10 + 8 >> 2] = 0; //@line 39171
 HEAP32[$10 + 12 >> 2] = 0; //@line 39171
 HEAP32[$10 + 16 >> 2] = 0; //@line 39171
 HEAP32[$10 + 20 >> 2] = 0; //@line 39171
 HEAP32[$10 + 24 >> 2] = 0; //@line 39171
 HEAP32[$10 + 28 >> 2] = 0; //@line 39171
 HEAP32[$8 >> 2] = 1984; //@line 39172
 HEAP32[$8 + 40 >> 2] = $7; //@line 39174
 $12 = $8 + 12 | 0; //@line 39175
 $$pre$i$i$i$i = $8 + 16 | 0; //@line 39176
 HEAP32[$12 >> 2] = 0; //@line 39177
 HEAP32[$$pre$i$i$i$i >> 2] = 0; //@line 39178
 $13 = $8 + 20 | 0; //@line 39179
 HEAP32[$13 >> 2] = 0; //@line 39180
 $14 = _strlen($6) | 0; //@line 39181
 $15 = $14 + 1 | 0; //@line 39182
 $16 = __Znaj($15) | 0; //@line 39183
 HEAP32[$$pre$i$i$i$i >> 2] = $16; //@line 39184
 _memcpy($16 | 0, $6 | 0, $15 | 0) | 0; //@line 39185
 HEAP32[$13 >> 2] = $16 + $14; //@line 39187
 HEAP32[$12 >> 2] = 512; //@line 39188
 return $8 | 0; //@line 39189
}
function __ZNK8tinyxml210XMLComment12ShallowCloneEPNS_11XMLDocumentE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$pre$i$i$i$i = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0;
 if (!$1) {
  $$0 = HEAP32[$0 + 4 >> 2] | 0; //@line 39680
 } else {
  $$0 = $1; //@line 39682
 }
 $6 = __ZN8tinyxml27StrPair6GetStrEv($0 + 12 | 0) | 0; //@line 39685
 $7 = $$0 + 296 | 0; //@line 39686
 $8 = __ZN8tinyxml28MemPoolTILi44EE5AllocEv($7) | 0; //@line 39687
 HEAP32[$8 + 4 >> 2] = $$0; //@line 39689
 $10 = $8 + 8 | 0; //@line 39690
 HEAP32[$10 >> 2] = 0; //@line 39691
 HEAP32[$10 + 4 >> 2] = 0; //@line 39691
 HEAP32[$10 + 8 >> 2] = 0; //@line 39691
 HEAP32[$10 + 12 >> 2] = 0; //@line 39691
 HEAP32[$10 + 16 >> 2] = 0; //@line 39691
 HEAP32[$10 + 20 >> 2] = 0; //@line 39691
 HEAP32[$10 + 24 >> 2] = 0; //@line 39691
 HEAP32[$10 + 28 >> 2] = 0; //@line 39691
 HEAP32[$8 >> 2] = 1824; //@line 39692
 HEAP32[$8 + 40 >> 2] = $7; //@line 39694
 $12 = $8 + 12 | 0; //@line 39695
 $$pre$i$i$i$i = $8 + 16 | 0; //@line 39696
 HEAP32[$12 >> 2] = 0; //@line 39697
 HEAP32[$$pre$i$i$i$i >> 2] = 0; //@line 39698
 $13 = $8 + 20 | 0; //@line 39699
 HEAP32[$13 >> 2] = 0; //@line 39700
 $14 = _strlen($6) | 0; //@line 39701
 $15 = $14 + 1 | 0; //@line 39702
 $16 = __Znaj($15) | 0; //@line 39703
 HEAP32[$$pre$i$i$i$i >> 2] = $16; //@line 39704
 _memcpy($16 | 0, $6 | 0, $15 | 0) | 0; //@line 39705
 HEAP32[$13 >> 2] = $16 + $14; //@line 39707
 HEAP32[$12 >> 2] = 512; //@line 39708
 return $8 | 0; //@line 39709
}
function __ZNSt3__26vectorI16cdrom_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 19740
 $4 = HEAP32[$0 >> 2] | 0; //@line 19742
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 19743
 $6 = ($5 | 0) / 840 | 0; //@line 19744
 $7 = $6 + 1 | 0; //@line 19745
 if ($7 >>> 0 > 5113056) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 19748
 }
 $9 = $0 + 8 | 0; //@line 19751
 $12 = ((HEAP32[$9 >> 2] | 0) - $4 | 0) / 840 | 0; //@line 19754
 $14 = $12 << 1; //@line 19756
 $$sroa$speculated$$i = $12 >>> 0 < 2556528 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 5113056; //@line 19759
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 19763
  } else {
   if ($$sroa$speculated$$i >>> 0 > 5113056) {
    _abort(); //@line 19767
   } else {
    $21 = __Znwj($$sroa$speculated$$i * 840 | 0) | 0; //@line 19772
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 * 840 | 0) | 0; //@line 19777
 _memcpy($20 | 0, $1 | 0, 840) | 0; //@line 19780
 $27 = $20 + ((($5 | 0) / -840 | 0) * 840 | 0) | 0; //@line 19784
 if (($5 | 0) > 0) {
  _memcpy($27 | 0, $4 | 0, $5 | 0) | 0; //@line 19789
 }
 HEAP32[$0 >> 2] = $27; //@line 19791
 HEAP32[$2 >> 2] = $20 + 840; //@line 19792
 HEAP32[$9 >> 2] = $21 + ($$sroa$speculated$$i * 840 | 0); //@line 19793
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 19799
 return;
}
function __Z9GetStringi($0) {
 $0 = $0 | 0;
 var $$013 = 0, $$09 = 0, $$112 = 0, $$sink = 0, $1 = 0, $13 = 0, $15 = 0, $3 = 0, $6 = 0, $8 = 0, label = 0;
 $1 = HEAP32[952] | 0; //@line 41596
 L1 : do {
  if (($1 | 0) > -1) {
   $$013 = 0; //@line 41600
   $6 = $1; //@line 41600
   while (1) {
    if (($6 | 0) == ($0 | 0)) {
     break;
    }
    $8 = $$013 + 1 | 0; //@line 41606
    $6 = HEAP32[3808 + ($8 << 3) >> 2] | 0; //@line 41608
    if (($6 | 0) <= -1) {
     label = 2; //@line 41613
     break L1;
    } else {
     $$013 = $8; //@line 41611
    }
   }
   $$sink = 3808 + ($$013 << 3) + 4 | 0; //@line 41618
  } else {
   label = 2; //@line 41620
  }
 } while (0);
 do {
  if ((label | 0) == 2) {
   $3 = HEAP32[590] | 0; //@line 41625
   if (($3 | 0) > -1) {
    $$112 = 0; //@line 41628
    $13 = $3; //@line 41628
   } else {
    $$09 = 0; //@line 41630
    return $$09 | 0; //@line 41631
   }
   while (1) {
    if (($13 | 0) == ($0 | 0)) {
     label = 7; //@line 41636
     break;
    }
    $15 = $$112 + 1 | 0; //@line 41639
    $13 = HEAP32[2360 + ($15 << 3) >> 2] | 0; //@line 41641
    if (($13 | 0) <= -1) {
     $$09 = 0; //@line 41646
     label = 10; //@line 41647
     break;
    } else {
     $$112 = $15; //@line 41644
    }
   }
   if ((label | 0) == 7) {
    $$sink = 2360 + ($$112 << 3) + 4 | 0; //@line 41653
    break;
   } else if ((label | 0) == 10) {
    return $$09 | 0; //@line 41657
   }
  }
 } while (0);
 $$09 = HEAP32[$$sink >> 2] | 0; //@line 41662
 return $$09 | 0; //@line 41663
}
function __Z12op_ebd0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $39 = 0, $40 = 0, $48 = 0, $5 = 0, $54 = 0, $57 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 44461
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 44464
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 44472
 $13 = $sext >> 16; //@line 44473
 $16 = $sext >> 22; //@line 44476
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 44479
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 44484
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 44489
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 44494
 }
 $28 = $27 + 31 & 31; //@line 44497
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 44502
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($34 >>> 16 << 2) >> 2] >> 2] & 127]($34) | 0; //@line 44507
 $40 = $34 + 4 | 0; //@line 44508
 $48 = $30 & 7; //@line 44516
 $54 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255) >>> (8 - $48 | 0) | $39 << $48) >>> ($28 ^ 31); //@line 44522
 $57 = ($54 & 1 << $28 | 0) != 0; //@line 44525
 HEAP32[96443] = $57 & 1; //@line 44527
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 44530
 HEAP32[96444] = 0; //@line 44531
 HEAP32[96441] = 0; //@line 44532
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = ($57 ? -2 << $28 : 0) | $54; //@line 44539
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44542
 return;
}
function __Z11op_ef8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $$lobit39 = 0, $1 = 0, $15 = 0, $17 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $41 = 0, $42 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 23095
 $3 = HEAP8[$1 + 2 >> 0] | 0; //@line 23097
 $6 = HEAPU8[$1 + 3 >> 0] | 0; //@line 23100
 $15 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 23110
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 23112
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$17 >> 2] >> 2] & 127]($15) | 0; //@line 23115
 $22 = 651008 + (($6 & 7) << 2) | 0; //@line 23117
 $23 = HEAP32[$22 >> 2] | 0; //@line 23118
 $24 = $20 - $23 | 0; //@line 23119
 $$lobit38 = $20 >>> 31; //@line 23121
 $$lobit39 = $24 >>> 31; //@line 23122
 $25 = ($24 | 0) == 0; //@line 23123
 HEAP32[96442] = $25 & 1; //@line 23125
 HEAP32[96444] = ($23 >>> 31 | 0) != ($$lobit38 | 0) & ($$lobit39 | 0) != ($$lobit38 | 0) & 1; //@line 23130
 HEAP32[96441] = $20 >>> 0 < $23 >>> 0 & 1; //@line 23133
 HEAP32[96443] = $$lobit39; //@line 23134
 if ($25) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 12 >> 2] & 31]($15, HEAP32[651008 + (((($3 & 255) << 8 | $6) >>> 6 & 7) << 2) >> 2] | 0); //@line 23146
  $41 = HEAP32[162769] | 0; //@line 23147
  $42 = $41 + 6 | 0; //@line 23148
  HEAP32[162769] = $42; //@line 23149
  return;
 } else {
  HEAP32[$22 >> 2] = $20; //@line 23152
  $41 = HEAP32[162769] | 0; //@line 23153
  $42 = $41 + 6 | 0; //@line 23154
  HEAP32[162769] = $42; //@line 23155
  return;
 }
}
function _atol($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$010$lcssa = 0, $$01016 = 0, $$011 = 0, $$1$ph = 0, $$112$ph = 0, $$11215 = 0, $1 = 0, $10 = 0, $2 = 0, $5 = 0, $7 = 0, $isdigittmp13 = 0, $isdigittmp17 = 0, label = 0;
 $$011 = $0; //@line 2893
 while (1) {
  $1 = HEAP8[$$011 >> 0] | 0; //@line 2895
  $2 = $1 << 24 >> 24; //@line 2896
  $5 = $$011 + 1 | 0; //@line 2899
  if (!(_isspace($2) | 0)) {
   break;
  } else {
   $$011 = $5; //@line 2903
  }
 }
 switch ($2 | 0) {
 case 45:
  {
   $$0 = 1; //@line 2908
   label = 5; //@line 2909
   break;
  }
 case 43:
  {
   $$0 = 0; //@line 2913
   label = 5; //@line 2914
   break;
  }
 default:
  {
   $$1$ph = 0; //@line 2918
   $$112$ph = $$011; //@line 2918
   $7 = $1; //@line 2918
  }
 }
 if ((label | 0) == 5) {
  $$1$ph = $$0; //@line 2923
  $$112$ph = $5; //@line 2923
  $7 = HEAP8[$5 >> 0] | 0; //@line 2923
 }
 $isdigittmp13 = ($7 << 24 >> 24) + -48 | 0; //@line 2926
 if ($isdigittmp13 >>> 0 < 10) {
  $$01016 = 0; //@line 2929
  $$11215 = $$112$ph; //@line 2929
  $isdigittmp17 = $isdigittmp13; //@line 2929
  while (1) {
   $$11215 = $$11215 + 1 | 0; //@line 2932
   $10 = ($$01016 * 10 | 0) - $isdigittmp17 | 0; //@line 2933
   $isdigittmp17 = (HEAP8[$$11215 >> 0] | 0) + -48 | 0; //@line 2936
   if ($isdigittmp17 >>> 0 >= 10) {
    $$010$lcssa = $10; //@line 2941
    break;
   } else {
    $$01016 = $10; //@line 2939
   }
  }
 } else {
  $$010$lcssa = 0; //@line 2946
 }
 return ($$1$ph | 0 ? $$010$lcssa : 0 - $$010$lcssa | 0) | 0; //@line 2951
}
function _atoi($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$010$lcssa = 0, $$01016 = 0, $$011 = 0, $$1$ph = 0, $$112$ph = 0, $$11215 = 0, $1 = 0, $10 = 0, $2 = 0, $5 = 0, $7 = 0, $isdigittmp13 = 0, $isdigittmp17 = 0, label = 0;
 $$011 = $0; //@line 2828
 while (1) {
  $1 = HEAP8[$$011 >> 0] | 0; //@line 2830
  $2 = $1 << 24 >> 24; //@line 2831
  $5 = $$011 + 1 | 0; //@line 2834
  if (!(_isspace($2) | 0)) {
   break;
  } else {
   $$011 = $5; //@line 2838
  }
 }
 switch ($2 | 0) {
 case 45:
  {
   $$0 = 1; //@line 2843
   label = 5; //@line 2844
   break;
  }
 case 43:
  {
   $$0 = 0; //@line 2848
   label = 5; //@line 2849
   break;
  }
 default:
  {
   $$1$ph = 0; //@line 2853
   $$112$ph = $$011; //@line 2853
   $7 = $1; //@line 2853
  }
 }
 if ((label | 0) == 5) {
  $$1$ph = $$0; //@line 2858
  $$112$ph = $5; //@line 2858
  $7 = HEAP8[$5 >> 0] | 0; //@line 2858
 }
 $isdigittmp13 = ($7 << 24 >> 24) + -48 | 0; //@line 2861
 if ($isdigittmp13 >>> 0 < 10) {
  $$01016 = 0; //@line 2864
  $$11215 = $$112$ph; //@line 2864
  $isdigittmp17 = $isdigittmp13; //@line 2864
  while (1) {
   $$11215 = $$11215 + 1 | 0; //@line 2867
   $10 = ($$01016 * 10 | 0) - $isdigittmp17 | 0; //@line 2868
   $isdigittmp17 = (HEAP8[$$11215 >> 0] | 0) + -48 | 0; //@line 2871
   if ($isdigittmp17 >>> 0 >= 10) {
    $$010$lcssa = $10; //@line 2876
    break;
   } else {
    $$01016 = $10; //@line 2874
   }
  }
 } else {
  $$010$lcssa = 0; //@line 2881
 }
 return ($$1$ph | 0 ? $$010$lcssa : 0 - $$010$lcssa | 0) | 0; //@line 2886
}
function __Z7InsTimejt($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$01013$i = 0, $$0911$i = 0, $13 = 0, $2 = 0, $23 = 0, $26 = 0, $29 = 0, $4 = 0, label = 0;
 $2 = $0 + 4 | 0; //@line 13061
 $4 = 123608 + ($2 >>> 16 << 2) | 0; //@line 13063
 $13 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$4 >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 8191 | ($1 & 65535) << 4 & 24576; //@line 13072
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$4 >> 2] | 0) + 16 >> 2] & 31]($2, $13); //@line 13076
 $$0911$i = 0; //@line 13077
 while (1) {
  if (HEAP8[112848 + ($$0911$i << 4) + 12 >> 0] | 0) {
   if ((HEAP32[112848 + ($$0911$i << 4) >> 2] | 0) == ($0 | 0)) {
    label = 5; //@line 13087
    break;
   }
  }
  $23 = $$0911$i + 1 | 0; //@line 13091
  if (($23 | 0) < 64) {
   $$0911$i = $23; //@line 13094
  } else {
   $$01013$i = 0; //@line 13096
   break;
  }
 }
 if ((label | 0) == 5) {
  if (($$0911$i | 0) > -1) {
   _puts(93189) | 0; //@line 13103
   return 0; //@line 13104
  } else {
   $$01013$i = 0; //@line 13106
  }
 }
 while (1) {
  $26 = 112848 + ($$01013$i << 4) + 12 | 0; //@line 13110
  if (!(HEAP8[$26 >> 0] | 0)) {
   label = 9; //@line 13114
   break;
  }
  $29 = $$01013$i + 1 | 0; //@line 13117
  if (($29 | 0) < 64) {
   $$01013$i = $29; //@line 13120
  } else {
   break;
  }
 }
 if ((label | 0) == 9) {
  HEAP32[112848 + ($$01013$i << 4) >> 2] = $0; //@line 13127
  HEAP8[$26 >> 0] = 1; //@line 13128
  if (($$01013$i | 0) >= 0) {
   return 0; //@line 13131
  }
 }
 _puts(93226) | 0; //@line 13134
 return 0; //@line 13135
}
function __Z11op_ef0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit41 = 0, $$lobit42 = 0, $10 = 0, $17 = 0, $19 = 0, $2 = 0, $21 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $4 = 0, $7 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 23027
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 23029
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 23032
 $8 = $2 + 4 | 0; //@line 23033
 HEAP32[162769] = $8; //@line 23034
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 23036
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 23043
 HEAP32[162769] = $2 + 6; //@line 23045
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 23046
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 23048
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$21 >> 2] >> 2] & 127]($19) | 0; //@line 23051
 $26 = 651008 + (($7 & 7) << 2) | 0; //@line 23053
 $27 = HEAP32[$26 >> 2] | 0; //@line 23054
 $28 = $24 - $27 | 0; //@line 23055
 $$lobit41 = $24 >>> 31; //@line 23057
 $$lobit42 = $28 >>> 31; //@line 23058
 $29 = ($28 | 0) == 0; //@line 23059
 HEAP32[96442] = $29 & 1; //@line 23061
 HEAP32[96444] = ($27 >>> 31 | 0) != ($$lobit41 | 0) & ($$lobit42 | 0) != ($$lobit41 | 0) & 1; //@line 23066
 HEAP32[96441] = $24 >>> 0 < $27 >>> 0 & 1; //@line 23069
 HEAP32[96443] = $$lobit42; //@line 23070
 if ($29) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 12 >> 2] & 31]($19, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 23082
  return;
 } else {
  HEAP32[$26 >> 2] = $24; //@line 23085
  return;
 }
}
function __Z11op_2f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$038 = 0, $$cast = 0, $18 = 0, $2 = 0, $27 = 0, $28 = 0, $31 = 0, $38 = 0, $39 = 0, $46 = 0, $5 = 0, $59 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 9973
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 9976
 $$cast = $2; //@line 9977
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 9980
 $18 = (HEAPU8[$$cast + 5 >> 0] | 0) << 16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 24; //@line 9990
 $27 = $18 | (HEAPU8[$$cast + 6 >> 0] | 0) << 8 | (HEAPU8[$$cast + 7 >> 0] | 0); //@line 9999
 $28 = $8 << 24 >> 16; //@line 10000
 $31 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 10003
 $38 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($27) | 0) << 16 >> 16; //@line 10011
 $39 = $27 + 2 | 0; //@line 10012
 $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($39) | 0) << 16 >> 16; //@line 10020
 $$038 = ($28 & 32768 | 0) == 0 ? $31 << 16 >> 16 : $31; //@line 10025
 HEAP32[96442] = (($38 | 0) == ($$038 | 0) | ($46 | 0) == ($$038 | 0)) & 1; //@line 10030
 if (($38 | 0) > ($46 | 0)) {
  $59 = ($$038 | 0) < ($38 | 0) | ($$038 | 0) > ($46 | 0); //@line 10036
 } else {
  $59 = ($$038 | 0) < ($38 | 0) | ($$038 | 0) > ($46 | 0); //@line 10041
 }
 HEAP32[96441] = $59 & 1; //@line 10044
 if (($28 & 2048 | 0) != 0 & $59) {
  __Z9Exceptionij(6, $5); //@line 10049
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 10054
  return;
 }
}
function __Z12op_e9f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $4 = 0, $40 = 0, $45 = 0, $46 = 0, $54 = 0, $60 = 0, $sext33 = 0;
 $1 = HEAP32[162769] | 0; //@line 43264
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 43267
 $sext33 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 43283
 $19 = $sext33 >> 16; //@line 43284
 $22 = $sext33 >> 22; //@line 43287
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 43290
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 43295
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 43300
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 43305
 }
 $34 = $33 + 31 & 31; //@line 43308
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 43313
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($40 >>> 16 << 2) >> 2] >> 2] & 127]($40) | 0; //@line 43318
 $46 = $40 + 4 | 0; //@line 43319
 $54 = $36 & 7; //@line 43327
 $60 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255) >>> (8 - $54 | 0) | $45 << $54) >>> ($34 ^ 31); //@line 43333
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 43338
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 43341
 HEAP32[96444] = 0; //@line 43342
 HEAP32[96441] = 0; //@line 43343
 HEAP32[651008 + (($4 >>> 4 & 7) << 2) >> 2] = $60; //@line 43347
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43350
 return;
}
function __Z10op_f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$038 = 0, $$cast = 0, $18 = 0, $2 = 0, $27 = 0, $28 = 0, $31 = 0, $38 = 0, $39 = 0, $46 = 0, $5 = 0, $59 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 6239
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 6242
 $$cast = $2; //@line 6243
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 6246
 $18 = (HEAPU8[$$cast + 5 >> 0] | 0) << 16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 24; //@line 6256
 $27 = $18 | (HEAPU8[$$cast + 6 >> 0] | 0) << 8 | (HEAPU8[$$cast + 7 >> 0] | 0); //@line 6265
 $28 = $8 << 24 >> 16; //@line 6266
 $31 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 6269
 $38 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($27) | 0) << 24 >> 24; //@line 6277
 $39 = $27 + 1 | 0; //@line 6278
 $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($39) | 0) << 24 >> 24; //@line 6286
 $$038 = ($28 & 32768 | 0) == 0 ? $31 << 24 >> 24 : $31; //@line 6291
 HEAP32[96442] = (($38 | 0) == ($$038 | 0) | ($46 | 0) == ($$038 | 0)) & 1; //@line 6296
 if (($38 | 0) > ($46 | 0)) {
  $59 = ($$038 | 0) < ($38 | 0) | ($$038 | 0) > ($46 | 0); //@line 6302
 } else {
  $59 = ($$038 | 0) < ($38 | 0) | ($$038 | 0) > ($46 | 0); //@line 6307
 }
 HEAP32[96441] = $59 & 1; //@line 6310
 if (($28 & 2048 | 0) != 0 & $59) {
  __Z9Exceptionij(6, $5); //@line 6315
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 6320
  return;
 }
}
function _wcrtomb($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0;
 do {
  if (!$0) {
   $$0 = 1; //@line 58826
  } else {
   if ($1 >>> 0 < 128) {
    HEAP8[$0 >> 0] = $1; //@line 58831
    $$0 = 1; //@line 58832
    break;
   }
   if (!(HEAP32[HEAP32[(___pthread_self_431() | 0) + 188 >> 2] >> 2] | 0)) {
    if (($1 & -128 | 0) == 57216) {
     HEAP8[$0 >> 0] = $1; //@line 58845
     $$0 = 1; //@line 58846
     break;
    } else {
     HEAP32[(___errno_location() | 0) >> 2] = 84; //@line 58850
     $$0 = -1; //@line 58851
     break;
    }
   }
   if ($1 >>> 0 < 2048) {
    HEAP8[$0 >> 0] = $1 >>> 6 | 192; //@line 58861
    HEAP8[$0 + 1 >> 0] = $1 & 63 | 128; //@line 58865
    $$0 = 2; //@line 58866
    break;
   }
   if ($1 >>> 0 < 55296 | ($1 & -8192 | 0) == 57344) {
    HEAP8[$0 >> 0] = $1 >>> 12 | 224; //@line 58878
    HEAP8[$0 + 1 >> 0] = $1 >>> 6 & 63 | 128; //@line 58884
    HEAP8[$0 + 2 >> 0] = $1 & 63 | 128; //@line 58888
    $$0 = 3; //@line 58889
    break;
   }
   if (($1 + -65536 | 0) >>> 0 < 1048576) {
    HEAP8[$0 >> 0] = $1 >>> 18 | 240; //@line 58899
    HEAP8[$0 + 1 >> 0] = $1 >>> 12 & 63 | 128; //@line 58905
    HEAP8[$0 + 2 >> 0] = $1 >>> 6 & 63 | 128; //@line 58911
    HEAP8[$0 + 3 >> 0] = $1 & 63 | 128; //@line 58915
    $$0 = 4; //@line 58916
    break;
   } else {
    HEAP32[(___errno_location() | 0) >> 2] = 84; //@line 58920
    $$0 = -1; //@line 58921
    break;
   }
  }
 } while (0);
 return $$0 | 0; //@line 58926
}
function __Z12op_9148_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $15 = 0, $17 = 0, $21 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $36 = 0, $4 = 0, $6 = 0, $sext48$lobit = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 20501
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 20503
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 20509
 HEAP32[$4 >> 2] = $6; //@line 20510
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 20511
 $15 = (HEAP32[$13 >> 2] | 0) + -2 | 0; //@line 20513
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 20515
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 20519
 HEAP32[$13 >> 2] = $15; //@line 20520
 $27 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) + (($21 << 16 >> 16) - ($12 << 16 >> 16)) | 0; //@line 20529
 $28 = $12 >>> 15; //@line 20530
 $29 = $21 >>> 15; //@line 20532
 $30 = $27 >>> 15; //@line 20534
 $sext48$lobit = $30 & 1; //@line 20535
 $32 = $sext48$lobit ^ $29 & 1; //@line 20537
 HEAP32[96444] = $32 & ($29 ^ $28); //@line 20539
 $36 = $32 & ($30 ^ $28) ^ $28 & 1; //@line 20542
 HEAP32[96441] = $36; //@line 20543
 HEAP32[96445] = $36; //@line 20544
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & HEAP32[96442]; //@line 20550
 HEAP32[96443] = $sext48$lobit; //@line 20551
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 16 >> 2] & 31]($15, $27); //@line 20555
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20558
 return;
}
function __ZNSt3__26vectorIP12monitor_descNS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $11 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $28 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 45979
 $4 = HEAP32[$0 >> 2] | 0; //@line 45981
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 45982
 $6 = $5 >> 2; //@line 45983
 $7 = $6 + 1 | 0; //@line 45984
 if ($7 >>> 0 > 1073741823) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 45987
 }
 $9 = $0 + 8 | 0; //@line 45990
 $11 = (HEAP32[$9 >> 2] | 0) - $4 | 0; //@line 45992
 $14 = $11 >> 1; //@line 45995
 $$sroa$speculated$$i = $11 >> 2 >>> 0 < 536870911 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 1073741823; //@line 45998
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 46002
  } else {
   if ($$sroa$speculated$$i >>> 0 > 1073741823) {
    _abort(); //@line 46006
   } else {
    $21 = __Znwj($$sroa$speculated$$i << 2) | 0; //@line 46011
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 << 2) | 0; //@line 46016
 HEAP32[$20 >> 2] = HEAP32[$1 >> 2]; //@line 46020
 $28 = $20 + (0 - $6 << 2) | 0; //@line 46024
 if (($5 | 0) > 0) {
  _memcpy($28 | 0, $4 | 0, $5 | 0) | 0; //@line 46029
 }
 HEAP32[$0 >> 2] = $28; //@line 46031
 HEAP32[$2 >> 2] = $20 + 4; //@line 46032
 HEAP32[$9 >> 2] = $21 + ($$sroa$speculated$$i << 2); //@line 46033
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 46039
 return;
}
function __Z12op_f608_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $28 = 0, $30 = 0, $38 = 0, $46 = 0, $54 = 0;
 $2 = HEAP32[162769] | 0; //@line 49451
 $11 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24; //@line 49460
 $19 = 651040 + (($0 & 7) << 2) | 0; //@line 49468
 $20 = HEAP32[$19 >> 2] | 0; //@line 49469
 $22 = $11 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | HEAP8[$2 + 5 >> 0] & -16 & 255; //@line 49472
 $23 = $20 & -16; //@line 49473
 $25 = 123608 + ($11 >>> 16 << 2) | 0; //@line 49475
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22) | 0; //@line 49478
 $30 = 123608 + ($20 >>> 16 << 2) | 0; //@line 49480
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23, $28); //@line 49484
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 4) | 0; //@line 49489
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 4, $38); //@line 49493
 $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 8) | 0; //@line 49498
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 8, $46); //@line 49502
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 12) | 0; //@line 49507
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 12, $54); //@line 49511
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 16; //@line 49514
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49517
 return;
}
function __Z11op_ed0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit41 = 0, $$lobit42 = 0, $11 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $35 = 0, $36 = 0, $4 = 0, $7 = 0, $9 = 0;
 $2 = HEAP32[162769] | 0; //@line 22759
 $4 = HEAP8[$2 + 2 >> 0] | 0; //@line 22761
 $7 = HEAPU8[$2 + 3 >> 0] | 0; //@line 22764
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 22766
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 22768
 $14 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$11 >> 2] >> 2] & 127]($9) | 0; //@line 22771
 $16 = 651008 + (($7 & 7) << 2) | 0; //@line 22773
 $17 = HEAP32[$16 >> 2] | 0; //@line 22774
 $18 = $14 - $17 | 0; //@line 22775
 $$lobit41 = $14 >>> 31; //@line 22777
 $$lobit42 = $18 >>> 31; //@line 22778
 $19 = ($18 | 0) == 0; //@line 22779
 HEAP32[96442] = $19 & 1; //@line 22781
 HEAP32[96444] = ($17 >>> 31 | 0) != ($$lobit41 | 0) & ($$lobit42 | 0) != ($$lobit41 | 0) & 1; //@line 22786
 HEAP32[96441] = $14 >>> 0 < $17 >>> 0 & 1; //@line 22789
 HEAP32[96443] = $$lobit42; //@line 22790
 if ($19) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 12 >> 2] & 31]($9, HEAP32[651008 + (((($4 & 255) << 8 | $7) >>> 6 & 7) << 2) >> 2] | 0); //@line 22802
  $35 = HEAP32[162769] | 0; //@line 22803
  $36 = $35 + 4 | 0; //@line 22804
  HEAP32[162769] = $36; //@line 22805
  return;
 } else {
  HEAP32[$16 >> 2] = $14; //@line 22808
  $35 = HEAP32[162769] | 0; //@line 22809
  $36 = $35 + 4 | 0; //@line 22810
  HEAP32[162769] = $36; //@line 22811
  return;
 }
}
function __Z17PrefsReplaceInt32PKci($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, $$sink$i = 0, $13 = 0, $15 = 0, $20 = 0, $22 = 0;
 $$01416$i = HEAP32[28198] | 0; //@line 953
 L1 : do {
  if ($$01416$i | 0) {
   $$01418$i = $$01416$i; //@line 957
   while (1) {
    if ((HEAP32[$$01418$i + 8 >> 2] | 0) == 2) {
     if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
      break;
     }
    }
    $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 971
    if (!$$014$i) {
     break L1;
    } else {
     $$01418$i = $$014$i; //@line 976
    }
   }
   HEAP32[HEAP32[$$01418$i + 12 >> 2] >> 2] = $1; //@line 981
   return;
  }
 } while (0);
 $13 = _malloc(4) | 0; //@line 985
 if (!$13) {
  return;
 }
 HEAP8[$13 >> 0] = $1; //@line 990
 HEAP8[$13 + 1 >> 0] = $1 >> 8; //@line 990
 HEAP8[$13 + 2 >> 0] = $1 >> 16; //@line 990
 HEAP8[$13 + 3 >> 0] = $1 >> 24; //@line 990
 $15 = __Znwj(16) | 0; //@line 991
 HEAP32[$15 >> 2] = 0; //@line 992
 HEAP32[$15 + 4 >> 2] = ___strdup($0) | 0; //@line 995
 HEAP32[$15 + 8 >> 2] = 2; //@line 997
 HEAP32[$15 + 12 >> 2] = $13; //@line 999
 $20 = HEAP32[28198] | 0; //@line 1000
 if (!$20) {
  $$sink$i = 112792; //@line 1003
 } else {
  $$0$i = $20; //@line 1005
  while (1) {
   $22 = HEAP32[$$0$i >> 2] | 0; //@line 1007
   if (!$22) {
    break;
   } else {
    $$0$i = $22; //@line 1012
   }
  }
  $$sink$i = $$0$i; //@line 1015
 }
 HEAP32[$$sink$i >> 2] = $15; //@line 1017
 return;
}
function __Z12op_d148_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $15 = 0, $17 = 0, $21 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $37 = 0, $4 = 0, $6 = 0, $sext48$lobit = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 34131
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 34133
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 34139
 HEAP32[$4 >> 2] = $6; //@line 34140
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 34141
 $15 = (HEAP32[$13 >> 2] | 0) + -2 | 0; //@line 34143
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 34145
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 34149
 HEAP32[$13 >> 2] = $15; //@line 34150
 $28 = ($21 << 16 >> 16) + ($12 << 16 >> 16) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 34159
 $29 = $12 >>> 15; //@line 34160
 $30 = $21 >>> 15; //@line 34162
 $31 = $28 >>> 15; //@line 34164
 $sext48$lobit = $31 & 1; //@line 34165
 $33 = $sext48$lobit ^ $30 & 1; //@line 34167
 HEAP32[96444] = $33 & ($31 ^ $29); //@line 34169
 $37 = $33 & ($30 ^ $29) ^ $29 & 1; //@line 34172
 HEAP32[96441] = $37; //@line 34173
 HEAP32[96445] = $37; //@line 34174
 HEAP32[96442] = ($28 & 65535 | 0) == 0 & HEAP32[96442]; //@line 34180
 HEAP32[96443] = $sext48$lobit; //@line 34181
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 16 >> 2] & 31]($15, $28); //@line 34185
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34188
 return;
}
function __Z12op_f600_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $3 = 0, $30 = 0, $38 = 0, $4 = 0, $46 = 0, $54 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 49374
 $3 = HEAP32[$2 >> 2] | 0; //@line 49375
 $4 = HEAP32[162769] | 0; //@line 49376
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 49385
 $21 = $3 & -16; //@line 49393
 $23 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | HEAP8[$4 + 5 >> 0] & -16 & 255; //@line 49396
 $25 = 123608 + ($3 >>> 16 << 2) | 0; //@line 49398
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21) | 0; //@line 49401
 $30 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49403
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23, $28); //@line 49407
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 4) | 0; //@line 49412
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 4, $38); //@line 49416
 $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 8) | 0; //@line 49421
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 8, $46); //@line 49425
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 12) | 0; //@line 49430
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 12, $54); //@line 49434
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 16; //@line 49437
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49440
 return;
}
function __Z12op_81fc_0_ffj($0) {
 $0 = $0 | 0;
 var $$034 = 0, $$cast = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $21 = 0, $22 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $sext36$mask = 0;
 $3 = HEAP32[162768] | 0; //@line 17578
 $4 = HEAP32[162769] | 0; //@line 17579
 $5 = HEAP32[162770] | 0; //@line 17580
 $$cast = $4; //@line 17581
 $13 = (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 17589
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17590
 $15 = HEAP32[$14 >> 2] | 0; //@line 17591
 HEAP32[162769] = $$cast + 4; //@line 17593
 $17 = $13 << 16 >> 16; //@line 17595
 if (!$17) {
  HEAP32[96444] = 0; //@line 17600
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 17601
  return;
 }
 $21 = ($15 | 0) / ($17 | 0) | 0; //@line 17604
 $22 = ($15 | 0) % ($17 | 0) | 0; //@line 17605
 if (($21 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 17609
  HEAP32[96443] = 1; //@line 17610
  HEAP32[96441] = 0; //@line 17611
  return;
 } else {
  $$034 = ($22 >>> 15 & 1 | 0) == ($15 >>> 31 | 0) ? $22 : 0 - $22 | 0; //@line 17619
  $sext36$mask = $21 & 65535; //@line 17620
  $28 = ($sext36$mask | 0) == 0 & 1; //@line 17622
  HEAP32[96441] = 0; //@line 17623
  HEAP32[96442] = 0; //@line 17623
  HEAP32[96443] = 0; //@line 17623
  HEAP32[96444] = 0; //@line 17623
  HEAP32[96442] = $28; //@line 17624
  HEAP32[96443] = $21 >>> 15 & 1; //@line 17627
  HEAP32[$14 >> 2] = $$034 << 16 | $sext36$mask; //@line 17630
  return;
 }
}
function __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIKjEEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $11 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $28 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 10309
 $4 = HEAP32[$0 >> 2] | 0; //@line 10311
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 10312
 $6 = $5 >> 2; //@line 10313
 $7 = $6 + 1 | 0; //@line 10314
 if ($7 >>> 0 > 1073741823) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 10317
 }
 $9 = $0 + 8 | 0; //@line 10320
 $11 = (HEAP32[$9 >> 2] | 0) - $4 | 0; //@line 10322
 $14 = $11 >> 1; //@line 10325
 $$sroa$speculated$$i = $11 >> 2 >>> 0 < 536870911 ? $14 >>> 0 < $7 >>> 0 ? $7 : $14 : 1073741823; //@line 10328
 do {
  if (!$$sroa$speculated$$i) {
   $21 = 0; //@line 10332
  } else {
   if ($$sroa$speculated$$i >>> 0 > 1073741823) {
    _abort(); //@line 10336
   } else {
    $21 = __Znwj($$sroa$speculated$$i << 2) | 0; //@line 10341
    break;
   }
  }
 } while (0);
 $20 = $21 + ($6 << 2) | 0; //@line 10346
 HEAP32[$20 >> 2] = HEAP32[$1 >> 2]; //@line 10350
 $28 = $20 + (0 - $6 << 2) | 0; //@line 10354
 if (($5 | 0) > 0) {
  _memcpy($28 | 0, $4 | 0, $5 | 0) | 0; //@line 10359
 }
 HEAP32[$0 >> 2] = $28; //@line 10361
 HEAP32[$2 >> 2] = $20 + 4; //@line 10362
 HEAP32[$9 >> 2] = $21 + ($$sroa$speculated$$i << 2); //@line 10363
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 10369
 return;
}
function __Z12op_e9d0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $39 = 0, $40 = 0, $48 = 0, $5 = 0, $54 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 42978
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 42981
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 42989
 $13 = $sext >> 16; //@line 42990
 $16 = $sext >> 22; //@line 42993
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 42996
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 43001
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 43006
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 43011
 }
 $28 = $27 + 31 & 31; //@line 43014
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 43019
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($34 >>> 16 << 2) >> 2] >> 2] & 127]($34) | 0; //@line 43024
 $40 = $34 + 4 | 0; //@line 43025
 $48 = $30 & 7; //@line 43033
 $54 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255) >>> (8 - $48 | 0) | $39 << $48) >>> ($28 ^ 31); //@line 43039
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 43044
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 43047
 HEAP32[96444] = 0; //@line 43048
 HEAP32[96441] = 0; //@line 43049
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = $54; //@line 43053
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43056
 return;
}
function __Z12op_80d0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $16 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $sext$mask = 0, $sext$mask39 = 0;
 $4 = HEAP32[162768] | 0; //@line 14975
 $5 = HEAP32[162769] | 0; //@line 14976
 $6 = HEAP32[162770] | 0; //@line 14977
 $8 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14979
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 14985
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14986
 $16 = HEAP32[$15 >> 2] | 0; //@line 14987
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14990
 $sext$mask = $14 & 65535; //@line 14991
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 14996
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 14997
  return;
 }
 $22 = ($16 >>> 0) / ($sext$mask >>> 0) | 0; //@line 15000
 if ($22 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15003
  HEAP32[96443] = 1; //@line 15004
  HEAP32[96441] = 0; //@line 15005
  return;
 } else {
  $24 = ($16 >>> 0) % ($sext$mask >>> 0) | 0; //@line 15008
  $sext$mask39 = $22 & 65535; //@line 15009
  $26 = ($sext$mask39 | 0) == 0 & 1; //@line 15011
  HEAP32[96441] = 0; //@line 15012
  HEAP32[96442] = 0; //@line 15012
  HEAP32[96443] = 0; //@line 15012
  HEAP32[96444] = 0; //@line 15012
  HEAP32[96442] = $26; //@line 15013
  HEAP32[96443] = $22 >>> 15 & 1; //@line 15016
  HEAP32[$15 >> 2] = $24 << 16 | $sext$mask39; //@line 15019
  return;
 }
}
function __Z12op_e8fa_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $22 = 0, $25 = 0, $36 = 0, $37 = 0, $39 = 0, $47 = 0, $52 = 0, $53 = 0, $61 = 0, $67 = 0, $sext34 = 0;
 $1 = HEAP32[162769] | 0; //@line 42715
 $sext34 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 42737
 $22 = $sext34 >> 16; //@line 42738
 $25 = $sext34 >> 22; //@line 42741
 if (!($22 & 2048)) {
  $39 = $25 & 31; //@line 42744
 } else {
  $39 = HEAP32[651008 + (($25 & 7) << 2) >> 2] | 0; //@line 42749
 }
 if (!($22 & 32)) {
  $36 = $22; //@line 42754
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 42759
 }
 $37 = $36 + 31 & 31; //@line 42762
 $47 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) + ($39 >> 31 & -536870912 | $39 >> 3) | 0; //@line 42771
 $52 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($47 >>> 16 << 2) >> 2] >> 2] & 127]($47) | 0; //@line 42776
 $53 = $47 + 4 | 0; //@line 42777
 $61 = $39 & 7; //@line 42785
 $67 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($53 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($53) | 0) & 255) >>> (8 - $61 | 0) | $52 << $61) >>> ($37 ^ 31); //@line 42791
 HEAP32[96443] = ($67 & 1 << $37 | 0) != 0 & 1; //@line 42796
 HEAP32[96442] = ($67 | 0) == 0 & 1; //@line 42799
 HEAP32[96444] = 0; //@line 42800
 HEAP32[96441] = 0; //@line 42801
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42804
 return;
}
function __Z11op_2e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $22 = 0, $23 = 0, $26 = 0, $3 = 0, $33 = 0, $34 = 0, $41 = 0, $54 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 9714
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 9717
 $$cast = $3; //@line 9718
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 9721
 $22 = (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 9735
 $23 = $9 << 24 >> 16; //@line 9736
 $26 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 9739
 $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($22) | 0) << 16 >> 16; //@line 9747
 $34 = $22 + 2 | 0; //@line 9748
 $41 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($34) | 0) << 16 >> 16; //@line 9756
 $$042 = ($23 & 32768 | 0) == 0 ? $26 << 16 >> 16 : $26; //@line 9761
 HEAP32[96442] = (($33 | 0) == ($$042 | 0) | ($41 | 0) == ($$042 | 0)) & 1; //@line 9766
 if (($33 | 0) > ($41 | 0)) {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 9772
 } else {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 9777
 }
 HEAP32[96441] = $54 & 1; //@line 9780
 if (($23 & 2048 | 0) != 0 & $54) {
  __Z9Exceptionij(6, $6); //@line 9785
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9790
  return;
 }
}
function __Z10op_e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $$cast = 0, $22 = 0, $23 = 0, $26 = 0, $3 = 0, $33 = 0, $34 = 0, $41 = 0, $54 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 5980
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 5983
 $$cast = $3; //@line 5984
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 5987
 $22 = (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6001
 $23 = $9 << 24 >> 16; //@line 6002
 $26 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 6005
 $33 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($22) | 0) << 24 >> 24; //@line 6013
 $34 = $22 + 1 | 0; //@line 6014
 $41 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($34) | 0) << 24 >> 24; //@line 6022
 $$042 = ($23 & 32768 | 0) == 0 ? $26 << 24 >> 24 : $26; //@line 6027
 HEAP32[96442] = (($33 | 0) == ($$042 | 0) | ($41 | 0) == ($$042 | 0)) & 1; //@line 6032
 if (($33 | 0) > ($41 | 0)) {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 6038
 } else {
  $54 = ($$042 | 0) < ($33 | 0) | ($$042 | 0) > ($41 | 0); //@line 6043
 }
 HEAP32[96441] = $54 & 1; //@line 6046
 if (($23 & 2048 | 0) != 0 & $54) {
  __Z9Exceptionij(6, $6); //@line 6051
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6056
  return;
 }
}
function __Z12op_e8f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $28 = 0, $31 = 0, $42 = 0, $43 = 0, $45 = 0, $49 = 0, $54 = 0, $55 = 0, $63 = 0, $69 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 42615
 $sext = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 42642
 $28 = $sext >> 16; //@line 42643
 $31 = $sext >> 22; //@line 42646
 if (!($28 & 2048)) {
  $45 = $31 & 31; //@line 42649
 } else {
  $45 = HEAP32[651008 + (($31 & 7) << 2) >> 2] | 0; //@line 42654
 }
 if (!($28 & 32)) {
  $42 = $28; //@line 42659
 } else {
  $42 = HEAP32[651008 + (($28 & 7) << 2) >> 2] | 0; //@line 42664
 }
 $43 = $42 + 31 & 31; //@line 42667
 $49 = ($45 >> 31 & -536870912 | $45 >> 3) + ((HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 42672
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($49 >>> 16 << 2) >> 2] >> 2] & 127]($49) | 0; //@line 42677
 $55 = $49 + 4 | 0; //@line 42678
 $63 = $45 & 7; //@line 42686
 $69 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($55 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($55) | 0) & 255) >>> (8 - $63 | 0) | $54 << $63) >>> ($43 ^ 31); //@line 42692
 HEAP32[96443] = ($69 & 1 << $43 | 0) != 0 & 1; //@line 42697
 HEAP32[96442] = ($69 | 0) == 0 & 1; //@line 42700
 HEAP32[96444] = 0; //@line 42701
 HEAP32[96441] = 0; //@line 42702
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 42705
 return;
}
function __Z12op_e8e8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $23 = 0, $26 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $49 = 0, $50 = 0, $58 = 0, $64 = 0, $sext35 = 0;
 $2 = HEAP32[162769] | 0; //@line 42334
 $sext35 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 42356
 $23 = $sext35 >> 16; //@line 42357
 $26 = $sext35 >> 22; //@line 42360
 if (!($23 & 2048)) {
  $40 = $26 & 31; //@line 42363
 } else {
  $40 = HEAP32[651008 + (($26 & 7) << 2) >> 2] | 0; //@line 42368
 }
 if (!($23 & 32)) {
  $37 = $23; //@line 42373
 } else {
  $37 = HEAP32[651008 + (($23 & 7) << 2) >> 2] | 0; //@line 42378
 }
 $38 = $37 + 31 & 31; //@line 42381
 $44 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) + ($40 >> 31 & -536870912 | $40 >> 3) | 0; //@line 42386
 $49 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($44 >>> 16 << 2) >> 2] >> 2] & 127]($44) | 0; //@line 42391
 $50 = $44 + 4 | 0; //@line 42392
 $58 = $40 & 7; //@line 42400
 $64 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($50 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($50) | 0) & 255) >>> (8 - $58 | 0) | $49 << $58) >>> ($38 ^ 31); //@line 42406
 HEAP32[96443] = ($64 & 1 << $38 | 0) != 0 & 1; //@line 42411
 HEAP32[96442] = ($64 | 0) == 0 & 1; //@line 42414
 HEAP32[96444] = 0; //@line 42415
 HEAP32[96441] = 0; //@line 42416
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42419
 return;
}
function __Z11op_eb0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $17 = 0, $24 = 0, $26 = 0, $33 = 0, $4 = 0, $40 = 0, $41 = 0, $46 = 0, $5 = 0, $50 = 0, $7 = 0, $9 = 0;
 $1 = $0 & 7; //@line 22527
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22531
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 22534
 $5 = $4 + 2 | 0; //@line 22535
 $7 = HEAPU8[$5 >> 0] | 0; //@line 22537
 $9 = $7 << 24 >> 16; //@line 22539
 if (!($9 & 2048)) {
  $33 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 22544
  $40 = HEAPU8[$4 >> 0] << 8 | HEAPU8[$4 + 1 >> 0]; //@line 22551
  HEAP32[162769] = $5; //@line 22552
  $41 = __Z15get_disp_ea_020jj($33, $40) | 0; //@line 22553
  $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($41 >>> 16 << 2) >> 2] >> 2] & 127]($41) | 0; //@line 22558
  $50 = $7 >>> 4 & 7; //@line 22562
  HEAP32[($9 & 32768 | 0 ? 651040 + ($50 << 2) | 0 : 651008 + ($50 << 2) | 0) >> 2] = $46; //@line 22566
  return;
 } else {
  $14 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 22571
  $15 = $4 + 4 | 0; //@line 22572
  HEAP32[162769] = $15; //@line 22573
  $17 = HEAP32[651040 + ($1 << 2) >> 2] | 0; //@line 22575
  $24 = HEAPU8[$15 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]; //@line 22582
  HEAP32[162769] = $4 + 6; //@line 22584
  $26 = __Z15get_disp_ea_020jj($17, $24) | 0; //@line 22585
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($26, $14); //@line 22591
  return;
 }
}
function __Z15SerialInterruptv() {
 var $0 = 0, $12 = 0, $15 = 0, $20 = 0, $24 = 0, $27 = 0, $32 = 0, $35 = 0, $4 = 0, $7 = 0;
 $0 = HEAP32[28475] | 0; //@line 14964
 if (HEAP8[$0 + 4 >> 0] | 0) {
  $4 = $0 + 6 | 0; //@line 14969
  if (HEAP8[$4 >> 0] | 0) {
   $7 = $0 + 7 | 0; //@line 14973
   if (HEAP8[$7 >> 0] | 0) {
    __Z10EnqueueMacjj(HEAP32[$0 + 8 >> 2] | 0, 3474); //@line 14979
    HEAP8[$7 >> 0] = 0; //@line 14980
    HEAP8[$4 >> 0] = 0; //@line 14981
   }
  }
  $12 = $0 + 12 | 0; //@line 14984
  if (HEAP8[$12 >> 0] | 0) {
   $15 = $0 + 13 | 0; //@line 14988
   if (HEAP8[$15 >> 0] | 0) {
    __Z10EnqueueMacjj(HEAP32[$0 + 16 >> 2] | 0, 3474); //@line 14994
    HEAP8[$15 >> 0] = 0; //@line 14995
    HEAP8[$12 >> 0] = 0; //@line 14996
   }
  }
 }
 $20 = HEAP32[28476] | 0; //@line 15000
 if (!(HEAP8[$20 + 4 >> 0] | 0)) {
  return;
 }
 $24 = $20 + 6 | 0; //@line 15007
 if (HEAP8[$24 >> 0] | 0) {
  $27 = $20 + 7 | 0; //@line 15011
  if (HEAP8[$27 >> 0] | 0) {
   __Z10EnqueueMacjj(HEAP32[$20 + 8 >> 2] | 0, 3474); //@line 15017
   HEAP8[$27 >> 0] = 0; //@line 15018
   HEAP8[$24 >> 0] = 0; //@line 15019
  }
 }
 $32 = $20 + 12 | 0; //@line 15022
 if (!(HEAP8[$32 >> 0] | 0)) {
  return;
 }
 $35 = $20 + 13 | 0; //@line 15028
 if (!(HEAP8[$35 >> 0] | 0)) {
  return;
 }
 __Z10EnqueueMacjj(HEAP32[$20 + 16 >> 2] | 0, 3474); //@line 15036
 HEAP8[$35 >> 0] = 0; //@line 15037
 HEAP8[$32 >> 0] = 0; //@line 15038
 return;
}
function _readdir($0) {
 $0 = $0 | 0;
 var $$1 = 0, $1 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 59518
 STACKTOP = STACKTOP + 16 | 0; //@line 59519
 $vararg_buffer = sp; //@line 59520
 $1 = $0 + 8 | 0; //@line 59521
 $2 = HEAP32[$1 >> 2] | 0; //@line 59522
 $3 = $0 + 12 | 0; //@line 59523
 L1 : do {
  if (($2 | 0) < (HEAP32[$3 >> 2] | 0)) {
   $14 = $2; //@line 59528
   label = 6; //@line 59529
  } else {
   HEAP32[$vararg_buffer >> 2] = HEAP32[$0 >> 2]; //@line 59534
   HEAP32[$vararg_buffer + 4 >> 2] = $0 + 24; //@line 59536
   HEAP32[$vararg_buffer + 8 >> 2] = 2048; //@line 59538
   $9 = ___syscall220(220, $vararg_buffer | 0) | 0; //@line 59539
   if (($9 | 0) >= 1) {
    HEAP32[$3 >> 2] = $9; //@line 59542
    HEAP32[$1 >> 2] = 0; //@line 59543
    $14 = 0; //@line 59544
    label = 6; //@line 59545
    break;
   }
   switch ($9 | 0) {
   case 0:
   case -2:
    {
     $$1 = 0; //@line 59550
     break L1;
     break;
    }
   default:
    {}
   }
   HEAP32[(___errno_location() | 0) >> 2] = 0 - $9; //@line 59559
   $$1 = 0; //@line 59560
  }
 } while (0);
 if ((label | 0) == 6) {
  $13 = $0 + 24 + $14 | 0; //@line 59564
  HEAP32[$1 >> 2] = (HEAPU16[$13 + 8 >> 1] | 0) + $14; //@line 59569
  HEAP32[$0 + 4 >> 2] = HEAP32[$13 + 4 >> 2]; //@line 59573
  $$1 = $13; //@line 59574
 }
 STACKTOP = sp; //@line 59576
 return $$1 | 0; //@line 59576
}
function __Z11op_2fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$041 = 0, $$cast = 0, $2 = 0, $20 = 0, $21 = 0, $24 = 0, $31 = 0, $32 = 0, $39 = 0, $5 = 0, $52 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 10066
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 10069
 $$cast = $2; //@line 10070
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 10073
 $20 = $5 + 4 + (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 10086
 $21 = $8 << 24 >> 16; //@line 10087
 $24 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 10090
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($20) | 0) << 16 >> 16; //@line 10098
 $32 = $20 + 2 | 0; //@line 10099
 $39 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($32) | 0) << 16 >> 16; //@line 10107
 $$041 = ($21 & 32768 | 0) == 0 ? $24 << 16 >> 16 : $24; //@line 10112
 HEAP32[96442] = (($31 | 0) == ($$041 | 0) | ($39 | 0) == ($$041 | 0)) & 1; //@line 10117
 if (($31 | 0) > ($39 | 0)) {
  $52 = ($$041 | 0) < ($31 | 0) | ($$041 | 0) > ($39 | 0); //@line 10123
 } else {
  $52 = ($$041 | 0) < ($31 | 0) | ($$041 | 0) > ($39 | 0); //@line 10128
 }
 HEAP32[96441] = $52 & 1; //@line 10131
 if (($21 & 2048 | 0) != 0 & $52) {
  __Z9Exceptionij(6, $5); //@line 10136
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10141
  return;
 }
}
function __Z12op_9188_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit47 = 0, $$lobit48 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $19 = 0, $23 = 0, $25 = 0, $29 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 21032
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 21034
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 21039
 HEAP32[$4 >> 2] = $6; //@line 21040
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21041
 $14 = (HEAP32[$12 >> 2] | 0) + -4 | 0; //@line 21043
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 21045
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 21048
 HEAP32[$12 >> 2] = $14; //@line 21049
 $23 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) + ($19 - $11) | 0; //@line 21054
 $$lobit = $11 >>> 31; //@line 21055
 $$lobit47 = $19 >>> 31; //@line 21056
 $$lobit48 = $23 >>> 31; //@line 21057
 $25 = $$lobit48 ^ $$lobit47; //@line 21059
 HEAP32[96444] = $25 & ($$lobit47 ^ $$lobit); //@line 21061
 $29 = ($$lobit48 ^ $$lobit) & $25 ^ $$lobit; //@line 21064
 HEAP32[96441] = $29; //@line 21065
 HEAP32[96445] = $29; //@line 21066
 HEAP32[96442] = ($23 | 0) == 0 & HEAP32[96442]; //@line 21071
 HEAP32[96443] = $$lobit48; //@line 21072
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $23); //@line 21076
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21079
 return;
}
function __Z18VideoDriverControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$sink13$i = 0, $10 = 0, $16 = 0, $17 = 0, $2 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $9 = 0, label = 0;
 $2 = $1 + 41 | 0; //@line 25328
 $9 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0) & 255; //@line 25335
 $10 = $0 + 26 | 0; //@line 25336
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 25342
 $17 = $0 + 28 | 0; //@line 25343
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 25348
 $23 = HEAP32[30549] | 0; //@line 25349
 $24 = HEAP32[30548] | 0; //@line 25350
 if (($24 | 0) == ($23 | 0)) {
  $$0 = -56; //@line 25353
  return $$0 | 0; //@line 25354
 } else {
  $$sink13$i = $24; //@line 25356
 }
 while (1) {
  $28 = HEAP32[$$sink13$i >> 2] | 0; //@line 25359
  $$sink13$i = $$sink13$i + 4 | 0; //@line 25363
  if ((HEAP8[$28 + 24 >> 0] | 0) == $9 << 24 >> 24) {
   break;
  }
  if (($$sink13$i | 0) == ($23 | 0)) {
   $$0 = -56; //@line 25369
   label = 6; //@line 25370
   break;
  }
 }
 if ((label | 0) == 6) {
  return $$0 | 0; //@line 25377
 }
 if (!$28) {
  $$0 = -56; //@line 25381
  return $$0 | 0; //@line 25382
 }
 $$0 = __ZN12monitor_desc14driver_controlEtjj($28, $16 & 65535, $22, $1) | 0; //@line 25386
 return $$0 | 0; //@line 25387
}
function __Z10fpuop_dbccjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$cast = 0, $13 = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $3 = 0, $30 = 0, $33 = 0, $39 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 55217
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 55220
 $$cast = $3; //@line 55221
 $13 = (HEAPU8[$$cast >> 0] | 0) << 8 | (HEAPU8[$$cast + 1 >> 0] | 0); //@line 55228
 HEAP32[162769] = $$cast + 2; //@line 55230
 switch (__ZL8fpp_condi($1 & 63) | 0) {
 case -1:
  {
   $18 = $6 + -4 | 0; //@line 55237
   $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($18) | 0; //@line 55243
   HEAP32[162770] = $24; //@line 55244
   HEAP32[162769] = $24; //@line 55245
   HEAP32[162768] = $18; //@line 55246
   __Z7op_illgj($0); //@line 55247
   return;
  }
 case 0:
  {
   $26 = 651008 + (($0 & 7) << 2) | 0; //@line 55253
   $27 = HEAP32[$26 >> 2] | 0; //@line 55254
   $30 = $27 + 65535 & 65535; //@line 55257
   HEAP32[$26 >> 2] = $30 | $27 & -65536; //@line 55259
   if (($30 | 0) == 65535) {
    return;
   }
   $33 = ($13 << 16 >> 16) + $6 | 0; //@line 55264
   $39 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($33) | 0; //@line 55270
   HEAP32[162770] = $39; //@line 55271
   HEAP32[162769] = $39; //@line 55272
   HEAP32[162768] = $33; //@line 55273
   return;
  }
 default:
  {
   return;
  }
 }
}
function __Z10op_fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$041 = 0, $$cast = 0, $2 = 0, $20 = 0, $21 = 0, $24 = 0, $31 = 0, $32 = 0, $39 = 0, $5 = 0, $52 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 6332
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 6335
 $$cast = $2; //@line 6336
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 6339
 $20 = $5 + 4 + (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 6352
 $21 = $8 << 24 >> 16; //@line 6353
 $24 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 6356
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($20) | 0) << 24 >> 24; //@line 6364
 $32 = $20 + 1 | 0; //@line 6365
 $39 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($32) | 0) << 24 >> 24; //@line 6373
 $$041 = ($21 & 32768 | 0) == 0 ? $24 << 24 >> 24 : $24; //@line 6378
 HEAP32[96442] = (($31 | 0) == ($$041 | 0) | ($39 | 0) == ($$041 | 0)) & 1; //@line 6383
 if (($31 | 0) > ($39 | 0)) {
  $52 = ($$041 | 0) < ($31 | 0) | ($$041 | 0) > ($39 | 0); //@line 6389
 } else {
  $52 = ($$041 | 0) < ($31 | 0) | ($$041 | 0) > ($39 | 0); //@line 6394
 }
 HEAP32[96441] = $52 & 1; //@line 6397
 if (($21 & 2048 | 0) != 0 & $52) {
  __Z9Exceptionij(6, $5); //@line 6402
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6407
  return;
 }
}
function __ZNSt3__26vectorItNS_9allocatorItEEE21__push_back_slow_pathIKtEEvRT_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sroa$speculated$$i = 0, $11 = 0, $19 = 0, $2 = 0, $20 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $2 = $0 + 4 | 0; //@line 47417
 $4 = HEAP32[$0 >> 2] | 0; //@line 47419
 $5 = (HEAP32[$2 >> 2] | 0) - $4 | 0; //@line 47420
 $6 = $5 >> 1; //@line 47421
 $7 = $6 + 1 | 0; //@line 47422
 if (($5 | 0) < -2) {
  __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0); //@line 47425
 }
 $9 = $0 + 8 | 0; //@line 47428
 $11 = (HEAP32[$9 >> 2] | 0) - $4 | 0; //@line 47430
 $$sroa$speculated$$i = $11 >> 1 >>> 0 < 1073741823 ? $11 >>> 0 < $7 >>> 0 ? $7 : $11 : 2147483647; //@line 47435
 do {
  if (!$$sroa$speculated$$i) {
   $20 = 0; //@line 47439
  } else {
   if (($$sroa$speculated$$i | 0) < 0) {
    _abort(); //@line 47443
   } else {
    $20 = __Znwj($$sroa$speculated$$i << 1) | 0; //@line 47448
    break;
   }
  }
 } while (0);
 $19 = $20 + ($6 << 1) | 0; //@line 47453
 HEAP16[$19 >> 1] = HEAP16[$1 >> 1] | 0; //@line 47457
 $27 = $19 + (0 - $6 << 1) | 0; //@line 47461
 if (($5 | 0) > 0) {
  _memcpy($27 | 0, $4 | 0, $5 | 0) | 0; //@line 47466
 }
 HEAP32[$0 >> 2] = $27; //@line 47468
 HEAP32[$2 >> 2] = $19 + 2; //@line 47469
 HEAP32[$9 >> 2] = $20 + ($$sroa$speculated$$i << 1); //@line 47470
 if (!$4) {
  return;
 }
 __ZdlPv($4); //@line 47476
 return;
}
function __Z9Sys_closePv($0) {
 $0 = $0 | 0;
 var $$0$i = 0, $$0$i$phi = 0, $$012$i = 0, $$pre = 0, $11 = 0, $19 = 0, $21 = 0, $23 = 0, $25 = 0, $7 = 0, label = 0;
 if (!$0) {
  return;
 }
 $$0$i = 0; //@line 2140
 $$012$i = HEAP32[28199] | 0; //@line 2140
 while (1) {
  if (!$$012$i) {
   break;
  }
  $7 = HEAP32[$$012$i + 4 >> 2] | 0; //@line 2149
  if ((HEAP32[$$012$i >> 2] | 0) == ($0 | 0)) {
   label = 5; //@line 2151
   break;
  } else {
   $$0$i$phi = $$012$i; //@line 2154
   $$012$i = $7; //@line 2154
   $$0$i = $$0$i$phi; //@line 2154
  }
 }
 if ((label | 0) == 5) {
  HEAP32[($$0$i | 0 ? $$0$i + 4 | 0 : 112796) >> 2] = $7; //@line 2161
  __ZdlPv($$012$i); //@line 2162
 }
 $11 = HEAP32[$0 + 24 >> 2] | 0; //@line 2165
 if ($11 | 0) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$11 >> 2] | 0) + 4 >> 2] & 4095]($11); //@line 2171
 }
 $$pre = $0 + 4 | 0; //@line 2176
 if (HEAP8[$0 + 10 >> 0] | 0) {
  $19 = HEAP32[$$pre >> 2] | 0; //@line 2178
  if (($19 | 0) > -1) {
   _close($19) | 0; //@line 2181
   HEAP32[$$pre >> 2] = -1; //@line 2182
  }
  $21 = HEAP32[$0 >> 2] | 0; //@line 2184
  if ($21 | 0) {
   _free($21); //@line 2187
   HEAP32[$0 >> 2] = 0; //@line 2188
  }
 }
 $23 = HEAP32[$$pre >> 2] | 0; //@line 2191
 if (($23 | 0) > -1) {
  _close($23) | 0; //@line 2194
 }
 $25 = HEAP32[$0 >> 2] | 0; //@line 2196
 if ($25 | 0) {
  _free($25); //@line 2199
 }
 __ZdlPv($0); //@line 2201
 return;
}
function __Z17VideoDriverStatusjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$sink13$i = 0, $10 = 0, $16 = 0, $17 = 0, $2 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $9 = 0, label = 0;
 $2 = $1 + 41 | 0; //@line 26384
 $9 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0) & 255; //@line 26391
 $10 = $0 + 26 | 0; //@line 26392
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 26398
 $17 = $0 + 28 | 0; //@line 26399
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 26404
 $23 = HEAP32[30549] | 0; //@line 26405
 $24 = HEAP32[30548] | 0; //@line 26406
 if (($24 | 0) == ($23 | 0)) {
  $$0 = -56; //@line 26409
  return $$0 | 0; //@line 26410
 } else {
  $$sink13$i = $24; //@line 26412
 }
 while (1) {
  $28 = HEAP32[$$sink13$i >> 2] | 0; //@line 26415
  $$sink13$i = $$sink13$i + 4 | 0; //@line 26419
  if ((HEAP8[$28 + 24 >> 0] | 0) == $9 << 24 >> 24) {
   break;
  }
  if (($$sink13$i | 0) == ($23 | 0)) {
   $$0 = -56; //@line 26425
   label = 6; //@line 26426
   break;
  }
 }
 if ((label | 0) == 6) {
  return $$0 | 0; //@line 26433
 }
 if (!$28) {
  $$0 = -56; //@line 26437
  return $$0 | 0; //@line 26438
 }
 $$0 = __ZN12monitor_desc13driver_statusEtj($28, $16 & 65535, $22) | 0; //@line 26442
 return $$0 | 0; //@line 26443
}
function __Z12op_d188_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit47 = 0, $$lobit48 = 0, $11 = 0, $12 = 0, $14 = 0, $16 = 0, $19 = 0, $24 = 0, $26 = 0, $30 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 34670
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 34672
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 34677
 HEAP32[$4 >> 2] = $6; //@line 34678
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 34679
 $14 = (HEAP32[$12 >> 2] | 0) + -4 | 0; //@line 34681
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 34683
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 34686
 HEAP32[$12 >> 2] = $14; //@line 34687
 $24 = $19 + $11 + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 34692
 $$lobit = $11 >>> 31; //@line 34693
 $$lobit47 = $19 >>> 31; //@line 34694
 $$lobit48 = $24 >>> 31; //@line 34695
 $26 = $$lobit48 ^ $$lobit47; //@line 34697
 HEAP32[96444] = ($$lobit48 ^ $$lobit) & $26; //@line 34699
 $30 = $26 & ($$lobit47 ^ $$lobit) ^ $$lobit; //@line 34702
 HEAP32[96441] = $30; //@line 34703
 HEAP32[96445] = $30; //@line 34704
 HEAP32[96442] = ($24 | 0) == 0 & HEAP32[96442]; //@line 34709
 HEAP32[96443] = $$lobit48; //@line 34710
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $24); //@line 34714
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34717
 return;
}
function __Z11op_4f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $10 = 0, $12 = 0, $19 = 0, $21 = 0, $24 = 0, $29 = 0, $3 = 0, $30 = 0, $35 = 0, $45 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 11833
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 11836
 $$cast = $3; //@line 11837
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 11840
 $10 = $$cast + 4 | 0; //@line 11841
 HEAP32[162769] = $10; //@line 11842
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11844
 $19 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 11851
 HEAP32[162769] = $$cast + 6; //@line 11853
 $21 = __Z15get_disp_ea_020jj($12, $19) | 0; //@line 11854
 $24 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 11857
 $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($21 >>> 16 << 2) >> 2] >> 2] & 127]($21) | 0; //@line 11862
 $30 = $21 + 4 | 0; //@line 11863
 $35 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($30 >>> 16 << 2) >> 2] >> 2] & 127]($30) | 0; //@line 11868
 HEAP32[96442] = (($29 | 0) == ($24 | 0) | ($35 | 0) == ($24 | 0)) & 1; //@line 11873
 if (($29 | 0) > ($35 | 0)) {
  $45 = ($24 | 0) < ($29 | 0) | ($24 | 0) > ($35 | 0); //@line 11879
 } else {
  $45 = ($24 | 0) < ($29 | 0) | ($24 | 0) > ($35 | 0); //@line 11884
 }
 HEAP32[96441] = $45 & 1; //@line 11887
 if (!(($9 & 8 | 0) != 0 & $45)) {
  return;
 }
 __Z9Exceptionij(6, $6); //@line 11894
 return;
}
function __Z12op_e8f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $22 = 0, $33 = 0, $34 = 0, $36 = 0, $40 = 0, $45 = 0, $46 = 0, $54 = 0, $60 = 0, $sext31 = 0;
 $1 = HEAP32[162769] | 0; //@line 42523
 $sext31 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16; //@line 42542
 $19 = $sext31 >> 16; //@line 42543
 $22 = $sext31 >> 22; //@line 42546
 if (!($19 & 2048)) {
  $36 = $22 & 31; //@line 42549
 } else {
  $36 = HEAP32[651008 + (($22 & 7) << 2) >> 2] | 0; //@line 42554
 }
 if (!($19 & 32)) {
  $33 = $19; //@line 42559
 } else {
  $33 = HEAP32[651008 + (($19 & 7) << 2) >> 2] | 0; //@line 42564
 }
 $34 = $33 + 31 & 31; //@line 42567
 $40 = ($36 >> 31 & -536870912 | $36 >> 3) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 42572
 $45 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($40 >>> 16 << 2) >> 2] >> 2] & 127]($40) | 0; //@line 42577
 $46 = $40 + 4 | 0; //@line 42578
 $54 = $36 & 7; //@line 42586
 $60 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($46 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($46) | 0) & 255) >>> (8 - $54 | 0) | $45 << $54) >>> ($34 ^ 31); //@line 42592
 HEAP32[96443] = ($60 & 1 << $34 | 0) != 0 & 1; //@line 42597
 HEAP32[96442] = ($60 | 0) == 0 & 1; //@line 42600
 HEAP32[96444] = 0; //@line 42601
 HEAP32[96441] = 0; //@line 42602
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42605
 return;
}
function __Z11op_2f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$038 = 0, $$cast = 0, $18 = 0, $19 = 0, $2 = 0, $22 = 0, $29 = 0, $30 = 0, $37 = 0, $5 = 0, $50 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 9888
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 9891
 $$cast = $2; //@line 9892
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 9895
 $18 = ((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16; //@line 9906
 $19 = $8 << 24 >> 16; //@line 9907
 $22 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 9910
 $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0) << 16 >> 16; //@line 9918
 $30 = $18 + 2 | 0; //@line 9919
 $37 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($30) | 0) << 16 >> 16; //@line 9927
 $$038 = ($19 & 32768 | 0) == 0 ? $22 << 16 >> 16 : $22; //@line 9932
 HEAP32[96442] = (($29 | 0) == ($$038 | 0) | ($37 | 0) == ($$038 | 0)) & 1; //@line 9937
 if (($29 | 0) > ($37 | 0)) {
  $50 = ($$038 | 0) < ($29 | 0) | ($$038 | 0) > ($37 | 0); //@line 9943
 } else {
  $50 = ($$038 | 0) < ($29 | 0) | ($$038 | 0) > ($37 | 0); //@line 9948
 }
 HEAP32[96441] = $50 & 1; //@line 9951
 if (($19 & 2048 | 0) != 0 & $50) {
  __Z9Exceptionij(6, $5); //@line 9956
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9961
  return;
 }
}
function _fmt_u($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$010$lcssa$off0 = 0, $$012 = 0, $$09$lcssa = 0, $$0914 = 0, $$1$lcssa = 0, $$111 = 0, $10 = 0, $26 = 0, $8 = 0, $9 = 0, $8$looptemp = 0;
 if ($1 >>> 0 > 0 | ($1 | 0) == 0 & $0 >>> 0 > 4294967295) {
  $$0914 = $2; //@line 57592
  $8 = $0; //@line 57592
  $9 = $1; //@line 57592
  while (1) {
   $10 = ___uremdi3($8 | 0, $9 | 0, 10, 0) | 0; //@line 57594
   $$0914 = $$0914 + -1 | 0; //@line 57598
   HEAP8[$$0914 >> 0] = $10 & 255 | 48; //@line 57599
   $8$looptemp = $8;
   $8 = ___udivdi3($8 | 0, $9 | 0, 10, 0) | 0; //@line 57600
   if (!($9 >>> 0 > 9 | ($9 | 0) == 9 & $8$looptemp >>> 0 > 4294967295)) {
    break;
   } else {
    $9 = tempRet0; //@line 57608
   }
  }
  $$010$lcssa$off0 = $8; //@line 57613
  $$09$lcssa = $$0914; //@line 57613
 } else {
  $$010$lcssa$off0 = $0; //@line 57615
  $$09$lcssa = $2; //@line 57615
 }
 if (!$$010$lcssa$off0) {
  $$1$lcssa = $$09$lcssa; //@line 57619
 } else {
  $$012 = $$010$lcssa$off0; //@line 57621
  $$111 = $$09$lcssa; //@line 57621
  while (1) {
   $26 = $$111 + -1 | 0; //@line 57626
   HEAP8[$26 >> 0] = ($$012 >>> 0) % 10 | 0 | 48; //@line 57627
   if ($$012 >>> 0 < 10) {
    $$1$lcssa = $26; //@line 57631
    break;
   } else {
    $$012 = ($$012 >>> 0) / 10 | 0; //@line 57634
    $$111 = $26; //@line 57634
   }
  }
 }
 return $$1$lcssa | 0; //@line 57638
}
function __Z10op_f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$038 = 0, $$cast = 0, $18 = 0, $19 = 0, $2 = 0, $22 = 0, $29 = 0, $30 = 0, $37 = 0, $5 = 0, $50 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 6154
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 6157
 $$cast = $2; //@line 6158
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 6161
 $18 = ((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16; //@line 6172
 $19 = $8 << 24 >> 16; //@line 6173
 $22 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 6176
 $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 6184
 $30 = $18 + 1 | 0; //@line 6185
 $37 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($30) | 0) << 24 >> 24; //@line 6193
 $$038 = ($19 & 32768 | 0) == 0 ? $22 << 24 >> 24 : $22; //@line 6198
 HEAP32[96442] = (($29 | 0) == ($$038 | 0) | ($37 | 0) == ($$038 | 0)) & 1; //@line 6203
 if (($29 | 0) > ($37 | 0)) {
  $50 = ($$038 | 0) < ($29 | 0) | ($$038 | 0) > ($37 | 0); //@line 6209
 } else {
  $50 = ($$038 | 0) < ($29 | 0) | ($$038 | 0) > ($37 | 0); //@line 6214
 }
 HEAP32[96441] = $50 & 1; //@line 6217
 if (($19 & 2048 | 0) != 0 & $50) {
  __Z9Exceptionij(6, $5); //@line 6222
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6227
  return;
 }
}
function __Z12op_e130_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$036 = 0, $$1$in = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $26 = 0, $28 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext38 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39092
 $7 = HEAP32[$6 >> 2] | 0; //@line 39093
 $8 = $7 & 255; //@line 39094
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39095
 $$ = $9 >>> 0 > 35 ? $9 + -36 | 0 : $9; //@line 39098
 $$1$in = ($$ | 0) > 17 ? $$ + -18 | 0 : $$; //@line 39101
 $sext38 = (($$1$in << 24 | 0) > 134217728 ? $$1$in + 247 | 0 : $$1$in) << 24; //@line 39106
 $16 = ($sext38 | 0) > 0; //@line 39107
 HEAP32[96441] = 0; //@line 39108
 HEAP32[96442] = 0; //@line 39108
 HEAP32[96443] = 0; //@line 39108
 HEAP32[96444] = 0; //@line 39108
 if ($16) {
  $17 = $sext38 + -16777216 >> 24; //@line 39111
  $19 = $8 >>> (7 - $17 | 0); //@line 39113
  $20 = $19 & 1; //@line 39114
  $26 = (HEAP32[96445] | $8 << 1) << $17 | $19 >>> 1; //@line 39120
  HEAP32[96445] = $20; //@line 39121
  $$036 = $26 & 255; //@line 39123
  $28 = $20; //@line 39123
 } else {
  $$036 = $8; //@line 39126
  $28 = HEAP32[96445] | 0; //@line 39126
 }
 HEAP32[96441] = $28; //@line 39128
 HEAP32[96442] = ($$036 | 0) == 0 & 1; //@line 39131
 HEAP32[96443] = $$036 >>> 7; //@line 39133
 HEAP32[$6 >> 2] = $7 & -256 | $$036; //@line 39136
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39139
 return;
}
function __Z12op_e030_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$039 = 0, $$1$in = 0, $16 = 0, $20 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext41 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37661
 $7 = HEAP32[$6 >> 2] | 0; //@line 37662
 $8 = $7 & 255; //@line 37663
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37664
 $$ = $9 >>> 0 > 35 ? $9 + -36 | 0 : $9; //@line 37667
 $$1$in = ($$ | 0) > 17 ? $$ + -18 | 0 : $$; //@line 37670
 $sext41 = (($$1$in << 24 | 0) > 134217728 ? $$1$in + 247 | 0 : $$1$in) << 24; //@line 37675
 $16 = ($sext41 | 0) > 0; //@line 37676
 HEAP32[96441] = 0; //@line 37677
 HEAP32[96442] = 0; //@line 37677
 HEAP32[96443] = 0; //@line 37677
 HEAP32[96444] = 0; //@line 37677
 if ($16) {
  $20 = $sext41 + -16777216 >> 24; //@line 37683
  $23 = $8 >>> $20; //@line 37686
  $24 = $23 & 1; //@line 37687
  $26 = (HEAP32[96445] | $8 << 1) << 7 - $20 | $23 >>> 1; //@line 37689
  HEAP32[96445] = $24; //@line 37690
  $$039 = $26 & 255; //@line 37692
  $28 = $24; //@line 37692
 } else {
  $$039 = $8; //@line 37695
  $28 = HEAP32[96445] | 0; //@line 37695
 }
 HEAP32[96441] = $28; //@line 37697
 HEAP32[96442] = ($$039 | 0) == 0 & 1; //@line 37700
 HEAP32[96443] = $$039 >>> 7; //@line 37702
 HEAP32[$6 >> 2] = $7 & -256 | $$039; //@line 37705
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37708
 return;
}
function __Z12op_81c0_0_ffj($0) {
 $0 = $0 | 0;
 var $$038 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $23 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $sext40$mask = 0;
 $4 = HEAP32[162768] | 0; //@line 16864
 $5 = HEAP32[162769] | 0; //@line 16865
 $6 = HEAP32[162770] | 0; //@line 16866
 $8 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 16868
 $9 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 16869
 $10 = HEAP32[$9 >> 2] | 0; //@line 16870
 HEAP32[162769] = $5 + 2; //@line 16873
 $12 = $8 << 16 >> 16; //@line 16875
 if (!$12) {
  HEAP32[96444] = 0; //@line 16880
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 16881
  return;
 }
 $16 = ($10 | 0) / ($12 | 0) | 0; //@line 16884
 $17 = ($10 | 0) % ($12 | 0) | 0; //@line 16885
 if (($16 + -32768 | 0) >>> 0 < 4294901760) {
  HEAP32[96444] = 1; //@line 16889
  HEAP32[96443] = 1; //@line 16890
  HEAP32[96441] = 0; //@line 16891
  return;
 } else {
  $$038 = ($17 >>> 15 & 1 | 0) == ($10 >>> 31 | 0) ? $17 : 0 - $17 | 0; //@line 16899
  $sext40$mask = $16 & 65535; //@line 16900
  $23 = ($sext40$mask | 0) == 0 & 1; //@line 16902
  HEAP32[96441] = 0; //@line 16903
  HEAP32[96442] = 0; //@line 16903
  HEAP32[96443] = 0; //@line 16903
  HEAP32[96444] = 0; //@line 16903
  HEAP32[96442] = $23; //@line 16904
  HEAP32[96443] = $16 >>> 15 & 1; //@line 16907
  HEAP32[$9 >> 2] = $$038 << 16 | $sext40$mask; //@line 16910
  return;
 }
}
function __Z23rpc_message_send_stringP13rpc_message_tPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $10 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 if (!$1) {
  $4 = 0; //@line 41815
 } else {
  $4 = _strlen($1) | 0; //@line 41818
 }
 $5 = _htonl($4) | 0; //@line 41820
 $6 = $0 + 4 | 0; //@line 41821
 $7 = HEAP32[$6 >> 2] | 0; //@line 41822
 $10 = $0 + 8 | 0; //@line 41825
 if (($7 + 4 | 0) >>> 0 > 1023) {
  $12 = (_send(HEAP32[$0 >> 2] | 0, $10, $7, 0) | 0) == ($7 | 0); //@line 41829
  HEAP32[$6 >> 2] = 0; //@line 41830
  if ($12) {
   $14 = 0; //@line 41832
  } else {
   $$0 = -1001; //@line 41834
   return $$0 | 0; //@line 41835
  }
 } else {
  $14 = $7; //@line 41838
 }
 $13 = $0 + 8 + $14 | 0; //@line 41840
 HEAP8[$13 >> 0] = $5; //@line 41841
 HEAP8[$13 + 1 >> 0] = $5 >> 8; //@line 41841
 HEAP8[$13 + 2 >> 0] = $5 >> 16; //@line 41841
 HEAP8[$13 + 3 >> 0] = $5 >> 24; //@line 41841
 $16 = (HEAP32[$6 >> 2] | 0) + 4 | 0; //@line 41843
 HEAP32[$6 >> 2] = $16; //@line 41844
 $18 = (_send(HEAP32[$0 >> 2] | 0, $10, $16, 0) | 0) == ($16 | 0); //@line 41847
 HEAP32[$6 >> 2] = 0; //@line 41848
 if (!$18) {
  $$0 = -1001; //@line 41850
  return $$0 | 0; //@line 41851
 }
 $20 = (_send(HEAP32[$0 >> 2] | 0, $1, $4, 0) | 0) == ($4 | 0); //@line 41855
 $$0 = $20 ? 0 : -1001; //@line 41857
 return $$0 | 0; //@line 41858
}
function __Z12op_d07b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $31 = 0, $4 = 0, $41 = 0, $8 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 32459
 $4 = $3 + 2 | 0; //@line 32460
 HEAP32[162769] = $4; //@line 32461
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 32466
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 32473
 HEAP32[162769] = $3 + 4; //@line 32475
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 32476
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 32482
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32483
 $25 = HEAP32[$24 >> 2] | 0; //@line 32484
 $26 = $25 << 16 >> 16; //@line 32486
 $28 = $26 + ($23 << 16 >> 16) | 0; //@line 32489
 $31 = $28 >>> 15; //@line 32493
 $sext38$lobit = $31 & 1; //@line 32494
 $sext38$mask = $28 & 65535; //@line 32495
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 32498
 HEAP32[96444] = ($sext38$lobit ^ $25 >>> 15 & 1) & ($31 ^ $23 >>> 15); //@line 32502
 $41 = ($26 & 65535 ^ 65535) >>> 0 < ($23 & 65535) >>> 0 & 1; //@line 32507
 HEAP32[96441] = $41; //@line 32508
 HEAP32[96445] = $41; //@line 32509
 HEAP32[96443] = $sext38$lobit; //@line 32510
 HEAP32[$24 >> 2] = $25 & -65536 | $sext38$mask; //@line 32513
 return;
}
function __Z12op_f618_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $28 = 0, $30 = 0, $38 = 0, $46 = 0, $54 = 0;
 $2 = HEAP32[162769] | 0; //@line 49602
 $11 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24; //@line 49611
 $20 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49620
 $22 = $11 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | HEAP8[$2 + 5 >> 0] & -16 & 255; //@line 49623
 $23 = $20 & -16; //@line 49624
 $25 = 123608 + ($11 >>> 16 << 2) | 0; //@line 49626
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22) | 0; //@line 49629
 $30 = 123608 + ($20 >>> 16 << 2) | 0; //@line 49631
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23, $28); //@line 49635
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 4) | 0; //@line 49640
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 4, $38); //@line 49644
 $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 8) | 0; //@line 49649
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 8, $46); //@line 49653
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($22 | 12) | 0; //@line 49658
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 12, $54); //@line 49662
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49665
 return;
}
function __Z11op_670_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $28 = 0, $29 = 0, $31 = 0, $34 = 0, $43 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12964
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12967
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12972
 $11 = $2 + 4 | 0; //@line 12973
 HEAP32[162769] = $11; //@line 12974
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 12976
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 12983
 HEAP32[162769] = $2 + 6; //@line 12985
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 12986
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 12988
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 12992
 $29 = $28 << 16 >> 16; //@line 12994
 $31 = $29 + ($10 << 16 >> 16) | 0; //@line 12997
 $34 = $31 >>> 15; //@line 13001
 $sext34$lobit = $34 & 1; //@line 13002
 HEAP32[96442] = ($31 & 65535 | 0) == 0 & 1; //@line 13006
 HEAP32[96444] = ($sext34$lobit ^ $28 >>> 15 & 1) & ($34 ^ $5 >>> 7); //@line 13010
 $43 = ($29 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 13014
 HEAP32[96441] = $43; //@line 13015
 HEAP32[96445] = $43; //@line 13016
 HEAP32[96443] = $sext34$lobit; //@line 13017
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $31); //@line 13021
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 3434
 STACKTOP = STACKTOP + 16 | 0; //@line 3435
 $3 = sp; //@line 3436
 $4 = $0 + 11 | 0; //@line 3437
 $5 = HEAP8[$4 >> 0] | 0; //@line 3438
 $6 = $5 << 24 >> 24 < 0; //@line 3439
 if ($6) {
  $14 = (HEAP32[$0 + 8 >> 2] & 2147483647) + -1 | 0; //@line 3447
  $15 = HEAP32[$0 + 4 >> 2] | 0; //@line 3447
 } else {
  $14 = 10; //@line 3450
  $15 = $5 & 255; //@line 3450
 }
 $17 = $15 + $2 | 0; //@line 3454
 if (($14 - $15 | 0) >>> 0 < $2 >>> 0) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0, $14, $17 - $14 | 0, $15, $15, 0, $2, $1); //@line 3457
 } else {
  if ($2 | 0) {
   if ($6) {
    $21 = HEAP32[$0 >> 2] | 0; //@line 3463
   } else {
    $21 = $0; //@line 3465
   }
   __ZNSt3__211char_traitsIcE4copyEPcPKcj($21 + $15 | 0, $1, $2) | 0; //@line 3468
   if ((HEAP8[$4 >> 0] | 0) < 0) {
    HEAP32[$0 + 4 >> 2] = $17; //@line 3473
   } else {
    HEAP8[$4 >> 0] = $17; //@line 3476
   }
   HEAP8[$3 >> 0] = 0; //@line 3479
   __ZNSt3__211char_traitsIcE6assignERcRKc($21 + $17 | 0, $3); //@line 3480
  }
 }
 STACKTOP = sp; //@line 3483
 return $0 | 0; //@line 3483
}
function __Z12op_d070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $5 = 0, $7 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 32199
 $5 = $4 + 2 | 0; //@line 32200
 HEAP32[162769] = $5; //@line 32201
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 32203
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 32210
 HEAP32[162769] = $4 + 4; //@line 32212
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 32213
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 32219
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32220
 $24 = HEAP32[$23 >> 2] | 0; //@line 32221
 $25 = $24 << 16 >> 16; //@line 32223
 $27 = $25 + ($22 << 16 >> 16) | 0; //@line 32226
 $30 = $27 >>> 15; //@line 32230
 $sext39$lobit = $30 & 1; //@line 32231
 $sext39$mask = $27 & 65535; //@line 32232
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 32235
 HEAP32[96444] = ($sext39$lobit ^ $24 >>> 15 & 1) & ($30 ^ $22 >>> 15); //@line 32239
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($22 & 65535) >>> 0 & 1; //@line 32244
 HEAP32[96441] = $40; //@line 32245
 HEAP32[96445] = $40; //@line 32246
 HEAP32[96443] = $sext39$lobit; //@line 32247
 HEAP32[$23 >> 2] = $24 & -65536 | $sext39$mask; //@line 32250
 return;
}
function __Z12op_f610_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $3 = 0, $30 = 0, $38 = 0, $4 = 0, $46 = 0, $54 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49529
 $4 = HEAP32[162769] | 0; //@line 49530
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 49539
 $21 = $3 & -16; //@line 49547
 $23 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | HEAP8[$4 + 5 >> 0] & -16 & 255; //@line 49550
 $25 = 123608 + ($3 >>> 16 << 2) | 0; //@line 49552
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21) | 0; //@line 49555
 $30 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49557
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23, $28); //@line 49561
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 4) | 0; //@line 49566
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 4, $38); //@line 49570
 $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 8) | 0; //@line 49575
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 8, $46); //@line 49579
 $54 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($21 | 12) | 0; //@line 49584
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($23 | 12, $54); //@line 49588
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49591
 return;
}
function __Z12op_d03b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $31 = 0, $4 = 0, $41 = 0, $8 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 31767
 $4 = $3 + 2 | 0; //@line 31768
 HEAP32[162769] = $4; //@line 31769
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 31774
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 31781
 HEAP32[162769] = $3 + 4; //@line 31783
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 31784
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 31790
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31791
 $25 = HEAP32[$24 >> 2] | 0; //@line 31792
 $26 = $25 << 24 >> 24; //@line 31794
 $28 = $26 + ($23 << 24 >> 24) | 0; //@line 31797
 $31 = $28 >>> 7; //@line 31801
 $sext34$lobit = $31 & 1; //@line 31802
 $sext34$mask = $28 & 255; //@line 31803
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 31806
 HEAP32[96444] = ($sext34$lobit ^ $25 >>> 7 & 1) & ($31 ^ $23 >>> 7); //@line 31810
 $41 = ($26 & 255 ^ 255) >>> 0 < ($23 & 255) >>> 0 & 1; //@line 31815
 HEAP32[96441] = $41; //@line 31816
 HEAP32[96445] = $41; //@line 31817
 HEAP32[96443] = $sext34$lobit; //@line 31818
 HEAP32[$24 >> 2] = $25 & -256 | $sext34$mask; //@line 31821
 return;
}
function __ZN8tinyxml214XMLDeclaration9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i7 = 0, $$01921$i = 0, $$pre$i$i$i = 0, $13 = 0, $15 = 0, $21 = 0, $3 = 0, $6 = 0, $9 = 0;
 $3 = HEAP8[$1 >> 0] | 0; //@line 40039
 L1 : do {
  if ($3 << 24 >> 24) {
   $$01921$i = $1; //@line 40043
   $6 = $3; //@line 40043
   while (1) {
    if ($6 << 24 >> 24 == 63) {
     if (!(_strncmp($$01921$i, 97459, 2) | 0)) {
      break;
     }
    }
    $15 = $$01921$i + 1 | 0; //@line 40053
    $6 = HEAP8[$15 >> 0] | 0; //@line 40054
    if (!($6 << 24 >> 24)) {
     break L1;
    } else {
     $$01921$i = $15; //@line 40059
    }
   }
   $9 = $0 + 12 | 0; //@line 40062
   $$pre$i$i$i = $0 + 16 | 0; //@line 40066
   if (HEAP32[$9 >> 2] & 512 | 0) {
    $13 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 40068
    if ($13 | 0) {
     __ZdaPv($13); //@line 40071
    }
   }
   HEAP32[$$pre$i$i$i >> 2] = $1; //@line 40075
   HEAP32[$0 + 20 >> 2] = $$01921$i; //@line 40076
   HEAP32[$9 >> 2] = 258; //@line 40077
   $$0$i7 = $$01921$i + 2 | 0; //@line 40079
   return $$0$i7 | 0; //@line 40080
  }
 } while (0);
 $21 = HEAP32[$0 + 4 >> 2] | 0; //@line 40084
 HEAP32[$21 + 48 >> 2] = 13; //@line 40086
 HEAP32[$21 + 56 >> 2] = $1; //@line 40088
 HEAP32[$21 + 60 >> 2] = 0; //@line 40090
 $$0$i7 = 0; //@line 40091
 return $$0$i7 | 0; //@line 40092
}
function __ZL11find_fsitemPKcP6FSItem($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$012 = 0, $$014 = 0, $$015 = 0, $11 = 0, $12 = 0, $14 = 0, $23 = 0;
 $$014 = HEAP32[30826] | 0; //@line 35402
 L1 : do {
  if ($$014 | 0) {
   $$015 = $$014; //@line 35406
   while (1) {
    if ((HEAP32[$$015 + 12 >> 2] | 0) == ($1 | 0)) {
     if (!(_strcmp(HEAP32[$$015 + 16 >> 2] | 0, $0) | 0)) {
      $$012 = $$015; //@line 35417
      break;
     }
    }
    $$015 = HEAP32[$$015 >> 2] | 0; //@line 35421
    if (!$$015) {
     break L1;
    }
   }
   return $$012 | 0; //@line 35429
  }
 } while (0);
 $11 = __Z25host_encoding_to_macromanPKc($0) | 0; //@line 35432
 $12 = __Znwj(60) | 0; //@line 35433
 HEAP32[HEAP32[30827] >> 2] = $12; //@line 35435
 HEAP32[$12 >> 2] = 0; //@line 35436
 HEAP32[30827] = $12; //@line 35437
 $14 = HEAP32[383] | 0; //@line 35438
 HEAP32[383] = $14 + 1; //@line 35440
 HEAP32[$12 + 4 >> 2] = $14; //@line 35442
 HEAP32[$12 + 8 >> 2] = HEAP32[$1 + 4 >> 2]; //@line 35446
 HEAP32[$12 + 12 >> 2] = $1; //@line 35448
 $23 = __Znaj((_strlen($0) | 0) + 1 | 0) | 0; //@line 35451
 HEAP32[$12 + 16 >> 2] = $23; //@line 35453
 _strcpy($23, $0) | 0; //@line 35454
 _strncpy($12 + 20 | 0, $11, 31) | 0; //@line 35456
 HEAP8[$12 + 51 >> 0] = 0; //@line 35458
 HEAP32[$12 + 52 >> 2] = 0; //@line 35460
 $$012 = $12; //@line 35461
 return $$012 | 0; //@line 35462
}
function __Z16PrefsReplaceBoolPKcb($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, $$sink$i = 0, $14 = 0, $16 = 0, $2 = 0, $21 = 0, $23 = 0;
 $2 = $1 & 1; //@line 879
 $$01416$i = HEAP32[28198] | 0; //@line 880
 L1 : do {
  if ($$01416$i | 0) {
   $$01418$i = $$01416$i; //@line 884
   while (1) {
    if ((HEAP32[$$01418$i + 8 >> 2] | 0) == 1) {
     if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
      break;
     }
    }
    $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 898
    if (!$$014$i) {
     break L1;
    } else {
     $$01418$i = $$014$i; //@line 903
    }
   }
   HEAP8[HEAP32[$$01418$i + 12 >> 2] >> 0] = $2; //@line 908
   return;
  }
 } while (0);
 $14 = _malloc(1) | 0; //@line 912
 if (!$14) {
  return;
 }
 HEAP8[$14 >> 0] = $2; //@line 917
 $16 = __Znwj(16) | 0; //@line 918
 HEAP32[$16 >> 2] = 0; //@line 919
 HEAP32[$16 + 4 >> 2] = ___strdup($0) | 0; //@line 922
 HEAP32[$16 + 8 >> 2] = 1; //@line 924
 HEAP32[$16 + 12 >> 2] = $14; //@line 926
 $21 = HEAP32[28198] | 0; //@line 927
 if (!$21) {
  $$sink$i = 112792; //@line 930
 } else {
  $$0$i = $21; //@line 932
  while (1) {
   $23 = HEAP32[$$0$i >> 2] | 0; //@line 934
   if (!$23) {
    break;
   } else {
    $$0$i = $23; //@line 939
   }
  }
  $$sink$i = $$0$i; //@line 942
 }
 HEAP32[$$sink$i >> 2] = $16; //@line 944
 return;
}
function _fopen($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $6 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer8 = 0, sp = 0;
 sp = STACKTOP; //@line 5
 STACKTOP = STACKTOP + 48 | 0; //@line 6
 $vararg_buffer8 = sp + 32 | 0; //@line 7
 $vararg_buffer3 = sp + 16 | 0; //@line 8
 $vararg_buffer = sp; //@line 9
 if (!(_memchr(112512, HEAP8[$1 >> 0] | 0, 4) | 0)) {
  HEAP32[(___errno_location() | 0) >> 2] = 22; //@line 16
  $$0 = 0; //@line 17
 } else {
  $6 = ___fmodeflags($1) | 0; //@line 19
  HEAP32[$vararg_buffer >> 2] = $0; //@line 22
  HEAP32[$vararg_buffer + 4 >> 2] = $6 | 32768; //@line 24
  HEAP32[$vararg_buffer + 8 >> 2] = 438; //@line 26
  $10 = ___syscall_ret(___syscall5(5, $vararg_buffer | 0) | 0) | 0; //@line 28
  if (($10 | 0) < 0) {
   $$0 = 0; //@line 31
  } else {
   if ($6 & 524288 | 0) {
    HEAP32[$vararg_buffer3 >> 2] = $10; //@line 36
    HEAP32[$vararg_buffer3 + 4 >> 2] = 2; //@line 38
    HEAP32[$vararg_buffer3 + 8 >> 2] = 1; //@line 40
    ___syscall221(221, $vararg_buffer3 | 0) | 0; //@line 41
   }
   $14 = ___fdopen($10, $1) | 0; //@line 43
   if (!$14) {
    HEAP32[$vararg_buffer8 >> 2] = $10; //@line 46
    ___syscall6(6, $vararg_buffer8 | 0) | 0; //@line 47
    $$0 = 0; //@line 48
   } else {
    $$0 = $14; //@line 50
   }
  }
 }
 STACKTOP = sp; //@line 54
 return $$0 | 0; //@line 54
}
function __ZN8tinyxml210XMLComment9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i7 = 0, $$01921$i = 0, $$pre$i$i$i = 0, $13 = 0, $15 = 0, $21 = 0, $3 = 0, $6 = 0, $9 = 0;
 $3 = HEAP8[$1 >> 0] | 0; //@line 39816
 L1 : do {
  if ($3 << 24 >> 24) {
   $$01921$i = $1; //@line 39820
   $6 = $3; //@line 39820
   while (1) {
    if ($6 << 24 >> 24 == 45) {
     if (!(_strncmp($$01921$i, 97431, 3) | 0)) {
      break;
     }
    }
    $15 = $$01921$i + 1 | 0; //@line 39830
    $6 = HEAP8[$15 >> 0] | 0; //@line 39831
    if (!($6 << 24 >> 24)) {
     break L1;
    } else {
     $$01921$i = $15; //@line 39836
    }
   }
   $9 = $0 + 12 | 0; //@line 39839
   $$pre$i$i$i = $0 + 16 | 0; //@line 39843
   if (HEAP32[$9 >> 2] & 512 | 0) {
    $13 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 39845
    if ($13 | 0) {
     __ZdaPv($13); //@line 39848
    }
   }
   HEAP32[$$pre$i$i$i >> 2] = $1; //@line 39852
   HEAP32[$0 + 20 >> 2] = $$01921$i; //@line 39853
   HEAP32[$9 >> 2] = 258; //@line 39854
   $$0$i7 = $$01921$i + 3 | 0; //@line 39856
   return $$0$i7 | 0; //@line 39857
  }
 } while (0);
 $21 = HEAP32[$0 + 4 >> 2] | 0; //@line 39861
 HEAP32[$21 + 48 >> 2] = 12; //@line 39863
 HEAP32[$21 + 56 >> 2] = $1; //@line 39865
 HEAP32[$21 + 60 >> 2] = 0; //@line 39867
 $$0$i7 = 0; //@line 39868
 return $$0$i7 | 0; //@line 39869
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $11 = 0, $13 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 3209
 STACKTOP = STACKTOP + 16 | 0; //@line 3210
 $3 = sp; //@line 3211
 $4 = $0 + 11 | 0; //@line 3212
 $5 = HEAP8[$4 >> 0] | 0; //@line 3213
 $6 = $5 << 24 >> 24 < 0; //@line 3214
 if ($6) {
  $11 = (HEAP32[$0 + 8 >> 2] & 2147483647) + -1 | 0; //@line 3220
 } else {
  $11 = 10; //@line 3222
 }
 do {
  if ($11 >>> 0 < $2 >>> 0) {
   if ($6) {
    $23 = HEAP32[$0 + 4 >> 2] | 0; //@line 3230
   } else {
    $23 = $5 & 255; //@line 3233
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($0, $11, $2 - $11 | 0, $23, 0, $23, $2, $1); //@line 3236
  } else {
   if ($6) {
    $13 = HEAP32[$0 >> 2] | 0; //@line 3240
   } else {
    $13 = $0; //@line 3242
   }
   __ZNSt3__211char_traitsIcE4moveEPcPKcj($13, $1, $2) | 0; //@line 3244
   HEAP8[$3 >> 0] = 0; //@line 3246
   __ZNSt3__211char_traitsIcE6assignERcRKc($13 + $2 | 0, $3); //@line 3247
   if ((HEAP8[$4 >> 0] | 0) < 0) {
    HEAP32[$0 + 4 >> 2] = $2; //@line 3252
    break;
   } else {
    HEAP8[$4 >> 0] = $2; //@line 3256
    break;
   }
  }
 } while (0);
 STACKTOP = sp; //@line 3261
 return $0 | 0; //@line 3261
}
function __Z11op_4fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $1 = 0, $18 = 0, $2 = 0, $20 = 0, $23 = 0, $28 = 0, $29 = 0, $3 = 0, $34 = 0, $44 = 0, $8 = 0, $9 = 0;
 $1 = HEAP32[162768] | 0; //@line 12127
 $2 = HEAP32[162769] | 0; //@line 12128
 $3 = HEAP32[162770] | 0; //@line 12129
 $$cast = $2; //@line 12132
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 12135
 $9 = $$cast + 4 | 0; //@line 12136
 HEAP32[162769] = $9; //@line 12137
 $18 = (HEAPU8[$9 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0); //@line 12147
 HEAP32[162769] = $$cast + 6; //@line 12149
 $20 = __Z15get_disp_ea_020jj($1 + $9 - $3 | 0, $18) | 0; //@line 12150
 $23 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 12153
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 12158
 $29 = $20 + 4 | 0; //@line 12159
 $34 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($29 >>> 16 << 2) >> 2] >> 2] & 127]($29) | 0; //@line 12164
 HEAP32[96442] = (($28 | 0) == ($23 | 0) | ($34 | 0) == ($23 | 0)) & 1; //@line 12169
 if (($28 | 0) > ($34 | 0)) {
  $44 = ($23 | 0) < ($28 | 0) | ($23 | 0) > ($34 | 0); //@line 12175
 } else {
  $44 = ($23 | 0) < ($28 | 0) | ($23 | 0) > ($34 | 0); //@line 12180
 }
 HEAP32[96441] = $44 & 1; //@line 12183
 if (!(($8 & 8 | 0) != 0 & $44)) {
  return;
 }
 __Z9Exceptionij(6, $2 + $1 - $3 | 0); //@line 12190
 return;
}
function __Z12op_d030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $5 = 0, $7 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 31507
 $5 = $4 + 2 | 0; //@line 31508
 HEAP32[162769] = $5; //@line 31509
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 31511
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 31518
 HEAP32[162769] = $4 + 4; //@line 31520
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 31521
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 31527
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31528
 $24 = HEAP32[$23 >> 2] | 0; //@line 31529
 $25 = $24 << 24 >> 24; //@line 31531
 $27 = $25 + ($22 << 24 >> 24) | 0; //@line 31534
 $30 = $27 >>> 7; //@line 31538
 $sext35$lobit = $30 & 1; //@line 31539
 $sext35$mask = $27 & 255; //@line 31540
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 31543
 HEAP32[96444] = ($sext35$lobit ^ $24 >>> 7 & 1) & ($30 ^ $22 >>> 7); //@line 31547
 $40 = ($25 & 255 ^ 255) >>> 0 < ($22 & 255) >>> 0 & 1; //@line 31552
 HEAP32[96441] = $40; //@line 31553
 HEAP32[96445] = $40; //@line 31554
 HEAP32[96443] = $sext35$lobit; //@line 31555
 HEAP32[$23 >> 2] = $24 & -256 | $sext35$mask; //@line 31558
 return;
}
function __Z12op_e8d0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $2 = 0, $27 = 0, $28 = 0, $30 = 0, $34 = 0, $39 = 0, $40 = 0, $48 = 0, $54 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 42249
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 42260
 $13 = $sext >> 16; //@line 42261
 $16 = $sext >> 22; //@line 42264
 if (!($13 & 2048)) {
  $30 = $16 & 31; //@line 42267
 } else {
  $30 = HEAP32[651008 + (($16 & 7) << 2) >> 2] | 0; //@line 42272
 }
 if (!($13 & 32)) {
  $27 = $13; //@line 42277
 } else {
  $27 = HEAP32[651008 + (($13 & 7) << 2) >> 2] | 0; //@line 42282
 }
 $28 = $27 + 31 & 31; //@line 42285
 $34 = ($30 >> 31 & -536870912 | $30 >> 3) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 42290
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($34 >>> 16 << 2) >> 2] >> 2] & 127]($34) | 0; //@line 42295
 $40 = $34 + 4 | 0; //@line 42296
 $48 = $30 & 7; //@line 42304
 $54 = (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($40) | 0) & 255) >>> (8 - $48 | 0) | $39 << $48) >>> ($28 ^ 31); //@line 42310
 HEAP32[96443] = ($54 & 1 << $28 | 0) != 0 & 1; //@line 42315
 HEAP32[96442] = ($54 | 0) == 0 & 1; //@line 42318
 HEAP32[96444] = 0; //@line 42319
 HEAP32[96441] = 0; //@line 42320
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42323
 return;
}
function __Z12op_e160_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $15 = 0, $19 = 0, $20 = 0, $24 = 0, $26 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39378
 $7 = HEAP32[$6 >> 2] | 0; //@line 39379
 $8 = $7 & 65535; //@line 39380
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39381
 $10 = $9 >>> 0 > 15; //@line 39382
 HEAP32[96441] = 0; //@line 39383
 HEAP32[96442] = 0; //@line 39383
 HEAP32[96443] = 0; //@line 39383
 HEAP32[96444] = 0; //@line 39383
 if ($10) {
  HEAP32[96444] = ($8 | 0) != 0 & 1; //@line 39387
  $15 = ($9 | 0) == 16 ? $7 & 1 : 0; //@line 39390
  HEAP32[96441] = $15; //@line 39391
  HEAP32[96445] = $15; //@line 39392
  $$0 = 0; //@line 39393
 } else {
  if (!$9) {
   $$0 = $8; //@line 39397
  } else {
   $19 = 65535 << 15 - $9 & 65535; //@line 39401
   $20 = $19 & $7; //@line 39402
   HEAP32[96444] = ($20 | 0) != 0 & ($20 | 0) != ($19 | 0) & 1; //@line 39407
   $24 = $8 << $9 + -1; //@line 39409
   $26 = $24 >>> 15 & 1; //@line 39411
   HEAP32[96441] = $26; //@line 39412
   HEAP32[96445] = $26; //@line 39413
   $$0 = $24 << 1 & 65534; //@line 39416
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39421
 HEAP32[96443] = $$0 >>> 15; //@line 39423
 HEAP32[$6 >> 2] = $7 & -65536 | $$0; //@line 39426
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39429
 return;
}
function __Z11op_e18_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $13 = 0, $16 = 0, $30 = 0, $38 = 0, $39 = 0, $41 = 0, $7 = 0, $9 = 0;
 $1 = $0 & 7; //@line 21211
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21215
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21221
 $9 = $7 << 24 >> 16; //@line 21223
 $12 = 651040 + ($1 << 2) | 0; //@line 21226
 $13 = HEAP32[$12 >> 2] | 0; //@line 21227
 do {
  if (!($9 & 2048)) {
   $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 21235
   HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 21240
   $38 = $30 << 24 >> 24; //@line 21245
   $39 = $7 >>> 4 & 7; //@line 21246
   if (!($9 & 32768)) {
    $41 = 651008 + ($39 << 2) | 0; //@line 21248
    HEAP32[$41 >> 2] = HEAP32[$41 >> 2] & -256 | $38 & 255; //@line 21253
    break;
   } else {
    HEAP32[651040 + ($39 << 2) >> 2] = $38; //@line 21257
    break;
   }
  } else {
   $16 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 21263
   HEAP32[$12 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $13; //@line 21267
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $16); //@line 21273
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21278
 return;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $21 = 0, $26 = 0;
 HEAP8[$1 + 53 >> 0] = 1; //@line 3807
 do {
  if ((HEAP32[$1 + 4 >> 2] | 0) == ($3 | 0)) {
   HEAP8[$1 + 52 >> 0] = 1; //@line 3814
   $10 = $1 + 16 | 0; //@line 3815
   $11 = HEAP32[$10 >> 2] | 0; //@line 3816
   $13 = $1 + 54 | 0; //@line 3818
   $14 = $1 + 48 | 0; //@line 3819
   $15 = $1 + 24 | 0; //@line 3820
   $16 = $1 + 36 | 0; //@line 3821
   if (!$11) {
    HEAP32[$10 >> 2] = $2; //@line 3823
    HEAP32[$15 >> 2] = $4; //@line 3824
    HEAP32[$16 >> 2] = 1; //@line 3825
    if (!((HEAP32[$14 >> 2] | 0) == 1 & ($4 | 0) == 1)) {
     break;
    }
    HEAP8[$13 >> 0] = 1; //@line 3833
    break;
   }
   if (($11 | 0) != ($2 | 0)) {
    HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 1; //@line 3840
    HEAP8[$13 >> 0] = 1; //@line 3841
    break;
   }
   $21 = HEAP32[$15 >> 2] | 0; //@line 3844
   if (($21 | 0) == 2) {
    HEAP32[$15 >> 2] = $4; //@line 3847
    $26 = $4; //@line 3848
   } else {
    $26 = $21; //@line 3850
   }
   if ((HEAP32[$14 >> 2] | 0) == 1 & ($26 | 0) == 1) {
    HEAP8[$13 >> 0] = 1; //@line 3857
   }
  }
 } while (0);
 return;
}
function __Z9LoadXPRAMPKc($0) {
 $0 = $0 | 0;
 var $2 = 0, $6 = 0, $endptr10 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, dest = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP; //@line 12966
 STACKTOP = STACKTOP + 16 | 0; //@line 12967
 $vararg_buffer1 = sp + 8 | 0; //@line 12968
 $vararg_buffer = sp; //@line 12969
 if (!$0) {
  HEAP8[656281] = 0; //@line 12972
  $2 = _getenv(105352) | 0; //@line 12973
  if ($2 | 0) {
   if ((_strlen($2) | 0) >>> 0 < 1e3) {
    _strncpy(656281, $2, 1e3) | 0; //@line 12979
    $endptr10 = 656281 + (_strlen(656281) | 0) | 0; //@line 12981
    HEAP8[$endptr10 >> 0] = 47; //@line 12982
    HEAP8[$endptr10 + 1 >> 0] = 0; //@line 12982
   }
  }
  dest = 656281 + (_strlen(656281) | 0) | 0; //@line 12987
  src = 93170; //@line 12987
  stop = dest + 19 | 0; //@line 12987
  do {
   HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 12987
   dest = dest + 1 | 0; //@line 12987
   src = src + 1 | 0; //@line 12987
  } while ((dest | 0) < (stop | 0));
 } else {
  HEAP32[$vararg_buffer >> 2] = $0; //@line 12989
  _snprintf(656281, 1024, 93161, $vararg_buffer) | 0; //@line 12990
 }
 $6 = _open(656281, 0, $vararg_buffer1) | 0; //@line 12992
 if (($6 | 0) <= -1) {
  STACKTOP = sp; //@line 12995
  return;
 }
 _read($6, 656025, 256) | 0; //@line 12997
 _close($6) | 0; //@line 12998
 STACKTOP = sp; //@line 12999
 return;
}
function __Z11op_4b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $45 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11488
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11491
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11506
 $21 = $2 + 6 | 0; //@line 11507
 HEAP32[162769] = $21; //@line 11508
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11510
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 11517
 HEAP32[162769] = $2 + 8; //@line 11519
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 11520
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 11522
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0; //@line 11525
 $38 = $37 - $20 | 0; //@line 11526
 $$lobit33 = $37 >>> 31; //@line 11528
 $$lobit34 = $38 >>> 31; //@line 11529
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 11532
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $5 >>> 7); //@line 11536
 $45 = $37 >>> 0 < $20 >>> 0 & 1; //@line 11538
 HEAP32[96441] = $45; //@line 11539
 HEAP32[96445] = $45; //@line 11540
 HEAP32[96443] = $$lobit34; //@line 11541
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 11545
 return;
}
function __Z12op_e120_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $15 = 0, $19 = 0, $20 = 0, $24 = 0, $26 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38972
 $7 = HEAP32[$6 >> 2] | 0; //@line 38973
 $8 = $7 & 255; //@line 38974
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38975
 $10 = $9 >>> 0 > 7; //@line 38976
 HEAP32[96441] = 0; //@line 38977
 HEAP32[96442] = 0; //@line 38977
 HEAP32[96443] = 0; //@line 38977
 HEAP32[96444] = 0; //@line 38977
 if ($10) {
  HEAP32[96444] = ($8 | 0) != 0 & 1; //@line 38981
  $15 = ($9 | 0) == 8 ? $7 & 1 : 0; //@line 38984
  HEAP32[96441] = $15; //@line 38985
  HEAP32[96445] = $15; //@line 38986
  $$0 = 0; //@line 38987
 } else {
  if (!$9) {
   $$0 = $8; //@line 38991
  } else {
   $19 = 255 << 7 - $9 & 255; //@line 38995
   $20 = $19 & $7; //@line 38996
   HEAP32[96444] = ($20 | 0) != 0 & ($20 | 0) != ($19 | 0) & 1; //@line 39001
   $24 = $8 << $9 + -1; //@line 39003
   $26 = $24 >>> 7 & 1; //@line 39005
   HEAP32[96441] = $26; //@line 39006
   HEAP32[96445] = $26; //@line 39007
   $$0 = $24 << 1 & 254; //@line 39010
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39015
 HEAP32[96443] = $$0 >>> 7; //@line 39017
 HEAP32[$6 >> 2] = $7 & -256 | $$0; //@line 39020
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39023
 return;
}
function __Z12op_907b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $40 = 0, $8 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18851
 $4 = $3 + 2 | 0; //@line 18852
 HEAP32[162769] = $4; //@line 18853
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 18858
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 18865
 HEAP32[162769] = $3 + 4; //@line 18867
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 18868
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 18874
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18875
 $25 = HEAP32[$24 >> 2] | 0; //@line 18876
 $28 = ($25 << 16 >> 16) - ($23 << 16 >> 16) | 0; //@line 18881
 $30 = $25 >>> 15; //@line 18883
 $sext38$lobit = $28 >>> 15 & 1; //@line 18886
 $sext38$mask = $28 & 65535; //@line 18887
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 18890
 HEAP32[96444] = ($sext38$lobit ^ $30 & 1) & ($30 ^ $23 >>> 15); //@line 18894
 $40 = ($23 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 18898
 HEAP32[96441] = $40; //@line 18899
 HEAP32[96445] = $40; //@line 18900
 HEAP32[96443] = $sext38$lobit; //@line 18901
 HEAP32[$24 >> 2] = $25 & -65536 | $sext38$mask; //@line 18904
 return;
}
function __Z12op_31bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 38554
 $4 = $3 + 2 | 0; //@line 38555
 HEAP32[162769] = $4; //@line 38556
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 38561
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 38568
 HEAP32[162769] = $3 + 4; //@line 38570
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 38571
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 38577
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38579
 $26 = HEAP32[162769] | 0; //@line 38580
 $33 = (HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$26 + 1 >> 0] | 0); //@line 38587
 HEAP32[162769] = $26 + 2; //@line 38589
 $35 = __Z15get_disp_ea_020jj($25, $33) | 0; //@line 38590
 $36 = $23 << 16 >> 16; //@line 38592
 $38 = ($36 | 0) == 0 & 1; //@line 38594
 HEAP32[96441] = 0; //@line 38595
 HEAP32[96442] = 0; //@line 38595
 HEAP32[96443] = 0; //@line 38595
 HEAP32[96444] = 0; //@line 38595
 HEAP32[96442] = $38; //@line 38596
 HEAP32[96443] = $23 >>> 15 & 1; //@line 38599
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 38605
 return;
}
function __Z12op_11bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 26523
 $4 = $3 + 2 | 0; //@line 26524
 HEAP32[162769] = $4; //@line 26525
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 26530
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 26537
 HEAP32[162769] = $3 + 4; //@line 26539
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 26540
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 26546
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26548
 $26 = HEAP32[162769] | 0; //@line 26549
 $33 = (HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$26 + 1 >> 0] | 0); //@line 26556
 HEAP32[162769] = $26 + 2; //@line 26558
 $35 = __Z15get_disp_ea_020jj($25, $33) | 0; //@line 26559
 $36 = $23 << 24 >> 24; //@line 26561
 $38 = ($36 | 0) == 0 & 1; //@line 26563
 HEAP32[96441] = 0; //@line 26564
 HEAP32[96442] = 0; //@line 26564
 HEAP32[96443] = 0; //@line 26564
 HEAP32[96444] = 0; //@line 26564
 HEAP32[96442] = $38; //@line 26565
 HEAP32[96443] = $23 >>> 7 & 1; //@line 26568
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 26574
 return;
}
function _strlen($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$015$lcssa = 0, $$01519 = 0, $$1$lcssa = 0, $$pn = 0, $$sink = 0, $1 = 0, $10 = 0, $19 = 0, $23 = 0, $6 = 0, label = 0;
 $1 = $0; //@line 61825
 L1 : do {
  if (!($1 & 3)) {
   $$015$lcssa = $0; //@line 61830
   label = 4; //@line 61831
  } else {
   $$01519 = $0; //@line 61833
   $23 = $1; //@line 61833
   while (1) {
    if (!(HEAP8[$$01519 >> 0] | 0)) {
     $$sink = $23; //@line 61838
     break L1;
    }
    $6 = $$01519 + 1 | 0; //@line 61841
    $23 = $6; //@line 61842
    if (!($23 & 3)) {
     $$015$lcssa = $6; //@line 61846
     label = 4; //@line 61847
     break;
    } else {
     $$01519 = $6; //@line 61850
    }
   }
  }
 } while (0);
 if ((label | 0) == 4) {
  $$0 = $$015$lcssa; //@line 61856
  while (1) {
   $10 = HEAP32[$$0 >> 2] | 0; //@line 61858
   if (!(($10 & -2139062144 ^ -2139062144) & $10 + -16843009)) {
    $$0 = $$0 + 4 | 0; //@line 61866
   } else {
    break;
   }
  }
  if (!(($10 & 255) << 24 >> 24)) {
   $$1$lcssa = $$0; //@line 61874
  } else {
   $$pn = $$0; //@line 61876
   while (1) {
    $19 = $$pn + 1 | 0; //@line 61878
    if (!(HEAP8[$19 >> 0] | 0)) {
     $$1$lcssa = $19; //@line 61882
     break;
    } else {
     $$pn = $19; //@line 61885
    }
   }
  }
  $$sink = $$1$lcssa; //@line 61890
 }
 return $$sink - $1 | 0; //@line 61893
}
function __Z12op_d170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34434
 $6 = HEAP32[162769] | 0; //@line 34435
 $7 = $6 + 2 | 0; //@line 34436
 HEAP32[162769] = $7; //@line 34437
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34439
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 34446
 HEAP32[162769] = $6 + 4; //@line 34448
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 34449
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 34451
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 34455
 $25 = $24 << 16 >> 16; //@line 34457
 $27 = $25 + ($5 << 16 >> 16) | 0; //@line 34460
 $30 = $27 >>> 15; //@line 34464
 $sext38$lobit = $30 & 1; //@line 34465
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 34469
 HEAP32[96444] = ($sext38$lobit ^ $24 >>> 15 & 1) & ($30 ^ $5 >>> 15); //@line 34473
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 34478
 HEAP32[96441] = $40; //@line 34479
 HEAP32[96445] = $40; //@line 34480
 HEAP32[96443] = $sext38$lobit; //@line 34481
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 34485
 return;
}
function __Z12op_8100_1_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $$neg = 0, $10 = 0, $14 = 0, $16 = 0, $20 = 0, $22 = 0, $26 = 0, $35 = 0, $6 = 0, $7 = 0, $8 = 0, $sext40$mask = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 22411
 $7 = HEAP32[$6 >> 2] | 0; //@line 22412
 $8 = $7 << 24 >> 24; //@line 22414
 $10 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << 24 >> 24; //@line 22417
 $14 = (HEAP32[96445] | 0) != 0; //@line 22421
 $$neg = $14 << 31 >> 31; //@line 22423
 $16 = ($8 & 15) - ($10 & 15) + $$neg | 0; //@line 22424
 $20 = $16 + (($8 & 240) - ($10 & 240)) | 0; //@line 22428
 $22 = ($16 & 240 | 0) == 0; //@line 22430
 $$ = $22 ? $20 : $20 + -6 | 0; //@line 22432
 $26 = ($8 & 255) - ($10 & 255) | 0; //@line 22435
 $$1$in = ($26 - ($14 & 1) & 256 | 0) == 0 ? $$ : $$ + 65440 | 0; //@line 22440
 $35 = ($26 + $$neg + ($22 ? 0 : 1018) & 768 | 0) != 0 & 1; //@line 22446
 HEAP32[96441] = $35; //@line 22447
 HEAP32[96445] = $35; //@line 22448
 $sext40$mask = $$1$in & 255; //@line 22450
 HEAP32[96442] = ($sext40$mask | 0) == 0 & HEAP32[96442]; //@line 22454
 HEAP32[96443] = $$1$in >>> 7 & 1; //@line 22457
 HEAP32[96444] = ($20 & 128 | 0) != 0 & ($$1$in & 128 | 0) == 0 & 1; //@line 22464
 HEAP32[$6 >> 2] = $sext40$mask | $7 & -256; //@line 22467
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 22470
 return;
}
function __Z11op_470_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $28 = 0, $31 = 0, $33 = 0, $42 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10989
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10992
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10997
 $11 = $2 + 4 | 0; //@line 10998
 HEAP32[162769] = $11; //@line 10999
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11001
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11008
 HEAP32[162769] = $2 + 6; //@line 11010
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 11011
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 11013
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 11017
 $31 = ($28 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 11022
 $33 = $28 >>> 15; //@line 11024
 $sext34$lobit = $31 >>> 15 & 1; //@line 11027
 HEAP32[96442] = ($31 & 65535 | 0) == 0 & 1; //@line 11031
 HEAP32[96444] = ($sext34$lobit ^ $33 & 1) & ($33 ^ $5 >>> 7); //@line 11035
 $42 = $10 >>> 0 > ($28 & 65535) >>> 0 & 1; //@line 11038
 HEAP32[96441] = $42; //@line 11039
 HEAP32[96445] = $42; //@line 11040
 HEAP32[96443] = $sext34$lobit; //@line 11041
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $31); //@line 11045
 return;
}
function _fputc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $13 = 0, $14 = 0, $24 = 0, $25 = 0, $31 = 0, $5 = 0, $6 = 0, label = 0;
 $5 = $0 & 255; //@line 2510
 $6 = $0 & 255; //@line 2511
 if ((HEAP32[$1 + 76 >> 2] | 0) < 0) {
  label = 3; //@line 2513
 } else {
  if (!(___lockfile($1) | 0)) {
   label = 3; //@line 2518
  } else {
   if (($6 | 0) == (HEAP8[$1 + 75 >> 0] | 0)) {
    label = 10; //@line 2525
   } else {
    $24 = $1 + 20 | 0; //@line 2527
    $25 = HEAP32[$24 >> 2] | 0; //@line 2528
    if ($25 >>> 0 < (HEAP32[$1 + 16 >> 2] | 0) >>> 0) {
     HEAP32[$24 >> 2] = $25 + 1; //@line 2534
     HEAP8[$25 >> 0] = $5; //@line 2535
     $31 = $6; //@line 2536
    } else {
     label = 10; //@line 2538
    }
   }
   if ((label | 0) == 10) {
    $31 = ___overflow($1, $0) | 0; //@line 2543
   }
   ___unlockfile($1); //@line 2545
   $$0 = $31; //@line 2546
  }
 }
 do {
  if ((label | 0) == 3) {
   if (($6 | 0) != (HEAP8[$1 + 75 >> 0] | 0)) {
    $13 = $1 + 20 | 0; //@line 2556
    $14 = HEAP32[$13 >> 2] | 0; //@line 2557
    if ($14 >>> 0 < (HEAP32[$1 + 16 >> 2] | 0) >>> 0) {
     HEAP32[$13 >> 2] = $14 + 1; //@line 2563
     HEAP8[$14 >> 0] = $5; //@line 2564
     $$0 = $6; //@line 2565
     break;
    }
   }
   $$0 = ___overflow($1, $0) | 0; //@line 2570
  }
 } while (0);
 return $$0 | 0; //@line 2573
}
function __Z12op_9070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $5 = 0, $7 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 18595
 $5 = $4 + 2 | 0; //@line 18596
 HEAP32[162769] = $5; //@line 18597
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18599
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 18606
 HEAP32[162769] = $4 + 4; //@line 18608
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 18609
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 18615
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18616
 $24 = HEAP32[$23 >> 2] | 0; //@line 18617
 $27 = ($24 << 16 >> 16) - ($22 << 16 >> 16) | 0; //@line 18622
 $29 = $24 >>> 15; //@line 18624
 $sext39$lobit = $27 >>> 15 & 1; //@line 18627
 $sext39$mask = $27 & 65535; //@line 18628
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 18631
 HEAP32[96444] = ($sext39$lobit ^ $29 & 1) & ($29 ^ $22 >>> 15); //@line 18635
 $39 = ($22 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 18639
 HEAP32[96441] = $39; //@line 18640
 HEAP32[96445] = $39; //@line 18641
 HEAP32[96443] = $sext39$lobit; //@line 18642
 HEAP32[$23 >> 2] = $24 & -65536 | $sext39$mask; //@line 18645
 return;
}
function __Z12op_903b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $40 = 0, $8 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18172
 $4 = $3 + 2 | 0; //@line 18173
 HEAP32[162769] = $4; //@line 18174
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 18179
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 18186
 HEAP32[162769] = $3 + 4; //@line 18188
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 18189
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 18195
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18196
 $25 = HEAP32[$24 >> 2] | 0; //@line 18197
 $28 = ($25 << 24 >> 24) - ($23 << 24 >> 24) | 0; //@line 18202
 $30 = $25 >>> 7; //@line 18204
 $sext34$lobit = $28 >>> 7 & 1; //@line 18207
 $sext34$mask = $28 & 255; //@line 18208
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 18211
 HEAP32[96444] = ($sext34$lobit ^ $30 & 1) & ($30 ^ $23 >>> 7); //@line 18215
 $40 = ($23 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 18219
 HEAP32[96441] = $40; //@line 18220
 HEAP32[96445] = $40; //@line 18221
 HEAP32[96443] = $sext34$lobit; //@line 18222
 HEAP32[$24 >> 2] = $25 & -256 | $sext34$mask; //@line 18225
 return;
}
function __Z12op_31b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $32 = 0, $34 = 0, $35 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 38309
 $5 = $4 + 2 | 0; //@line 38310
 HEAP32[162769] = $5; //@line 38311
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38313
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 38320
 HEAP32[162769] = $4 + 4; //@line 38322
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 38323
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 38329
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38331
 $25 = HEAP32[162769] | 0; //@line 38332
 $32 = (HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0); //@line 38339
 HEAP32[162769] = $25 + 2; //@line 38341
 $34 = __Z15get_disp_ea_020jj($24, $32) | 0; //@line 38342
 $35 = $22 << 16 >> 16; //@line 38344
 $37 = ($35 | 0) == 0 & 1; //@line 38346
 HEAP32[96441] = 0; //@line 38347
 HEAP32[96442] = 0; //@line 38347
 HEAP32[96443] = 0; //@line 38347
 HEAP32[96444] = 0; //@line 38347
 HEAP32[96442] = $37; //@line 38348
 HEAP32[96443] = $22 >>> 15 & 1; //@line 38351
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($34, $35); //@line 38357
 return;
}
function __Z12op_11b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $32 = 0, $34 = 0, $35 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 26278
 $5 = $4 + 2 | 0; //@line 26279
 HEAP32[162769] = $5; //@line 26280
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26282
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 26289
 HEAP32[162769] = $4 + 4; //@line 26291
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 26292
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 26298
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26300
 $25 = HEAP32[162769] | 0; //@line 26301
 $32 = (HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0); //@line 26308
 HEAP32[162769] = $25 + 2; //@line 26310
 $34 = __Z15get_disp_ea_020jj($24, $32) | 0; //@line 26311
 $35 = $22 << 24 >> 24; //@line 26313
 $37 = ($35 | 0) == 0 & 1; //@line 26315
 HEAP32[96441] = 0; //@line 26316
 HEAP32[96442] = 0; //@line 26316
 HEAP32[96443] = 0; //@line 26316
 HEAP32[96444] = 0; //@line 26316
 HEAP32[96442] = $37; //@line 26317
 HEAP32[96443] = $22 >>> 7 & 1; //@line 26320
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, $35); //@line 26326
 return;
}
function __ZN8tinyxml210XMLUnknown9ParseDeepEPcPNS_7StrPairE($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$i7 = 0, $$01921$i = 0, $$pre$i$i$i = 0, $10 = 0, $12 = 0, $18 = 0, $3 = 0, $6 = 0, $lhsc = 0;
 $3 = HEAP8[$1 >> 0] | 0; //@line 39296
 L1 : do {
  if ($3 << 24 >> 24) {
   $$01921$i = $1; //@line 39300
   $lhsc = $3; //@line 39300
   while (1) {
    if ($lhsc << 24 >> 24 == 62) {
     break;
    }
    $12 = $$01921$i + 1 | 0; //@line 39306
    $lhsc = HEAP8[$12 >> 0] | 0; //@line 39307
    if (!($lhsc << 24 >> 24)) {
     break L1;
    } else {
     $$01921$i = $12; //@line 39312
    }
   }
   $6 = $0 + 12 | 0; //@line 39315
   $$pre$i$i$i = $0 + 16 | 0; //@line 39319
   if (HEAP32[$6 >> 2] & 512 | 0) {
    $10 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 39321
    if ($10 | 0) {
     __ZdaPv($10); //@line 39324
    }
   }
   HEAP32[$$pre$i$i$i >> 2] = $1; //@line 39328
   HEAP32[$0 + 20 >> 2] = $$01921$i; //@line 39329
   HEAP32[$6 >> 2] = 258; //@line 39330
   $$0$i7 = $$01921$i + 1 | 0; //@line 39332
   return $$0$i7 | 0; //@line 39333
  }
 } while (0);
 $18 = HEAP32[$0 + 4 >> 2] | 0; //@line 39337
 HEAP32[$18 + 48 >> 2] = 14; //@line 39339
 HEAP32[$18 + 56 >> 2] = $1; //@line 39341
 HEAP32[$18 + 60 >> 2] = 0; //@line 39343
 $$0$i7 = 0; //@line 39344
 return $$0$i7 | 0; //@line 39345
}
function __Z12op_d130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33885
 $6 = HEAP32[162769] | 0; //@line 33886
 $7 = $6 + 2 | 0; //@line 33887
 HEAP32[162769] = $7; //@line 33888
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33890
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 33897
 HEAP32[162769] = $6 + 4; //@line 33899
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 33900
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 33902
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 33906
 $25 = $24 << 24 >> 24; //@line 33908
 $27 = $25 + ($5 << 24 >> 24) | 0; //@line 33911
 $30 = $27 >>> 7; //@line 33915
 $sext34$lobit = $30 & 1; //@line 33916
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 33920
 HEAP32[96444] = ($sext34$lobit ^ $24 >>> 7 & 1) & ($30 ^ $5 >>> 7); //@line 33924
 $40 = ($25 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 33929
 HEAP32[96441] = $40; //@line 33930
 HEAP32[96445] = $40; //@line 33931
 HEAP32[96443] = $sext34$lobit; //@line 33932
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 33936
 return;
}
function __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$2 = 0, $3 = 0, $6 = 0, dest = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 3592
 STACKTOP = STACKTOP + 64 | 0; //@line 3593
 $3 = sp; //@line 3594
 if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, $1, 0) | 0) {
  $$2 = 1; //@line 3597
 } else {
  if (!$1) {
   $$2 = 0; //@line 3601
  } else {
   $6 = ___dynamic_cast($1, 320, 304, 0) | 0; //@line 3603
   if (!$6) {
    $$2 = 0; //@line 3606
   } else {
    dest = $3 + 4 | 0; //@line 3609
    stop = dest + 52 | 0; //@line 3609
    do {
     HEAP32[dest >> 2] = 0; //@line 3609
     dest = dest + 4 | 0; //@line 3609
    } while ((dest | 0) < (stop | 0));
    HEAP32[$3 >> 2] = $6; //@line 3610
    HEAP32[$3 + 8 >> 2] = $0; //@line 3612
    HEAP32[$3 + 12 >> 2] = -1; //@line 3614
    HEAP32[$3 + 48 >> 2] = 1; //@line 3616
    FUNCTION_TABLE_viiii[HEAP32[(HEAP32[$6 >> 2] | 0) + 28 >> 2] & 3]($6, $3, HEAP32[$2 >> 2] | 0, 1); //@line 3621
    if ((HEAP32[$3 + 24 >> 2] | 0) == 1) {
     HEAP32[$2 >> 2] = HEAP32[$3 + 16 >> 2]; //@line 3628
     $$0 = 1; //@line 3629
    } else {
     $$0 = 0; //@line 3631
    }
    $$2 = $$0; //@line 3633
   }
  }
 }
 STACKTOP = sp; //@line 3637
 return $$2 | 0; //@line 3637
}
function __Z12op_4070_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $5 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 40663
 $3 = $2 + 2 | 0; //@line 40664
 HEAP32[162769] = $3; //@line 40665
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40667
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 40674
 HEAP32[162769] = $2 + 4; //@line 40676
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 40677
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40679
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40683
 $24 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($20 << 16 >> 16) | 0; //@line 40689
 $25 = $20 >>> 15; //@line 40690
 $sext$lobit = $25 & 1; //@line 40691
 $26 = $24 >>> 15; //@line 40692
 $sext32$lobit = $26 & 1; //@line 40693
 HEAP32[96444] = $sext32$lobit & $25; //@line 40695
 $30 = ($sext32$lobit ^ $sext$lobit) & $26 ^ $sext$lobit; //@line 40698
 HEAP32[96441] = $30; //@line 40699
 HEAP32[96445] = $30; //@line 40700
 HEAP32[96442] = ($24 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40706
 HEAP32[96443] = $sext32$lobit; //@line 40707
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $24); //@line 40711
 return;
}
function __ZL13mode_from_strPKc($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if (!(_strncmp($0, 106180, 4) | 0)) {
  $$0 = 0; //@line 54821
 } else {
  if (!(_strncmp($0, 106185, 4) | 0)) {
   $$0 = 1; //@line 54826
  } else {
   if (!(_strncmp($0, 106190, 4) | 0)) {
    $$0 = 2; //@line 54831
   } else {
    if (!(_strncmp($0, 106195, 4) | 0)) {
     $$0 = 4; //@line 54836
    } else {
     if (!(_strncmp($0, 106200, 4) | 0)) {
      $$0 = 3; //@line 54841
     } else {
      if (!(_strncmp($0, 106205, 4) | 0)) {
       $$0 = 5; //@line 54846
      } else {
       if (!(_strncmp($0, 106210, 4) | 0)) {
        $$0 = 6; //@line 54851
       } else {
        if (!(_strncmp($0, 106215, 4) | 0)) {
         $$0 = 7; //@line 54856
        } else {
         if (!(_strncmp($0, 106220, 4) | 0)) {
          $$0 = 8; //@line 54861
         } else {
          if (!(_strncmp($0, 106225, 4) | 0)) {
           $$0 = 9; //@line 54866
          } else {
           if (!(_strncmp($0, 106230, 4) | 0)) {
            $$0 = 10; //@line 54871
           } else {
            if (!(_strncmp($0, 106235, 4) | 0)) {
             $$0 = 11; //@line 54876
            } else {
             _abort(); //@line 54878
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 return $$0 | 0; //@line 54892
}
function __Z12op_9030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $5 = 0, $7 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 17916
 $5 = $4 + 2 | 0; //@line 17917
 HEAP32[162769] = $5; //@line 17918
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 17920
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 17927
 HEAP32[162769] = $4 + 4; //@line 17929
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 17930
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 17936
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17937
 $24 = HEAP32[$23 >> 2] | 0; //@line 17938
 $27 = ($24 << 24 >> 24) - ($22 << 24 >> 24) | 0; //@line 17943
 $29 = $24 >>> 7; //@line 17945
 $sext35$lobit = $27 >>> 7 & 1; //@line 17948
 $sext35$mask = $27 & 255; //@line 17949
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 17952
 HEAP32[96444] = ($sext35$lobit ^ $29 & 1) & ($29 ^ $22 >>> 7); //@line 17956
 $39 = ($22 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 17960
 HEAP32[96441] = $39; //@line 17961
 HEAP32[96445] = $39; //@line 17962
 HEAP32[96443] = $sext35$lobit; //@line 17963
 HEAP32[$23 >> 2] = $24 & -256 | $sext35$mask; //@line 17966
 return;
}
function __Z12op_4030_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $30 = 0, $5 = 0, $sext$lobit = 0, $sext30$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 40239
 $3 = $2 + 2 | 0; //@line 40240
 HEAP32[162769] = $3; //@line 40241
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40243
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 40250
 HEAP32[162769] = $2 + 4; //@line 40252
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 40253
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40255
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 40259
 $24 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($20 << 24 >> 24) | 0; //@line 40265
 $25 = $20 >>> 7; //@line 40266
 $sext$lobit = $25 & 1; //@line 40267
 $26 = $24 >>> 7; //@line 40268
 $sext30$lobit = $26 & 1; //@line 40269
 HEAP32[96444] = $sext30$lobit & $25; //@line 40271
 $30 = ($sext30$lobit ^ $sext$lobit) & $26 ^ $sext$lobit; //@line 40274
 HEAP32[96441] = $30; //@line 40275
 HEAP32[96445] = $30; //@line 40276
 HEAP32[96442] = ($24 & 255 | 0) == 0 & HEAP32[96442]; //@line 40282
 HEAP32[96443] = $sext30$lobit; //@line 40283
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $24); //@line 40287
 return;
}
function __Z12op_33fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $30 = 0, $39 = 0, $40 = 0, $42 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 39868
 $2 = $1 + 2 | 0; //@line 39869
 HEAP32[162769] = $2; //@line 39870
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 39875
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 39882
 HEAP32[162769] = $1 + 4; //@line 39884
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 39885
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 39891
 $22 = HEAP32[162769] | 0; //@line 39892
 $30 = (HEAPU8[$22 + 1 >> 0] | 0) << 16 | (HEAPU8[$22 >> 0] | 0) << 24; //@line 39900
 $39 = $30 | (HEAPU8[$22 + 2 >> 0] | 0) << 8 | (HEAPU8[$22 + 3 >> 0] | 0); //@line 39909
 $40 = $21 << 16 >> 16; //@line 39911
 $42 = ($40 | 0) == 0 & 1; //@line 39913
 HEAP32[96441] = 0; //@line 39914
 HEAP32[96442] = 0; //@line 39914
 HEAP32[96443] = 0; //@line 39914
 HEAP32[96444] = 0; //@line 39914
 HEAP32[96442] = $42; //@line 39915
 HEAP32[96443] = $21 >>> 15 & 1; //@line 39918
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($39, $40); //@line 39924
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 39927
 return;
}
function __Z12op_13fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $30 = 0, $39 = 0, $40 = 0, $42 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 27747
 $2 = $1 + 2 | 0; //@line 27748
 HEAP32[162769] = $2; //@line 27749
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 27754
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 27761
 HEAP32[162769] = $1 + 4; //@line 27763
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 27764
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 27770
 $22 = HEAP32[162769] | 0; //@line 27771
 $30 = (HEAPU8[$22 + 1 >> 0] | 0) << 16 | (HEAPU8[$22 >> 0] | 0) << 24; //@line 27779
 $39 = $30 | (HEAPU8[$22 + 2 >> 0] | 0) << 8 | (HEAPU8[$22 + 3 >> 0] | 0); //@line 27788
 $40 = $21 << 24 >> 24; //@line 27790
 $42 = ($40 | 0) == 0 & 1; //@line 27792
 HEAP32[96441] = 0; //@line 27793
 HEAP32[96442] = 0; //@line 27793
 HEAP32[96443] = 0; //@line 27793
 HEAP32[96444] = 0; //@line 27793
 HEAP32[96442] = $42; //@line 27794
 HEAP32[96443] = $21 >>> 7 & 1; //@line 27797
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($39, $40); //@line 27803
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27806
 return;
}
function __Z11op_4f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $26 = 0, $29 = 0, $34 = 0, $35 = 0, $40 = 0, $5 = 0, $50 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 11976
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 11979
 $$cast = $2; //@line 11980
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 11983
 $17 = (HEAPU8[$$cast + 5 >> 0] | 0) << 16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 24; //@line 11992
 $26 = $17 | (HEAPU8[$$cast + 6 >> 0] | 0) << 8 | (HEAPU8[$$cast + 7 >> 0] | 0); //@line 12001
 $29 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 12004
 $34 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($26) | 0; //@line 12009
 $35 = $26 + 4 | 0; //@line 12010
 $40 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($35 >>> 16 << 2) >> 2] >> 2] & 127]($35) | 0; //@line 12015
 HEAP32[96442] = (($34 | 0) == ($29 | 0) | ($40 | 0) == ($29 | 0)) & 1; //@line 12020
 if (($34 | 0) > ($40 | 0)) {
  $50 = ($29 | 0) < ($34 | 0) | ($29 | 0) > ($40 | 0); //@line 12026
 } else {
  $50 = ($29 | 0) < ($34 | 0) | ($29 | 0) > ($40 | 0); //@line 12031
 }
 HEAP32[96441] = $50 & 1; //@line 12034
 if (($8 & 8 | 0) != 0 & $50) {
  __Z9Exceptionij(6, $5); //@line 12039
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 12044
  return;
 }
}
function __Z12op_efc0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $36 = 0, $5 = 0, $50 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 47557
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 47560
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 47566
 $11 = $sext >> 16; //@line 47567
 $14 = $sext >> 22; //@line 47570
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 47573
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 47578
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 47583
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 47588
 }
 $26 = $25 + 31 & 31; //@line 47591
 $27 = 651008 + (($0 & 7) << 2) | 0; //@line 47592
 $28 = HEAP32[$27 >> 2] | 0; //@line 47593
 $29 = $30 & 31; //@line 47594
 HEAP32[96444] = 0; //@line 47597
 HEAP32[96441] = 0; //@line 47598
 $36 = HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] | 0; //@line 47602
 HEAP32[96443] = ($36 & 1 << $26 | 0) != 0 & 1; //@line 47606
 HEAP32[96442] = ($36 | 0) == 0 & 1; //@line 47609
 $50 = $29 + 1 + $26 | 0; //@line 47618
 HEAP32[$27 >> 2] = ($50 >>> 0 > 31 ? 0 : -1 >>> $50 & $28) | $28 & (($29 | 0) == 0 ? 0 : -1 << 32 - $29) | $36 << ($26 ^ 31) >>> $29; //@line 47625
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47628
 return;
}
function __Z12op_d07b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $31 = 0, $4 = 0, $41 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 36666
 $$cast = $4; //@line 36671
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36680
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36686
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36687
 $25 = HEAP32[$24 >> 2] | 0; //@line 36688
 $26 = $25 << 16 >> 16; //@line 36690
 $28 = $26 + ($23 << 16 >> 16) | 0; //@line 36693
 $31 = $28 >>> 15; //@line 36697
 $sext38$lobit = $31 & 1; //@line 36698
 $sext38$mask = $28 & 65535; //@line 36699
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 36702
 HEAP32[96444] = ($sext38$lobit ^ $25 >>> 15 & 1) & ($31 ^ $23 >>> 15); //@line 36706
 $41 = ($26 & 65535 ^ 65535) >>> 0 < ($23 & 65535) >>> 0 & 1; //@line 36711
 HEAP32[96441] = $41; //@line 36712
 HEAP32[96445] = $41; //@line 36713
 HEAP32[96443] = $sext38$lobit; //@line 36714
 HEAP32[$24 >> 2] = $25 & -65536 | $sext38$mask; //@line 36717
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36720
 return;
}
function __Z12op_b108_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $23 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $sext$lobit = 0, $sext39$lobit = 0;
 $1 = $0 & 7; //@line 26207
 $3 = $0 >>> 9 & 7; //@line 26209
 $4 = 651040 + ($1 << 2) | 0; //@line 26210
 $5 = HEAP32[$4 >> 2] | 0; //@line 26211
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 26217
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 26222
 $16 = 651040 + ($3 << 2) | 0; //@line 26223
 $17 = HEAP32[$16 >> 2] | 0; //@line 26224
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 26230
 HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 26235
 $28 = $23 - $11 | 0; //@line 26236
 $sext$lobit = $23 >>> 7 & 1; //@line 26240
 $sext39$lobit = $28 >>> 7 & 1; //@line 26242
 HEAP32[96442] = ($28 & 255 | 0) == 0 & 1; //@line 26246
 HEAP32[96444] = ($11 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext39$lobit | 0) != ($sext$lobit | 0) & 1; //@line 26251
 HEAP32[96441] = ($11 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 26256
 HEAP32[96443] = $sext39$lobit; //@line 26257
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26260
 return;
}
function __Z11op_2d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $12 = 0, $13 = 0, $16 = 0, $23 = 0, $24 = 0, $3 = 0, $31 = 0, $44 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 9636
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 9639
 $9 = HEAPU8[$3 + 2 >> 0] | 0; //@line 9643
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9646
 $13 = $9 << 24 >> 16; //@line 9647
 $16 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 9650
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0) << 16 >> 16; //@line 9658
 $24 = $12 + 2 | 0; //@line 9659
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($24) | 0) << 16 >> 16; //@line 9667
 $$042 = ($13 & 32768 | 0) == 0 ? $16 << 16 >> 16 : $16; //@line 9672
 HEAP32[96442] = (($23 | 0) == ($$042 | 0) | ($31 | 0) == ($$042 | 0)) & 1; //@line 9677
 if (($23 | 0) > ($31 | 0)) {
  $44 = ($$042 | 0) < ($23 | 0) | ($$042 | 0) > ($31 | 0); //@line 9683
 } else {
  $44 = ($$042 | 0) < ($23 | 0) | ($$042 | 0) > ($31 | 0); //@line 9688
 }
 HEAP32[96441] = $44 & 1; //@line 9691
 if (($13 & 2048 | 0) != 0 & $44) {
  __Z9Exceptionij(6, $6); //@line 9696
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9701
  return;
 }
}
function __Z12op_5070_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4164
 $6 = HEAP32[162769] | 0; //@line 4166
 $7 = $6 + 2 | 0; //@line 4167
 HEAP32[162769] = $7; //@line 4168
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4170
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 4177
 HEAP32[162769] = $6 + 4; //@line 4179
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 4180
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 4182
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 4186
 $25 = $24 << 16 >> 16; //@line 4188
 $27 = $25 + ($4 << 16 >> 16) | 0; //@line 4191
 $30 = $27 >>> 15; //@line 4195
 $sext38$lobit = $30 & 1; //@line 4196
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 4200
 HEAP32[96444] = ($sext38$lobit ^ $24 >>> 15 & 1) & ($30 ^ $4 >>> 15); //@line 4204
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4209
 HEAP32[96441] = $40; //@line 4210
 HEAP32[96445] = $40; //@line 4211
 HEAP32[96443] = $sext38$lobit; //@line 4212
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 4216
 return;
}
function __Z11op_630_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $19 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $38 = 0, $4 = 0, $6 = 0, $8 = 0, $sext29$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12476
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 12478
 $6 = $2 + 4 | 0; //@line 12480
 HEAP32[162769] = $6; //@line 12481
 $8 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 12483
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 12490
 HEAP32[162769] = $2 + 6; //@line 12492
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 12493
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 12495
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 12499
 $24 = $23 << 24 >> 24; //@line 12501
 $26 = $24 + ($4 << 24 >> 24) | 0; //@line 12503
 $29 = $26 >>> 7; //@line 12508
 $sext29$lobit = $29 & 1; //@line 12509
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 12513
 HEAP32[96444] = ($sext29$lobit ^ $23 >>> 7 & 1) & ($29 ^ ($4 & 255) >>> 7 & 255); //@line 12517
 $38 = ($24 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12521
 HEAP32[96441] = $38; //@line 12522
 HEAP32[96445] = $38; //@line 12523
 HEAP32[96443] = $sext29$lobit; //@line 12524
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 12528
 return;
}
function __Z10op_d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$042 = 0, $12 = 0, $13 = 0, $16 = 0, $23 = 0, $24 = 0, $3 = 0, $31 = 0, $44 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 5902
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 5905
 $9 = HEAPU8[$3 + 2 >> 0] | 0; //@line 5909
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5912
 $13 = $9 << 24 >> 16; //@line 5913
 $16 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 5916
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0) << 24 >> 24; //@line 5924
 $24 = $12 + 1 | 0; //@line 5925
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($24) | 0) << 24 >> 24; //@line 5933
 $$042 = ($13 & 32768 | 0) == 0 ? $16 << 24 >> 24 : $16; //@line 5938
 HEAP32[96442] = (($23 | 0) == ($$042 | 0) | ($31 | 0) == ($$042 | 0)) & 1; //@line 5943
 if (($23 | 0) > ($31 | 0)) {
  $44 = ($$042 | 0) < ($23 | 0) | ($$042 | 0) > ($31 | 0); //@line 5949
 } else {
  $44 = ($$042 | 0) < ($23 | 0) | ($$042 | 0) > ($31 | 0); //@line 5954
 }
 HEAP32[96441] = $44 & 1; //@line 5957
 if (($13 & 2048 | 0) != 0 & $44) {
  __Z9Exceptionij(6, $6); //@line 5962
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5967
  return;
 }
}
function __Z12op_8188_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $19 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $33 = 0, $34 = 0, $42 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 16516
 $3 = $0 >>> 9 & 7; //@line 16518
 $6 = 651040 + ($1 << 2) | 0; //@line 16521
 $8 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 16523
 HEAP32[$6 >> 2] = $8; //@line 16524
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 16530
 $19 = HEAP32[162769] | 0; //@line 16535
 $28 = ((HEAPU8[$19 + 2 >> 0] | 0) << 8 | (HEAPU8[$19 + 3 >> 0] | 0)) + ($14 << 4 & 3840 | $14 & 15) | 0; //@line 16544
 $29 = 5656 + ($3 << 2) | 0; //@line 16545
 $31 = 651040 + ($3 << 2) | 0; //@line 16547
 $33 = (HEAP32[$31 >> 2] | 0) - (HEAP32[$29 >> 2] | 0) | 0; //@line 16549
 HEAP32[$31 >> 2] = $33; //@line 16550
 $34 = $28 & 65535; //@line 16551
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($33, $34); //@line 16557
 $42 = (HEAP32[$31 >> 2] | 0) - (HEAP32[$29 >> 2] | 0) | 0; //@line 16560
 HEAP32[$31 >> 2] = $42; //@line 16561
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($42 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($42, $34 >>> 8); //@line 16568
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16571
 return;
}
function __Z9CDROMInitv() {
 var $0 = 0, $12 = 0, $15 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 19687
 STACKTOP = STACKTOP + 848 | 0; //@line 19688
 $0 = sp; //@line 19689
 if (!(__Z15PrefsFindStringPKci(95141, 0) | 0)) {
  __Z16SysAddCDROMPrefsv(); //@line 19693
 }
 $3 = __Z15PrefsFindStringPKci(95141, 0) | 0; //@line 19695
 if (!$3) {
  STACKTOP = sp; //@line 19698
  return;
 }
 $5 = $0 + 4 | 0; //@line 19700
 $6 = $0 + 16 | 0; //@line 19701
 $7 = $0 + 836 | 0; //@line 19702
 $12 = 1; //@line 19703
 $8 = $3; //@line 19703
 while (1) {
  $9 = __Z8Sys_openPKcb($8, 1) | 0; //@line 19705
  if ($9 | 0) {
   HEAP32[$0 >> 2] = 0; //@line 19708
   HEAP32[$5 >> 2] = $9; //@line 19709
   HEAP32[$6 >> 2] = 0; //@line 19710
   HEAP32[$7 >> 2] = 0; //@line 19711
   $15 = HEAP32[28494] | 0; //@line 19712
   if (($15 | 0) == (HEAP32[28495] | 0)) {
    __ZNSt3__26vectorI16cdrom_drive_infoNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_(113972, $0); //@line 19716
   } else {
    _memcpy($15 | 0, $0 | 0, 840) | 0; //@line 19718
    HEAP32[28494] = $15 + 840; //@line 19720
   }
  }
  $8 = __Z15PrefsFindStringPKci(95141, $12) | 0; //@line 19724
  if (!$8) {
   break;
  } else {
   $12 = $12 + 1 | 0; //@line 19729
  }
 }
 STACKTOP = sp; //@line 19732
 return;
}
function __Z12op_33f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $3 = 0, $38 = 0, $39 = 0, $41 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 39602
 $3 = $2 + 2 | 0; //@line 39603
 HEAP32[162769] = $3; //@line 39604
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 39606
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 39613
 HEAP32[162769] = $2 + 4; //@line 39615
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 39616
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 39622
 $21 = HEAP32[162769] | 0; //@line 39623
 $29 = (HEAPU8[$21 + 1 >> 0] | 0) << 16 | (HEAPU8[$21 >> 0] | 0) << 24; //@line 39631
 $38 = $29 | (HEAPU8[$21 + 2 >> 0] | 0) << 8 | (HEAPU8[$21 + 3 >> 0] | 0); //@line 39640
 $39 = $20 << 16 >> 16; //@line 39642
 $41 = ($39 | 0) == 0 & 1; //@line 39644
 HEAP32[96441] = 0; //@line 39645
 HEAP32[96442] = 0; //@line 39645
 HEAP32[96443] = 0; //@line 39645
 HEAP32[96444] = 0; //@line 39645
 HEAP32[96442] = $41; //@line 39646
 HEAP32[96443] = $20 >>> 15 & 1; //@line 39649
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($38, $39); //@line 39655
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 39658
 return;
}
function __Z11op_e20_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $16 = 0, $19 = 0, $30 = 0, $33 = 0, $35 = 0, $37 = 0, $7 = 0, $9 = 0;
 $1 = $0 & 7; //@line 21287
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21291
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21297
 $9 = $7 << 24 >> 16; //@line 21299
 $12 = 651040 + ($1 << 2) | 0; //@line 21302
 $16 = (HEAP32[$12 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 21306
 do {
  if (!($9 & 2048)) {
   $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 21314
   HEAP32[$12 >> 2] = $16; //@line 21315
   $33 = $30 << 24 >> 24; //@line 21319
   $35 = $7 >>> 4 & 7; //@line 21321
   if (!($9 & 32768)) {
    $37 = 651008 + ($35 << 2) | 0; //@line 21323
    HEAP32[$37 >> 2] = HEAP32[$37 >> 2] & -256 | $33 & 255; //@line 21328
    break;
   } else {
    HEAP32[651040 + ($35 << 2) >> 2] = $33; //@line 21332
    break;
   }
  } else {
   $19 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 21338
   HEAP32[$12 >> 2] = $16; //@line 21339
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, $19); //@line 21345
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21350
 return;
}
function __Z12op_80c0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $15 = 0, $17 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $sext$mask = 0, $sext$mask34 = 0;
 $4 = HEAP32[162768] | 0; //@line 14925
 $5 = HEAP32[162769] | 0; //@line 14926
 $6 = HEAP32[162770] | 0; //@line 14927
 $8 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 14929
 $9 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14930
 $10 = HEAP32[$9 >> 2] | 0; //@line 14931
 HEAP32[162769] = $5 + 2; //@line 14934
 $sext$mask = $8 & 65535; //@line 14935
 if (!$sext$mask) {
  HEAP32[96444] = 0; //@line 14940
  __Z9Exceptionij(5, $5 + $4 - $6 | 0); //@line 14941
  return;
 }
 $15 = ($10 >>> 0) / ($sext$mask >>> 0) | 0; //@line 14944
 if ($15 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 14947
  HEAP32[96443] = 1; //@line 14948
  HEAP32[96441] = 0; //@line 14949
  return;
 } else {
  $17 = ($10 >>> 0) % ($sext$mask >>> 0) | 0; //@line 14952
  $sext$mask34 = $15 & 65535; //@line 14953
  $19 = ($sext$mask34 | 0) == 0 & 1; //@line 14955
  HEAP32[96441] = 0; //@line 14956
  HEAP32[96442] = 0; //@line 14956
  HEAP32[96443] = 0; //@line 14956
  HEAP32[96444] = 0; //@line 14956
  HEAP32[96442] = $19; //@line 14957
  HEAP32[96443] = $15 >>> 15 & 1; //@line 14960
  HEAP32[$9 >> 2] = $17 << 16 | $sext$mask34; //@line 14963
  return;
 }
}
function __Z12op_13f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $3 = 0, $38 = 0, $39 = 0, $41 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 27481
 $3 = $2 + 2 | 0; //@line 27482
 HEAP32[162769] = $3; //@line 27483
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27485
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 27492
 HEAP32[162769] = $2 + 4; //@line 27494
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 27495
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 27501
 $21 = HEAP32[162769] | 0; //@line 27502
 $29 = (HEAPU8[$21 + 1 >> 0] | 0) << 16 | (HEAPU8[$21 >> 0] | 0) << 24; //@line 27510
 $38 = $29 | (HEAPU8[$21 + 2 >> 0] | 0) << 8 | (HEAPU8[$21 + 3 >> 0] | 0); //@line 27519
 $39 = $20 << 24 >> 24; //@line 27521
 $41 = ($39 | 0) == 0 & 1; //@line 27523
 HEAP32[96441] = 0; //@line 27524
 HEAP32[96442] = 0; //@line 27524
 HEAP32[96443] = 0; //@line 27524
 HEAP32[96444] = 0; //@line 27524
 HEAP32[96442] = $41; //@line 27525
 HEAP32[96443] = $20 >>> 7 & 1; //@line 27528
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($38, $39); //@line 27534
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27537
 return;
}
function __Z12op_d07a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $32 = 0, $4 = 0, $42 = 0, $sext37$lobit = 0, $sext37$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 32392
 $$cast = $4; //@line 32394
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 32408
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 32414
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32415
 $26 = HEAP32[$25 >> 2] | 0; //@line 32416
 $27 = $26 << 16 >> 16; //@line 32418
 $29 = $27 + ($24 << 16 >> 16) | 0; //@line 32421
 $32 = $29 >>> 15; //@line 32425
 $sext37$lobit = $32 & 1; //@line 32426
 $sext37$mask = $29 & 65535; //@line 32427
 HEAP32[96442] = ($sext37$mask | 0) == 0 & 1; //@line 32430
 HEAP32[96444] = ($sext37$lobit ^ $26 >>> 15 & 1) & ($32 ^ $24 >>> 15); //@line 32434
 $42 = ($27 & 65535 ^ 65535) >>> 0 < ($24 & 65535) >>> 0 & 1; //@line 32439
 HEAP32[96441] = $42; //@line 32440
 HEAP32[96445] = $42; //@line 32441
 HEAP32[96443] = $sext37$lobit; //@line 32442
 HEAP32[$25 >> 2] = $26 & -65536 | $sext37$mask; //@line 32445
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32448
 return;
}
function __Z12op_80fc_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $13 = 0, $14 = 0, $15 = 0, $20 = 0, $22 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $sext$mask30 = 0;
 $3 = HEAP32[162768] | 0; //@line 15555
 $4 = HEAP32[162769] | 0; //@line 15556
 $5 = HEAP32[162770] | 0; //@line 15557
 $$cast = $4; //@line 15558
 $13 = (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 15566
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15567
 $15 = HEAP32[$14 >> 2] | 0; //@line 15568
 HEAP32[162769] = $$cast + 4; //@line 15570
 if (!$13) {
  HEAP32[96444] = 0; //@line 15575
  __Z9Exceptionij(5, $4 + $3 - $5 | 0); //@line 15576
  return;
 }
 $20 = ($15 >>> 0) / ($13 >>> 0) | 0; //@line 15579
 if ($20 >>> 0 > 65535) {
  HEAP32[96444] = 1; //@line 15582
  HEAP32[96443] = 1; //@line 15583
  HEAP32[96441] = 0; //@line 15584
  return;
 } else {
  $22 = ($15 >>> 0) % ($13 >>> 0) | 0; //@line 15587
  $sext$mask30 = $20 & 65535; //@line 15588
  $24 = ($sext$mask30 | 0) == 0 & 1; //@line 15590
  HEAP32[96441] = 0; //@line 15591
  HEAP32[96442] = 0; //@line 15591
  HEAP32[96443] = 0; //@line 15591
  HEAP32[96444] = 0; //@line 15591
  HEAP32[96442] = $24; //@line 15592
  HEAP32[96443] = $20 >>> 15 & 1; //@line 15595
  HEAP32[$14 >> 2] = $22 << 16 | $sext$mask30; //@line 15598
  return;
 }
}
function __Z12op_d03b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $31 = 0, $4 = 0, $41 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 36537
 $$cast = $4; //@line 36542
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36551
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 36557
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36558
 $25 = HEAP32[$24 >> 2] | 0; //@line 36559
 $26 = $25 << 24 >> 24; //@line 36561
 $28 = $26 + ($23 << 24 >> 24) | 0; //@line 36564
 $31 = $28 >>> 7; //@line 36568
 $sext34$lobit = $31 & 1; //@line 36569
 $sext34$mask = $28 & 255; //@line 36570
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 36573
 HEAP32[96444] = ($sext34$lobit ^ $25 >>> 7 & 1) & ($31 ^ $23 >>> 7); //@line 36577
 $41 = ($26 & 255 ^ 255) >>> 0 < ($23 & 255) >>> 0 & 1; //@line 36582
 HEAP32[96441] = $41; //@line 36583
 HEAP32[96445] = $41; //@line 36584
 HEAP32[96443] = $sext34$lobit; //@line 36585
 HEAP32[$24 >> 2] = $25 & -256 | $sext34$mask; //@line 36588
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36591
 return;
}
function __Z14CDROMInterruptv() {
 var $$sroa$03$012$i = 0, $0 = 0, $17 = 0, $21 = 0, $3 = 0, $4 = 0, $6 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 22729
 STACKTOP = STACKTOP + 80 | 0; //@line 22730
 $0 = sp; //@line 22731
 if (!(HEAP8[657354] | 0)) {
  STACKTOP = sp; //@line 22735
  return;
 }
 $3 = HEAP32[28494] | 0; //@line 22737
 $4 = HEAP32[28493] | 0; //@line 22738
 if (($4 | 0) == ($3 | 0)) {
  STACKTOP = sp; //@line 22741
  return;
 }
 $6 = $0 + 32 | 0; //@line 22743
 $$sroa$03$012$i = $4; //@line 22744
 do {
  $9 = (HEAP32[$$sroa$03$012$i + 836 >> 2] | 0) + 3 | 0; //@line 22748
  if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($9) | 0)) {
   $17 = $$sroa$03$012$i + 4 | 0; //@line 22757
   if (__Z17SysIsDiskInsertedPv(HEAP32[$17 >> 2] | 0) | 0) {
    __Z16CDROMMountVolumePv(HEAP32[$17 >> 2] | 0) | 0; //@line 22762
   }
  }
  $21 = $$sroa$03$012$i + 20 | 0; //@line 22765
  if (HEAP8[$21 >> 0] | 0) {
   HEAP32[$0 >> 2] = HEAP32[$$sroa$03$012$i >> 2]; //@line 22770
   HEAP32[$6 >> 2] = 7; //@line 22771
   _Execute68kTrap(-24529, $0); //@line 22772
   HEAP8[$21 >> 0] = 0; //@line 22773
  }
  $$sroa$03$012$i = $$sroa$03$012$i + 840 | 0; //@line 22775
 } while (($$sroa$03$012$i | 0) != ($3 | 0));
 STACKTOP = sp; //@line 22783
 return;
}
function __Z12op_5030_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $6 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1479
 $6 = HEAP32[162769] | 0; //@line 1481
 $7 = $6 + 2 | 0; //@line 1482
 HEAP32[162769] = $7; //@line 1483
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1485
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 1492
 HEAP32[162769] = $6 + 4; //@line 1494
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 1495
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 1497
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 1501
 $25 = $24 << 24 >> 24; //@line 1503
 $27 = $25 + ($4 << 24 >> 24) | 0; //@line 1506
 $30 = $27 >>> 7; //@line 1510
 $sext36$lobit = $30 & 1; //@line 1511
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 1515
 HEAP32[96444] = ($sext36$lobit ^ $24 >>> 7 & 1) & ($30 ^ $4 >>> 7); //@line 1519
 $40 = ($25 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1524
 HEAP32[96441] = $40; //@line 1525
 HEAP32[96445] = $40; //@line 1526
 HEAP32[96443] = $sext36$lobit; //@line 1527
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 1531
 return;
}
function __Z12op_4830_1_ffj($0) {
 $0 = $0 | 0;
 var $$028$in = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $3 = 0, $30 = 0, $32 = 0, $33 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 1960
 $3 = $2 + 2 | 0; //@line 1961
 HEAP32[162769] = $3; //@line 1962
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1964
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 1971
 HEAP32[162769] = $2 + 4; //@line 1973
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 1974
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 1976
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 1982
 $25 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($21 & 15) | 0; //@line 1987
 $27 = $25 & 65535; //@line 1989
 $30 = ($27 >>> 0 > 9 ? $27 + -6 | 0 : $25) - ($21 & 240) | 0; //@line 1993
 $32 = ($30 & 496) >>> 0 > 144; //@line 1995
 $33 = $32 & 1; //@line 1996
 $$028$in = $32 ? ($30 & 65535) + -96 | 0 : $30; //@line 1999
 HEAP32[96441] = $33; //@line 2000
 HEAP32[96445] = $33; //@line 2001
 HEAP32[96442] = ($$028$in & 255 | 0) == 0 & HEAP32[96442]; //@line 2007
 HEAP32[96443] = $$028$in >>> 7 & 1; //@line 2010
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $$028$in & 65535); //@line 2015
 return;
}
function __ZN16SDL_monitor_desc11set_paletteEPhi($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$04347 = 0, $$04446 = 0, $$045 = 0, $11 = 0, $12 = 0, $35 = 0, $5 = 0;
 $5 = (HEAP32[$0 + 16 >> 2] | 0) + 12 | 0; //@line 44145
 if ((HEAP32[$5 >> 2] | 0) > 3) {
  return;
 }
 _SDL_mutexP(0) | 0; //@line 44151
 $$04347 = 658447; //@line 44152
 $$04446 = 0; //@line 44152
 while (1) {
  $12 = $$04446 * 3 | 0; //@line 44154
  HEAP8[$$04347 >> 0] = (HEAPU8[$1 + $12 >> 0] | 0) * 257; //@line 44160
  HEAP8[$$04347 + 1 >> 0] = (HEAPU8[$1 + ($12 + 1) >> 0] | 0) * 257; //@line 44168
  HEAP8[$$04347 + 2 >> 0] = (HEAPU8[$1 + ($12 + 2) >> 0] | 0) * 257; //@line 44176
  $$04446 = $$04446 + 1 | 0; //@line 44178
  if (($$04446 | 0) == 256) {
   break;
  } else {
   $$04347 = $$04347 + 4 | 0; //@line 44183
  }
 }
 if ((HEAP32[$5 >> 2] | 1 | 0) != 5) {
  $11 = $2 + -1 | 0; //@line 44190
  $$045 = 0; //@line 44191
  do {
   $35 = ($$045 & $11) * 3 | 0; //@line 44194
   HEAP32[122204 + ($$045 << 2) >> 2] = HEAPU8[$1 + $35 >> 0] | 0 | (HEAPU8[$1 + ($35 + 1) >> 0] | 0) << 8 | (HEAPU8[$1 + ($35 + 2) >> 0] | 0) << 16 | -16777216; //@line 44212
   $$045 = $$045 + 1 | 0; //@line 44213
  } while (($$045 | 0) != 256);
 }
 HEAP8[659471] = 1; //@line 44222
 _SDL_mutexV(0) | 0; //@line 44223
 return;
}
function __Z13DiskInterruptv() {
 var $$sroa$03$012$i = 0, $0 = 0, $17 = 0, $21 = 0, $3 = 0, $4 = 0, $6 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 19594
 STACKTOP = STACKTOP + 80 | 0; //@line 19595
 $0 = sp; //@line 19596
 if (!(HEAP8[657353] | 0)) {
  STACKTOP = sp; //@line 19600
  return;
 }
 $3 = HEAP32[28490] | 0; //@line 19602
 $4 = HEAP32[28489] | 0; //@line 19603
 if (($4 | 0) == ($3 | 0)) {
  STACKTOP = sp; //@line 19606
  return;
 }
 $6 = $0 + 32 | 0; //@line 19608
 $$sroa$03$012$i = $4; //@line 19609
 do {
  $9 = (HEAP32[$$sroa$03$012$i + 20 >> 2] | 0) + 3 | 0; //@line 19613
  if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($9) | 0)) {
   $17 = $$sroa$03$012$i + 4 | 0; //@line 19622
   if (__Z17SysIsDiskInsertedPv(HEAP32[$17 >> 2] | 0) | 0) {
    __Z15DiskMountVolumePv(HEAP32[$17 >> 2] | 0) | 0; //@line 19627
   }
  }
  $21 = $$sroa$03$012$i + 16 | 0; //@line 19630
  if (HEAP8[$21 >> 0] | 0) {
   HEAP32[$0 >> 2] = HEAP32[$$sroa$03$012$i >> 2]; //@line 19635
   HEAP32[$6 >> 2] = 7; //@line 19636
   _Execute68kTrap(-24529, $0); //@line 19637
   HEAP8[$21 >> 0] = 0; //@line 19638
  }
  $$sroa$03$012$i = $$sroa$03$012$i + 24 | 0; //@line 19640
 } while (($$sroa$03$012$i | 0) != ($3 | 0));
 STACKTOP = sp; //@line 19648
 return;
}
function __Z12op_9170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20799
 $6 = HEAP32[162769] | 0; //@line 20800
 $7 = $6 + 2 | 0; //@line 20801
 HEAP32[162769] = $7; //@line 20802
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20804
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 20811
 HEAP32[162769] = $6 + 4; //@line 20813
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 20814
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 20816
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 20820
 $27 = ($24 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 20825
 $29 = $24 >>> 15; //@line 20827
 $sext38$lobit = $27 >>> 15 & 1; //@line 20830
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 20834
 HEAP32[96444] = ($sext38$lobit ^ $29 & 1) & ($29 ^ $5 >>> 15); //@line 20838
 $39 = ($5 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 20842
 HEAP32[96441] = $39; //@line 20843
 HEAP32[96445] = $39; //@line 20844
 HEAP32[96443] = $sext38$lobit; //@line 20845
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 20849
 return;
}
function __Z11op_6b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $46 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13471
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13474
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13489
 $21 = $2 + 6 | 0; //@line 13490
 HEAP32[162769] = $21; //@line 13491
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13493
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 13500
 HEAP32[162769] = $2 + 8; //@line 13502
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 13503
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 13505
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0; //@line 13508
 $38 = $37 + $20 | 0; //@line 13509
 $$lobit34 = $38 >>> 31; //@line 13512
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 13515
 HEAP32[96444] = ($$lobit34 ^ $5 >>> 7) & ($$lobit34 ^ $37 >>> 31); //@line 13519
 $46 = $20 >>> 0 > ~$37 >>> 0 & 1; //@line 13522
 HEAP32[96441] = $46; //@line 13523
 HEAP32[96445] = $46; //@line 13524
 HEAP32[96443] = $$lobit34; //@line 13525
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 13529
 return;
}
function __Z12op_e140_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $15 = 0, $18 = 0, $19 = 0, $23 = 0, $25 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39194
 $7 = HEAP32[$6 >> 2] | 0; //@line 39195
 $8 = $7 & 65535; //@line 39196
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39197
 $10 = $9 >>> 0 > 15; //@line 39198
 HEAP32[96441] = 0; //@line 39199
 HEAP32[96442] = 0; //@line 39199
 HEAP32[96443] = 0; //@line 39199
 HEAP32[96444] = 0; //@line 39199
 if ($10) {
  HEAP32[96444] = ($8 | 0) != 0 & 1; //@line 39203
  $15 = ($9 | 0) == 16 ? $7 & 1 : 0; //@line 39206
  HEAP32[96441] = $15; //@line 39207
  HEAP32[96445] = $15; //@line 39208
  $$0 = 0; //@line 39209
 } else {
  $18 = 65535 << 15 - $9 & 65535; //@line 39213
  $19 = $18 & $7; //@line 39214
  HEAP32[96444] = ($19 | 0) != 0 & ($19 | 0) != ($18 | 0) & 1; //@line 39219
  $23 = $8 << $9 + -1; //@line 39221
  $25 = $23 >>> 15 & 1; //@line 39223
  HEAP32[96441] = $25; //@line 39224
  HEAP32[96445] = $25; //@line 39225
  $$0 = $23 << 1 & 65534; //@line 39228
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39232
 HEAP32[96443] = $$0 >>> 15; //@line 39234
 HEAP32[$6 >> 2] = $7 & -65536 | $$0; //@line 39237
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39240
 return;
}
function __ZL18find_hfs_partitionR15disk_drive_info($0) {
 $0 = $0 | 0;
 var $$028 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0;
 $1 = $0 + 8 | 0; //@line 18487
 HEAP32[$1 >> 2] = 0; //@line 18488
 $2 = $0 + 12 | 0; //@line 18489
 HEAP32[$2 >> 2] = 0; //@line 18490
 $3 = __Znaj(512) | 0; //@line 18491
 $4 = $0 + 4 | 0; //@line 18492
 $5 = $3 + 1 | 0; //@line 18493
 $6 = $3 + 48 | 0; //@line 18494
 $$028 = 0; //@line 18495
 while (1) {
  if ((__Z8Sys_readPvS_ij(HEAP32[$4 >> 2] | 0, $3, $$028 << 9, 512) | 0) != 512) {
   label = 7; //@line 18502
   break;
  }
  if (((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$5 >> 0] | 0) | 0) == 20557) {
   if (!(_strcmp($6, 95147) | 0)) {
    label = 5; //@line 18516
    break;
   }
  }
  $$028 = $$028 + 1 | 0; //@line 18520
  if (($$028 | 0) >= 64) {
   label = 7; //@line 18525
   break;
  }
 }
 if ((label | 0) == 5) {
  HEAP32[$1 >> 2] = ((HEAPU8[$3 + 10 >> 0] | 0) << 8 | (HEAPU8[$3 + 9 >> 0] | 0) << 16 | (HEAPU8[$3 + 11 >> 0] | 0)) << 9; //@line 18544
  HEAP32[$2 >> 2] = (HEAPU8[$3 + 13 >> 0] | 0) << 16 | (HEAPU8[$3 + 12 >> 0] | 0) << 24 | (HEAPU8[$3 + 14 >> 0] | 0) << 8 | (HEAPU8[$3 + 15 >> 0] | 0); //@line 18563
  __ZdaPv($3); //@line 18564
  return;
 } else if ((label | 0) == 7) {
  __ZdaPv($3); //@line 18568
  return;
 }
}
function __Z12op_d03a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $32 = 0, $4 = 0, $42 = 0, $sext33$lobit = 0, $sext33$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 31700
 $$cast = $4; //@line 31702
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 31716
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 31722
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31723
 $26 = HEAP32[$25 >> 2] | 0; //@line 31724
 $27 = $26 << 24 >> 24; //@line 31726
 $29 = $27 + ($24 << 24 >> 24) | 0; //@line 31729
 $32 = $29 >>> 7; //@line 31733
 $sext33$lobit = $32 & 1; //@line 31734
 $sext33$mask = $29 & 255; //@line 31735
 HEAP32[96442] = ($sext33$mask | 0) == 0 & 1; //@line 31738
 HEAP32[96444] = ($sext33$lobit ^ $26 >>> 7 & 1) & ($32 ^ $24 >>> 7); //@line 31742
 $42 = ($27 & 255 ^ 255) >>> 0 < ($24 & 255) >>> 0 & 1; //@line 31747
 HEAP32[96441] = $42; //@line 31748
 HEAP32[96445] = $42; //@line 31749
 HEAP32[96443] = $sext33$lobit; //@line 31750
 HEAP32[$25 >> 2] = $26 & -256 | $sext33$mask; //@line 31753
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31756
 return;
}
function __Z12op_eac0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $50 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 43669
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 43678
 $11 = $sext >> 16; //@line 43679
 $14 = $sext >> 22; //@line 43682
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 43685
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 43690
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 43695
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 43700
 }
 $26 = $25 + 31 & 31; //@line 43703
 $27 = 651008 + (($0 & 7) << 2) | 0; //@line 43704
 $28 = HEAP32[$27 >> 2] | 0; //@line 43705
 $29 = $30 & 31; //@line 43706
 $32 = $26 ^ 31; //@line 43708
 $33 = $28 << $29 >>> $32; //@line 43709
 HEAP32[96443] = ($33 & 1 << $26 | 0) != 0 & 1; //@line 43714
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 43717
 HEAP32[96444] = 0; //@line 43718
 HEAP32[96441] = 0; //@line 43719
 $50 = $29 + 1 + $26 | 0; //@line 43730
 HEAP32[$27 >> 2] = ~$33 << $32 >>> $29 | $28 & (($29 | 0) == 0 ? 0 : -1 << 32 - $29) | ($50 >>> 0 > 31 ? 0 : -1 >>> $50 & $28); //@line 43736
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43739
 return;
}
function __Z12op_eec0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $32 = 0, $33 = 0, $49 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 46841
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 46850
 $11 = $sext >> 16; //@line 46851
 $14 = $sext >> 22; //@line 46854
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 46857
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 46862
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 46867
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 46872
 }
 $26 = $25 + 31 & 31; //@line 46875
 $27 = 651008 + (($0 & 7) << 2) | 0; //@line 46876
 $28 = HEAP32[$27 >> 2] | 0; //@line 46877
 $29 = $30 & 31; //@line 46878
 $32 = $26 ^ 31; //@line 46880
 $33 = $28 << $29 >>> $32; //@line 46881
 HEAP32[96443] = ($33 & 1 << $26 | 0) != 0 & 1; //@line 46886
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 46889
 HEAP32[96444] = 0; //@line 46890
 HEAP32[96441] = 0; //@line 46891
 $49 = $29 + 1 + $26 | 0; //@line 46901
 HEAP32[$27 >> 2] = -1 << $32 >>> $29 | $28 & (($29 | 0) == 0 ? 0 : -1 << 32 - $29) | ($49 >>> 0 > 31 ? 0 : -1 >>> $49 & $28); //@line 46907
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46910
 return;
}
function __Z11op_e68_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $26 = 0, $4 = 0, $41 = 0, $50 = 0, $52 = 0, $54 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21932
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 21936
 $7 = HEAPU8[$4 + 2 >> 0] | 0; //@line 21939
 $9 = $7 << 24 >> 16; //@line 21941
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21945
 do {
  if (!($9 & 2048)) {
   $41 = ((HEAPU8[$4 + 6 >> 0] << 8 | HEAPU8[$4 + 7 >> 0]) << 16 >> 16) + $13 | 0; //@line 21958
   $50 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($41) | 0) << 16 >> 16; //@line 21968
   $52 = $7 >>> 4 & 7; //@line 21970
   if (!($9 & 32768)) {
    $54 = 651008 + ($52 << 2) | 0; //@line 21972
    HEAP32[$54 >> 2] = HEAP32[$54 >> 2] & -65536 | $50 & 65535; //@line 21977
    break;
   } else {
    HEAP32[651040 + ($52 << 2) >> 2] = $50; //@line 21981
    break;
   }
  } else {
   $26 = ((HEAPU8[$4 + 4 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]) << 16 >> 16) + $13 | 0; //@line 21998
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 22004
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 22009
 return;
}
function __Z12op_e068_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink28 = 0, $10 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext27$mask = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37994
 $7 = HEAP32[$6 >> 2] | 0; //@line 37995
 $8 = $7 & 65535; //@line 37996
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37997
 $10 = $9 >>> 0 > 15; //@line 37998
 HEAP32[96441] = 0; //@line 37999
 HEAP32[96442] = 0; //@line 37999
 HEAP32[96443] = 0; //@line 37999
 HEAP32[96444] = 0; //@line 37999
 if ($10) {
  $$0$ph = 0; //@line 38005
  $$sink28 = ($9 | 0) == 16 & $8 >>> 15; //@line 38005
  label = 4; //@line 38006
 } else {
  $17 = $8 >>> ($9 + -1 | 0); //@line 38010
  if (!$9) {
   $$0 = $8; //@line 38014
  } else {
   $$0$ph = $17 >>> 1; //@line 38016
   $$sink28 = $17 & 1; //@line 38016
   label = 4; //@line 38017
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink28; //@line 38021
  HEAP32[96445] = $$sink28; //@line 38022
  $$0 = $$0$ph; //@line 38023
 }
 $sext27$mask = $$0 & 65535; //@line 38025
 HEAP32[96442] = ($sext27$mask | 0) == 0 & 1; //@line 38028
 HEAP32[96443] = $$0 >>> 15 & 1; //@line 38031
 HEAP32[$6 >> 2] = $sext27$mask | $7 & -65536; //@line 38034
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38037
 return;
}
function __Z12op_9130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20258
 $6 = HEAP32[162769] | 0; //@line 20259
 $7 = $6 + 2 | 0; //@line 20260
 HEAP32[162769] = $7; //@line 20261
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20263
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 20270
 HEAP32[162769] = $6 + 4; //@line 20272
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 20273
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 20275
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 20279
 $27 = ($24 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 20284
 $29 = $24 >>> 7; //@line 20286
 $sext34$lobit = $27 >>> 7 & 1; //@line 20289
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 20293
 HEAP32[96444] = ($sext34$lobit ^ $29 & 1) & ($29 ^ $5 >>> 7); //@line 20297
 $39 = ($5 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 20301
 HEAP32[96441] = $39; //@line 20302
 HEAP32[96445] = $39; //@line 20303
 HEAP32[96443] = $sext34$lobit; //@line 20304
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 20308
 return;
}
function __Z12op_31ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $35 = 0, $37 = 0, $38 = 0, $4 = 0, $40 = 0;
 $4 = HEAP32[162769] | 0; //@line 38491
 $$cast = $4; //@line 38493
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 38507
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 38513
 $25 = HEAP32[162769] | 0; //@line 38514
 $26 = $25 + 4 | 0; //@line 38515
 HEAP32[162769] = $26; //@line 38516
 $28 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38518
 $35 = (HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0); //@line 38525
 HEAP32[162769] = $25 + 6; //@line 38527
 $37 = __Z15get_disp_ea_020jj($28, $35) | 0; //@line 38528
 $38 = $24 << 16 >> 16; //@line 38530
 $40 = ($38 | 0) == 0 & 1; //@line 38532
 HEAP32[96441] = 0; //@line 38533
 HEAP32[96442] = 0; //@line 38533
 HEAP32[96443] = 0; //@line 38533
 HEAP32[96444] = 0; //@line 38533
 HEAP32[96442] = $40; //@line 38534
 HEAP32[96443] = $24 >>> 15 & 1; //@line 38537
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($37, $38); //@line 38543
 return;
}
function __Z12op_317b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $26 = 0, $3 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 37901
 $4 = $3 + 2 | 0; //@line 37902
 HEAP32[162769] = $4; //@line 37903
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 37908
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 37915
 HEAP32[162769] = $3 + 4; //@line 37917
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 37918
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 37924
 $26 = HEAP32[162769] | 0; //@line 37927
 $35 = (((HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$26 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37937
 $36 = $23 << 16 >> 16; //@line 37939
 $38 = ($36 | 0) == 0 & 1; //@line 37941
 HEAP32[96441] = 0; //@line 37942
 HEAP32[96442] = 0; //@line 37942
 HEAP32[96443] = 0; //@line 37942
 HEAP32[96444] = 0; //@line 37942
 HEAP32[96442] = $38; //@line 37943
 HEAP32[96443] = $23 >>> 15 & 1; //@line 37946
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 37952
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37955
 return;
}
function __Z12op_11ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $35 = 0, $37 = 0, $38 = 0, $4 = 0, $40 = 0;
 $4 = HEAP32[162769] | 0; //@line 26460
 $$cast = $4; //@line 26462
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 26476
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 26482
 $25 = HEAP32[162769] | 0; //@line 26483
 $26 = $25 + 4 | 0; //@line 26484
 HEAP32[162769] = $26; //@line 26485
 $28 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26487
 $35 = (HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0); //@line 26494
 HEAP32[162769] = $25 + 6; //@line 26496
 $37 = __Z15get_disp_ea_020jj($28, $35) | 0; //@line 26497
 $38 = $24 << 24 >> 24; //@line 26499
 $40 = ($38 | 0) == 0 & 1; //@line 26501
 HEAP32[96441] = 0; //@line 26502
 HEAP32[96442] = 0; //@line 26502
 HEAP32[96443] = 0; //@line 26502
 HEAP32[96444] = 0; //@line 26502
 HEAP32[96442] = $40; //@line 26503
 HEAP32[96443] = $24 >>> 7 & 1; //@line 26506
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($37, $38); //@line 26512
 return;
}
function __Z12op_117b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $26 = 0, $3 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 25913
 $4 = $3 + 2 | 0; //@line 25914
 HEAP32[162769] = $4; //@line 25915
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 25920
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 25927
 HEAP32[162769] = $3 + 4; //@line 25929
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 25930
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 25936
 $26 = HEAP32[162769] | 0; //@line 25939
 $35 = (((HEAPU8[$26 >> 0] | 0) << 8 | (HEAPU8[$26 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25949
 $36 = $23 << 24 >> 24; //@line 25951
 $38 = ($36 | 0) == 0 & 1; //@line 25953
 HEAP32[96441] = 0; //@line 25954
 HEAP32[96442] = 0; //@line 25954
 HEAP32[96443] = 0; //@line 25954
 HEAP32[96444] = 0; //@line 25954
 HEAP32[96442] = $38; //@line 25955
 HEAP32[96443] = $23 >>> 7 & 1; //@line 25958
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 25964
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25967
 return;
}
function __Z12op_21bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $24 = 0, $25 = 0, $3 = 0, $32 = 0, $34 = 0, $36 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 33491
 $4 = $3 + 2 | 0; //@line 33492
 HEAP32[162769] = $4; //@line 33493
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 33498
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 33505
 HEAP32[162769] = $3 + 4; //@line 33507
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 33508
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 33513
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33515
 $25 = HEAP32[162769] | 0; //@line 33516
 $32 = (HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0); //@line 33523
 HEAP32[162769] = $25 + 2; //@line 33525
 $34 = __Z15get_disp_ea_020jj($24, $32) | 0; //@line 33526
 $36 = ($22 | 0) == 0 & 1; //@line 33528
 HEAP32[96441] = 0; //@line 33529
 HEAP32[96442] = 0; //@line 33529
 HEAP32[96443] = 0; //@line 33529
 HEAP32[96444] = 0; //@line 33529
 HEAP32[96442] = $36; //@line 33530
 HEAP32[96443] = $22 >>> 31; //@line 33532
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $22); //@line 33538
 return;
}
function __Z11op_e28_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $26 = 0, $4 = 0, $41 = 0, $50 = 0, $52 = 0, $54 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21363
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 21367
 $7 = HEAPU8[$4 + 2 >> 0] | 0; //@line 21370
 $9 = $7 << 24 >> 16; //@line 21372
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21376
 do {
  if (!($9 & 2048)) {
   $41 = ((HEAPU8[$4 + 6 >> 0] << 8 | HEAPU8[$4 + 7 >> 0]) << 16 >> 16) + $13 | 0; //@line 21389
   $50 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($41 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($41) | 0) << 24 >> 24; //@line 21399
   $52 = $7 >>> 4 & 7; //@line 21401
   if (!($9 & 32768)) {
    $54 = 651008 + ($52 << 2) | 0; //@line 21403
    HEAP32[$54 >> 2] = HEAP32[$54 >> 2] & -256 | $50 & 255; //@line 21408
    break;
   } else {
    HEAP32[651040 + ($52 << 2) >> 2] = $50; //@line 21412
    break;
   }
  } else {
   $26 = ((HEAPU8[$4 + 4 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]) << 16 >> 16) + $13 | 0; //@line 21429
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 21435
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 21440
 return;
}
function __Z12op_8148_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $17 = 0, $25 = 0, $26 = 0, $3 = 0, $35 = 0, $38 = 0, $4 = 0, $40 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 16106
 $3 = $0 >>> 9 & 7; //@line 16108
 $4 = 5656 + ($1 << 2) | 0; //@line 16109
 $6 = 651040 + ($1 << 2) | 0; //@line 16111
 $8 = (HEAP32[$6 >> 2] | 0) - (HEAP32[$4 >> 2] | 0) | 0; //@line 16113
 HEAP32[$6 >> 2] = $8; //@line 16114
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 16120
 $17 = (HEAP32[$6 >> 2] | 0) - (HEAP32[$4 >> 2] | 0) | 0; //@line 16123
 HEAP32[$6 >> 2] = $17; //@line 16124
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 8 | $14; //@line 16132
 $26 = HEAP32[162769] | 0; //@line 16133
 $35 = ((HEAPU8[$26 + 2 >> 0] | 0) << 8 | (HEAPU8[$26 + 3 >> 0] | 0)) + $25 | 0; //@line 16142
 $38 = 651040 + ($3 << 2) | 0; //@line 16145
 $40 = (HEAP32[$38 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 16147
 HEAP32[$38 >> 2] = $40; //@line 16148
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($40, $35 >>> 4 & 240 | $35 & 15); //@line 16158
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16161
 return;
}
function __Z12op_e1a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $14 = 0, $17 = 0, $18 = 0, $22 = 0, $23 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39755
 $7 = HEAP32[$6 >> 2] | 0; //@line 39756
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39757
 $9 = $8 >>> 0 > 31; //@line 39758
 HEAP32[96441] = 0; //@line 39759
 HEAP32[96442] = 0; //@line 39759
 HEAP32[96443] = 0; //@line 39759
 HEAP32[96444] = 0; //@line 39759
 if ($9) {
  HEAP32[96444] = ($7 | 0) != 0 & 1; //@line 39763
  $14 = ($8 | 0) == 32 ? $7 & 1 : 0; //@line 39766
  HEAP32[96441] = $14; //@line 39767
  HEAP32[96445] = $14; //@line 39768
  $$0 = 0; //@line 39769
 } else {
  if (!$8) {
   $$0 = $7; //@line 39773
  } else {
   $17 = -1 << 31 - $8; //@line 39776
   $18 = $17 & $7; //@line 39777
   HEAP32[96444] = ($18 | 0) != 0 & ($18 | 0) != ($17 | 0) & 1; //@line 39782
   $22 = $7 << $8 + -1; //@line 39784
   $23 = $22 >>> 31; //@line 39785
   HEAP32[96441] = $23; //@line 39786
   HEAP32[96445] = $23; //@line 39787
   $$0 = $22 << 1; //@line 39789
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39794
 HEAP32[96443] = $$0 >>> 31; //@line 39796
 HEAP32[$6 >> 2] = $$0; //@line 39797
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39800
 return;
}
function __Z12op_e100_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $15 = 0, $18 = 0, $19 = 0, $23 = 0, $25 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38789
 $7 = HEAP32[$6 >> 2] | 0; //@line 38790
 $8 = $7 & 255; //@line 38791
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38792
 $10 = $9 >>> 0 > 7; //@line 38793
 HEAP32[96441] = 0; //@line 38794
 HEAP32[96442] = 0; //@line 38794
 HEAP32[96443] = 0; //@line 38794
 HEAP32[96444] = 0; //@line 38794
 if ($10) {
  HEAP32[96444] = ($8 | 0) != 0 & 1; //@line 38798
  $15 = ($9 | 0) == 8 ? $7 & 1 : 0; //@line 38801
  HEAP32[96441] = $15; //@line 38802
  HEAP32[96445] = $15; //@line 38803
  $$0 = 0; //@line 38804
 } else {
  $18 = 255 << 7 - $9 & 255; //@line 38808
  $19 = $18 & $7; //@line 38809
  HEAP32[96444] = ($19 | 0) != 0 & ($19 | 0) != ($18 | 0) & 1; //@line 38814
  $23 = $8 << $9 + -1; //@line 38816
  $25 = $23 >>> 7 & 1; //@line 38818
  HEAP32[96441] = $25; //@line 38819
  HEAP32[96445] = $25; //@line 38820
  $$0 = $23 << 1 & 254; //@line 38823
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38827
 HEAP32[96443] = $$0 >>> 7; //@line 38829
 HEAP32[$6 >> 2] = $7 & -256 | $$0; //@line 38832
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38835
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($0, $1, $2, $3, $4, $5, $6) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 $6 = $6 | 0;
 var $$sroa$speculated = 0, $14 = 0, $15 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0;
 if ((-17 - $1 | 0) >>> 0 < $2 >>> 0) {
  __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0); //@line 3377
 }
 if ((HEAP8[$0 + 11 >> 0] | 0) < 0) {
  $23 = HEAP32[$0 >> 2] | 0; //@line 3385
 } else {
  $23 = $0; //@line 3387
 }
 if ($1 >>> 0 < 2147483623) {
  $14 = $2 + $1 | 0; //@line 3391
  $15 = $1 << 1; //@line 3392
  $$sroa$speculated = $14 >>> 0 < $15 >>> 0 ? $15 : $14; //@line 3394
  $20 = $$sroa$speculated >>> 0 < 11 ? 11 : $$sroa$speculated + 16 & -16; //@line 3399
 } else {
  $20 = -17; //@line 3401
 }
 $21 = __Znwj($20) | 0; //@line 3403
 if ($4 | 0) {
  __ZNSt3__211char_traitsIcE4copyEPcPKcj($21, $23, $4) | 0; //@line 3406
 }
 $25 = $3 - $5 - $4 | 0; //@line 3409
 if ($25 | 0) {
  __ZNSt3__211char_traitsIcE4copyEPcPKcj($21 + $4 + $6 | 0, $23 + $4 + $5 | 0, $25) | 0; //@line 3416
 }
 if (($1 | 0) != 10) {
  __ZdlPv($23); //@line 3420
 }
 HEAP32[$0 >> 2] = $21; //@line 3422
 HEAP32[$0 + 8 >> 2] = $20 | -2147483648; //@line 3425
 return;
}
function __Z11op_e79_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $45 = 0, $6 = 0, $64 = 0, $65 = 0, $67 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22191
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 22194
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 22197
 $8 = $6 << 24 >> 16; //@line 22199
 do {
  if (!($8 & 2048)) {
   $45 = HEAPU8[$3 + 9 >> 0] << 16 | HEAPU8[$3 + 8 >> 0] << 24; //@line 22212
   $64 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($45 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($45 | HEAPU8[$3 + 10 >> 0] << 8 | HEAPU8[$3 + 11 >> 0]) | 0) << 16 >> 16; //@line 22232
   $65 = $6 >>> 4 & 7; //@line 22233
   if (!($8 & 32768)) {
    $67 = 651008 + ($65 << 2) | 0; //@line 22235
    HEAP32[$67 >> 2] = HEAP32[$67 >> 2] & -65536 | $64 & 65535; //@line 22240
    break;
   } else {
    HEAP32[651040 + ($65 << 2) >> 2] = $64; //@line 22244
    break;
   }
  } else {
   $22 = HEAPU8[$3 + 5 >> 0] << 16 | HEAPU8[$3 + 4 >> 0] << 24; //@line 22259
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($22 | HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0], HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 22274
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 12; //@line 22279
 return;
}
function _open($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $14 = 0, $18 = 0, $2 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, sp = 0;
 sp = STACKTOP; //@line 59463
 STACKTOP = STACKTOP + 48 | 0; //@line 59464
 $vararg_buffer3 = sp + 16 | 0; //@line 59465
 $vararg_buffer = sp; //@line 59466
 $2 = sp + 32 | 0; //@line 59467
 if (!($1 & 4194368)) {
  $$0 = 0; //@line 59471
 } else {
  HEAP32[$2 >> 2] = $varargs; //@line 59473
  $10 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 59485
  $11 = HEAP32[$10 >> 2] | 0; //@line 59486
  HEAP32[$2 >> 2] = $10 + 4; //@line 59488
  $$0 = $11; //@line 59489
 }
 HEAP32[$vararg_buffer >> 2] = $0; //@line 59493
 HEAP32[$vararg_buffer + 4 >> 2] = $1 | 32768; //@line 59495
 HEAP32[$vararg_buffer + 8 >> 2] = $$0; //@line 59497
 $14 = ___syscall5(5, $vararg_buffer | 0) | 0; //@line 59498
 if (!(($1 & 524288 | 0) == 0 | ($14 | 0) < 0)) {
  HEAP32[$vararg_buffer3 >> 2] = $14; //@line 59504
  HEAP32[$vararg_buffer3 + 4 >> 2] = 2; //@line 59506
  HEAP32[$vararg_buffer3 + 8 >> 2] = 1; //@line 59508
  ___syscall221(221, $vararg_buffer3 | 0) | 0; //@line 59509
 }
 $18 = ___syscall_ret($14) | 0; //@line 59511
 STACKTOP = sp; //@line 59512
 return $18 | 0; //@line 59512
}
function __Z12op_e028_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink24 = 0, $10 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext23$mask = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37604
 $7 = HEAP32[$6 >> 2] | 0; //@line 37605
 $8 = $7 & 255; //@line 37606
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37607
 $10 = $9 >>> 0 > 7; //@line 37608
 HEAP32[96441] = 0; //@line 37609
 HEAP32[96442] = 0; //@line 37609
 HEAP32[96443] = 0; //@line 37609
 HEAP32[96444] = 0; //@line 37609
 if ($10) {
  $$0$ph = 0; //@line 37615
  $$sink24 = ($9 | 0) == 8 & $8 >>> 7; //@line 37615
  label = 4; //@line 37616
 } else {
  $17 = $8 >>> ($9 + -1 | 0); //@line 37620
  if (!$9) {
   $$0 = $8; //@line 37624
  } else {
   $$0$ph = $17 >>> 1; //@line 37626
   $$sink24 = $17 & 1; //@line 37626
   label = 4; //@line 37627
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink24; //@line 37631
  HEAP32[96445] = $$sink24; //@line 37632
  $$0 = $$0$ph; //@line 37633
 }
 $sext23$mask = $$0 & 255; //@line 37635
 HEAP32[96442] = ($sext23$mask | 0) == 0 & 1; //@line 37638
 HEAP32[96443] = $$0 >>> 7 & 1; //@line 37641
 HEAP32[$6 >> 2] = $sext23$mask | $7 & -256; //@line 37644
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37647
 return;
}
function __Z11op_679_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $29 = 0, $33 = 0, $34 = 0, $36 = 0, $39 = 0, $4 = 0, $48 = 0, $9 = 0, $sext30$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 13095
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 13098
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 13103
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 13112
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 13121
 $29 = 123608 + ($18 >>> 16 << 2) | 0; //@line 13123
 $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 13127
 $34 = $33 << 16 >> 16; //@line 13129
 $36 = $34 + ($9 << 16 >> 16) | 0; //@line 13132
 $39 = $36 >>> 15; //@line 13136
 $sext30$lobit = $39 & 1; //@line 13137
 HEAP32[96442] = ($36 & 65535 | 0) == 0 & 1; //@line 13141
 HEAP32[96444] = ($sext30$lobit ^ $33 >>> 15 & 1) & ($39 ^ $4 >>> 7); //@line 13145
 $48 = ($34 & 65535 ^ 65535) >>> 0 < $9 >>> 0 & 1; //@line 13149
 HEAP32[96441] = $48; //@line 13150
 HEAP32[96445] = $48; //@line 13151
 HEAP32[96443] = $sext30$lobit; //@line 13152
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $36); //@line 13156
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 13159
 return;
}
function __ZN17disk_sparsebundle9band_readEPcijj($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$2 = 0, $$sroa$speculated = 0, $12 = 0, $17 = 0, $19 = 0, $7 = 0, $9 = 0, label = 0;
 switch (__ZN17disk_sparsebundle9open_bandEib($0, $2, 0) | 0) {
 case 1:
  {
   $19 = 0; //@line 36059
   break;
  }
 case 0:
  {
   $$2 = -1; //@line 36063
   return $$2 | 0; //@line 36064
  }
 default:
  {
   label = 2; //@line 36068
  }
 }
 if ((label | 0) == 2) {
  $7 = HEAP32[$0 + 32 >> 2] | 0; //@line 36073
  $9 = $7 - $3 | 0; //@line 36075
  $$sroa$speculated = $9 >>> 0 < $4 >>> 0 ? $9 : $4; //@line 36077
  if ($7 >>> 0 <= $3 >>> 0 | ($$sroa$speculated | 0) == 0) {
   $19 = 0; //@line 36081
  } else {
   $12 = $0 + 28 | 0; //@line 36083
   if ((_lseek(HEAP32[$12 >> 2] | 0, $3, 0) | 0) == -1) {
    $$2 = -1; //@line 36088
    return $$2 | 0; //@line 36089
   }
   $17 = _read(HEAP32[$12 >> 2] | 0, $1, $$sroa$speculated) | 0; //@line 36092
   if ($17 >>> 0 < $$sroa$speculated >>> 0) {
    $$2 = $17; //@line 36095
    return $$2 | 0; //@line 36096
   } else {
    $19 = $$sroa$speculated; //@line 36098
   }
  }
 }
 _memset($1 + $19 | 0, 0, $4 - $19 | 0) | 0; //@line 36104
 $$2 = $4; //@line 36105
 return $$2 | 0; //@line 36106
}
function __Z12op_907b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $30 = 0, $4 = 0, $40 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 23893
 $$cast = $4; //@line 23898
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23907
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23913
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23914
 $25 = HEAP32[$24 >> 2] | 0; //@line 23915
 $28 = ($25 << 16 >> 16) - ($23 << 16 >> 16) | 0; //@line 23920
 $30 = $25 >>> 15; //@line 23922
 $sext38$lobit = $28 >>> 15 & 1; //@line 23925
 $sext38$mask = $28 & 65535; //@line 23926
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 23929
 HEAP32[96444] = ($sext38$lobit ^ $30 & 1) & ($30 ^ $23 >>> 15); //@line 23933
 $40 = ($23 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 23937
 HEAP32[96441] = $40; //@line 23938
 HEAP32[96445] = $40; //@line 23939
 HEAP32[96443] = $sext38$lobit; //@line 23940
 HEAP32[$24 >> 2] = $25 & -65536 | $sext38$mask; //@line 23943
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23946
 return;
}
function __Z12op_3170_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $25 = 0, $34 = 0, $35 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 37647
 $5 = $4 + 2 | 0; //@line 37648
 HEAP32[162769] = $5; //@line 37649
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 37651
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 37658
 HEAP32[162769] = $4 + 4; //@line 37660
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 37661
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 37667
 $25 = HEAP32[162769] | 0; //@line 37670
 $34 = (((HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37680
 $35 = $22 << 16 >> 16; //@line 37682
 $37 = ($35 | 0) == 0 & 1; //@line 37684
 HEAP32[96441] = 0; //@line 37685
 HEAP32[96442] = 0; //@line 37685
 HEAP32[96443] = 0; //@line 37685
 HEAP32[96444] = 0; //@line 37685
 HEAP32[96442] = $37; //@line 37686
 HEAP32[96443] = $22 >>> 15 & 1; //@line 37689
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($34, $35); //@line 37695
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37698
 return;
}
function __Z12op_1170_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $25 = 0, $34 = 0, $35 = 0, $37 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 25659
 $5 = $4 + 2 | 0; //@line 25660
 HEAP32[162769] = $5; //@line 25661
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25663
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 25670
 HEAP32[162769] = $4 + 4; //@line 25672
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 25673
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 25679
 $25 = HEAP32[162769] | 0; //@line 25682
 $34 = (((HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25692
 $35 = $22 << 24 >> 24; //@line 25694
 $37 = ($35 | 0) == 0 & 1; //@line 25696
 HEAP32[96441] = 0; //@line 25697
 HEAP32[96442] = 0; //@line 25697
 HEAP32[96443] = 0; //@line 25697
 HEAP32[96444] = 0; //@line 25697
 HEAP32[96442] = $37; //@line 25698
 HEAP32[96443] = $22 >>> 7 & 1; //@line 25701
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, $35); //@line 25707
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25710
 return;
}
function __Z11op_430_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $19 = 0, $2 = 0, $23 = 0, $26 = 0, $28 = 0, $37 = 0, $4 = 0, $6 = 0, $8 = 0, $sext29$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10509
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 10511
 $6 = $2 + 4 | 0; //@line 10513
 HEAP32[162769] = $6; //@line 10514
 $8 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10516
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 10523
 HEAP32[162769] = $2 + 6; //@line 10525
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 10526
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 10528
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 10532
 $26 = ($23 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10536
 $28 = $23 >>> 7; //@line 10539
 $sext29$lobit = $26 >>> 7 & 1; //@line 10542
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 10546
 HEAP32[96444] = ($sext29$lobit ^ $28 & 1) & ($28 ^ ($4 & 255) >>> 7 & 255); //@line 10550
 $37 = ($4 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 10553
 HEAP32[96441] = $37; //@line 10554
 HEAP32[96445] = $37; //@line 10555
 HEAP32[96443] = $sext29$lobit; //@line 10556
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 10560
 return;
}
function __Z12op_5170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5770
 $6 = HEAP32[162769] | 0; //@line 5772
 $7 = $6 + 2 | 0; //@line 5773
 HEAP32[162769] = $7; //@line 5774
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5776
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 5783
 HEAP32[162769] = $6 + 4; //@line 5785
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 5786
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5788
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 5792
 $27 = ($24 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5797
 $29 = $24 >>> 15; //@line 5799
 $sext38$lobit = $27 >>> 15 & 1; //@line 5802
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 5806
 HEAP32[96444] = ($sext38$lobit ^ $29 & 1) & ($29 ^ $4 >>> 15); //@line 5810
 $39 = ($4 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 5814
 HEAP32[96441] = $39; //@line 5815
 HEAP32[96445] = $39; //@line 5816
 HEAP32[96443] = $sext38$lobit; //@line 5817
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 5821
 return;
}
function __Z11op_e39_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $45 = 0, $6 = 0, $64 = 0, $65 = 0, $67 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21622
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 21625
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 21628
 $8 = $6 << 24 >> 16; //@line 21630
 do {
  if (!($8 & 2048)) {
   $45 = HEAPU8[$3 + 9 >> 0] << 16 | HEAPU8[$3 + 8 >> 0] << 24; //@line 21643
   $64 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($45 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($45 | HEAPU8[$3 + 10 >> 0] << 8 | HEAPU8[$3 + 11 >> 0]) | 0) << 24 >> 24; //@line 21663
   $65 = $6 >>> 4 & 7; //@line 21664
   if (!($8 & 32768)) {
    $67 = 651008 + ($65 << 2) | 0; //@line 21666
    HEAP32[$67 >> 2] = HEAP32[$67 >> 2] & -256 | $64 & 255; //@line 21671
    break;
   } else {
    HEAP32[651040 + ($65 << 2) >> 2] = $64; //@line 21675
    break;
   }
  } else {
   $22 = HEAPU8[$3 + 5 >> 0] << 16 | HEAPU8[$3 + 4 >> 0] << 24; //@line 21690
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($22 | HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0], HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 21705
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 12; //@line 21710
 return;
}
function __Z11op_4e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $21 = 0, $24 = 0, $29 = 0, $3 = 0, $30 = 0, $35 = 0, $45 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 11758
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 11761
 $$cast = $3; //@line 11762
 $9 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 11765
 $21 = (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 11778
 $24 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 11781
 $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($21 >>> 16 << 2) >> 2] >> 2] & 127]($21) | 0; //@line 11786
 $30 = $21 + 4 | 0; //@line 11787
 $35 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($30 >>> 16 << 2) >> 2] >> 2] & 127]($30) | 0; //@line 11792
 HEAP32[96442] = (($29 | 0) == ($24 | 0) | ($35 | 0) == ($24 | 0)) & 1; //@line 11797
 if (($29 | 0) > ($35 | 0)) {
  $45 = ($24 | 0) < ($29 | 0) | ($24 | 0) > ($35 | 0); //@line 11803
 } else {
  $45 = ($24 | 0) < ($29 | 0) | ($24 | 0) > ($35 | 0); //@line 11808
 }
 HEAP32[96441] = $45 & 1; //@line 11811
 if (($9 & 8 | 0) != 0 & $45) {
  __Z9Exceptionij(6, $6); //@line 11816
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11821
  return;
 }
}
function __Z12op_21b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $24 = 0, $31 = 0, $33 = 0, $35 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 33262
 $5 = $4 + 2 | 0; //@line 33263
 HEAP32[162769] = $5; //@line 33264
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33266
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 33273
 HEAP32[162769] = $4 + 4; //@line 33275
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 33276
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 33281
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33283
 $24 = HEAP32[162769] | 0; //@line 33284
 $31 = (HEAPU8[$24 >> 0] | 0) << 8 | (HEAPU8[$24 + 1 >> 0] | 0); //@line 33291
 HEAP32[162769] = $24 + 2; //@line 33293
 $33 = __Z15get_disp_ea_020jj($23, $31) | 0; //@line 33294
 $35 = ($21 | 0) == 0 & 1; //@line 33296
 HEAP32[96441] = 0; //@line 33297
 HEAP32[96442] = 0; //@line 33297
 HEAP32[96443] = 0; //@line 33297
 HEAP32[96444] = 0; //@line 33297
 HEAP32[96442] = $35; //@line 33298
 HEAP32[96443] = $21 >>> 31; //@line 33300
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $21); //@line 33306
 return;
}
function __Z12op_4830_0_ffj($0) {
 $0 = $0 | 0;
 var $$027$in = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $21 = 0, $25 = 0, $27 = 0, $3 = 0, $30 = 0, $32 = 0, $33 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 49863
 $3 = $2 + 2 | 0; //@line 49864
 HEAP32[162769] = $3; //@line 49865
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49867
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 49874
 HEAP32[162769] = $2 + 4; //@line 49876
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 49877
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 49879
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 49885
 $25 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($21 & 15) | 0; //@line 49890
 $27 = $25 & 65535; //@line 49892
 $30 = ($27 >>> 0 > 9 ? $27 + -6 | 0 : $25) - ($21 & 240) | 0; //@line 49896
 $32 = ($30 & 496) >>> 0 > 144; //@line 49898
 $33 = $32 & 1; //@line 49899
 $$027$in = $32 ? ($30 & 65535) + -96 | 0 : $30; //@line 49902
 HEAP32[96441] = $33; //@line 49903
 HEAP32[96445] = $33; //@line 49904
 HEAP32[96442] = ($$027$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49910
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $$027$in & 65535); //@line 49915
 return;
}
function __Z11op_e58_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $16 = 0, $28 = 0, $33 = 0, $35 = 0, $37 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21789
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21796
 $9 = $7 << 24 >> 16; //@line 21798
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 21801
 $13 = HEAP32[$12 >> 2] | 0; //@line 21802
 do {
  if (!($9 & 2048)) {
   $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 21810
   HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 2; //@line 21813
   $33 = $28 << 16 >> 16; //@line 21817
   $35 = $7 >>> 4 & 7; //@line 21819
   if (!($9 & 32768)) {
    $37 = 651008 + ($35 << 2) | 0; //@line 21821
    HEAP32[$37 >> 2] = HEAP32[$37 >> 2] & -65536 | $33 & 65535; //@line 21826
    break;
   } else {
    HEAP32[651040 + ($35 << 2) >> 2] = $33; //@line 21830
    break;
   }
  } else {
   $16 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 21836
   HEAP32[$12 >> 2] = $13 + 2; //@line 21838
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $16); //@line 21844
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21849
 return;
}
function __Z12op_907a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $31 = 0, $4 = 0, $41 = 0, $sext37$lobit = 0, $sext37$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 18785
 $$cast = $4; //@line 18787
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 18801
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 18807
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18808
 $26 = HEAP32[$25 >> 2] | 0; //@line 18809
 $29 = ($26 << 16 >> 16) - ($24 << 16 >> 16) | 0; //@line 18814
 $31 = $26 >>> 15; //@line 18816
 $sext37$lobit = $29 >>> 15 & 1; //@line 18819
 $sext37$mask = $29 & 65535; //@line 18820
 HEAP32[96442] = ($sext37$mask | 0) == 0 & 1; //@line 18823
 HEAP32[96444] = ($sext37$lobit ^ $31 & 1) & ($31 ^ $24 >>> 15); //@line 18827
 $41 = ($24 & 65535) >>> 0 > ($26 & 65535) >>> 0 & 1; //@line 18831
 HEAP32[96441] = $41; //@line 18832
 HEAP32[96445] = $41; //@line 18833
 HEAP32[96443] = $sext37$lobit; //@line 18834
 HEAP32[$25 >> 2] = $26 & -65536 | $sext37$mask; //@line 18837
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18840
 return;
}
function __Z12op_903b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $30 = 0, $4 = 0, $40 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 23766
 $$cast = $4; //@line 23771
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23780
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 23786
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23787
 $25 = HEAP32[$24 >> 2] | 0; //@line 23788
 $28 = ($25 << 24 >> 24) - ($23 << 24 >> 24) | 0; //@line 23793
 $30 = $25 >>> 7; //@line 23795
 $sext34$lobit = $28 >>> 7 & 1; //@line 23798
 $sext34$mask = $28 & 255; //@line 23799
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 23802
 HEAP32[96444] = ($sext34$lobit ^ $30 & 1) & ($30 ^ $23 >>> 7); //@line 23806
 $40 = ($23 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 23810
 HEAP32[96441] = $40; //@line 23811
 HEAP32[96445] = $40; //@line 23812
 HEAP32[96443] = $sext34$lobit; //@line 23813
 HEAP32[$24 >> 2] = $25 & -256 | $sext34$mask; //@line 23816
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23819
 return;
}
function __Z12op_5130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5286
 $6 = HEAP32[162769] | 0; //@line 5288
 $7 = $6 + 2 | 0; //@line 5289
 HEAP32[162769] = $7; //@line 5290
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5292
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 5299
 HEAP32[162769] = $6 + 4; //@line 5301
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 5302
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5304
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 5308
 $27 = ($24 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5313
 $29 = $24 >>> 7; //@line 5315
 $sext36$lobit = $27 >>> 7 & 1; //@line 5318
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 5322
 HEAP32[96444] = ($sext36$lobit ^ $29 & 1) & ($29 ^ $4 >>> 7); //@line 5326
 $39 = ($4 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 5330
 HEAP32[96441] = $39; //@line 5331
 HEAP32[96445] = $39; //@line 5332
 HEAP32[96443] = $sext36$lobit; //@line 5333
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 5337
 return;
}
function __Z11op_658_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $21 = 0, $23 = 0, $26 = 0, $35 = 0, $5 = 0, $sext35$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12774
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12777
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12782
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 12783
 $12 = HEAP32[$11 >> 2] | 0; //@line 12784
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 12786
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 12790
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 12793
 $21 = $18 << 16 >> 16; //@line 12795
 $23 = $21 + ($10 << 16 >> 16) | 0; //@line 12798
 $26 = $23 >>> 15; //@line 12802
 $sext35$lobit = $26 & 1; //@line 12803
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 12807
 HEAP32[96444] = ($sext35$lobit ^ $18 >>> 15 & 1) & ($26 ^ $5 >>> 7); //@line 12811
 $35 = ($21 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 12815
 HEAP32[96441] = $35; //@line 12816
 HEAP32[96445] = $35; //@line 12817
 HEAP32[96443] = $sext35$lobit; //@line 12818
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $23); //@line 12822
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12825
 return;
}
function __Z12op_d018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $23 = 0, $33 = 0, $4 = 0, $5 = 0, $sext37$lobit = 0, $sext37$mask = 0;
 $1 = $0 & 7; //@line 31324
 $4 = 651040 + ($1 << 2) | 0; //@line 31327
 $5 = HEAP32[$4 >> 2] | 0; //@line 31328
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 31334
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 31339
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31340
 $17 = HEAP32[$16 >> 2] | 0; //@line 31341
 $18 = $17 << 24 >> 24; //@line 31343
 $20 = $18 + ($11 << 24 >> 24) | 0; //@line 31346
 $23 = $20 >>> 7; //@line 31350
 $sext37$lobit = $23 & 1; //@line 31351
 $sext37$mask = $20 & 255; //@line 31352
 HEAP32[96442] = ($sext37$mask | 0) == 0 & 1; //@line 31355
 HEAP32[96444] = ($sext37$lobit ^ $17 >>> 7 & 1) & ($23 ^ $11 >>> 7); //@line 31359
 $33 = ($18 & 255 ^ 255) >>> 0 < ($11 & 255) >>> 0 & 1; //@line 31364
 HEAP32[96441] = $33; //@line 31365
 HEAP32[96445] = $33; //@line 31366
 HEAP32[96443] = $sext37$lobit; //@line 31367
 HEAP32[$16 >> 2] = $17 & -256 | $sext37$mask; //@line 31370
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31373
 return;
}
function __Z6mmu_opjt($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $11 = 0, $trunc$i = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 52167
 STACKTOP = STACKTOP + 16 | 0; //@line 52168
 $vararg_buffer = sp; //@line 52169
 if (($0 & 4064 | 0) == 1280) {
  HEAP32[162818] = 0; //@line 52173
  STACKTOP = sp; //@line 52174
  return;
 }
 if (($0 & 4056 | 0) == 1352) {
  STACKTOP = sp; //@line 52179
  return;
 }
 $trunc$i = $0 & 61440; //@line 52182
 L8 : do {
  if ($trunc$i << 16 >> 16 < -4096) {
   switch ($trunc$i << 16 >> 16) {
   case -24576:
    {
     break;
    }
   default:
    {
     break L8;
    }
   }
   __Z9Exceptionij(10, 0); //@line 52194
   STACKTOP = sp; //@line 52195
   return;
  } else {
   switch ($trunc$i << 16 >> 16) {
   case -4096:
    {
     break;
    }
   default:
    {
     break L8;
    }
   }
   __Z9Exceptionij(11, 0); //@line 52205
   STACKTOP = sp; //@line 52206
   return;
  }
 } while (0);
 $11 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 52213
 HEAP32[$vararg_buffer >> 2] = $0; //@line 52214
 HEAP32[$vararg_buffer + 4 >> 2] = $11; //@line 52216
 _printf(105458, $vararg_buffer) | 0; //@line 52217
 __Z9Exceptionij(4, 0); //@line 52218
 STACKTOP = sp; //@line 52219
 return;
}
function __Z12op_23fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $38 = 0, $40 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 34736
 $2 = $1 + 2 | 0; //@line 34737
 HEAP32[162769] = $2; //@line 34738
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 34743
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 34750
 HEAP32[162769] = $1 + 4; //@line 34752
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 34753
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 34758
 $21 = HEAP32[162769] | 0; //@line 34759
 $29 = (HEAPU8[$21 + 1 >> 0] | 0) << 16 | (HEAPU8[$21 >> 0] | 0) << 24; //@line 34767
 $38 = $29 | (HEAPU8[$21 + 2 >> 0] | 0) << 8 | (HEAPU8[$21 + 3 >> 0] | 0); //@line 34776
 $40 = ($20 | 0) == 0 & 1; //@line 34778
 HEAP32[96441] = 0; //@line 34779
 HEAP32[96442] = 0; //@line 34779
 HEAP32[96443] = 0; //@line 34779
 HEAP32[96444] = 0; //@line 34779
 HEAP32[96442] = $40; //@line 34780
 HEAP32[96443] = $20 >>> 31; //@line 34782
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($38, $20); //@line 34788
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 34791
 return;
}
function __Z12op_d070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $6 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 36605
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36614
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 36620
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36621
 $23 = HEAP32[$22 >> 2] | 0; //@line 36622
 $24 = $23 << 16 >> 16; //@line 36624
 $26 = $24 + ($21 << 16 >> 16) | 0; //@line 36627
 $29 = $26 >>> 15; //@line 36631
 $sext39$lobit = $29 & 1; //@line 36632
 $sext39$mask = $26 & 65535; //@line 36633
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 36636
 HEAP32[96444] = ($sext39$lobit ^ $23 >>> 15 & 1) & ($29 ^ $21 >>> 15); //@line 36640
 $39 = ($24 & 65535 ^ 65535) >>> 0 < ($21 & 65535) >>> 0 & 1; //@line 36645
 HEAP32[96441] = $39; //@line 36646
 HEAP32[96445] = $39; //@line 36647
 HEAP32[96443] = $sext39$lobit; //@line 36648
 HEAP32[$22 >> 2] = $23 & -65536 | $sext39$mask; //@line 36651
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36654
 return;
}
function __Z12op_903a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $29 = 0, $31 = 0, $4 = 0, $41 = 0, $sext33$lobit = 0, $sext33$mask = 0;
 $4 = HEAP32[162769] | 0; //@line 18106
 $$cast = $4; //@line 18108
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 18122
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 18128
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18129
 $26 = HEAP32[$25 >> 2] | 0; //@line 18130
 $29 = ($26 << 24 >> 24) - ($24 << 24 >> 24) | 0; //@line 18135
 $31 = $26 >>> 7; //@line 18137
 $sext33$lobit = $29 >>> 7 & 1; //@line 18140
 $sext33$mask = $29 & 255; //@line 18141
 HEAP32[96442] = ($sext33$mask | 0) == 0 & 1; //@line 18144
 HEAP32[96444] = ($sext33$lobit ^ $31 & 1) & ($31 ^ $24 >>> 7); //@line 18148
 $41 = ($24 & 255) >>> 0 > ($26 & 255) >>> 0 & 1; //@line 18152
 HEAP32[96441] = $41; //@line 18153
 HEAP32[96445] = $41; //@line 18154
 HEAP32[96443] = $sext33$lobit; //@line 18155
 HEAP32[$25 >> 2] = $26 & -256 | $sext33$mask; //@line 18158
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18161
 return;
}
function __Z12op_1198_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $19 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 26108
 $4 = 651040 + ($1 << 2) | 0; //@line 26111
 $5 = HEAP32[$4 >> 2] | 0; //@line 26112
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 26118
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 26123
 $16 = HEAP32[162769] | 0; //@line 26124
 $17 = $16 + 2 | 0; //@line 26125
 HEAP32[162769] = $17; //@line 26126
 $19 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26128
 $26 = (HEAPU8[$17 >> 0] | 0) << 8 | (HEAPU8[$16 + 3 >> 0] | 0); //@line 26135
 HEAP32[162769] = $16 + 4; //@line 26137
 $28 = __Z15get_disp_ea_020jj($19, $26) | 0; //@line 26138
 $29 = $11 << 24 >> 24; //@line 26140
 $31 = ($29 | 0) == 0 & 1; //@line 26142
 HEAP32[96441] = 0; //@line 26143
 HEAP32[96442] = 0; //@line 26143
 HEAP32[96443] = 0; //@line 26143
 HEAP32[96444] = 0; //@line 26143
 HEAP32[96442] = $31; //@line 26144
 HEAP32[96443] = $11 >>> 7 & 1; //@line 26147
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, $29); //@line 26153
 return;
}
function __Z11op_4b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit29 = 0, $$lobit30 = 0, $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $4 = 0, $42 = 0, $43 = 0, $50 = 0;
 $1 = HEAP32[162769] | 0; //@line 11619
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 11622
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 11637
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 11646
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 11655
 $39 = 123608 + ($28 >>> 16 << 2) | 0; //@line 11657
 $42 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$39 >> 2] >> 2] & 127]($37) | 0; //@line 11660
 $43 = $42 - $19 | 0; //@line 11661
 $$lobit29 = $42 >>> 31; //@line 11663
 $$lobit30 = $43 >>> 31; //@line 11664
 HEAP32[96442] = ($43 | 0) == 0 & 1; //@line 11667
 HEAP32[96444] = ($$lobit30 ^ $$lobit29) & ($$lobit29 ^ $4 >>> 7); //@line 11671
 $50 = $42 >>> 0 < $19 >>> 0 & 1; //@line 11673
 HEAP32[96441] = $50; //@line 11674
 HEAP32[96445] = $50; //@line 11675
 HEAP32[96443] = $$lobit30; //@line 11676
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$39 >> 2] | 0) + 12 >> 2] & 31]($37, $43); //@line 11680
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 11683
 return;
}
function __Z12op_d079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $35 = 0, $45 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 32322
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 32331
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 32346
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32347
 $29 = HEAP32[$28 >> 2] | 0; //@line 32348
 $30 = $29 << 16 >> 16; //@line 32350
 $32 = $30 + ($27 << 16 >> 16) | 0; //@line 32353
 $35 = $32 >>> 15; //@line 32357
 $sext35$lobit = $35 & 1; //@line 32358
 $sext35$mask = $32 & 65535; //@line 32359
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 32362
 HEAP32[96444] = ($sext35$lobit ^ $29 >>> 15 & 1) & ($35 ^ $27 >>> 15); //@line 32366
 $45 = ($30 & 65535 ^ 65535) >>> 0 < ($27 & 65535) >>> 0 & 1; //@line 32371
 HEAP32[96441] = $45; //@line 32372
 HEAP32[96445] = $45; //@line 32373
 HEAP32[96443] = $sext35$lobit; //@line 32374
 HEAP32[$28 >> 2] = $29 & -65536 | $sext35$mask; //@line 32377
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 32380
 return;
}
function __Z11op_e60_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $17 = 0, $28 = 0, $31 = 0, $33 = 0, $35 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21861
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21868
 $9 = $7 << 24 >> 16; //@line 21870
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 21873
 $14 = (HEAP32[$12 >> 2] | 0) + -2 | 0; //@line 21875
 do {
  if (!($9 & 2048)) {
   $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 21883
   HEAP32[$12 >> 2] = $14; //@line 21884
   $31 = $28 << 16 >> 16; //@line 21888
   $33 = $7 >>> 4 & 7; //@line 21890
   if (!($9 & 32768)) {
    $35 = 651008 + ($33 << 2) | 0; //@line 21892
    HEAP32[$35 >> 2] = HEAP32[$35 >> 2] & -65536 | $31 & 65535; //@line 21897
    break;
   } else {
    HEAP32[651040 + ($33 << 2) >> 2] = $31; //@line 21901
    break;
   }
  } else {
   $17 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 21907
   HEAP32[$12 >> 2] = $14; //@line 21908
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, $17); //@line 21914
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21919
 return;
}
function __Z11op_660_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $25 = 0, $34 = 0, $5 = 0, $sext36$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12835
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12838
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12843
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 12844
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 12846
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 12848
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 12852
 HEAP32[$11 >> 2] = $13; //@line 12853
 $20 = $19 << 16 >> 16; //@line 12855
 $22 = $20 + ($10 << 16 >> 16) | 0; //@line 12858
 $25 = $22 >>> 15; //@line 12862
 $sext36$lobit = $25 & 1; //@line 12863
 HEAP32[96442] = ($22 & 65535 | 0) == 0 & 1; //@line 12867
 HEAP32[96444] = ($sext36$lobit ^ $19 >>> 15 & 1) & ($25 ^ $5 >>> 7); //@line 12871
 $34 = ($20 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 12875
 HEAP32[96441] = $34; //@line 12876
 HEAP32[96445] = $34; //@line 12877
 HEAP32[96443] = $sext36$lobit; //@line 12878
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $22); //@line 12882
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12885
 return;
}
function __Z12op_d068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $6 = 0, $sext40$lobit = 0, $sext40$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 32136
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 32147
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 32153
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32154
 $24 = HEAP32[$23 >> 2] | 0; //@line 32155
 $25 = $24 << 16 >> 16; //@line 32157
 $27 = $25 + ($22 << 16 >> 16) | 0; //@line 32160
 $30 = $27 >>> 15; //@line 32164
 $sext40$lobit = $30 & 1; //@line 32165
 $sext40$mask = $27 & 65535; //@line 32166
 HEAP32[96442] = ($sext40$mask | 0) == 0 & 1; //@line 32169
 HEAP32[96444] = ($sext40$lobit ^ $24 >>> 15 & 1) & ($30 ^ $22 >>> 15); //@line 32173
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($22 & 65535) >>> 0 & 1; //@line 32178
 HEAP32[96441] = $40; //@line 32179
 HEAP32[96445] = $40; //@line 32180
 HEAP32[96443] = $sext40$lobit; //@line 32181
 HEAP32[$23 >> 2] = $24 & -65536 | $sext40$mask; //@line 32184
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32187
 return;
}
function __Z12op_113b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $4 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 25299
 $3 = HEAP32[162769] | 0; //@line 25300
 $4 = $3 + 2 | 0; //@line 25301
 HEAP32[162769] = $4; //@line 25302
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 25307
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 25314
 HEAP32[162769] = $3 + 4; //@line 25316
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 25317
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 25323
 $24 = 651040 + ($2 << 2) | 0; //@line 25324
 $28 = (HEAP32[$24 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 25328
 HEAP32[$24 >> 2] = $28; //@line 25329
 $29 = $23 << 24 >> 24; //@line 25331
 $31 = ($29 | 0) == 0 & 1; //@line 25333
 HEAP32[96441] = 0; //@line 25334
 HEAP32[96442] = 0; //@line 25334
 HEAP32[96443] = 0; //@line 25334
 HEAP32[96444] = 0; //@line 25334
 HEAP32[96442] = $31; //@line 25335
 HEAP32[96443] = $23 >>> 7 & 1; //@line 25338
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, $29); //@line 25344
 return;
}
function __Z11op_670_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $23 = 0, $27 = 0, $28 = 0, $30 = 0, $33 = 0, $42 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 17158
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 17161
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 17166
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17177
 $23 = 123608 + ($21 >>> 16 << 2) | 0; //@line 17179
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 4 >> 2] & 127]($21) | 0; //@line 17183
 $28 = $27 << 16 >> 16; //@line 17185
 $30 = $28 + ($10 << 16 >> 16) | 0; //@line 17188
 $33 = $30 >>> 15; //@line 17192
 $sext34$lobit = $33 & 1; //@line 17193
 HEAP32[96442] = ($30 & 65535 | 0) == 0 & 1; //@line 17197
 HEAP32[96444] = ($sext34$lobit ^ $27 >>> 15 & 1) & ($33 ^ $5 >>> 7); //@line 17201
 $42 = ($28 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 17205
 HEAP32[96441] = $42; //@line 17206
 HEAP32[96445] = $42; //@line 17207
 HEAP32[96443] = $sext34$lobit; //@line 17208
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($21, $30); //@line 17212
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17215
 return;
}
function __Z12op_d179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $35 = 0, $4 = 0, $45 = 0, $5 = 0, $sext34$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34559
 $5 = HEAP32[162769] | 0; //@line 34560
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 34569
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 34578
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 34580
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0; //@line 34584
 $30 = $29 << 16 >> 16; //@line 34586
 $32 = $30 + ($4 << 16 >> 16) | 0; //@line 34589
 $35 = $32 >>> 15; //@line 34593
 $sext34$lobit = $35 & 1; //@line 34594
 HEAP32[96442] = ($32 & 65535 | 0) == 0 & 1; //@line 34598
 HEAP32[96444] = ($sext34$lobit ^ $29 >>> 15 & 1) & ($35 ^ $4 >>> 15); //@line 34602
 $45 = ($30 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 34607
 HEAP32[96441] = $45; //@line 34608
 HEAP32[96445] = $45; //@line 34609
 HEAP32[96443] = $sext34$lobit; //@line 34610
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $32); //@line 34614
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34617
 return;
}
function __Z12op_d020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $22 = 0, $32 = 0, $4 = 0, $8 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $1 = $0 & 7; //@line 31382
 $4 = 651040 + ($1 << 2) | 0; //@line 31385
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 31389
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 31395
 HEAP32[$4 >> 2] = $8; //@line 31396
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31397
 $16 = HEAP32[$15 >> 2] | 0; //@line 31398
 $17 = $16 << 24 >> 24; //@line 31400
 $19 = $17 + ($14 << 24 >> 24) | 0; //@line 31403
 $22 = $19 >>> 7; //@line 31407
 $sext38$lobit = $22 & 1; //@line 31408
 $sext38$mask = $19 & 255; //@line 31409
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 31412
 HEAP32[96444] = ($sext38$lobit ^ $16 >>> 7 & 1) & ($22 ^ $14 >>> 7); //@line 31416
 $32 = ($17 & 255 ^ 255) >>> 0 < ($14 & 255) >>> 0 & 1; //@line 31421
 HEAP32[96441] = $32; //@line 31422
 HEAP32[96445] = $32; //@line 31423
 HEAP32[96443] = $sext38$lobit; //@line 31424
 HEAP32[$15 >> 2] = $16 & -256 | $sext38$mask; //@line 31427
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31430
 return;
}
function __Z12op_23f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $19 = 0, $2 = 0, $20 = 0, $28 = 0, $3 = 0, $37 = 0, $39 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 34486
 $3 = $2 + 2 | 0; //@line 34487
 HEAP32[162769] = $3; //@line 34488
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34490
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 34497
 HEAP32[162769] = $2 + 4; //@line 34499
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 34500
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 34505
 $20 = HEAP32[162769] | 0; //@line 34506
 $28 = (HEAPU8[$20 + 1 >> 0] | 0) << 16 | (HEAPU8[$20 >> 0] | 0) << 24; //@line 34514
 $37 = $28 | (HEAPU8[$20 + 2 >> 0] | 0) << 8 | (HEAPU8[$20 + 3 >> 0] | 0); //@line 34523
 $39 = ($19 | 0) == 0 & 1; //@line 34525
 HEAP32[96441] = 0; //@line 34526
 HEAP32[96442] = 0; //@line 34526
 HEAP32[96443] = 0; //@line 34526
 HEAP32[96444] = 0; //@line 34526
 HEAP32[96442] = $39; //@line 34527
 HEAP32[96443] = $19 >>> 31; //@line 34529
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($37, $19); //@line 34535
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 34538
 return;
}
function __Z12op_e170_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$038 = 0, $$1$in = 0, $14 = 0, $17 = 0, $18 = 0, $24 = 0, $26 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39497
 $7 = HEAP32[$6 >> 2] | 0; //@line 39498
 $8 = $7 & 65535; //@line 39499
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39500
 $$ = $9 >>> 0 > 33 ? $9 + -34 | 0 : $9; //@line 39503
 $$1$in = ($$ | 0) > 16 ? $$ + -17 | 0 : $$; //@line 39506
 $14 = ($$1$in | 0) > 0; //@line 39507
 HEAP32[96441] = 0; //@line 39508
 HEAP32[96442] = 0; //@line 39508
 HEAP32[96443] = 0; //@line 39508
 HEAP32[96444] = 0; //@line 39508
 if ($14) {
  $17 = $8 >>> (16 - $$1$in | 0); //@line 39512
  $18 = $17 & 1; //@line 39513
  $24 = (HEAP32[96445] | $8 << 1) << $$1$in + -1 | $17 >>> 1; //@line 39519
  HEAP32[96445] = $18; //@line 39520
  $$038 = $24 & 65535; //@line 39522
  $26 = $18; //@line 39522
 } else {
  $$038 = $8; //@line 39525
  $26 = HEAP32[96445] | 0; //@line 39525
 }
 HEAP32[96441] = $26; //@line 39527
 HEAP32[96442] = ($$038 | 0) == 0 & 1; //@line 39530
 HEAP32[96443] = $$038 >>> 15; //@line 39532
 HEAP32[$6 >> 2] = $7 & -65536 | $$038; //@line 39535
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39538
 return;
}
function __Z12op_e070_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$041 = 0, $$1$in = 0, $14 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38050
 $7 = HEAP32[$6 >> 2] | 0; //@line 38051
 $8 = $7 & 65535; //@line 38052
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38053
 $$ = $9 >>> 0 > 33 ? $9 + -34 | 0 : $9; //@line 38056
 $$1$in = ($$ | 0) > 16 ? $$ + -17 | 0 : $$; //@line 38059
 $14 = ($$1$in | 0) > 0; //@line 38060
 HEAP32[96441] = 0; //@line 38061
 HEAP32[96442] = 0; //@line 38061
 HEAP32[96443] = 0; //@line 38061
 HEAP32[96444] = 0; //@line 38061
 if ($14) {
  $21 = $8 >>> ($$1$in + -1 | 0); //@line 38069
  $22 = $21 & 1; //@line 38070
  $24 = (HEAP32[96445] | $8 << 1) << 16 - $$1$in | $21 >>> 1; //@line 38072
  HEAP32[96445] = $22; //@line 38073
  $$041 = $24 & 65535; //@line 38075
  $26 = $22; //@line 38075
 } else {
  $$041 = $8; //@line 38078
  $26 = HEAP32[96445] | 0; //@line 38078
 }
 HEAP32[96441] = $26; //@line 38080
 HEAP32[96442] = ($$041 | 0) == 0 & 1; //@line 38083
 HEAP32[96443] = $$041 >>> 15; //@line 38085
 HEAP32[$6 >> 2] = $7 & -65536 | $$041; //@line 38088
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38091
 return;
}
function __Z11op_668_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $24 = 0, $28 = 0, $29 = 0, $31 = 0, $34 = 0, $43 = 0, $5 = 0, $sext35$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12895
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12898
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12903
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 12916
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 12918
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 12922
 $29 = $28 << 16 >> 16; //@line 12924
 $31 = $29 + ($10 << 16 >> 16) | 0; //@line 12927
 $34 = $31 >>> 15; //@line 12931
 $sext35$lobit = $34 & 1; //@line 12932
 HEAP32[96442] = ($31 & 65535 | 0) == 0 & 1; //@line 12936
 HEAP32[96444] = ($sext35$lobit ^ $28 >>> 15 & 1) & ($34 ^ $5 >>> 7); //@line 12940
 $43 = ($29 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 12944
 HEAP32[96441] = $43; //@line 12945
 HEAP32[96445] = $43; //@line 12946
 HEAP32[96443] = $sext35$lobit; //@line 12947
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $31); //@line 12951
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 12954
 return;
}
function __Z12op_10fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $3 = 0, $31 = 0, $4 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 24764
 $3 = HEAP32[162769] | 0; //@line 24765
 $4 = $3 + 2 | 0; //@line 24766
 HEAP32[162769] = $4; //@line 24767
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 24772
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 24779
 HEAP32[162769] = $3 + 4; //@line 24781
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 24782
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 24788
 $24 = 651040 + ($2 << 2) | 0; //@line 24789
 $25 = HEAP32[$24 >> 2] | 0; //@line 24790
 HEAP32[$24 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $25; //@line 24794
 $29 = $23 << 24 >> 24; //@line 24796
 $31 = ($29 | 0) == 0 & 1; //@line 24798
 HEAP32[96441] = 0; //@line 24799
 HEAP32[96442] = 0; //@line 24799
 HEAP32[96443] = 0; //@line 24799
 HEAP32[96444] = 0; //@line 24799
 HEAP32[96442] = $31; //@line 24800
 HEAP32[96443] = $23 >>> 7 & 1; //@line 24803
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $29); //@line 24809
 return;
}
function __Z12op_d030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $6 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 36476
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36485
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 36491
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36492
 $23 = HEAP32[$22 >> 2] | 0; //@line 36493
 $24 = $23 << 24 >> 24; //@line 36495
 $26 = $24 + ($21 << 24 >> 24) | 0; //@line 36498
 $29 = $26 >>> 7; //@line 36502
 $sext35$lobit = $29 & 1; //@line 36503
 $sext35$mask = $26 & 255; //@line 36504
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 36507
 HEAP32[96444] = ($sext35$lobit ^ $23 >>> 7 & 1) & ($29 ^ $21 >>> 7); //@line 36511
 $39 = ($24 & 255 ^ 255) >>> 0 < ($21 & 255) >>> 0 & 1; //@line 36516
 HEAP32[96441] = $39; //@line 36517
 HEAP32[96445] = $39; //@line 36518
 HEAP32[96443] = $sext35$lobit; //@line 36519
 HEAP32[$22 >> 2] = $23 & -256 | $sext35$mask; //@line 36522
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36525
 return;
}
function __Z12op_11a0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 26161
 $4 = 651040 + ($1 << 2) | 0; //@line 26164
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 26168
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 26174
 HEAP32[$4 >> 2] = $8; //@line 26175
 $15 = HEAP32[162769] | 0; //@line 26176
 $16 = $15 + 2 | 0; //@line 26177
 HEAP32[162769] = $16; //@line 26178
 $18 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26180
 $25 = (HEAPU8[$16 >> 0] | 0) << 8 | (HEAPU8[$15 + 3 >> 0] | 0); //@line 26187
 HEAP32[162769] = $15 + 4; //@line 26189
 $27 = __Z15get_disp_ea_020jj($18, $25) | 0; //@line 26190
 $28 = $14 << 24 >> 24; //@line 26192
 $30 = ($28 | 0) == 0 & 1; //@line 26194
 HEAP32[96441] = 0; //@line 26195
 HEAP32[96442] = 0; //@line 26195
 HEAP32[96443] = 0; //@line 26195
 HEAP32[96444] = 0; //@line 26195
 HEAP32[96442] = $30; //@line 26196
 HEAP32[96443] = $14 >>> 7 & 1; //@line 26199
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($27, $28); //@line 26205
 return;
}
function __Z12op_d039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $35 = 0, $45 = 0, $sext31$lobit = 0, $sext31$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 31630
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 31639
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 31654
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31655
 $29 = HEAP32[$28 >> 2] | 0; //@line 31656
 $30 = $29 << 24 >> 24; //@line 31658
 $32 = $30 + ($27 << 24 >> 24) | 0; //@line 31661
 $35 = $32 >>> 7; //@line 31665
 $sext31$lobit = $35 & 1; //@line 31666
 $sext31$mask = $32 & 255; //@line 31667
 HEAP32[96442] = ($sext31$mask | 0) == 0 & 1; //@line 31670
 HEAP32[96444] = ($sext31$lobit ^ $29 >>> 7 & 1) & ($35 ^ $27 >>> 7); //@line 31674
 $45 = ($30 & 255 ^ 255) >>> 0 < ($27 & 255) >>> 0 & 1; //@line 31679
 HEAP32[96441] = $45; //@line 31680
 HEAP32[96445] = $45; //@line 31681
 HEAP32[96443] = $sext31$lobit; //@line 31682
 HEAP32[$28 >> 2] = $29 & -256 | $sext31$mask; //@line 31685
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31688
 return;
}
function __Z12op_1130_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 25080
 $4 = HEAP32[162769] | 0; //@line 25081
 $5 = $4 + 2 | 0; //@line 25082
 HEAP32[162769] = $5; //@line 25083
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25085
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 25092
 HEAP32[162769] = $4 + 4; //@line 25094
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 25095
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 25101
 $23 = 651040 + ($3 << 2) | 0; //@line 25102
 $27 = (HEAP32[$23 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 25106
 HEAP32[$23 >> 2] = $27; //@line 25107
 $28 = $22 << 24 >> 24; //@line 25109
 $30 = ($28 | 0) == 0 & 1; //@line 25111
 HEAP32[96441] = 0; //@line 25112
 HEAP32[96442] = 0; //@line 25112
 HEAP32[96443] = 0; //@line 25112
 HEAP32[96444] = 0; //@line 25112
 HEAP32[96442] = $30; //@line 25113
 HEAP32[96443] = $22 >>> 7 & 1; //@line 25116
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($27, $28); //@line 25122
 return;
}
function __Z12op_ecc0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $33 = 0, $46 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 45175
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 45184
 $11 = $sext >> 16; //@line 45185
 $14 = $sext >> 22; //@line 45188
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 45191
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 45196
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 45201
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 45206
 }
 $26 = $25 + 31 & 31; //@line 45209
 $27 = 651008 + (($0 & 7) << 2) | 0; //@line 45210
 $28 = HEAP32[$27 >> 2] | 0; //@line 45211
 $29 = $30 & 31; //@line 45212
 $33 = $28 << $29 >>> ($26 ^ 31); //@line 45215
 HEAP32[96443] = ($33 & 1 << $26 | 0) != 0 & 1; //@line 45220
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 45223
 HEAP32[96444] = 0; //@line 45224
 HEAP32[96441] = 0; //@line 45225
 $46 = $29 + 1 + $26 | 0; //@line 45232
 HEAP32[$27 >> 2] = ($46 >>> 0 > 31 ? 0 : -1 >>> $46 & $28) | $28 & (($29 | 0) == 0 ? 0 : -1 << 32 - $29); //@line 45238
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45241
 return;
}
function __Z12op_d139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $35 = 0, $4 = 0, $45 = 0, $5 = 0, $sext30$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34010
 $5 = HEAP32[162769] | 0; //@line 34011
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 34020
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 34029
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 34031
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0; //@line 34035
 $30 = $29 << 24 >> 24; //@line 34037
 $32 = $30 + ($4 << 24 >> 24) | 0; //@line 34040
 $35 = $32 >>> 7; //@line 34044
 $sext30$lobit = $35 & 1; //@line 34045
 HEAP32[96442] = ($32 & 255 | 0) == 0 & 1; //@line 34049
 HEAP32[96444] = ($sext30$lobit ^ $29 >>> 7 & 1) & ($35 ^ $4 >>> 7); //@line 34053
 $45 = ($30 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 34058
 HEAP32[96441] = $45; //@line 34059
 HEAP32[96445] = $45; //@line 34060
 HEAP32[96443] = $sext30$lobit; //@line 34061
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $32); //@line 34065
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34068
 return;
}
function __Z11op_4fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $2 = 0, $22 = 0, $27 = 0, $28 = 0, $33 = 0, $43 = 0, $5 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 12055
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 12058
 $$cast = $2; //@line 12059
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 12062
 $19 = $5 + 4 + (((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 12074
 $22 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 12077
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19) | 0; //@line 12082
 $28 = $19 + 4 | 0; //@line 12083
 $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($28 >>> 16 << 2) >> 2] >> 2] & 127]($28) | 0; //@line 12088
 HEAP32[96442] = (($27 | 0) == ($22 | 0) | ($33 | 0) == ($22 | 0)) & 1; //@line 12093
 if (($27 | 0) > ($33 | 0)) {
  $43 = ($22 | 0) < ($27 | 0) | ($22 | 0) > ($33 | 0); //@line 12099
 } else {
  $43 = ($22 | 0) < ($27 | 0) | ($22 | 0) > ($33 | 0); //@line 12104
 }
 HEAP32[96441] = $43 & 1; //@line 12107
 if (($8 & 8 | 0) != 0 & $43) {
  __Z9Exceptionij(6, $5); //@line 12112
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 12117
  return;
 }
}
function __Z12op_d028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $6 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 31444
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 31455
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 31461
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31462
 $24 = HEAP32[$23 >> 2] | 0; //@line 31463
 $25 = $24 << 24 >> 24; //@line 31465
 $27 = $25 + ($22 << 24 >> 24) | 0; //@line 31468
 $30 = $27 >>> 7; //@line 31472
 $sext36$lobit = $30 & 1; //@line 31473
 $sext36$mask = $27 & 255; //@line 31474
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 31477
 HEAP32[96444] = ($sext36$lobit ^ $24 >>> 7 & 1) & ($30 ^ $22 >>> 7); //@line 31481
 $40 = ($25 & 255 ^ 255) >>> 0 < ($22 & 255) >>> 0 & 1; //@line 31486
 HEAP32[96441] = $40; //@line 31487
 HEAP32[96445] = $40; //@line 31488
 HEAP32[96443] = $sext36$lobit; //@line 31489
 HEAP32[$23 >> 2] = $24 & -256 | $sext36$mask; //@line 31492
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31495
 return;
}
function __Z11op_479_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $29 = 0, $33 = 0, $36 = 0, $38 = 0, $4 = 0, $47 = 0, $9 = 0, $sext30$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 11118
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 11121
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 11126
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 11135
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 11144
 $29 = 123608 + ($18 >>> 16 << 2) | 0; //@line 11146
 $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0; //@line 11150
 $36 = ($33 << 16 >> 16) - ($9 << 16 >> 16) | 0; //@line 11155
 $38 = $33 >>> 15; //@line 11157
 $sext30$lobit = $36 >>> 15 & 1; //@line 11160
 HEAP32[96442] = ($36 & 65535 | 0) == 0 & 1; //@line 11164
 HEAP32[96444] = ($sext30$lobit ^ $38 & 1) & ($38 ^ $4 >>> 7); //@line 11168
 $47 = $9 >>> 0 > ($33 & 65535) >>> 0 & 1; //@line 11171
 HEAP32[96441] = $47; //@line 11172
 HEAP32[96445] = $47; //@line 11173
 HEAP32[96443] = $sext30$lobit; //@line 11174
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $36); //@line 11178
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 11181
 return;
}
function ___overflow($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $10 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 62803
 STACKTOP = STACKTOP + 16 | 0; //@line 62804
 $2 = sp; //@line 62805
 $3 = $1 & 255; //@line 62806
 HEAP8[$2 >> 0] = $3; //@line 62807
 $4 = $0 + 16 | 0; //@line 62808
 $5 = HEAP32[$4 >> 2] | 0; //@line 62809
 if (!$5) {
  if (!(___towrite($0) | 0)) {
   $12 = HEAP32[$4 >> 2] | 0; //@line 62816
   label = 4; //@line 62817
  } else {
   $$0 = -1; //@line 62819
  }
 } else {
  $12 = $5; //@line 62822
  label = 4; //@line 62823
 }
 do {
  if ((label | 0) == 4) {
   $9 = $0 + 20 | 0; //@line 62827
   $10 = HEAP32[$9 >> 2] | 0; //@line 62828
   if ($10 >>> 0 < $12 >>> 0) {
    $13 = $1 & 255; //@line 62831
    if (($13 | 0) != (HEAP8[$0 + 75 >> 0] | 0)) {
     HEAP32[$9 >> 2] = $10 + 1; //@line 62838
     HEAP8[$10 >> 0] = $3; //@line 62839
     $$0 = $13; //@line 62840
     break;
    }
   }
   if ((FUNCTION_TABLE_iiii[HEAP32[$0 + 36 >> 2] & 15]($0, $2, 1) | 0) == 1) {
    $$0 = HEAPU8[$2 >> 0] | 0; //@line 62851
   } else {
    $$0 = -1; //@line 62853
   }
  }
 } while (0);
 STACKTOP = sp; //@line 62857
 return $$0 | 0; //@line 62857
}
function __ZN5plist5valueEPKcS1_($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$off014 = 0, $$01013 = 0, $$011 = 0, $17 = 0, $19 = 0, $5 = 0, $8 = 0, label = 0;
 $5 = __ZNK8tinyxml27XMLNode17FirstChildElementEPKc(HEAP32[$0 + 372 >> 2] | 0, 0) | 0; //@line 35686
 if (!$5) {
  $$011 = 0; //@line 35689
  return $$011 | 0; //@line 35690
 } else {
  $$0$off014 = 0; //@line 35692
  $$01013 = $5; //@line 35692
 }
 while (1) {
  $8 = __ZN8tinyxml27StrPair6GetStrEv($$01013 + 12 | 0) | 0; //@line 35696
  if ($$0$off014) {
   break;
  }
  if (!(_strcmp($8, 97286) | 0)) {
   $19 = (_strcmp(__ZNK8tinyxml210XMLElement7GetTextEv($$01013) | 0, $1) | 0) == 0; //@line 35706
  } else {
   $19 = 0; //@line 35708
  }
  $17 = __ZNK8tinyxml27XMLNode18NextSiblingElementEPKc($$01013, 0) | 0; //@line 35710
  if (!$17) {
   $$011 = 0; //@line 35713
   label = 8; //@line 35714
   break;
  } else {
   $$0$off014 = $19; //@line 35717
   $$01013 = $17; //@line 35717
  }
 }
 if ((label | 0) == 8) {
  return $$011 | 0; //@line 35721
 }
 if (_strcmp($8, $2) | 0) {
  $$011 = 0; //@line 35726
  return $$011 | 0; //@line 35727
 }
 $$011 = __ZNK8tinyxml210XMLElement7GetTextEv($$01013) | 0; //@line 35730
 return $$011 | 0; //@line 35731
}
function __Z12op_4079_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $29 = 0, $30 = 0, $31 = 0, $35 = 0, $sext$lobit = 0, $sext28$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 40776
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 40785
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 40794
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40796
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 40800
 $29 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($25 << 16 >> 16) | 0; //@line 40806
 $30 = $25 >>> 15; //@line 40807
 $sext$lobit = $30 & 1; //@line 40808
 $31 = $29 >>> 15; //@line 40809
 $sext28$lobit = $31 & 1; //@line 40810
 HEAP32[96444] = $sext28$lobit & $30; //@line 40812
 $35 = ($sext28$lobit ^ $sext$lobit) & $31 ^ $sext$lobit; //@line 40815
 HEAP32[96441] = $35; //@line 40816
 HEAP32[96445] = $35; //@line 40817
 HEAP32[96442] = ($29 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40823
 HEAP32[96443] = $sext28$lobit; //@line 40824
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $29); //@line 40828
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 40831
 return;
}
function __Z11op_498_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $27 = 0, $30 = 0, $37 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11298
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11301
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11316
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 11317
 $22 = HEAP32[$21 >> 2] | 0; //@line 11318
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 11320
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 11323
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 11326
 $30 = $27 - $20 | 0; //@line 11327
 $$lobit34 = $27 >>> 31; //@line 11329
 $$lobit35 = $30 >>> 31; //@line 11330
 HEAP32[96442] = ($30 | 0) == 0 & 1; //@line 11333
 HEAP32[96444] = ($$lobit35 ^ $$lobit34) & ($$lobit34 ^ $5 >>> 7); //@line 11337
 $37 = $27 >>> 0 < $20 >>> 0 & 1; //@line 11339
 HEAP32[96441] = $37; //@line 11340
 HEAP32[96445] = $37; //@line 11341
 HEAP32[96443] = $$lobit35; //@line 11342
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $30); //@line 11346
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11349
 return;
}
function __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $13 = 0, $14 = 0, $18 = 0;
 do {
  if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, $4) | 0) {
   __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi(0, $1, $2, $3); //@line 3670
  } else {
   if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 >> 2] | 0, $4) | 0) {
    $13 = $1 + 32 | 0; //@line 3678
    if ((HEAP32[$1 + 16 >> 2] | 0) != ($2 | 0)) {
     $14 = $1 + 20 | 0; //@line 3680
     if ((HEAP32[$14 >> 2] | 0) != ($2 | 0)) {
      HEAP32[$13 >> 2] = $3; //@line 3684
      HEAP32[$14 >> 2] = $2; //@line 3685
      $18 = $1 + 40 | 0; //@line 3686
      HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 1; //@line 3689
      if ((HEAP32[$1 + 36 >> 2] | 0) == 1) {
       if ((HEAP32[$1 + 24 >> 2] | 0) == 2) {
        HEAP8[$1 + 54 >> 0] = 1; //@line 3699
       }
      }
      HEAP32[$1 + 44 >> 2] = 4; //@line 3703
      break;
     }
    }
    if (($3 | 0) == 1) {
     HEAP32[$13 >> 2] = 1; //@line 3709
    }
   }
  }
 } while (0);
 return;
}
function __Z12op_31b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0;
 $3 = HEAP32[162769] | 0; //@line 38425
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 38434
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 38449
 $28 = HEAP32[162769] | 0; //@line 38450
 $29 = $28 + 6 | 0; //@line 38451
 HEAP32[162769] = $29; //@line 38452
 $31 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38454
 $38 = (HEAPU8[$29 >> 0] | 0) << 8 | (HEAPU8[$28 + 7 >> 0] | 0); //@line 38461
 HEAP32[162769] = $28 + 8; //@line 38463
 $40 = __Z15get_disp_ea_020jj($31, $38) | 0; //@line 38464
 $41 = $27 << 16 >> 16; //@line 38466
 $43 = ($41 | 0) == 0 & 1; //@line 38468
 HEAP32[96441] = 0; //@line 38469
 HEAP32[96442] = 0; //@line 38469
 HEAP32[96443] = 0; //@line 38469
 HEAP32[96444] = 0; //@line 38469
 HEAP32[96442] = $43; //@line 38470
 HEAP32[96443] = $27 >>> 15 & 1; //@line 38473
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($40, $41); //@line 38479
 return;
}
function __Z12op_10f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 24545
 $4 = HEAP32[162769] | 0; //@line 24546
 $5 = $4 + 2 | 0; //@line 24547
 HEAP32[162769] = $5; //@line 24548
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24550
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 24557
 HEAP32[162769] = $4 + 4; //@line 24559
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 24560
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 24566
 $23 = 651040 + ($3 << 2) | 0; //@line 24567
 $24 = HEAP32[$23 >> 2] | 0; //@line 24568
 HEAP32[$23 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $24; //@line 24572
 $28 = $22 << 24 >> 24; //@line 24574
 $30 = ($28 | 0) == 0 & 1; //@line 24576
 HEAP32[96441] = 0; //@line 24577
 HEAP32[96442] = 0; //@line 24577
 HEAP32[96443] = 0; //@line 24577
 HEAP32[96444] = 0; //@line 24577
 HEAP32[96442] = $30; //@line 24578
 HEAP32[96443] = $22 >>> 7 & 1; //@line 24581
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $28); //@line 24587
 return;
}
function __Z12op_4039_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $29 = 0, $30 = 0, $31 = 0, $35 = 0, $sext$lobit = 0, $sext26$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 40352
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 40361
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 40370
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40372
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 40376
 $29 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($25 << 24 >> 24) | 0; //@line 40382
 $30 = $25 >>> 7; //@line 40383
 $sext$lobit = $30 & 1; //@line 40384
 $31 = $29 >>> 7; //@line 40385
 $sext26$lobit = $31 & 1; //@line 40386
 HEAP32[96444] = $sext26$lobit & $30; //@line 40388
 $35 = ($sext26$lobit ^ $sext$lobit) & $31 ^ $sext$lobit; //@line 40391
 HEAP32[96441] = $35; //@line 40392
 HEAP32[96445] = $35; //@line 40393
 HEAP32[96442] = ($29 & 255 | 0) == 0 & HEAP32[96442]; //@line 40399
 HEAP32[96443] = $sext26$lobit; //@line 40400
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $29); //@line 40404
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 40407
 return;
}
function __Z12op_11b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0;
 $3 = HEAP32[162769] | 0; //@line 26394
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 26403
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 26418
 $28 = HEAP32[162769] | 0; //@line 26419
 $29 = $28 + 6 | 0; //@line 26420
 HEAP32[162769] = $29; //@line 26421
 $31 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26423
 $38 = (HEAPU8[$29 >> 0] | 0) << 8 | (HEAPU8[$28 + 7 >> 0] | 0); //@line 26430
 HEAP32[162769] = $28 + 8; //@line 26432
 $40 = __Z15get_disp_ea_020jj($31, $38) | 0; //@line 26433
 $41 = $27 << 24 >> 24; //@line 26435
 $43 = ($41 | 0) == 0 & 1; //@line 26437
 HEAP32[96441] = 0; //@line 26438
 HEAP32[96442] = 0; //@line 26438
 HEAP32[96443] = 0; //@line 26438
 HEAP32[96444] = 0; //@line 26438
 HEAP32[96442] = $43; //@line 26439
 HEAP32[96443] = $27 >>> 7 & 1; //@line 26442
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($40, $41); //@line 26448
 return;
}
function __Z12op_91b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $31 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21277
 $6 = HEAP32[162769] | 0; //@line 21278
 $7 = $6 + 2 | 0; //@line 21279
 HEAP32[162769] = $7; //@line 21280
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21282
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 21289
 HEAP32[162769] = $6 + 4; //@line 21291
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 21292
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 21294
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 21297
 $24 = $23 - $5 | 0; //@line 21298
 $$lobit37 = $23 >>> 31; //@line 21300
 $$lobit38 = $24 >>> 31; //@line 21301
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 21304
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $5 >>> 31); //@line 21308
 $31 = $23 >>> 0 < $5 >>> 0 & 1; //@line 21310
 HEAP32[96441] = $31; //@line 21311
 HEAP32[96445] = $31; //@line 21312
 HEAP32[96443] = $$lobit38; //@line 21313
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 21317
 return;
}
function __Z12op_31a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 38250
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 38261
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 38267
 $23 = HEAP32[162769] | 0; //@line 38268
 $24 = $23 + 4 | 0; //@line 38269
 HEAP32[162769] = $24; //@line 38270
 $26 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38272
 $33 = (HEAPU8[$24 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0); //@line 38279
 HEAP32[162769] = $23 + 6; //@line 38281
 $35 = __Z15get_disp_ea_020jj($26, $33) | 0; //@line 38282
 $36 = $22 << 16 >> 16; //@line 38284
 $38 = ($36 | 0) == 0 & 1; //@line 38286
 HEAP32[96441] = 0; //@line 38287
 HEAP32[96442] = 0; //@line 38287
 HEAP32[96443] = 0; //@line 38287
 HEAP32[96444] = 0; //@line 38287
 HEAP32[96442] = $38; //@line 38288
 HEAP32[96443] = $22 >>> 15 & 1; //@line 38291
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 38297
 return;
}
function __Z12op_31fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $30 = 0, $31 = 0, $33 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 39171
 $2 = $1 + 2 | 0; //@line 39172
 HEAP32[162769] = $2; //@line 39173
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 39178
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 39185
 HEAP32[162769] = $1 + 4; //@line 39187
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 39188
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 39194
 $22 = HEAP32[162769] | 0; //@line 39195
 $30 = ((HEAPU8[$22 >> 0] | 0) << 8 | (HEAPU8[$22 + 1 >> 0] | 0)) << 16 >> 16; //@line 39204
 $31 = $21 << 16 >> 16; //@line 39206
 $33 = ($31 | 0) == 0 & 1; //@line 39208
 HEAP32[96441] = 0; //@line 39209
 HEAP32[96442] = 0; //@line 39209
 HEAP32[96443] = 0; //@line 39209
 HEAP32[96444] = 0; //@line 39209
 HEAP32[96442] = $33; //@line 39210
 HEAP32[96443] = $21 >>> 15 & 1; //@line 39213
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, $31); //@line 39219
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39222
 return;
}
function __Z12op_11a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $33 = 0, $35 = 0, $36 = 0, $38 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 26219
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 26230
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 26236
 $23 = HEAP32[162769] | 0; //@line 26237
 $24 = $23 + 4 | 0; //@line 26238
 HEAP32[162769] = $24; //@line 26239
 $26 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26241
 $33 = (HEAPU8[$24 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0); //@line 26248
 HEAP32[162769] = $23 + 6; //@line 26250
 $35 = __Z15get_disp_ea_020jj($26, $33) | 0; //@line 26251
 $36 = $22 << 24 >> 24; //@line 26253
 $38 = ($36 | 0) == 0 & 1; //@line 26255
 HEAP32[96441] = 0; //@line 26256
 HEAP32[96442] = 0; //@line 26256
 HEAP32[96443] = 0; //@line 26256
 HEAP32[96444] = 0; //@line 26256
 HEAP32[96442] = $38; //@line 26257
 HEAP32[96443] = $22 >>> 7 & 1; //@line 26260
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 26266
 return;
}
function __Z12op_5079_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $35 = 0, $4 = 0, $45 = 0, $5 = 0, $sext34$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4290
 $5 = HEAP32[162769] | 0; //@line 4291
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 4300
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 4309
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 4311
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0; //@line 4315
 $30 = $29 << 16 >> 16; //@line 4317
 $32 = $30 + ($4 << 16 >> 16) | 0; //@line 4320
 $35 = $32 >>> 15; //@line 4324
 $sext34$lobit = $35 & 1; //@line 4325
 HEAP32[96442] = ($32 & 65535 | 0) == 0 & 1; //@line 4329
 HEAP32[96444] = ($sext34$lobit ^ $29 >>> 15 & 1) & ($35 ^ $4 >>> 15); //@line 4333
 $45 = ($30 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4338
 HEAP32[96441] = $45; //@line 4339
 HEAP32[96445] = $45; //@line 4340
 HEAP32[96443] = $sext34$lobit; //@line 4341
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $32); //@line 4345
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 4348
 return;
}
function __Z12op_11fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $30 = 0, $31 = 0, $33 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 27099
 $2 = $1 + 2 | 0; //@line 27100
 HEAP32[162769] = $2; //@line 27101
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 27106
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 27113
 HEAP32[162769] = $1 + 4; //@line 27115
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 27116
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 27122
 $22 = HEAP32[162769] | 0; //@line 27123
 $30 = ((HEAPU8[$22 >> 0] | 0) << 8 | (HEAPU8[$22 + 1 >> 0] | 0)) << 16 >> 16; //@line 27132
 $31 = $21 << 24 >> 24; //@line 27134
 $33 = ($31 | 0) == 0 & 1; //@line 27136
 HEAP32[96441] = 0; //@line 27137
 HEAP32[96442] = 0; //@line 27137
 HEAP32[96443] = 0; //@line 27137
 HEAP32[96444] = 0; //@line 27137
 HEAP32[96442] = $33; //@line 27138
 HEAP32[96443] = $21 >>> 7 & 1; //@line 27141
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($30, $31); //@line 27147
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27150
 return;
}
function __Z12op_4818_1_ffj($0) {
 $0 = $0 | 0;
 var $$030$in = 0, $1 = 0, $14 = 0, $18 = 0, $2 = 0, $20 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 1773
 $2 = 651040 + ($1 << 2) | 0; //@line 1774
 $3 = HEAP32[$2 >> 2] | 0; //@line 1775
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 1777
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 1781
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 1786
 $14 = $9 << 24 >> 24; //@line 1788
 $18 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($14 & 15) | 0; //@line 1793
 $20 = $18 & 65535; //@line 1795
 $23 = ($20 >>> 0 > 9 ? $20 + -6 | 0 : $18) - ($14 & 240) | 0; //@line 1799
 $25 = ($23 & 496) >>> 0 > 144; //@line 1801
 $26 = $25 & 1; //@line 1802
 $$030$in = $25 ? ($23 & 65535) + -96 | 0 : $23; //@line 1805
 HEAP32[96441] = $26; //@line 1806
 HEAP32[96445] = $26; //@line 1807
 HEAP32[96442] = ($$030$in & 255 | 0) == 0 & HEAP32[96442]; //@line 1813
 HEAP32[96443] = $$030$in >>> 7 & 1; //@line 1816
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $$030$in & 65535); //@line 1821
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1824
 return;
}
function __Z12op_21ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $34 = 0, $36 = 0, $38 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 33432
 $$cast = $4; //@line 33434
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 33448
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 33453
 $24 = HEAP32[162769] | 0; //@line 33454
 $25 = $24 + 4 | 0; //@line 33455
 HEAP32[162769] = $25; //@line 33456
 $27 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33458
 $34 = (HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0); //@line 33465
 HEAP32[162769] = $24 + 6; //@line 33467
 $36 = __Z15get_disp_ea_020jj($27, $34) | 0; //@line 33468
 $38 = ($23 | 0) == 0 & 1; //@line 33470
 HEAP32[96441] = 0; //@line 33471
 HEAP32[96442] = 0; //@line 33471
 HEAP32[96443] = 0; //@line 33471
 HEAP32[96444] = 0; //@line 33471
 HEAP32[96442] = $38; //@line 33472
 HEAP32[96443] = $23 >>> 31; //@line 33474
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($36, $23); //@line 33480
 return;
}
function __Z12op_217b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $25 = 0, $3 = 0, $34 = 0, $36 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 32871
 $4 = $3 + 2 | 0; //@line 32872
 HEAP32[162769] = $4; //@line 32873
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 32878
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 32885
 HEAP32[162769] = $3 + 4; //@line 32887
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 32888
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32893
 $25 = HEAP32[162769] | 0; //@line 32896
 $34 = (((HEAPU8[$25 >> 0] | 0) << 8 | (HEAPU8[$25 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32906
 $36 = ($22 | 0) == 0 & 1; //@line 32908
 HEAP32[96441] = 0; //@line 32909
 HEAP32[96442] = 0; //@line 32909
 HEAP32[96443] = 0; //@line 32909
 HEAP32[96444] = 0; //@line 32909
 HEAP32[96442] = $36; //@line 32910
 HEAP32[96443] = $22 >>> 31; //@line 32912
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $22); //@line 32918
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32921
 return;
}
function __Z11op_618_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $18 = 0, $20 = 0, $23 = 0, $32 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext31$lobit = 0;
 $1 = $0 & 7; //@line 12296
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 12299
 $6 = 651040 + ($1 << 2) | 0; //@line 12301
 $7 = HEAP32[$6 >> 2] | 0; //@line 12302
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 12304
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 12308
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 12313
 $18 = $13 << 24 >> 24; //@line 12315
 $20 = $18 + ($4 << 24 >> 24) | 0; //@line 12317
 $23 = $20 >>> 7; //@line 12322
 $sext31$lobit = $23 & 1; //@line 12323
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 12327
 HEAP32[96444] = ($sext31$lobit ^ $13 >>> 7 & 1) & ($23 ^ ($4 & 255) >>> 7 & 255); //@line 12331
 $32 = ($18 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12335
 HEAP32[96441] = $32; //@line 12336
 HEAP32[96445] = $32; //@line 12337
 HEAP32[96443] = $sext31$lobit; //@line 12338
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 12342
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12345
 return;
}
function __Z11op_639_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $22 = 0, $24 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $34 = 0, $43 = 0, $sext25$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 12597
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 12599
 $13 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 12609
 $22 = $13 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 12618
 $24 = 123608 + ($13 >>> 16 << 2) | 0; //@line 12620
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 8 >> 2] & 127]($22) | 0; //@line 12624
 $29 = $28 << 24 >> 24; //@line 12626
 $31 = $29 + ($3 << 24 >> 24) | 0; //@line 12628
 $34 = $31 >>> 7; //@line 12633
 $sext25$lobit = $34 & 1; //@line 12634
 HEAP32[96442] = ($31 & 255 | 0) == 0 & 1; //@line 12638
 HEAP32[96444] = ($sext25$lobit ^ $28 >>> 7 & 1) & ($34 ^ ($3 & 255) >>> 7 & 255); //@line 12642
 $43 = ($29 & 255 ^ 255) >>> 0 < ($3 & 255) >>> 0 & 1; //@line 12646
 HEAP32[96441] = $43; //@line 12647
 HEAP32[96445] = $43; //@line 12648
 HEAP32[96443] = $sext25$lobit; //@line 12649
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 20 >> 2] & 31]($22, $31); //@line 12653
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 12656
 return;
}
function _fstat($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 59344
 STACKTOP = STACKTOP + 48 | 0; //@line 59345
 $vararg_buffer6 = sp + 40 | 0; //@line 59346
 $vararg_buffer2 = sp + 8 | 0; //@line 59347
 $vararg_buffer = sp; //@line 59348
 $2 = $1; //@line 59349
 HEAP32[$vararg_buffer >> 2] = $0; //@line 59350
 HEAP32[$vararg_buffer + 4 >> 2] = $2; //@line 59352
 $3 = ___syscall197(197, $vararg_buffer | 0) | 0; //@line 59353
 if (($3 | 0) == -9) {
  HEAP32[$vararg_buffer2 >> 2] = $0; //@line 59356
  HEAP32[$vararg_buffer2 + 4 >> 2] = 1; //@line 59358
  if ((___syscall221(221, $vararg_buffer2 | 0) | 0) < 0) {
   label = 3; //@line 59362
  } else {
   ___procfdname($vararg_buffer2, $0); //@line 59364
   HEAP32[$vararg_buffer6 >> 2] = $vararg_buffer2; //@line 59366
   HEAP32[$vararg_buffer6 + 4 >> 2] = $2; //@line 59368
   $$0 = ___syscall_ret(___syscall195(195, $vararg_buffer6 | 0) | 0) | 0; //@line 59371
  }
 } else {
  label = 3; //@line 59374
 }
 if ((label | 0) == 3) {
  $$0 = ___syscall_ret($3) | 0; //@line 59378
 }
 STACKTOP = sp; //@line 59380
 return $$0 | 0; //@line 59380
}
function __Z11op_620_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $22 = 0, $31 = 0, $4 = 0, $6 = 0, $sext32$lobit = 0;
 $1 = $0 & 7; //@line 12354
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 12357
 $6 = 651040 + ($1 << 2) | 0; //@line 12359
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 12363
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 12365
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 12369
 HEAP32[$6 >> 2] = $10; //@line 12370
 $17 = $16 << 24 >> 24; //@line 12372
 $19 = $17 + ($4 << 24 >> 24) | 0; //@line 12374
 $22 = $19 >>> 7; //@line 12379
 $sext32$lobit = $22 & 1; //@line 12380
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 12384
 HEAP32[96444] = ($sext32$lobit ^ $16 >>> 7 & 1) & ($22 ^ ($4 & 255) >>> 7 & 255); //@line 12388
 $31 = ($17 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12392
 HEAP32[96441] = $31; //@line 12393
 HEAP32[96445] = $31; //@line 12394
 HEAP32[96443] = $sext32$lobit; //@line 12395
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 12399
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12402
 return;
}
function __Z12op_9018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $20 = 0, $22 = 0, $32 = 0, $4 = 0, $5 = 0, $sext37$lobit = 0, $sext37$mask = 0;
 $1 = $0 & 7; //@line 17736
 $4 = 651040 + ($1 << 2) | 0; //@line 17739
 $5 = HEAP32[$4 >> 2] | 0; //@line 17740
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 17746
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 17751
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17752
 $17 = HEAP32[$16 >> 2] | 0; //@line 17753
 $20 = ($17 << 24 >> 24) - ($11 << 24 >> 24) | 0; //@line 17758
 $22 = $17 >>> 7; //@line 17760
 $sext37$lobit = $20 >>> 7 & 1; //@line 17763
 $sext37$mask = $20 & 255; //@line 17764
 HEAP32[96442] = ($sext37$mask | 0) == 0 & 1; //@line 17767
 HEAP32[96444] = ($sext37$lobit ^ $22 & 1) & ($22 ^ $11 >>> 7); //@line 17771
 $32 = ($11 & 255) >>> 0 > ($17 & 255) >>> 0 & 1; //@line 17775
 HEAP32[96441] = $32; //@line 17776
 HEAP32[96445] = $32; //@line 17777
 HEAP32[96443] = $sext37$lobit; //@line 17778
 HEAP32[$16 >> 2] = $17 & -256 | $sext37$mask; //@line 17781
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17784
 return;
}
function __Z11op_4f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $20 = 0, $25 = 0, $26 = 0, $31 = 0, $41 = 0, $5 = 0, $8 = 0;
 $2 = HEAP32[162769] | 0; //@line 11904
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 11907
 $$cast = $2; //@line 11908
 $8 = HEAPU8[$$cast + 2 >> 0] | 0; //@line 11911
 $17 = ((HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) << 16 >> 16; //@line 11921
 $20 = HEAP32[651008 + ($8 >>> 4 << 2) >> 2] | 0; //@line 11924
 $25 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 11929
 $26 = $17 + 4 | 0; //@line 11930
 $31 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($26 >>> 16 << 2) >> 2] >> 2] & 127]($26) | 0; //@line 11935
 HEAP32[96442] = (($25 | 0) == ($20 | 0) | ($31 | 0) == ($20 | 0)) & 1; //@line 11940
 if (($25 | 0) > ($31 | 0)) {
  $41 = ($20 | 0) < ($25 | 0) | ($20 | 0) > ($31 | 0); //@line 11946
 } else {
  $41 = ($20 | 0) < ($25 | 0) | ($20 | 0) > ($31 | 0); //@line 11951
 }
 HEAP32[96441] = $41 & 1; //@line 11954
 if (($8 & 8 | 0) != 0 & $41) {
  __Z9Exceptionij(6, $5); //@line 11959
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11964
  return;
 }
}
function __Z11op_4a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $36 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11359
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11362
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11377
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 11378
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 11380
 $25 = 123608 + ($23 >>> 16 << 2) | 0; //@line 11382
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 11385
 HEAP32[$21 >> 2] = $23; //@line 11386
 $29 = $28 - $20 | 0; //@line 11387
 $$lobit35 = $28 >>> 31; //@line 11389
 $$lobit36 = $29 >>> 31; //@line 11390
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 11393
 HEAP32[96444] = ($$lobit36 ^ $$lobit35) & ($$lobit35 ^ $5 >>> 7); //@line 11397
 $36 = $28 >>> 0 < $20 >>> 0 & 1; //@line 11399
 HEAP32[96441] = $36; //@line 11400
 HEAP32[96445] = $36; //@line 11401
 HEAP32[96443] = $$lobit36; //@line 11402
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 11406
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11409
 return;
}
function __Z11op_458_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $23 = 0, $25 = 0, $34 = 0, $5 = 0, $sext35$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10802
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10805
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10810
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 10811
 $12 = HEAP32[$11 >> 2] | 0; //@line 10812
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 10814
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 10818
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 10821
 $23 = ($18 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 10826
 $25 = $18 >>> 15; //@line 10828
 $sext35$lobit = $23 >>> 15 & 1; //@line 10831
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 10835
 HEAP32[96444] = ($sext35$lobit ^ $25 & 1) & ($25 ^ $5 >>> 7); //@line 10839
 $34 = $10 >>> 0 > ($18 & 65535) >>> 0 & 1; //@line 10842
 HEAP32[96441] = $34; //@line 10843
 HEAP32[96445] = $34; //@line 10844
 HEAP32[96443] = $sext35$lobit; //@line 10845
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $23); //@line 10849
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10852
 return;
}
function __Z12op_d118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $23 = 0, $3 = 0, $33 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $3 = $0 & 7; //@line 33700
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33702
 $6 = 651040 + ($3 << 2) | 0; //@line 33703
 $7 = HEAP32[$6 >> 2] | 0; //@line 33704
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 33706
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 33710
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 33715
 $18 = $13 << 24 >> 24; //@line 33717
 $20 = $18 + ($5 << 24 >> 24) | 0; //@line 33720
 $23 = $20 >>> 7; //@line 33724
 $sext36$lobit = $23 & 1; //@line 33725
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 33729
 HEAP32[96444] = ($sext36$lobit ^ $13 >>> 7 & 1) & ($23 ^ $5 >>> 7); //@line 33733
 $33 = ($18 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 33738
 HEAP32[96441] = $33; //@line 33739
 HEAP32[96445] = $33; //@line 33740
 HEAP32[96443] = $sext36$lobit; //@line 33741
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 33745
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33748
 return;
}
function __Z11op_4b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $2 = 0, $20 = 0, $31 = 0, $33 = 0, $36 = 0, $37 = 0, $44 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 17029
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 17032
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 17047
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 17058
 $33 = 123608 + ($31 >>> 16 << 2) | 0; //@line 17060
 $36 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$33 >> 2] >> 2] & 127]($31) | 0; //@line 17063
 $37 = $36 - $20 | 0; //@line 17064
 $$lobit33 = $36 >>> 31; //@line 17066
 $$lobit34 = $37 >>> 31; //@line 17067
 HEAP32[96442] = ($37 | 0) == 0 & 1; //@line 17070
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $5 >>> 7); //@line 17074
 $44 = $36 >>> 0 < $20 >>> 0 & 1; //@line 17076
 HEAP32[96441] = $44; //@line 17077
 HEAP32[96445] = $44; //@line 17078
 HEAP32[96443] = $$lobit34; //@line 17079
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$33 >> 2] | 0) + 12 >> 2] & 31]($31, $37); //@line 17083
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 17086
 return;
}
function __Z12op_31f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 38937
 $3 = $2 + 2 | 0; //@line 38938
 HEAP32[162769] = $3; //@line 38939
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38941
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 38948
 HEAP32[162769] = $2 + 4; //@line 38950
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 38951
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 38957
 $21 = HEAP32[162769] | 0; //@line 38958
 $29 = ((HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$21 + 1 >> 0] | 0)) << 16 >> 16; //@line 38967
 $30 = $20 << 16 >> 16; //@line 38969
 $32 = ($30 | 0) == 0 & 1; //@line 38971
 HEAP32[96441] = 0; //@line 38972
 HEAP32[96442] = 0; //@line 38972
 HEAP32[96443] = 0; //@line 38972
 HEAP32[96444] = 0; //@line 38972
 HEAP32[96442] = $32; //@line 38973
 HEAP32[96443] = $20 >>> 15 & 1; //@line 38976
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, $30); //@line 38982
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38985
 return;
}
function __Z12op_d120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $22 = 0, $3 = 0, $32 = 0, $5 = 0, $6 = 0, $sext37$lobit = 0;
 $3 = $0 & 7; //@line 33759
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33761
 $6 = 651040 + ($3 << 2) | 0; //@line 33762
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 33766
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 33768
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 33772
 HEAP32[$6 >> 2] = $10; //@line 33773
 $17 = $16 << 24 >> 24; //@line 33775
 $19 = $17 + ($5 << 24 >> 24) | 0; //@line 33778
 $22 = $19 >>> 7; //@line 33782
 $sext37$lobit = $22 & 1; //@line 33783
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 33787
 HEAP32[96444] = ($sext37$lobit ^ $16 >>> 7 & 1) & ($22 ^ $5 >>> 7); //@line 33791
 $32 = ($17 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 33796
 HEAP32[96441] = $32; //@line 33797
 HEAP32[96445] = $32; //@line 33798
 HEAP32[96443] = $sext37$lobit; //@line 33799
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 33803
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33806
 return;
}
function __Z12op_5039_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $35 = 0, $4 = 0, $45 = 0, $5 = 0, $sext32$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1605
 $5 = HEAP32[162769] | 0; //@line 1606
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 1615
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 1624
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 1626
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0; //@line 1630
 $30 = $29 << 24 >> 24; //@line 1632
 $32 = $30 + ($4 << 24 >> 24) | 0; //@line 1635
 $35 = $32 >>> 7; //@line 1639
 $sext32$lobit = $35 & 1; //@line 1640
 HEAP32[96442] = ($32 & 255 | 0) == 0 & 1; //@line 1644
 HEAP32[96444] = ($sext32$lobit ^ $29 >>> 7 & 1) & ($35 ^ $4 >>> 7); //@line 1648
 $45 = ($30 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1653
 HEAP32[96441] = $45; //@line 1654
 HEAP32[96445] = $45; //@line 1655
 HEAP32[96443] = $sext32$lobit; //@line 1656
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $32); //@line 1660
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 1663
 return;
}
function __Z12op_11f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 26865
 $3 = $2 + 2 | 0; //@line 26866
 HEAP32[162769] = $3; //@line 26867
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26869
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 26876
 HEAP32[162769] = $2 + 4; //@line 26878
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 26879
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 26885
 $21 = HEAP32[162769] | 0; //@line 26886
 $29 = ((HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$21 + 1 >> 0] | 0)) << 16 >> 16; //@line 26895
 $30 = $20 << 24 >> 24; //@line 26897
 $32 = ($30 | 0) == 0 & 1; //@line 26899
 HEAP32[96441] = 0; //@line 26900
 HEAP32[96442] = 0; //@line 26900
 HEAP32[96443] = 0; //@line 26900
 HEAP32[96444] = 0; //@line 26900
 HEAP32[96442] = $32; //@line 26901
 HEAP32[96443] = $20 >>> 7 & 1; //@line 26904
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($29, $30); //@line 26910
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26913
 return;
}
function __Z12op_d170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $5 = 0, $8 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36978
 $8 = HEAP32[162769] | 0; //@line 36981
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 36990
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 36992
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36996
 $24 = $23 << 16 >> 16; //@line 36998
 $26 = $24 + ($5 << 16 >> 16) | 0; //@line 37001
 $29 = $26 >>> 15; //@line 37005
 $sext38$lobit = $29 & 1; //@line 37006
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 37010
 HEAP32[96444] = ($sext38$lobit ^ $23 >>> 15 & 1) & ($29 ^ $5 >>> 15); //@line 37014
 $39 = ($24 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 37019
 HEAP32[96441] = $39; //@line 37020
 HEAP32[96445] = $39; //@line 37021
 HEAP32[96443] = $sext38$lobit; //@line 37022
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $26); //@line 37026
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37029
 return;
}
function __Z12op_4820_1_ffj($0) {
 $0 = $0 | 0;
 var $$031$in = 0, $1 = 0, $12 = 0, $13 = 0, $17 = 0, $19 = 0, $2 = 0, $22 = 0, $24 = 0, $25 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 1833
 $2 = 651040 + ($1 << 2) | 0; //@line 1834
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 1838
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 1840
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 1844
 HEAP32[$2 >> 2] = $6; //@line 1845
 $13 = $12 << 24 >> 24; //@line 1847
 $17 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($13 & 15) | 0; //@line 1852
 $19 = $17 & 65535; //@line 1854
 $22 = ($19 >>> 0 > 9 ? $19 + -6 | 0 : $17) - ($13 & 240) | 0; //@line 1858
 $24 = ($22 & 496) >>> 0 > 144; //@line 1860
 $25 = $24 & 1; //@line 1861
 $$031$in = $24 ? ($22 & 65535) + -96 | 0 : $22; //@line 1864
 HEAP32[96441] = $25; //@line 1865
 HEAP32[96445] = $25; //@line 1866
 HEAP32[96442] = ($$031$in & 255 | 0) == 0 & HEAP32[96442]; //@line 1872
 HEAP32[96443] = $$031$in >>> 7 & 1; //@line 1875
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $$031$in & 65535); //@line 1880
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1883
 return;
}
function __Z12op_e180_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $14 = 0, $16 = 0, $17 = 0, $21 = 0, $22 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39593
 $7 = HEAP32[$6 >> 2] | 0; //@line 39594
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39595
 $9 = $8 >>> 0 > 31; //@line 39596
 HEAP32[96441] = 0; //@line 39597
 HEAP32[96442] = 0; //@line 39597
 HEAP32[96443] = 0; //@line 39597
 HEAP32[96444] = 0; //@line 39597
 if ($9) {
  HEAP32[96444] = ($7 | 0) != 0 & 1; //@line 39601
  $14 = ($8 | 0) == 32 ? $7 & 1 : 0; //@line 39604
  HEAP32[96441] = $14; //@line 39605
  HEAP32[96445] = $14; //@line 39606
  $$0 = 0; //@line 39607
 } else {
  $16 = -1 << 31 - $8; //@line 39610
  $17 = $16 & $7; //@line 39611
  HEAP32[96444] = ($17 | 0) != 0 & ($17 | 0) != ($16 | 0) & 1; //@line 39616
  $21 = $7 << $8 + -1; //@line 39618
  $22 = $21 >>> 31; //@line 39619
  HEAP32[96441] = $22; //@line 39620
  HEAP32[96445] = $22; //@line 39621
  $$0 = $21 << 1; //@line 39623
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39627
 HEAP32[96443] = $$0 >>> 31; //@line 39629
 HEAP32[$6 >> 2] = $$0; //@line 39630
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39633
 return;
}
function __Z12op_4839_1_ffj($0) {
 $0 = $0 | 0;
 var $$024$in = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $26 = 0, $30 = 0, $32 = 0, $35 = 0, $37 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 2087
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 2096
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 2105
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 2107
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 2113
 $30 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($26 & 15) | 0; //@line 2118
 $32 = $30 & 65535; //@line 2120
 $35 = ($32 >>> 0 > 9 ? $32 + -6 | 0 : $30) - ($26 & 240) | 0; //@line 2124
 $37 = ($35 & 496) >>> 0 > 144; //@line 2126
 $38 = $37 & 1; //@line 2127
 $$024$in = $37 ? ($35 & 65535) + -96 | 0 : $35; //@line 2130
 HEAP32[96441] = $38; //@line 2131
 HEAP32[96445] = $38; //@line 2132
 HEAP32[96442] = ($$024$in & 255 | 0) == 0 & HEAP32[96442]; //@line 2138
 HEAP32[96443] = $$024$in >>> 7 & 1; //@line 2141
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$024$in & 65535); //@line 2146
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 2149
 return;
}
function __Z12op_2170_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $24 = 0, $33 = 0, $35 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 32633
 $5 = $4 + 2 | 0; //@line 32634
 HEAP32[162769] = $5; //@line 32635
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 32637
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 32644
 HEAP32[162769] = $4 + 4; //@line 32646
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 32647
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 32652
 $24 = HEAP32[162769] | 0; //@line 32655
 $33 = (((HEAPU8[$24 >> 0] | 0) << 8 | (HEAPU8[$24 + 1 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32665
 $35 = ($21 | 0) == 0 & 1; //@line 32667
 HEAP32[96441] = 0; //@line 32668
 HEAP32[96442] = 0; //@line 32668
 HEAP32[96443] = 0; //@line 32668
 HEAP32[96444] = 0; //@line 32668
 HEAP32[96442] = $35; //@line 32669
 HEAP32[96443] = $21 >>> 31; //@line 32671
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $21); //@line 32677
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32680
 return;
}
function __Z11op_4a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $2 = 0, $20 = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $45 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11419
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11422
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11437
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 11450
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 11452
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0; //@line 11455
 $38 = $37 - $20 | 0; //@line 11456
 $$lobit33 = $37 >>> 31; //@line 11458
 $$lobit34 = $38 >>> 31; //@line 11459
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 11462
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $5 >>> 7); //@line 11466
 $45 = $37 >>> 0 < $20 >>> 0 & 1; //@line 11468
 HEAP32[96441] = $45; //@line 11469
 HEAP32[96445] = $45; //@line 11470
 HEAP32[96443] = $$lobit34; //@line 11471
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 11475
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 11478
 return;
}
function __Z12op_5070_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $4 = 0, $8 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 11378
 $8 = HEAP32[162769] | 0; //@line 11382
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 11391
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 11393
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 11397
 $24 = $23 << 16 >> 16; //@line 11399
 $26 = $24 + ($4 << 16 >> 16) | 0; //@line 11402
 $29 = $26 >>> 15; //@line 11406
 $sext38$lobit = $29 & 1; //@line 11407
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 11411
 HEAP32[96444] = ($sext38$lobit ^ $23 >>> 15 & 1) & ($29 ^ $4 >>> 15); //@line 11415
 $39 = ($24 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 11420
 HEAP32[96441] = $39; //@line 11421
 HEAP32[96445] = $39; //@line 11422
 HEAP32[96443] = $sext38$lobit; //@line 11423
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $26); //@line 11427
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11430
 return;
}
function __Z12op_9070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $6 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 23833
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23842
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 23848
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23849
 $23 = HEAP32[$22 >> 2] | 0; //@line 23850
 $26 = ($23 << 16 >> 16) - ($21 << 16 >> 16) | 0; //@line 23855
 $28 = $23 >>> 15; //@line 23857
 $sext39$lobit = $26 >>> 15 & 1; //@line 23860
 $sext39$mask = $26 & 65535; //@line 23861
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 23864
 HEAP32[96444] = ($sext39$lobit ^ $28 & 1) & ($28 ^ $21 >>> 15); //@line 23868
 $38 = ($21 & 65535) >>> 0 > ($23 & 65535) >>> 0 & 1; //@line 23872
 HEAP32[96441] = $38; //@line 23873
 HEAP32[96445] = $38; //@line 23874
 HEAP32[96443] = $sext39$lobit; //@line 23875
 HEAP32[$22 >> 2] = $23 & -65536 | $sext39$mask; //@line 23878
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23881
 return;
}
function __Z12op_e168_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink29 = 0, $10 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39442
 $7 = HEAP32[$6 >> 2] | 0; //@line 39443
 $8 = $7 & 65535; //@line 39444
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39445
 $10 = $9 >>> 0 > 15; //@line 39446
 HEAP32[96441] = 0; //@line 39447
 HEAP32[96442] = 0; //@line 39447
 HEAP32[96443] = 0; //@line 39447
 HEAP32[96444] = 0; //@line 39447
 if ($10) {
  $$0$ph = 0; //@line 39452
  $$sink29 = ($9 | 0) == 16 ? $7 & 1 : 0; //@line 39452
  label = 4; //@line 39453
 } else {
  $16 = $8 << $9 + -1; //@line 39457
  if (!$9) {
   $$0 = $8; //@line 39463
  } else {
   $$0$ph = $16 << 1 & 65534; //@line 39465
   $$sink29 = $16 >>> 15 & 1; //@line 39465
   label = 4; //@line 39466
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink29; //@line 39470
  HEAP32[96445] = $$sink29; //@line 39471
  $$0 = $$0$ph; //@line 39472
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39476
 HEAP32[96443] = $$0 >>> 15; //@line 39478
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 39481
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39484
 return;
}
function __Z12op_d168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $5 = 0, $8 = 0, $sext39$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34368
 $8 = HEAP32[162769] | 0; //@line 34371
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 34382
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 34384
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 34388
 $25 = $24 << 16 >> 16; //@line 34390
 $27 = $25 + ($5 << 16 >> 16) | 0; //@line 34393
 $30 = $27 >>> 15; //@line 34397
 $sext39$lobit = $30 & 1; //@line 34398
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 34402
 HEAP32[96444] = ($sext39$lobit ^ $24 >>> 15 & 1) & ($30 ^ $5 >>> 15); //@line 34406
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 34411
 HEAP32[96441] = $40; //@line 34412
 HEAP32[96445] = $40; //@line 34413
 HEAP32[96443] = $sext39$lobit; //@line 34414
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 34418
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 34421
 return;
}
function __Z12op_d058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $21 = 0, $31 = 0, $4 = 0, $5 = 0, $sext40$lobit = 0, $sext40$mask = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32023
 $5 = HEAP32[$4 >> 2] | 0; //@line 32024
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 32030
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 32033
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32034
 $15 = HEAP32[$14 >> 2] | 0; //@line 32035
 $16 = $15 << 16 >> 16; //@line 32037
 $18 = $16 + ($11 << 16 >> 16) | 0; //@line 32040
 $21 = $18 >>> 15; //@line 32044
 $sext40$lobit = $21 & 1; //@line 32045
 $sext40$mask = $18 & 65535; //@line 32046
 HEAP32[96442] = ($sext40$mask | 0) == 0 & 1; //@line 32049
 HEAP32[96444] = ($sext40$lobit ^ $15 >>> 15 & 1) & ($21 ^ $11 >>> 15); //@line 32053
 $31 = ($16 & 65535 ^ 65535) >>> 0 < ($11 & 65535) >>> 0 & 1; //@line 32058
 HEAP32[96441] = $31; //@line 32059
 HEAP32[96445] = $31; //@line 32060
 HEAP32[96443] = $sext40$lobit; //@line 32061
 HEAP32[$14 >> 2] = $15 & -65536 | $sext40$mask; //@line 32064
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32067
 return;
}
function __Z12op_9079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $32 = 0, $34 = 0, $44 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18716
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 18725
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 18740
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18741
 $29 = HEAP32[$28 >> 2] | 0; //@line 18742
 $32 = ($29 << 16 >> 16) - ($27 << 16 >> 16) | 0; //@line 18747
 $34 = $29 >>> 15; //@line 18749
 $sext35$lobit = $32 >>> 15 & 1; //@line 18752
 $sext35$mask = $32 & 65535; //@line 18753
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 18756
 HEAP32[96444] = ($sext35$lobit ^ $34 & 1) & ($34 ^ $27 >>> 15); //@line 18760
 $44 = ($27 & 65535) >>> 0 > ($29 & 65535) >>> 0 & 1; //@line 18764
 HEAP32[96441] = $44; //@line 18765
 HEAP32[96445] = $44; //@line 18766
 HEAP32[96443] = $sext35$lobit; //@line 18767
 HEAP32[$28 >> 2] = $29 & -65536 | $sext35$mask; //@line 18770
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 18773
 return;
}
function __Z12op_4018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $23 = 0, $3 = 0, $5 = 0, $9 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $1 = $0 & 7; //@line 40074
 $2 = 651040 + ($1 << 2) | 0; //@line 40075
 $3 = HEAP32[$2 >> 2] | 0; //@line 40076
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40078
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 40082
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 40087
 $17 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($9 << 24 >> 24) | 0; //@line 40093
 $18 = $9 >>> 7; //@line 40094
 $sext$lobit = $18 & 1; //@line 40095
 $19 = $17 >>> 7; //@line 40096
 $sext32$lobit = $19 & 1; //@line 40097
 HEAP32[96444] = $sext32$lobit & $18; //@line 40099
 $23 = ($sext32$lobit ^ $sext$lobit) & $19 ^ $sext$lobit; //@line 40102
 HEAP32[96441] = $23; //@line 40103
 HEAP32[96445] = $23; //@line 40104
 HEAP32[96442] = ($17 & 255 | 0) == 0 & HEAP32[96442]; //@line 40110
 HEAP32[96443] = $sext32$lobit; //@line 40111
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $17); //@line 40115
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40118
 return;
}
function __Z12op_9020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $19 = 0, $21 = 0, $31 = 0, $4 = 0, $8 = 0, $sext38$lobit = 0, $sext38$mask = 0;
 $1 = $0 & 7; //@line 17793
 $4 = 651040 + ($1 << 2) | 0; //@line 17796
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 17800
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 17806
 HEAP32[$4 >> 2] = $8; //@line 17807
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17808
 $16 = HEAP32[$15 >> 2] | 0; //@line 17809
 $19 = ($16 << 24 >> 24) - ($14 << 24 >> 24) | 0; //@line 17814
 $21 = $16 >>> 7; //@line 17816
 $sext38$lobit = $19 >>> 7 & 1; //@line 17819
 $sext38$mask = $19 & 255; //@line 17820
 HEAP32[96442] = ($sext38$mask | 0) == 0 & 1; //@line 17823
 HEAP32[96444] = ($sext38$lobit ^ $21 & 1) & ($21 ^ $14 >>> 7); //@line 17827
 $31 = ($14 & 255) >>> 0 > ($16 & 255) >>> 0 & 1; //@line 17831
 HEAP32[96441] = $31; //@line 17832
 HEAP32[96445] = $31; //@line 17833
 HEAP32[96443] = $sext38$lobit; //@line 17834
 HEAP32[$15 >> 2] = $16 & -256 | $sext38$mask; //@line 17837
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17840
 return;
}
function __Z11op_460_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $19 = 0, $2 = 0, $22 = 0, $24 = 0, $33 = 0, $5 = 0, $sext36$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10862
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10865
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10870
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 10871
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 10873
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 10875
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 10879
 HEAP32[$11 >> 2] = $13; //@line 10880
 $22 = ($19 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 10885
 $24 = $19 >>> 15; //@line 10887
 $sext36$lobit = $22 >>> 15 & 1; //@line 10890
 HEAP32[96442] = ($22 & 65535 | 0) == 0 & 1; //@line 10894
 HEAP32[96444] = ($sext36$lobit ^ $24 & 1) & ($24 ^ $5 >>> 7); //@line 10898
 $33 = $10 >>> 0 > ($19 & 65535) >>> 0 & 1; //@line 10901
 HEAP32[96441] = $33; //@line 10902
 HEAP32[96445] = $33; //@line 10903
 HEAP32[96443] = $sext36$lobit; //@line 10904
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $22); //@line 10908
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10911
 return;
}
function ___strerror_l($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$012$lcssa = 0, $$01214 = 0, $$016 = 0, $$113 = 0, $$115 = 0, $7 = 0, label = 0, $$113$looptemp = 0;
 $$016 = 0; //@line 58946
 while (1) {
  if ((HEAPU8[110592 + $$016 >> 0] | 0) == ($0 | 0)) {
   label = 2; //@line 58953
   break;
  }
  $7 = $$016 + 1 | 0; //@line 58956
  if (($7 | 0) == 87) {
   $$01214 = 110680; //@line 58959
   $$115 = 87; //@line 58959
   label = 5; //@line 58960
   break;
  } else {
   $$016 = $7; //@line 58963
  }
 }
 if ((label | 0) == 2) {
  if (!$$016) {
   $$012$lcssa = 110680; //@line 58969
  } else {
   $$01214 = 110680; //@line 58971
   $$115 = $$016; //@line 58971
   label = 5; //@line 58972
  }
 }
 if ((label | 0) == 5) {
  while (1) {
   label = 0; //@line 58977
   $$113 = $$01214; //@line 58978
   do {
    $$113$looptemp = $$113;
    $$113 = $$113 + 1 | 0; //@line 58982
   } while ((HEAP8[$$113$looptemp >> 0] | 0) != 0);
   $$115 = $$115 + -1 | 0; //@line 58989
   if (!$$115) {
    $$012$lcssa = $$113; //@line 58992
    break;
   } else {
    $$01214 = $$113; //@line 58995
    label = 5; //@line 58996
   }
  }
 }
 return ___lctrans($$012$lcssa, HEAP32[$1 + 20 >> 2] | 0) | 0; //@line 59003
}
function __Z12op_9068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $6 = 0, $sext40$lobit = 0, $sext40$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 18533
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 18544
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 18550
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18551
 $24 = HEAP32[$23 >> 2] | 0; //@line 18552
 $27 = ($24 << 16 >> 16) - ($22 << 16 >> 16) | 0; //@line 18557
 $29 = $24 >>> 15; //@line 18559
 $sext40$lobit = $27 >>> 15 & 1; //@line 18562
 $sext40$mask = $27 & 65535; //@line 18563
 HEAP32[96442] = ($sext40$mask | 0) == 0 & 1; //@line 18566
 HEAP32[96444] = ($sext40$lobit ^ $29 & 1) & ($29 ^ $22 >>> 15); //@line 18570
 $39 = ($22 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 18574
 HEAP32[96441] = $39; //@line 18575
 HEAP32[96445] = $39; //@line 18576
 HEAP32[96443] = $sext40$lobit; //@line 18577
 HEAP32[$23 >> 2] = $24 & -65536 | $sext40$mask; //@line 18580
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18583
 return;
}
function __Z12op_51b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $31 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6200
 $6 = HEAP32[162769] | 0; //@line 6202
 $7 = $6 + 2 | 0; //@line 6203
 HEAP32[162769] = $7; //@line 6204
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6206
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 6213
 HEAP32[162769] = $6 + 4; //@line 6215
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 6216
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 6218
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 6221
 $24 = $23 - $4 | 0; //@line 6222
 $$lobit37 = $23 >>> 31; //@line 6224
 $$lobit38 = $24 >>> 31; //@line 6225
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 6228
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $4 >>> 31); //@line 6232
 $31 = $23 >>> 0 < $4 >>> 0 & 1; //@line 6234
 HEAP32[96441] = $31; //@line 6235
 HEAP32[96445] = $31; //@line 6236
 HEAP32[96443] = $$lobit38; //@line 6237
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 6241
 return;
}
function __Z11op_470_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $23 = 0, $27 = 0, $30 = 0, $32 = 0, $41 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 16963
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 16966
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 16971
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16982
 $23 = 123608 + ($21 >>> 16 << 2) | 0; //@line 16984
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 4 >> 2] & 127]($21) | 0; //@line 16988
 $30 = ($27 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 16993
 $32 = $27 >>> 15; //@line 16995
 $sext34$lobit = $30 >>> 15 & 1; //@line 16998
 HEAP32[96442] = ($30 & 65535 | 0) == 0 & 1; //@line 17002
 HEAP32[96444] = ($sext34$lobit ^ $32 & 1) & ($32 ^ $5 >>> 7); //@line 17006
 $41 = $10 >>> 0 > ($27 & 65535) >>> 0 & 1; //@line 17009
 HEAP32[96441] = $41; //@line 17010
 HEAP32[96445] = $41; //@line 17011
 HEAP32[96443] = $sext34$lobit; //@line 17012
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($21, $30); //@line 17016
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17019
 return;
}
function __Z12op_9179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $32 = 0, $34 = 0, $4 = 0, $44 = 0, $5 = 0, $sext34$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20922
 $5 = HEAP32[162769] | 0; //@line 20923
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 20932
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 20941
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 20943
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0; //@line 20947
 $32 = ($29 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 20952
 $34 = $29 >>> 15; //@line 20954
 $sext34$lobit = $32 >>> 15 & 1; //@line 20957
 HEAP32[96442] = ($32 & 65535 | 0) == 0 & 1; //@line 20961
 HEAP32[96444] = ($sext34$lobit ^ $34 & 1) & ($34 ^ $4 >>> 15); //@line 20965
 $44 = ($4 & 65535) >>> 0 > ($29 & 65535) >>> 0 & 1; //@line 20969
 HEAP32[96441] = $44; //@line 20970
 HEAP32[96445] = $44; //@line 20971
 HEAP32[96443] = $sext34$lobit; //@line 20972
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $32); //@line 20976
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 20979
 return;
}
function __Z12op_4068_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $4 = 0, $sext32$lobit = 0, $sext33$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 40605
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 40616
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40618
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40622
 $24 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($20 << 16 >> 16) | 0; //@line 40628
 $25 = $20 >>> 15; //@line 40629
 $sext32$lobit = $25 & 1; //@line 40630
 $26 = $24 >>> 15; //@line 40631
 $sext33$lobit = $26 & 1; //@line 40632
 HEAP32[96444] = $sext33$lobit & $25; //@line 40634
 $30 = ($sext33$lobit ^ $sext32$lobit) & $26 ^ $sext32$lobit; //@line 40637
 HEAP32[96441] = $30; //@line 40638
 HEAP32[96445] = $30; //@line 40639
 HEAP32[96442] = ($24 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40645
 HEAP32[96443] = $sext33$lobit; //@line 40646
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $24); //@line 40650
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40653
 return;
}
function __Z12op_d130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $5 = 0, $8 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36914
 $8 = HEAP32[162769] | 0; //@line 36917
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 36926
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 36928
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 36932
 $24 = $23 << 24 >> 24; //@line 36934
 $26 = $24 + ($5 << 24 >> 24) | 0; //@line 36937
 $29 = $26 >>> 7; //@line 36941
 $sext34$lobit = $29 & 1; //@line 36942
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 36946
 HEAP32[96444] = ($sext34$lobit ^ $23 >>> 7 & 1) & ($29 ^ $5 >>> 7); //@line 36950
 $39 = ($24 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 36955
 HEAP32[96441] = $39; //@line 36956
 HEAP32[96445] = $39; //@line 36957
 HEAP32[96443] = $sext34$lobit; //@line 36958
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 36962
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36965
 return;
}
function __Z12op_4070_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $4 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 45738
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 45747
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 45749
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 45753
 $23 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($19 << 16 >> 16) | 0; //@line 45759
 $24 = $19 >>> 15; //@line 45760
 $sext$lobit = $24 & 1; //@line 45761
 $25 = $23 >>> 15; //@line 45762
 $sext32$lobit = $25 & 1; //@line 45763
 HEAP32[96444] = $sext32$lobit & $24; //@line 45765
 $29 = ($sext32$lobit ^ $sext$lobit) & $25 ^ $sext$lobit; //@line 45768
 HEAP32[96441] = $29; //@line 45769
 HEAP32[96445] = $29; //@line 45770
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & HEAP32[96442]; //@line 45776
 HEAP32[96443] = $sext32$lobit; //@line 45777
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $23); //@line 45781
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45784
 return;
}
function __Z11op_468_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $24 = 0, $28 = 0, $31 = 0, $33 = 0, $42 = 0, $5 = 0, $sext35$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10921
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10924
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10929
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 10942
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 10944
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 10948
 $31 = ($28 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 10953
 $33 = $28 >>> 15; //@line 10955
 $sext35$lobit = $31 >>> 15 & 1; //@line 10958
 HEAP32[96442] = ($31 & 65535 | 0) == 0 & 1; //@line 10962
 HEAP32[96444] = ($sext35$lobit ^ $33 & 1) & ($33 ^ $5 >>> 7); //@line 10966
 $42 = $10 >>> 0 > ($28 & 65535) >>> 0 & 1; //@line 10969
 HEAP32[96441] = $42; //@line 10970
 HEAP32[96445] = $42; //@line 10971
 HEAP32[96443] = $sext35$lobit; //@line 10972
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $31); //@line 10976
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10979
 return;
}
function __Z12op_e128_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink25 = 0, $10 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39036
 $7 = HEAP32[$6 >> 2] | 0; //@line 39037
 $8 = $7 & 255; //@line 39038
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39039
 $10 = $9 >>> 0 > 7; //@line 39040
 HEAP32[96441] = 0; //@line 39041
 HEAP32[96442] = 0; //@line 39041
 HEAP32[96443] = 0; //@line 39041
 HEAP32[96444] = 0; //@line 39041
 if ($10) {
  $$0$ph = 0; //@line 39046
  $$sink25 = ($9 | 0) == 8 ? $7 & 1 : 0; //@line 39046
  label = 4; //@line 39047
 } else {
  $16 = $8 << $9 + -1; //@line 39051
  if (!$9) {
   $$0 = $8; //@line 39057
  } else {
   $$0$ph = $16 << 1 & 254; //@line 39059
   $$sink25 = $16 >>> 7 & 1; //@line 39059
   label = 4; //@line 39060
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink25; //@line 39064
  HEAP32[96445] = $$sink25; //@line 39065
  $$0 = $$0$ph; //@line 39066
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39070
 HEAP32[96443] = $$0 >>> 7; //@line 39072
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 39075
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39078
 return;
}
function __Z12op_9030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $6 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 23706
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23715
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 23721
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23722
 $23 = HEAP32[$22 >> 2] | 0; //@line 23723
 $26 = ($23 << 24 >> 24) - ($21 << 24 >> 24) | 0; //@line 23728
 $28 = $23 >>> 7; //@line 23730
 $sext35$lobit = $26 >>> 7 & 1; //@line 23733
 $sext35$mask = $26 & 255; //@line 23734
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 23737
 HEAP32[96444] = ($sext35$lobit ^ $28 & 1) & ($28 ^ $21 >>> 7); //@line 23741
 $38 = ($21 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 23745
 HEAP32[96441] = $38; //@line 23746
 HEAP32[96445] = $38; //@line 23747
 HEAP32[96443] = $sext35$lobit; //@line 23748
 HEAP32[$22 >> 2] = $23 & -256 | $sext35$mask; //@line 23751
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23754
 return;
}
function __Z12op_4028_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $4 = 0, $sext30$lobit = 0, $sext31$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 40181
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 40192
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40194
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 40198
 $24 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($20 << 24 >> 24) | 0; //@line 40204
 $25 = $20 >>> 7; //@line 40205
 $sext30$lobit = $25 & 1; //@line 40206
 $26 = $24 >>> 7; //@line 40207
 $sext31$lobit = $26 & 1; //@line 40208
 HEAP32[96444] = $sext31$lobit & $25; //@line 40210
 $30 = ($sext31$lobit ^ $sext30$lobit) & $26 ^ $sext30$lobit; //@line 40213
 HEAP32[96441] = $30; //@line 40214
 HEAP32[96445] = $30; //@line 40215
 HEAP32[96442] = ($24 & 255 | 0) == 0 & HEAP32[96442]; //@line 40221
 HEAP32[96443] = $sext31$lobit; //@line 40222
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $24); //@line 40226
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40229
 return;
}
function __Z12op_4020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $22 = 0, $6 = 0, $8 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $1 = $0 & 7; //@line 40126
 $2 = 651040 + ($1 << 2) | 0; //@line 40127
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 40131
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 40133
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 40137
 HEAP32[$2 >> 2] = $6; //@line 40138
 $16 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($12 << 24 >> 24) | 0; //@line 40144
 $17 = $12 >>> 7; //@line 40145
 $sext$lobit = $17 & 1; //@line 40146
 $18 = $16 >>> 7; //@line 40147
 $sext33$lobit = $18 & 1; //@line 40148
 HEAP32[96444] = $sext33$lobit & $17; //@line 40150
 $22 = ($sext33$lobit ^ $sext$lobit) & $18 ^ $sext$lobit; //@line 40153
 HEAP32[96441] = $22; //@line 40154
 HEAP32[96445] = $22; //@line 40155
 HEAP32[96442] = ($16 & 255 | 0) == 0 & HEAP32[96442]; //@line 40161
 HEAP32[96443] = $sext33$lobit; //@line 40162
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $16); //@line 40166
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40169
 return;
}
function __Z11op_6b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit30 = 0, $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $4 = 0, $42 = 0, $43 = 0, $51 = 0;
 $1 = HEAP32[162769] | 0; //@line 13605
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 13608
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 13623
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 13632
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 13641
 $39 = 123608 + ($28 >>> 16 << 2) | 0; //@line 13643
 $42 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$39 >> 2] >> 2] & 127]($37) | 0; //@line 13646
 $43 = $42 + $19 | 0; //@line 13647
 $$lobit30 = $43 >>> 31; //@line 13650
 HEAP32[96442] = ($43 | 0) == 0 & 1; //@line 13653
 HEAP32[96444] = ($$lobit30 ^ $4 >>> 7) & ($$lobit30 ^ $42 >>> 31); //@line 13657
 $51 = $19 >>> 0 > ~$42 >>> 0 & 1; //@line 13660
 HEAP32[96441] = $51; //@line 13661
 HEAP32[96445] = $51; //@line 13662
 HEAP32[96443] = $$lobit30; //@line 13663
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$39 >> 2] | 0) + 12 >> 2] & 31]($37, $43); //@line 13667
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 13670
 return;
}
function __Z12op_d128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $40 = 0, $5 = 0, $8 = 0, $sext35$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33819
 $8 = HEAP32[162769] | 0; //@line 33822
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 33833
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 33835
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 33839
 $25 = $24 << 24 >> 24; //@line 33841
 $27 = $25 + ($5 << 24 >> 24) | 0; //@line 33844
 $30 = $27 >>> 7; //@line 33848
 $sext35$lobit = $30 & 1; //@line 33849
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 33853
 HEAP32[96444] = ($sext35$lobit ^ $24 >>> 7 & 1) & ($30 ^ $5 >>> 7); //@line 33857
 $40 = ($25 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 33862
 HEAP32[96441] = $40; //@line 33863
 HEAP32[96445] = $40; //@line 33864
 HEAP32[96443] = $sext35$lobit; //@line 33865
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 33869
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33872
 return;
}
function __Z12op_9039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $32 = 0, $34 = 0, $44 = 0, $sext31$lobit = 0, $sext31$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18037
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 18046
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 18061
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18062
 $29 = HEAP32[$28 >> 2] | 0; //@line 18063
 $32 = ($29 << 24 >> 24) - ($27 << 24 >> 24) | 0; //@line 18068
 $34 = $29 >>> 7; //@line 18070
 $sext31$lobit = $32 >>> 7 & 1; //@line 18073
 $sext31$mask = $32 & 255; //@line 18074
 HEAP32[96442] = ($sext31$mask | 0) == 0 & 1; //@line 18077
 HEAP32[96444] = ($sext31$lobit ^ $34 & 1) & ($34 ^ $27 >>> 7); //@line 18081
 $44 = ($27 & 255) >>> 0 > ($29 & 255) >>> 0 & 1; //@line 18085
 HEAP32[96441] = $44; //@line 18086
 HEAP32[96445] = $44; //@line 18087
 HEAP32[96443] = $sext31$lobit; //@line 18088
 HEAP32[$28 >> 2] = $29 & -256 | $sext31$mask; //@line 18091
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 18094
 return;
}
function __Z12op_5018_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $23 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1296
 $5 = $0 & 7; //@line 1297
 $6 = 651040 + ($5 << 2) | 0; //@line 1298
 $7 = HEAP32[$6 >> 2] | 0; //@line 1299
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 1301
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 1305
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($5 << 2) >> 2] | 0); //@line 1310
 $18 = $13 << 24 >> 24; //@line 1312
 $20 = $18 + ($4 << 24 >> 24) | 0; //@line 1315
 $23 = $20 >>> 7; //@line 1319
 $sext38$lobit = $23 & 1; //@line 1320
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 1324
 HEAP32[96444] = ($sext38$lobit ^ $13 >>> 7 & 1) & ($23 ^ $4 >>> 7); //@line 1328
 $33 = ($18 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1333
 HEAP32[96441] = $33; //@line 1334
 HEAP32[96445] = $33; //@line 1335
 HEAP32[96443] = $sext38$lobit; //@line 1336
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 1340
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1343
 return;
}
function __Z12op_4030_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $4 = 0, $sext$lobit = 0, $sext30$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 45680
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 45689
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 45691
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 45695
 $23 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($19 << 24 >> 24) | 0; //@line 45701
 $24 = $19 >>> 7; //@line 45702
 $sext$lobit = $24 & 1; //@line 45703
 $25 = $23 >>> 7; //@line 45704
 $sext30$lobit = $25 & 1; //@line 45705
 HEAP32[96444] = $sext30$lobit & $24; //@line 45707
 $29 = ($sext30$lobit ^ $sext$lobit) & $25 ^ $sext$lobit; //@line 45710
 HEAP32[96441] = $29; //@line 45711
 HEAP32[96445] = $29; //@line 45712
 HEAP32[96442] = ($23 & 255 | 0) == 0 & HEAP32[96442]; //@line 45718
 HEAP32[96443] = $sext30$lobit; //@line 45719
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $23); //@line 45723
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45726
 return;
}
function __Z12op_d060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $20 = 0, $30 = 0, $4 = 0, $6 = 0, $sext41$lobit = 0, $sext41$mask = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32079
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 32081
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 32087
 HEAP32[$4 >> 2] = $6; //@line 32088
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32089
 $14 = HEAP32[$13 >> 2] | 0; //@line 32090
 $15 = $14 << 16 >> 16; //@line 32092
 $17 = $15 + ($12 << 16 >> 16) | 0; //@line 32095
 $20 = $17 >>> 15; //@line 32099
 $sext41$lobit = $20 & 1; //@line 32100
 $sext41$mask = $17 & 65535; //@line 32101
 HEAP32[96442] = ($sext41$mask | 0) == 0 & 1; //@line 32104
 HEAP32[96444] = ($sext41$lobit ^ $14 >>> 15 & 1) & ($20 ^ $12 >>> 15); //@line 32108
 $30 = ($15 & 65535 ^ 65535) >>> 0 < ($12 & 65535) >>> 0 & 1; //@line 32113
 HEAP32[96441] = $30; //@line 32114
 HEAP32[96445] = $30; //@line 32115
 HEAP32[96443] = $sext41$lobit; //@line 32116
 HEAP32[$13 >> 2] = $14 & -65536 | $sext41$mask; //@line 32119
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32122
 return;
}
function __Z12op_9139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $32 = 0, $34 = 0, $4 = 0, $44 = 0, $5 = 0, $sext30$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20381
 $5 = HEAP32[162769] | 0; //@line 20382
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 20391
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 20400
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 20402
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0; //@line 20406
 $32 = ($29 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 20411
 $34 = $29 >>> 7; //@line 20413
 $sext30$lobit = $32 >>> 7 & 1; //@line 20416
 HEAP32[96442] = ($32 & 255 | 0) == 0 & 1; //@line 20420
 HEAP32[96444] = ($sext30$lobit ^ $34 & 1) & ($34 ^ $4 >>> 7); //@line 20424
 $44 = ($4 & 255) >>> 0 > ($29 & 255) >>> 0 & 1; //@line 20428
 HEAP32[96441] = $44; //@line 20429
 HEAP32[96445] = $44; //@line 20430
 HEAP32[96443] = $sext30$lobit; //@line 20431
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $32); //@line 20435
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 20438
 return;
}
function __Z12op_d078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $3 = 0, $36 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 32261
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 32271
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 32277
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32278
 $20 = HEAP32[$19 >> 2] | 0; //@line 32279
 $21 = $20 << 16 >> 16; //@line 32281
 $23 = $21 + ($18 << 16 >> 16) | 0; //@line 32284
 $26 = $23 >>> 15; //@line 32288
 $sext36$lobit = $26 & 1; //@line 32289
 $sext36$mask = $23 & 65535; //@line 32290
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 32293
 HEAP32[96444] = ($sext36$lobit ^ $20 >>> 15 & 1) & ($26 ^ $18 >>> 15); //@line 32297
 $36 = ($21 & 65535 ^ 65535) >>> 0 < ($18 & 65535) >>> 0 & 1; //@line 32302
 HEAP32[96441] = $36; //@line 32303
 HEAP32[96445] = $36; //@line 32304
 HEAP32[96443] = $sext36$lobit; //@line 32305
 HEAP32[$19 >> 2] = $20 & -65536 | $sext36$mask; //@line 32308
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32311
 return;
}
function __Z12op_b148_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $21 = 0, $24 = 0, $4 = 0, $5 = 0, $sext$lobit = 0, $sext41$lobit = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 26618
 $5 = HEAP32[$4 >> 2] | 0; //@line 26619
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 26625
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 26628
 $14 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 26629
 $15 = HEAP32[$14 >> 2] | 0; //@line 26630
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 26636
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 2; //@line 26639
 $24 = $21 - $11 | 0; //@line 26640
 $sext$lobit = $21 >>> 15 & 1; //@line 26644
 $sext41$lobit = $24 >>> 15 & 1; //@line 26646
 HEAP32[96442] = ($24 & 65535 | 0) == 0 & 1; //@line 26650
 HEAP32[96444] = ($11 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext41$lobit | 0) != ($sext$lobit | 0) & 1; //@line 26655
 HEAP32[96441] = ($11 & 65535) >>> 0 > ($21 & 65535) >>> 0 & 1; //@line 26660
 HEAP32[96443] = $sext41$lobit; //@line 26661
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26664
 return;
}
function __Z12op_9028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $6 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $6 = HEAP32[162769] | 0; //@line 17854
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 17865
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 17871
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17872
 $24 = HEAP32[$23 >> 2] | 0; //@line 17873
 $27 = ($24 << 24 >> 24) - ($22 << 24 >> 24) | 0; //@line 17878
 $29 = $24 >>> 7; //@line 17880
 $sext36$lobit = $27 >>> 7 & 1; //@line 17883
 $sext36$mask = $27 & 255; //@line 17884
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 17887
 HEAP32[96444] = ($sext36$lobit ^ $29 & 1) & ($29 ^ $22 >>> 7); //@line 17891
 $39 = ($22 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 17895
 HEAP32[96441] = $39; //@line 17896
 HEAP32[96445] = $39; //@line 17897
 HEAP32[96443] = $sext36$lobit; //@line 17898
 HEAP32[$23 >> 2] = $24 & -256 | $sext36$mask; //@line 17901
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 17904
 return;
}
function __Z12op_33fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $40 = 0, $41 = 0, $43 = 0;
 $2 = HEAP32[162769] | 0; //@line 45611
 $$cast = $2; //@line 45616
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45625
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 45631
 $22 = HEAP32[162769] | 0; //@line 45632
 $31 = (HEAPU8[$22 + 5 >> 0] | 0) << 16 | (HEAPU8[$22 + 4 >> 0] | 0) << 24; //@line 45641
 $40 = $31 | (HEAPU8[$22 + 6 >> 0] | 0) << 8 | (HEAPU8[$22 + 7 >> 0] | 0); //@line 45650
 $41 = $21 << 16 >> 16; //@line 45652
 $43 = ($41 | 0) == 0 & 1; //@line 45654
 HEAP32[96441] = 0; //@line 45655
 HEAP32[96442] = 0; //@line 45655
 HEAP32[96443] = 0; //@line 45655
 HEAP32[96444] = 0; //@line 45655
 HEAP32[96442] = $43; //@line 45656
 HEAP32[96443] = $21 >>> 15 & 1; //@line 45659
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($40, $41); //@line 45665
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 45668
 return;
}
function __Z12op_5020_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $22 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1355
 $5 = $0 & 7; //@line 1356
 $6 = 651040 + ($5 << 2) | 0; //@line 1357
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($5 << 2) >> 2] | 0) | 0; //@line 1361
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 1363
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 1367
 HEAP32[$6 >> 2] = $10; //@line 1368
 $17 = $16 << 24 >> 24; //@line 1370
 $19 = $17 + ($4 << 24 >> 24) | 0; //@line 1373
 $22 = $19 >>> 7; //@line 1377
 $sext39$lobit = $22 & 1; //@line 1378
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 1382
 HEAP32[96444] = ($sext39$lobit ^ $16 >>> 7 & 1) & ($22 ^ $4 >>> 7); //@line 1386
 $32 = ($17 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1391
 HEAP32[96441] = $32; //@line 1392
 HEAP32[96445] = $32; //@line 1393
 HEAP32[96443] = $sext39$lobit; //@line 1394
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 1398
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1401
 return;
}
function __Z12op_13fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $40 = 0, $41 = 0, $43 = 0;
 $2 = HEAP32[162769] | 0; //@line 31981
 $$cast = $2; //@line 31986
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 31995
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 32001
 $22 = HEAP32[162769] | 0; //@line 32002
 $31 = (HEAPU8[$22 + 5 >> 0] | 0) << 16 | (HEAPU8[$22 + 4 >> 0] | 0) << 24; //@line 32011
 $40 = $31 | (HEAPU8[$22 + 6 >> 0] | 0) << 8 | (HEAPU8[$22 + 7 >> 0] | 0); //@line 32020
 $41 = $21 << 24 >> 24; //@line 32022
 $43 = ($41 | 0) == 0 & 1; //@line 32024
 HEAP32[96441] = 0; //@line 32025
 HEAP32[96442] = 0; //@line 32025
 HEAP32[96443] = 0; //@line 32025
 HEAP32[96444] = 0; //@line 32025
 HEAP32[96442] = $43; //@line 32026
 HEAP32[96443] = $21 >>> 7 & 1; //@line 32029
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($40, $41); //@line 32035
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 32038
 return;
}
function __Z12op_4818_0_ffj($0) {
 $0 = $0 | 0;
 var $$029$in = 0, $1 = 0, $14 = 0, $18 = 0, $2 = 0, $20 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 49685
 $2 = 651040 + ($1 << 2) | 0; //@line 49686
 $3 = HEAP32[$2 >> 2] | 0; //@line 49687
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 49689
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 49693
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 49698
 $14 = $9 << 24 >> 24; //@line 49700
 $18 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($14 & 15) | 0; //@line 49705
 $20 = $18 & 65535; //@line 49707
 $23 = ($20 >>> 0 > 9 ? $20 + -6 | 0 : $18) - ($14 & 240) | 0; //@line 49711
 $25 = ($23 & 496) >>> 0 > 144; //@line 49713
 $26 = $25 & 1; //@line 49714
 $$029$in = $25 ? ($23 & 65535) + -96 | 0 : $23; //@line 49717
 HEAP32[96441] = $26; //@line 49718
 HEAP32[96445] = $26; //@line 49719
 HEAP32[96442] = ($$029$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49725
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $$029$in & 65535); //@line 49730
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49733
 return;
}
function __Z12op_90bb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit36 = 0, $$lobit37 = 0, $15 = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $32 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 19412
 $4 = $3 + 2 | 0; //@line 19413
 HEAP32[162769] = $4; //@line 19414
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 19419
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 19426
 HEAP32[162769] = $3 + 4; //@line 19428
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 19429
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 19434
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19435
 $24 = HEAP32[$23 >> 2] | 0; //@line 19436
 $25 = $24 - $22 | 0; //@line 19437
 $$lobit36 = $24 >>> 31; //@line 19439
 $$lobit37 = $25 >>> 31; //@line 19440
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 19443
 HEAP32[96444] = ($$lobit37 ^ $$lobit36) & ($$lobit36 ^ $22 >>> 31); //@line 19447
 $32 = $24 >>> 0 < $22 >>> 0 & 1; //@line 19449
 HEAP32[96441] = $32; //@line 19450
 HEAP32[96445] = $32; //@line 19451
 HEAP32[96443] = $$lobit37; //@line 19452
 HEAP32[$23 >> 2] = $25; //@line 19453
 return;
}
function __Z11op_630_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $22 = 0, $23 = 0, $25 = 0, $28 = 0, $37 = 0, $4 = 0, $sext29$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 17096
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17098
 $16 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17110
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 17112
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 17116
 $23 = $22 << 24 >> 24; //@line 17118
 $25 = $23 + ($4 << 24 >> 24) | 0; //@line 17120
 $28 = $25 >>> 7; //@line 17125
 $sext29$lobit = $28 & 1; //@line 17126
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 17130
 HEAP32[96444] = ($sext29$lobit ^ $22 >>> 7 & 1) & ($28 ^ ($4 & 255) >>> 7 & 255); //@line 17134
 $37 = ($23 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 17138
 HEAP32[96441] = $37; //@line 17139
 HEAP32[96445] = $37; //@line 17140
 HEAP32[96443] = $sext29$lobit; //@line 17141
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 17145
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17148
 return;
}
function __Z12op_5068_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $8 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4098
 $8 = HEAP32[162769] | 0; //@line 4102
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 4113
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 4115
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 4119
 $25 = $24 << 16 >> 16; //@line 4121
 $27 = $25 + ($4 << 16 >> 16) | 0; //@line 4124
 $30 = $27 >>> 15; //@line 4128
 $sext39$lobit = $30 & 1; //@line 4129
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 4133
 HEAP32[96444] = ($sext39$lobit ^ $24 >>> 15 & 1) & ($30 ^ $4 >>> 15); //@line 4137
 $40 = ($25 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4142
 HEAP32[96441] = $40; //@line 4143
 HEAP32[96445] = $40; //@line 4144
 HEAP32[96443] = $sext39$lobit; //@line 4145
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 4149
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4152
 return;
}
function __Z12op_3198_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $17 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 38146
 $5 = HEAP32[$4 >> 2] | 0; //@line 38147
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 38153
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 38156
 $14 = HEAP32[162769] | 0; //@line 38157
 $15 = $14 + 2 | 0; //@line 38158
 HEAP32[162769] = $15; //@line 38159
 $17 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38161
 $24 = (HEAPU8[$15 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0); //@line 38168
 HEAP32[162769] = $14 + 4; //@line 38170
 $26 = __Z15get_disp_ea_020jj($17, $24) | 0; //@line 38171
 $27 = $11 << 16 >> 16; //@line 38173
 $29 = ($27 | 0) == 0 & 1; //@line 38175
 HEAP32[96441] = 0; //@line 38176
 HEAP32[96442] = 0; //@line 38176
 HEAP32[96443] = 0; //@line 38176
 HEAP32[96444] = 0; //@line 38176
 HEAP32[96442] = $29; //@line 38177
 HEAP32[96443] = $11 >>> 15 & 1; //@line 38180
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 38186
 return;
}
function __Z11op_e78_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $36 = 0, $46 = 0, $47 = 0, $49 = 0, $6 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22106
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 22109
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 22112
 $8 = $6 << 24 >> 16; //@line 22114
 do {
  if (!($8 & 2048)) {
   $36 = (HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0]) << 16 >> 16; //@line 22128
   $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($36) | 0) << 16 >> 16; //@line 22139
   $47 = $6 >>> 4 & 7; //@line 22140
   if (!($8 & 32768)) {
    $49 = 651008 + ($47 << 2) | 0; //@line 22142
    HEAP32[$49 >> 2] = HEAP32[$49 >> 2] & -65536 | $46 & 65535; //@line 22147
    break;
   } else {
    HEAP32[651040 + ($47 << 2) >> 2] = $46; //@line 22151
    break;
   }
  } else {
   $22 = (HEAPU8[$3 + 4 >> 0] << 8 | HEAPU8[$3 + 5 >> 0]) << 16 >> 16; //@line 22167
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($22, HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 22173
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 22178
 return;
}
function __Z12op_5179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $32 = 0, $34 = 0, $4 = 0, $44 = 0, $5 = 0, $sext34$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5894
 $5 = HEAP32[162769] | 0; //@line 5895
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 5904
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 5913
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 5915
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0; //@line 5919
 $32 = ($29 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5924
 $34 = $29 >>> 15; //@line 5926
 $sext34$lobit = $32 >>> 15 & 1; //@line 5929
 HEAP32[96442] = ($32 & 65535 | 0) == 0 & 1; //@line 5933
 HEAP32[96444] = ($sext34$lobit ^ $34 & 1) & ($34 ^ $4 >>> 15); //@line 5937
 $44 = ($4 & 65535) >>> 0 > ($29 & 65535) >>> 0 & 1; //@line 5941
 HEAP32[96441] = $44; //@line 5942
 HEAP32[96445] = $44; //@line 5943
 HEAP32[96443] = $sext34$lobit; //@line 5944
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $32); //@line 5948
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5951
 return;
}
function __Z11op_678_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $39 = 0, $4 = 0, $9 = 0, $sext31$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 13030
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 13033
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 13038
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 13048
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 13050
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 13054
 $25 = $24 << 16 >> 16; //@line 13056
 $27 = $25 + ($9 << 16 >> 16) | 0; //@line 13059
 $30 = $27 >>> 15; //@line 13063
 $sext31$lobit = $30 & 1; //@line 13064
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 13068
 HEAP32[96444] = ($sext31$lobit ^ $24 >>> 15 & 1) & ($30 ^ $4 >>> 7); //@line 13072
 $39 = ($25 & 65535 ^ 65535) >>> 0 < $9 >>> 0 & 1; //@line 13076
 HEAP32[96441] = $39; //@line 13077
 HEAP32[96445] = $39; //@line 13078
 HEAP32[96443] = $sext31$lobit; //@line 13079
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 13083
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13086
 return;
}
function __Z11op_628_0_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $38 = 0, $4 = 0, $sext30$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12412
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 12414
 $17 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 12428
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 12430
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 12434
 $24 = $23 << 24 >> 24; //@line 12436
 $26 = $24 + ($4 << 24 >> 24) | 0; //@line 12438
 $29 = $26 >>> 7; //@line 12443
 $sext30$lobit = $29 & 1; //@line 12444
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 12448
 HEAP32[96444] = ($sext30$lobit ^ $23 >>> 7 & 1) & ($29 ^ ($4 & 255) >>> 7 & 255); //@line 12452
 $38 = ($24 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12456
 HEAP32[96441] = $38; //@line 12457
 HEAP32[96445] = $38; //@line 12458
 HEAP32[96443] = $sext30$lobit; //@line 12459
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 12463
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 12466
 return;
}
function __Z12op_313b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 37246
 $4 = $3 + 2 | 0; //@line 37247
 HEAP32[162769] = $4; //@line 37248
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 37253
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 37260
 HEAP32[162769] = $3 + 4; //@line 37262
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 37263
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 37269
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37270
 $26 = (HEAP32[$24 >> 2] | 0) + -2 | 0; //@line 37272
 HEAP32[$24 >> 2] = $26; //@line 37273
 $27 = $23 << 16 >> 16; //@line 37275
 $29 = ($27 | 0) == 0 & 1; //@line 37277
 HEAP32[96441] = 0; //@line 37278
 HEAP32[96442] = 0; //@line 37278
 HEAP32[96443] = 0; //@line 37278
 HEAP32[96444] = 0; //@line 37278
 HEAP32[96442] = $29; //@line 37279
 HEAP32[96443] = $23 >>> 15 & 1; //@line 37282
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 37288
 return;
}
function __Z11op_e38_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $36 = 0, $46 = 0, $47 = 0, $49 = 0, $6 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21537
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 21540
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 21543
 $8 = $6 << 24 >> 16; //@line 21545
 do {
  if (!($8 & 2048)) {
   $36 = (HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0]) << 16 >> 16; //@line 21559
   $46 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($36) | 0) << 24 >> 24; //@line 21570
   $47 = $6 >>> 4 & 7; //@line 21571
   if (!($8 & 32768)) {
    $49 = 651008 + ($47 << 2) | 0; //@line 21573
    HEAP32[$49 >> 2] = HEAP32[$49 >> 2] & -256 | $46 & 255; //@line 21578
    break;
   } else {
    HEAP32[651040 + ($47 << 2) >> 2] = $46; //@line 21582
    break;
   }
  } else {
   $22 = (HEAPU8[$3 + 4 >> 0] << 8 | HEAPU8[$3 + 5 >> 0]) << 16 >> 16; //@line 21598
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($22, HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 21604
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 21609
 return;
}
function __Z11op_418_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $20 = 0, $22 = 0, $31 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext31$lobit = 0;
 $1 = $0 & 7; //@line 10332
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 10335
 $6 = 651040 + ($1 << 2) | 0; //@line 10337
 $7 = HEAP32[$6 >> 2] | 0; //@line 10338
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 10340
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 10344
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 10349
 $20 = ($13 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10353
 $22 = $13 >>> 7; //@line 10356
 $sext31$lobit = $20 >>> 7 & 1; //@line 10359
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 10363
 HEAP32[96444] = ($sext31$lobit ^ $22 & 1) & ($22 ^ ($4 & 255) >>> 7 & 255); //@line 10367
 $31 = ($4 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 10370
 HEAP32[96441] = $31; //@line 10371
 HEAP32[96445] = $31; //@line 10372
 HEAP32[96443] = $sext31$lobit; //@line 10373
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 10377
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10380
 return;
}
function __Z12op_5030_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $24 = 0, $26 = 0, $29 = 0, $39 = 0, $4 = 0, $8 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 3759
 $8 = HEAP32[162769] | 0; //@line 3763
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 3772
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 3774
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 3778
 $24 = $23 << 24 >> 24; //@line 3780
 $26 = $24 + ($4 << 24 >> 24) | 0; //@line 3783
 $29 = $26 >>> 7; //@line 3787
 $sext36$lobit = $29 & 1; //@line 3788
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 3792
 HEAP32[96444] = ($sext36$lobit ^ $23 >>> 7 & 1) & ($29 ^ $4 >>> 7); //@line 3796
 $39 = ($24 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 3801
 HEAP32[96441] = $39; //@line 3802
 HEAP32[96445] = $39; //@line 3803
 HEAP32[96443] = $sext36$lobit; //@line 3804
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 3808
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3811
 return;
}
function __Z12op_33fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $32 = 0, $41 = 0, $42 = 0, $44 = 0;
 $2 = HEAP32[162769] | 0; //@line 39800
 $$cast = $2; //@line 39802
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 39816
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 39822
 $23 = HEAP32[162769] | 0; //@line 39823
 $32 = (HEAPU8[$23 + 5 >> 0] | 0) << 16 | (HEAPU8[$23 + 4 >> 0] | 0) << 24; //@line 39832
 $41 = $32 | (HEAPU8[$23 + 6 >> 0] | 0) << 8 | (HEAPU8[$23 + 7 >> 0] | 0); //@line 39841
 $42 = $22 << 16 >> 16; //@line 39843
 $44 = ($42 | 0) == 0 & 1; //@line 39845
 HEAP32[96441] = 0; //@line 39846
 HEAP32[96442] = 0; //@line 39846
 HEAP32[96443] = 0; //@line 39846
 HEAP32[96444] = 0; //@line 39846
 HEAP32[96442] = $44; //@line 39847
 HEAP32[96443] = $22 >>> 15 & 1; //@line 39850
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($41, $42); //@line 39856
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 39859
 return;
}
function __Z11op_439_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $22 = 0, $24 = 0, $28 = 0, $3 = 0, $31 = 0, $33 = 0, $42 = 0, $sext25$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 10628
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 10630
 $13 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 10640
 $22 = $13 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 10649
 $24 = 123608 + ($13 >>> 16 << 2) | 0; //@line 10651
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 8 >> 2] & 127]($22) | 0; //@line 10655
 $31 = ($28 << 24 >> 24) - ($3 << 24 >> 24) | 0; //@line 10659
 $33 = $28 >>> 7; //@line 10662
 $sext25$lobit = $31 >>> 7 & 1; //@line 10665
 HEAP32[96442] = ($31 & 255 | 0) == 0 & 1; //@line 10669
 HEAP32[96444] = ($sext25$lobit ^ $33 & 1) & ($33 ^ ($3 & 255) >>> 7 & 255); //@line 10673
 $42 = ($3 & 255) >>> 0 > ($28 & 255) >>> 0 & 1; //@line 10676
 HEAP32[96441] = $42; //@line 10677
 HEAP32[96445] = $42; //@line 10678
 HEAP32[96443] = $sext25$lobit; //@line 10679
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 20 >> 2] & 31]($22, $31); //@line 10683
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 10686
 return;
}
function __Z12op_13fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $32 = 0, $41 = 0, $42 = 0, $44 = 0;
 $2 = HEAP32[162769] | 0; //@line 27679
 $$cast = $2; //@line 27681
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 27695
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 27701
 $23 = HEAP32[162769] | 0; //@line 27702
 $32 = (HEAPU8[$23 + 5 >> 0] | 0) << 16 | (HEAPU8[$23 + 4 >> 0] | 0) << 24; //@line 27711
 $41 = $32 | (HEAPU8[$23 + 6 >> 0] | 0) << 8 | (HEAPU8[$23 + 7 >> 0] | 0); //@line 27720
 $42 = $22 << 24 >> 24; //@line 27722
 $44 = ($42 | 0) == 0 & 1; //@line 27724
 HEAP32[96441] = 0; //@line 27725
 HEAP32[96442] = 0; //@line 27725
 HEAP32[96443] = 0; //@line 27725
 HEAP32[96444] = 0; //@line 27725
 HEAP32[96442] = $44; //@line 27726
 HEAP32[96443] = $22 >>> 7 & 1; //@line 27729
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($41, $42); //@line 27735
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 27738
 return;
}
function __Z12op_d038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $3 = 0, $36 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 31569
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 31579
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 31585
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31586
 $20 = HEAP32[$19 >> 2] | 0; //@line 31587
 $21 = $20 << 24 >> 24; //@line 31589
 $23 = $21 + ($18 << 24 >> 24) | 0; //@line 31592
 $26 = $23 >>> 7; //@line 31596
 $sext32$lobit = $26 & 1; //@line 31597
 $sext32$mask = $23 & 255; //@line 31598
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 31601
 HEAP32[96444] = ($sext32$lobit ^ $20 >>> 7 & 1) & ($26 ^ $18 >>> 7); //@line 31605
 $36 = ($21 & 255 ^ 255) >>> 0 < ($18 & 255) >>> 0 & 1; //@line 31610
 HEAP32[96441] = $36; //@line 31611
 HEAP32[96445] = $36; //@line 31612
 HEAP32[96443] = $sext32$lobit; //@line 31613
 HEAP32[$19 >> 2] = $20 & -256 | $sext32$mask; //@line 31616
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31619
 return;
}
function __Z12op_4830_3_ffj($0) {
 $0 = $0 | 0;
 var $$028$in = 0, $13 = 0, $15 = 0, $20 = 0, $24 = 0, $26 = 0, $29 = 0, $31 = 0, $32 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2660
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2669
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2671
 $20 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0) << 24 >> 24; //@line 2677
 $24 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($20 & 15) | 0; //@line 2682
 $26 = $24 & 65535; //@line 2684
 $29 = ($26 >>> 0 > 9 ? $26 + -6 | 0 : $24) - ($20 & 240) | 0; //@line 2688
 $31 = ($29 & 496) >>> 0 > 144; //@line 2690
 $32 = $31 & 1; //@line 2691
 $$028$in = $31 ? ($29 & 65535) + -96 | 0 : $29; //@line 2694
 HEAP32[96441] = $32; //@line 2695
 HEAP32[96445] = $32; //@line 2696
 HEAP32[96442] = ($$028$in & 255 | 0) == 0 & HEAP32[96442]; //@line 2702
 HEAP32[96443] = $$028$in >>> 7 & 1; //@line 2705
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $$028$in & 65535); //@line 2710
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2713
 return;
}
function __Z12op_4820_0_ffj($0) {
 $0 = $0 | 0;
 var $$030$in = 0, $1 = 0, $12 = 0, $13 = 0, $17 = 0, $19 = 0, $2 = 0, $22 = 0, $24 = 0, $25 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 49742
 $2 = 651040 + ($1 << 2) | 0; //@line 49743
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 49747
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 49749
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 49753
 HEAP32[$2 >> 2] = $6; //@line 49754
 $13 = $12 << 24 >> 24; //@line 49756
 $17 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($13 & 15) | 0; //@line 49761
 $19 = $17 & 65535; //@line 49763
 $22 = ($19 >>> 0 > 9 ? $19 + -6 | 0 : $17) - ($13 & 240) | 0; //@line 49767
 $24 = ($22 & 496) >>> 0 > 144; //@line 49769
 $25 = $24 & 1; //@line 49770
 $$030$in = $24 ? ($22 & 65535) + -96 | 0 : $22; //@line 49773
 HEAP32[96441] = $25; //@line 49774
 HEAP32[96445] = $25; //@line 49775
 HEAP32[96442] = ($$030$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49781
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $$030$in & 65535); //@line 49786
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49789
 return;
}
function __Z11op_cbb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $1 = 0, $19 = 0, $20 = 0, $24 = 0, $31 = 0, $33 = 0, $38 = 0, $39 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 20379
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 20382
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 20397
 $20 = $1 + 6 | 0; //@line 20398
 HEAP32[162769] = $20; //@line 20399
 $24 = (HEAP32[162768] | 0) + $20 - (HEAP32[162770] | 0) | 0; //@line 20404
 $31 = (HEAPU8[$20 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 20411
 HEAP32[162769] = $1 + 8; //@line 20413
 $33 = __Z15get_disp_ea_020jj($24, $31) | 0; //@line 20414
 $38 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($33 >>> 16 << 2) >> 2] >> 2] & 127]($33) | 0; //@line 20419
 $39 = $38 - $19 | 0; //@line 20420
 $$lobit32 = $38 >>> 31; //@line 20422
 $$lobit33 = $39 >>> 31; //@line 20423
 HEAP32[96442] = ($39 | 0) == 0 & 1; //@line 20426
 HEAP32[96444] = ($4 >>> 7 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 20431
 HEAP32[96441] = $38 >>> 0 < $19 >>> 0 & 1; //@line 20434
 HEAP32[96443] = $$lobit33; //@line 20435
 return;
}
function __Z11op_420_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $19 = 0, $21 = 0, $30 = 0, $4 = 0, $6 = 0, $sext32$lobit = 0;
 $1 = $0 & 7; //@line 10389
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 10392
 $6 = 651040 + ($1 << 2) | 0; //@line 10394
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 10398
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 10400
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 10404
 HEAP32[$6 >> 2] = $10; //@line 10405
 $19 = ($16 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10409
 $21 = $16 >>> 7; //@line 10412
 $sext32$lobit = $19 >>> 7 & 1; //@line 10415
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 10419
 HEAP32[96444] = ($sext32$lobit ^ $21 & 1) & ($21 ^ ($4 & 255) >>> 7 & 255); //@line 10423
 $30 = ($4 & 255) >>> 0 > ($16 & 255) >>> 0 & 1; //@line 10426
 HEAP32[96441] = $30; //@line 10427
 HEAP32[96445] = $30; //@line 10428
 HEAP32[96443] = $sext32$lobit; //@line 10429
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 10433
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10436
 return;
}
function __Z12op_90b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $14 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $31 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 19206
 $5 = $4 + 2 | 0; //@line 19207
 HEAP32[162769] = $5; //@line 19208
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19210
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 19217
 HEAP32[162769] = $4 + 4; //@line 19219
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 19220
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 19225
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19226
 $23 = HEAP32[$22 >> 2] | 0; //@line 19227
 $24 = $23 - $21 | 0; //@line 19228
 $$lobit37 = $23 >>> 31; //@line 19230
 $$lobit38 = $24 >>> 31; //@line 19231
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 19234
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $21 >>> 31); //@line 19238
 $31 = $23 >>> 0 < $21 >>> 0 & 1; //@line 19240
 HEAP32[96441] = $31; //@line 19241
 HEAP32[96445] = $31; //@line 19242
 HEAP32[96443] = $$lobit38; //@line 19243
 HEAP32[$22 >> 2] = $24; //@line 19244
 return;
}
function __Z12op_9118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $20 = 0, $22 = 0, $3 = 0, $32 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $3 = $0 & 7; //@line 20076
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20078
 $6 = 651040 + ($3 << 2) | 0; //@line 20079
 $7 = HEAP32[$6 >> 2] | 0; //@line 20080
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 20082
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 20086
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 20091
 $20 = ($13 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 20096
 $22 = $13 >>> 7; //@line 20098
 $sext36$lobit = $20 >>> 7 & 1; //@line 20101
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 20105
 HEAP32[96444] = ($sext36$lobit ^ $22 & 1) & ($22 ^ $5 >>> 7); //@line 20109
 $32 = ($5 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 20113
 HEAP32[96441] = $32; //@line 20114
 HEAP32[96445] = $32; //@line 20115
 HEAP32[96443] = $sext36$lobit; //@line 20116
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 20120
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20123
 return;
}
function __Z12op_5028_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $25 = 0, $27 = 0, $30 = 0, $4 = 0, $40 = 0, $8 = 0, $sext37$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1413
 $8 = HEAP32[162769] | 0; //@line 1417
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 1428
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 1430
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 1434
 $25 = $24 << 24 >> 24; //@line 1436
 $27 = $25 + ($4 << 24 >> 24) | 0; //@line 1439
 $30 = $27 >>> 7; //@line 1443
 $sext37$lobit = $30 & 1; //@line 1444
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 1448
 HEAP32[96444] = ($sext37$lobit ^ $24 >>> 7 & 1) & ($30 ^ $4 >>> 7); //@line 1452
 $40 = ($25 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1457
 HEAP32[96441] = $40; //@line 1458
 HEAP32[96445] = $40; //@line 1459
 HEAP32[96443] = $sext37$lobit; //@line 1460
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 1464
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 1467
 return;
}
function __Z12op_4839_0_ffj($0) {
 $0 = $0 | 0;
 var $$023$in = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $26 = 0, $30 = 0, $32 = 0, $35 = 0, $37 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 49984
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 49993
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 50002
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 50004
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 50010
 $30 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($26 & 15) | 0; //@line 50015
 $32 = $30 & 65535; //@line 50017
 $35 = ($32 >>> 0 > 9 ? $32 + -6 | 0 : $30) - ($26 & 240) | 0; //@line 50021
 $37 = ($35 & 496) >>> 0 > 144; //@line 50023
 $38 = $37 & 1; //@line 50024
 $$023$in = $37 ? ($35 & 65535) + -96 | 0 : $35; //@line 50027
 HEAP32[96441] = $38; //@line 50028
 HEAP32[96445] = $38; //@line 50029
 HEAP32[96442] = ($$023$in & 255 | 0) == 0 & HEAP32[96442]; //@line 50035
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $$023$in & 65535); //@line 50040
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 50043
 return;
}
function __Z11op_698_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $27 = 0, $30 = 0, $38 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13278
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13281
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13296
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 13297
 $22 = HEAP32[$21 >> 2] | 0; //@line 13298
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 13300
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 13303
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 13306
 $30 = $27 + $20 | 0; //@line 13307
 $$lobit35 = $30 >>> 31; //@line 13310
 HEAP32[96442] = ($30 | 0) == 0 & 1; //@line 13313
 HEAP32[96444] = ($$lobit35 ^ $5 >>> 7) & ($$lobit35 ^ $27 >>> 31); //@line 13317
 $38 = $20 >>> 0 > ~$27 >>> 0 & 1; //@line 13320
 HEAP32[96441] = $38; //@line 13321
 HEAP32[96445] = $38; //@line 13322
 HEAP32[96443] = $$lobit35; //@line 13323
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $30); //@line 13327
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13330
 return;
}
function __Z12op_30fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 36698
 $4 = $3 + 2 | 0; //@line 36699
 HEAP32[162769] = $4; //@line 36700
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 36705
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 36712
 HEAP32[162769] = $3 + 4; //@line 36714
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 36715
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36721
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36722
 $25 = HEAP32[$24 >> 2] | 0; //@line 36723
 HEAP32[$24 >> 2] = $25 + 2; //@line 36725
 $27 = $23 << 16 >> 16; //@line 36727
 $29 = ($27 | 0) == 0 & 1; //@line 36729
 HEAP32[96441] = 0; //@line 36730
 HEAP32[96442] = 0; //@line 36730
 HEAP32[96443] = 0; //@line 36730
 HEAP32[96444] = 0; //@line 36730
 HEAP32[96442] = $29; //@line 36731
 HEAP32[96443] = $23 >>> 15 & 1; //@line 36734
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $27); //@line 36740
 return;
}
function __Z12op_113b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $28 = 0, $29 = 0, $31 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 31016
 $4 = HEAP32[162769] | 0; //@line 31018
 $$cast = $4; //@line 31023
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 31032
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 31038
 $24 = 651040 + ($2 << 2) | 0; //@line 31039
 $28 = (HEAP32[$24 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 31043
 HEAP32[$24 >> 2] = $28; //@line 31044
 $29 = $23 << 24 >> 24; //@line 31046
 $31 = ($29 | 0) == 0 & 1; //@line 31048
 HEAP32[96441] = 0; //@line 31049
 HEAP32[96442] = 0; //@line 31049
 HEAP32[96443] = 0; //@line 31049
 HEAP32[96444] = 0; //@line 31049
 HEAP32[96442] = $31; //@line 31050
 HEAP32[96443] = $23 >>> 7 & 1; //@line 31053
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, $29); //@line 31059
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31062
 return;
}
function __Z15ChecksumSlotROMv() {
 var $$023$lcssa = 0, $$02324 = 0, $$025 = 0, $11 = 0, $13 = 0, $28 = 0, $3 = 0, $5 = 0, $7 = 0, $9 = 0;
 $3 = HEAP32[28211] | 0; //@line 10379
 $5 = (HEAP32[30897] | 0) + (HEAP32[30898] | 0) + (0 - $3) | 0; //@line 10381
 $7 = $5 + ($3 + -12) | 0; //@line 10383
 HEAP8[$7 >> 0] = 0; //@line 10384
 $9 = $5 + ($3 + -11) | 0; //@line 10386
 HEAP8[$9 >> 0] = 0; //@line 10387
 $11 = $5 + ($3 + -10) | 0; //@line 10389
 HEAP8[$11 >> 0] = 0; //@line 10390
 $13 = $5 + ($3 + -9) | 0; //@line 10392
 HEAP8[$13 >> 0] = 0; //@line 10393
 if (($3 | 0) > 0) {
  $$02324 = 0; //@line 10396
  $$025 = 0; //@line 10396
  while (1) {
   $28 = (HEAPU8[$5 + $$025 >> 0] | 0) + ($$02324 << 1 | $$02324 >>> 31) | 0; //@line 10404
   $$025 = $$025 + 1 | 0; //@line 10405
   if (($$025 | 0) >= ($3 | 0)) {
    $$023$lcssa = $28; //@line 10410
    break;
   } else {
    $$02324 = $28; //@line 10408
   }
  }
 } else {
  $$023$lcssa = 0; //@line 10415
 }
 HEAP8[$7 >> 0] = $$023$lcssa >>> 24; //@line 10419
 HEAP8[$9 >> 0] = $$023$lcssa >>> 16; //@line 10422
 HEAP8[$11 >> 0] = $$023$lcssa >>> 8; //@line 10425
 HEAP8[$13 >> 0] = $$023$lcssa; //@line 10427
 return;
}
function __Z12op_5139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $32 = 0, $34 = 0, $4 = 0, $44 = 0, $5 = 0, $sext32$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5410
 $5 = HEAP32[162769] | 0; //@line 5411
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 5420
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 5429
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 5431
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0; //@line 5435
 $32 = ($29 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5440
 $34 = $29 >>> 7; //@line 5442
 $sext32$lobit = $32 >>> 7 & 1; //@line 5445
 HEAP32[96442] = ($32 & 255 | 0) == 0 & 1; //@line 5449
 HEAP32[96444] = ($sext32$lobit ^ $34 & 1) & ($34 ^ $4 >>> 7); //@line 5453
 $44 = ($4 & 255) >>> 0 > ($29 & 255) >>> 0 & 1; //@line 5457
 HEAP32[96441] = $44; //@line 5458
 HEAP32[96445] = $44; //@line 5459
 HEAP32[96443] = $sext32$lobit; //@line 5460
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $32); //@line 5464
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5467
 return;
}
function __Z12op_4828_1_ffj($0) {
 $0 = $0 | 0;
 var $$028$in = 0, $14 = 0, $16 = 0, $21 = 0, $25 = 0, $27 = 0, $30 = 0, $32 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 1895
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 1906
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 1908
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 1914
 $25 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($21 & 15) | 0; //@line 1919
 $27 = $25 & 65535; //@line 1921
 $30 = ($27 >>> 0 > 9 ? $27 + -6 | 0 : $25) - ($21 & 240) | 0; //@line 1925
 $32 = ($30 & 496) >>> 0 > 144; //@line 1927
 $33 = $32 & 1; //@line 1928
 $$028$in = $32 ? ($30 & 65535) + -96 | 0 : $30; //@line 1931
 HEAP32[96441] = $33; //@line 1932
 HEAP32[96445] = $33; //@line 1933
 HEAP32[96442] = ($$028$in & 255 | 0) == 0 & HEAP32[96442]; //@line 1939
 HEAP32[96443] = $$028$in >>> 7 & 1; //@line 1942
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $$028$in & 65535); //@line 1947
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 1950
 return;
}
function __Z12op_31a0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $16 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 38197
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 38199
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 38205
 HEAP32[$4 >> 2] = $6; //@line 38206
 $13 = HEAP32[162769] | 0; //@line 38207
 $14 = $13 + 2 | 0; //@line 38208
 HEAP32[162769] = $14; //@line 38209
 $16 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38211
 $23 = (HEAPU8[$14 >> 0] | 0) << 8 | (HEAPU8[$13 + 3 >> 0] | 0); //@line 38218
 HEAP32[162769] = $13 + 4; //@line 38220
 $25 = __Z15get_disp_ea_020jj($16, $23) | 0; //@line 38221
 $26 = $12 << 16 >> 16; //@line 38223
 $28 = ($26 | 0) == 0 & 1; //@line 38225
 HEAP32[96441] = 0; //@line 38226
 HEAP32[96442] = 0; //@line 38226
 HEAP32[96443] = 0; //@line 38226
 HEAP32[96444] = 0; //@line 38226
 HEAP32[96442] = $28; //@line 38227
 HEAP32[96443] = $12 >>> 15 & 1; //@line 38230
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 38236
 return;
}
function __Z12op_d1b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $32 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34919
 $6 = HEAP32[162769] | 0; //@line 34920
 $7 = $6 + 2 | 0; //@line 34921
 HEAP32[162769] = $7; //@line 34922
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34924
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 34931
 HEAP32[162769] = $6 + 4; //@line 34933
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 34934
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 34936
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 34939
 $24 = $23 + $5 | 0; //@line 34940
 $$lobit38 = $24 >>> 31; //@line 34943
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 34946
 HEAP32[96444] = ($$lobit38 ^ $5 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 34950
 $32 = $5 >>> 0 > ~$23 >>> 0 & 1; //@line 34953
 HEAP32[96441] = $32; //@line 34954
 HEAP32[96445] = $32; //@line 34955
 HEAP32[96443] = $$lobit38; //@line 34956
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 34960
 return;
}
function __Z12op_9120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $19 = 0, $21 = 0, $3 = 0, $31 = 0, $5 = 0, $6 = 0, $sext37$lobit = 0;
 $3 = $0 & 7; //@line 20134
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20136
 $6 = 651040 + ($3 << 2) | 0; //@line 20137
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 20141
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 20143
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 20147
 HEAP32[$6 >> 2] = $10; //@line 20148
 $19 = ($16 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 20153
 $21 = $16 >>> 7; //@line 20155
 $sext37$lobit = $19 >>> 7 & 1; //@line 20158
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 20162
 HEAP32[96444] = ($sext37$lobit ^ $21 & 1) & ($21 ^ $5 >>> 7); //@line 20166
 $31 = ($5 & 255) >>> 0 > ($16 & 255) >>> 0 & 1; //@line 20170
 HEAP32[96441] = $31; //@line 20171
 HEAP32[96445] = $31; //@line 20172
 HEAP32[96443] = $sext37$lobit; //@line 20173
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 20177
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20180
 return;
}
function __Z12op_31b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $29 = 0, $3 = 0, $31 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 38368
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 38378
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 38384
 $19 = HEAP32[162769] | 0; //@line 38385
 $20 = $19 + 4 | 0; //@line 38386
 HEAP32[162769] = $20; //@line 38387
 $22 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38389
 $29 = (HEAPU8[$20 >> 0] | 0) << 8 | (HEAPU8[$19 + 5 >> 0] | 0); //@line 38396
 HEAP32[162769] = $19 + 6; //@line 38398
 $31 = __Z15get_disp_ea_020jj($22, $29) | 0; //@line 38399
 $32 = $18 << 16 >> 16; //@line 38401
 $34 = ($32 | 0) == 0 & 1; //@line 38403
 HEAP32[96441] = 0; //@line 38404
 HEAP32[96442] = 0; //@line 38404
 HEAP32[96443] = 0; //@line 38404
 HEAP32[96444] = 0; //@line 38404
 HEAP32[96442] = $34; //@line 38405
 HEAP32[96443] = $18 >>> 15 & 1; //@line 38408
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($31, $32); //@line 38414
 return;
}
function __Z12op_11b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $29 = 0, $3 = 0, $31 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 26337
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 26347
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 26353
 $19 = HEAP32[162769] | 0; //@line 26354
 $20 = $19 + 4 | 0; //@line 26355
 HEAP32[162769] = $20; //@line 26356
 $22 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26358
 $29 = (HEAPU8[$20 >> 0] | 0) << 8 | (HEAPU8[$19 + 5 >> 0] | 0); //@line 26365
 HEAP32[162769] = $19 + 6; //@line 26367
 $31 = __Z15get_disp_ea_020jj($22, $29) | 0; //@line 26368
 $32 = $18 << 24 >> 24; //@line 26370
 $34 = ($32 | 0) == 0 & 1; //@line 26372
 HEAP32[96441] = 0; //@line 26373
 HEAP32[96442] = 0; //@line 26373
 HEAP32[96443] = 0; //@line 26373
 HEAP32[96444] = 0; //@line 26373
 HEAP32[96442] = $34; //@line 26374
 HEAP32[96443] = $18 >>> 7 & 1; //@line 26377
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($31, $32); //@line 26383
 return;
}
function __Z12op_3130_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 37036
 $5 = $4 + 2 | 0; //@line 37037
 HEAP32[162769] = $5; //@line 37038
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 37040
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 37047
 HEAP32[162769] = $4 + 4; //@line 37049
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 37050
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 37056
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37057
 $25 = (HEAP32[$23 >> 2] | 0) + -2 | 0; //@line 37059
 HEAP32[$23 >> 2] = $25; //@line 37060
 $26 = $22 << 16 >> 16; //@line 37062
 $28 = ($26 | 0) == 0 & 1; //@line 37064
 HEAP32[96441] = 0; //@line 37065
 HEAP32[96442] = 0; //@line 37065
 HEAP32[96443] = 0; //@line 37065
 HEAP32[96444] = 0; //@line 37065
 HEAP32[96442] = $28; //@line 37066
 HEAP32[96443] = $22 >>> 15 & 1; //@line 37069
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 37075
 return;
}
function __Z12op_9170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $5 = 0, $8 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24200
 $8 = HEAP32[162769] | 0; //@line 24203
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 24212
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 24214
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 24218
 $26 = ($23 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 24223
 $28 = $23 >>> 15; //@line 24225
 $sext38$lobit = $26 >>> 15 & 1; //@line 24228
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 24232
 HEAP32[96444] = ($sext38$lobit ^ $28 & 1) & ($28 ^ $5 >>> 15); //@line 24236
 $38 = ($5 & 65535) >>> 0 > ($23 & 65535) >>> 0 & 1; //@line 24240
 HEAP32[96441] = $38; //@line 24241
 HEAP32[96445] = $38; //@line 24242
 HEAP32[96443] = $sext38$lobit; //@line 24243
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $26); //@line 24247
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24250
 return;
}
function __Z12op_40b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $12 = 0, $14 = 0, $16 = 0, $19 = 0, $2 = 0, $22 = 0, $26 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 41055
 $3 = $2 + 2 | 0; //@line 41056
 HEAP32[162769] = $3; //@line 41057
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41059
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 41066
 HEAP32[162769] = $2 + 4; //@line 41068
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 41069
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41071
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 41074
 $22 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $19 | 0; //@line 41078
 $$lobit = $19 >>> 31; //@line 41079
 $$lobit32 = $22 >>> 31; //@line 41080
 HEAP32[96444] = $$lobit32 & $$lobit; //@line 41082
 $26 = $$lobit32 & ~$$lobit ^ $$lobit; //@line 41085
 HEAP32[96441] = $26; //@line 41086
 HEAP32[96445] = $26; //@line 41087
 HEAP32[96442] = ($22 | 0) == 0 & HEAP32[96442]; //@line 41092
 HEAP32[96443] = $$lobit32; //@line 41093
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $22); //@line 41097
 return;
}
function __Z12op_10fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 30907
 $4 = HEAP32[162769] | 0; //@line 30909
 $$cast = $4; //@line 30914
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 30923
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 30929
 $24 = 651040 + ($2 << 2) | 0; //@line 30930
 $25 = HEAP32[$24 >> 2] | 0; //@line 30931
 HEAP32[$24 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $25; //@line 30935
 $29 = $23 << 24 >> 24; //@line 30937
 $31 = ($29 | 0) == 0 & 1; //@line 30939
 HEAP32[96441] = 0; //@line 30940
 HEAP32[96442] = 0; //@line 30940
 HEAP32[96443] = 0; //@line 30940
 HEAP32[96444] = 0; //@line 30940
 HEAP32[96442] = $31; //@line 30941
 HEAP32[96443] = $23 >>> 7 & 1; //@line 30944
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $29); //@line 30950
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30953
 return;
}
function __Z12op_5170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $4 = 0, $8 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 11588
 $8 = HEAP32[162769] | 0; //@line 11592
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 11601
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 11603
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 11607
 $26 = ($23 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 11612
 $28 = $23 >>> 15; //@line 11614
 $sext38$lobit = $26 >>> 15 & 1; //@line 11617
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 11621
 HEAP32[96444] = ($sext38$lobit ^ $28 & 1) & ($28 ^ $4 >>> 15); //@line 11625
 $38 = ($4 & 65535) >>> 0 > ($23 & 65535) >>> 0 & 1; //@line 11629
 HEAP32[96441] = $38; //@line 11630
 HEAP32[96445] = $38; //@line 11631
 HEAP32[96443] = $sext38$lobit; //@line 11632
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $26); //@line 11636
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11639
 return;
}
function __Z11op_cb0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $37 = 0, $38 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 20119
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 20122
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 20137
 $21 = $2 + 6 | 0; //@line 20138
 HEAP32[162769] = $21; //@line 20139
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20141
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 20148
 HEAP32[162769] = $2 + 8; //@line 20150
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 20151
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($32 >>> 16 << 2) >> 2] >> 2] & 127]($32) | 0; //@line 20156
 $38 = $37 - $20 | 0; //@line 20157
 $$lobit31 = $37 >>> 31; //@line 20159
 $$lobit32 = $38 >>> 31; //@line 20160
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 20163
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 20168
 HEAP32[96441] = $37 >>> 0 < $20 >>> 0 & 1; //@line 20171
 HEAP32[96443] = $$lobit32; //@line 20172
 return;
}
function __Z11op_c7b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $14 = 0, $21 = 0, $23 = 0, $29 = 0, $30 = 0, $4 = 0, $9 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19779
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 19782
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 19787
 $10 = $1 + 4 | 0; //@line 19788
 HEAP32[162769] = $10; //@line 19789
 $14 = (HEAP32[162768] | 0) + $10 - (HEAP32[162770] | 0) | 0; //@line 19794
 $21 = (HEAPU8[$10 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 19801
 HEAP32[162769] = $1 + 6; //@line 19803
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 19804
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($23) | 0; //@line 19810
 $30 = $29 - $9 | 0; //@line 19811
 $sext$lobit = $29 >>> 15 & 1; //@line 19814
 $sext33$lobit = $30 >>> 15 & 1; //@line 19816
 HEAP32[96442] = ($30 & 65535 | 0) == 0 & 1; //@line 19820
 HEAP32[96444] = ($4 >>> 7 | 0) != ($sext$lobit | 0) & ($sext33$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19825
 HEAP32[96441] = $9 >>> 0 > ($29 & 65535) >>> 0 & 1; //@line 19829
 HEAP32[96443] = $sext33$lobit; //@line 19830
 return;
}
function __Z12op_21b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $37 = 0, $39 = 0, $41 = 0;
 $3 = HEAP32[162769] | 0; //@line 33370
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 33379
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 33393
 $27 = HEAP32[162769] | 0; //@line 33394
 $28 = $27 + 6 | 0; //@line 33395
 HEAP32[162769] = $28; //@line 33396
 $30 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33398
 $37 = (HEAPU8[$28 >> 0] | 0) << 8 | (HEAPU8[$27 + 7 >> 0] | 0); //@line 33405
 HEAP32[162769] = $27 + 8; //@line 33407
 $39 = __Z15get_disp_ea_020jj($30, $37) | 0; //@line 33408
 $41 = ($26 | 0) == 0 & 1; //@line 33410
 HEAP32[96441] = 0; //@line 33411
 HEAP32[96442] = 0; //@line 33411
 HEAP32[96443] = 0; //@line 33411
 HEAP32[96444] = 0; //@line 33411
 HEAP32[96442] = $41; //@line 33412
 HEAP32[96443] = $26 >>> 31; //@line 33414
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($39, $26); //@line 33420
 return;
}
function __ZN8tinyxml28MemPoolTILi52EED0Ev($0) {
 $0 = $0 | 0;
 var $$04$i = 0, $$lcssa$i = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2336; //@line 40477
 $1 = $0 + 52 | 0; //@line 40478
 $2 = HEAP32[$1 >> 2] | 0; //@line 40479
 $4 = $0 + 4 | 0; //@line 40481
 $5 = HEAP32[$4 >> 2] | 0; //@line 40482
 if (($2 | 0) > 0) {
  $$04$i = 0; //@line 40484
  $10 = $5; //@line 40484
  $16 = $2; //@line 40484
  while (1) {
   $11 = HEAP32[$10 + ($$04$i << 2) >> 2] | 0; //@line 40487
   if (!$11) {
    $15 = $16; //@line 40490
    $17 = $10; //@line 40490
   } else {
    __ZdlPv($11); //@line 40492
    $15 = HEAP32[$1 >> 2] | 0; //@line 40495
    $17 = HEAP32[$4 >> 2] | 0; //@line 40495
   }
   $$04$i = $$04$i + 1 | 0; //@line 40497
   if (($$04$i | 0) >= ($15 | 0)) {
    $$lcssa$i = $17; //@line 40502
    break;
   } else {
    $10 = $17; //@line 40500
    $16 = $15; //@line 40500
   }
  }
 } else {
  $$lcssa$i = $5; //@line 40507
 }
 if (($$lcssa$i | 0) == ($0 + 8 | 0) | ($$lcssa$i | 0) == 0) {
  __ZdlPv($0); //@line 40514
  return;
 }
 __ZdaPv($$lcssa$i); //@line 40517
 __ZdlPv($0); //@line 40518
 return;
}
function __ZN8tinyxml28MemPoolTILi48EED0Ev($0) {
 $0 = $0 | 0;
 var $$04$i = 0, $$lcssa$i = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2272; //@line 40739
 $1 = $0 + 52 | 0; //@line 40740
 $2 = HEAP32[$1 >> 2] | 0; //@line 40741
 $4 = $0 + 4 | 0; //@line 40743
 $5 = HEAP32[$4 >> 2] | 0; //@line 40744
 if (($2 | 0) > 0) {
  $$04$i = 0; //@line 40746
  $10 = $5; //@line 40746
  $16 = $2; //@line 40746
  while (1) {
   $11 = HEAP32[$10 + ($$04$i << 2) >> 2] | 0; //@line 40749
   if (!$11) {
    $15 = $16; //@line 40752
    $17 = $10; //@line 40752
   } else {
    __ZdlPv($11); //@line 40754
    $15 = HEAP32[$1 >> 2] | 0; //@line 40757
    $17 = HEAP32[$4 >> 2] | 0; //@line 40757
   }
   $$04$i = $$04$i + 1 | 0; //@line 40759
   if (($$04$i | 0) >= ($15 | 0)) {
    $$lcssa$i = $17; //@line 40764
    break;
   } else {
    $10 = $17; //@line 40762
    $16 = $15; //@line 40762
   }
  }
 } else {
  $$lcssa$i = $5; //@line 40769
 }
 if (($$lcssa$i | 0) == ($0 + 8 | 0) | ($$lcssa$i | 0) == 0) {
  __ZdlPv($0); //@line 40776
  return;
 }
 __ZdaPv($$lcssa$i); //@line 40779
 __ZdlPv($0); //@line 40780
 return;
}
function __ZN8tinyxml28MemPoolTILi44EED0Ev($0) {
 $0 = $0 | 0;
 var $$04$i = 0, $$lcssa$i = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2240; //@line 40870
 $1 = $0 + 52 | 0; //@line 40871
 $2 = HEAP32[$1 >> 2] | 0; //@line 40872
 $4 = $0 + 4 | 0; //@line 40874
 $5 = HEAP32[$4 >> 2] | 0; //@line 40875
 if (($2 | 0) > 0) {
  $$04$i = 0; //@line 40877
  $10 = $5; //@line 40877
  $16 = $2; //@line 40877
  while (1) {
   $11 = HEAP32[$10 + ($$04$i << 2) >> 2] | 0; //@line 40880
   if (!$11) {
    $15 = $16; //@line 40883
    $17 = $10; //@line 40883
   } else {
    __ZdlPv($11); //@line 40885
    $15 = HEAP32[$1 >> 2] | 0; //@line 40888
    $17 = HEAP32[$4 >> 2] | 0; //@line 40888
   }
   $$04$i = $$04$i + 1 | 0; //@line 40890
   if (($$04$i | 0) >= ($15 | 0)) {
    $$lcssa$i = $17; //@line 40895
    break;
   } else {
    $10 = $17; //@line 40893
    $16 = $15; //@line 40893
   }
  }
 } else {
  $$lcssa$i = $5; //@line 40900
 }
 if (($$lcssa$i | 0) == ($0 + 8 | 0) | ($$lcssa$i | 0) == 0) {
  __ZdlPv($0); //@line 40907
  return;
 }
 __ZdaPv($$lcssa$i); //@line 40910
 __ZdlPv($0); //@line 40911
 return;
}
function __ZN8tinyxml28MemPoolTILi36EED0Ev($0) {
 $0 = $0 | 0;
 var $$04$i = 0, $$lcssa$i = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2304; //@line 40608
 $1 = $0 + 52 | 0; //@line 40609
 $2 = HEAP32[$1 >> 2] | 0; //@line 40610
 $4 = $0 + 4 | 0; //@line 40612
 $5 = HEAP32[$4 >> 2] | 0; //@line 40613
 if (($2 | 0) > 0) {
  $$04$i = 0; //@line 40615
  $10 = $5; //@line 40615
  $16 = $2; //@line 40615
  while (1) {
   $11 = HEAP32[$10 + ($$04$i << 2) >> 2] | 0; //@line 40618
   if (!$11) {
    $15 = $16; //@line 40621
    $17 = $10; //@line 40621
   } else {
    __ZdlPv($11); //@line 40623
    $15 = HEAP32[$1 >> 2] | 0; //@line 40626
    $17 = HEAP32[$4 >> 2] | 0; //@line 40626
   }
   $$04$i = $$04$i + 1 | 0; //@line 40628
   if (($$04$i | 0) >= ($15 | 0)) {
    $$lcssa$i = $17; //@line 40633
    break;
   } else {
    $10 = $17; //@line 40631
    $16 = $15; //@line 40631
   }
  }
 } else {
  $$lcssa$i = $5; //@line 40638
 }
 if (($$lcssa$i | 0) == ($0 + 8 | 0) | ($$lcssa$i | 0) == 0) {
  __ZdlPv($0); //@line 40645
  return;
 }
 __ZdaPv($$lcssa$i); //@line 40648
 __ZdlPv($0); //@line 40649
 return;
}
function __Z12op_9168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $5 = 0, $8 = 0, $sext39$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20734
 $8 = HEAP32[162769] | 0; //@line 20737
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 20748
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 20750
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 20754
 $27 = ($24 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 20759
 $29 = $24 >>> 15; //@line 20761
 $sext39$lobit = $27 >>> 15 & 1; //@line 20764
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 20768
 HEAP32[96444] = ($sext39$lobit ^ $29 & 1) & ($29 ^ $5 >>> 15); //@line 20772
 $39 = ($5 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 20776
 HEAP32[96441] = $39; //@line 20777
 HEAP32[96445] = $39; //@line 20778
 HEAP32[96443] = $sext39$lobit; //@line 20779
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 20783
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 20786
 return;
}
function __Z19FindFreeDriveNumberi($0) {
 $0 = $0 | 0;
 var $$01012$i = 0, $$04 = 0, $$05 = 0, $19 = 0, $24 = 0, $3 = 0, $5 = 0, label = 0;
 $3 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](778) | 0; //@line 12780
 if (!$3) {
  $$04 = $0; //@line 12783
  return $$04 | 0; //@line 12784
 } else {
  $$05 = $0; //@line 12786
  $24 = $3; //@line 12786
 }
 L3 : while (1) {
  $$01012$i = $24; //@line 12789
  while (1) {
   $5 = $$01012$i + 6 | 0; //@line 12791
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0) == ($$05 | 0)) {
    break;
   }
   $$01012$i = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($$01012$i >>> 16 << 2) >> 2] >> 2] & 127]($$01012$i) | 0; //@line 12806
   if (!$$01012$i) {
    $$04 = $$05; //@line 12809
    label = 6; //@line 12810
    break L3;
   }
  }
  $19 = $$05 + 1 | 0; //@line 12816
  $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[30902] >> 2] & 127](778) | 0; //@line 12819
  if (!$24) {
   $$04 = $19; //@line 12822
   label = 6; //@line 12823
   break;
  } else {
   $$05 = $19; //@line 12826
  }
 }
 if ((label | 0) == 6) {
  return $$04 | 0; //@line 12830
 }
 return 0; //@line 12832
}
function __Z12op_9058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $18 = 0, $20 = 0, $30 = 0, $4 = 0, $5 = 0, $sext40$lobit = 0, $sext40$mask = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 18423
 $5 = HEAP32[$4 >> 2] | 0; //@line 18424
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 18430
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 18433
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18434
 $15 = HEAP32[$14 >> 2] | 0; //@line 18435
 $18 = ($15 << 16 >> 16) - ($11 << 16 >> 16) | 0; //@line 18440
 $20 = $15 >>> 15; //@line 18442
 $sext40$lobit = $18 >>> 15 & 1; //@line 18445
 $sext40$mask = $18 & 65535; //@line 18446
 HEAP32[96442] = ($sext40$mask | 0) == 0 & 1; //@line 18449
 HEAP32[96444] = ($sext40$lobit ^ $20 & 1) & ($20 ^ $11 >>> 15); //@line 18453
 $30 = ($11 & 65535) >>> 0 > ($15 & 65535) >>> 0 & 1; //@line 18457
 HEAP32[96441] = $30; //@line 18458
 HEAP32[96445] = $30; //@line 18459
 HEAP32[96443] = $sext40$lobit; //@line 18460
 HEAP32[$14 >> 2] = $15 & -65536 | $sext40$mask; //@line 18463
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18466
 return;
}
function __Z12op_31bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 45326
 $$cast = $4; //@line 45331
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45340
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 45346
 $26 = HEAP32[162769] | 0; //@line 45349
 $35 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) | 0; //@line 45358
 $36 = $23 << 16 >> 16; //@line 45360
 $38 = ($36 | 0) == 0 & 1; //@line 45362
 HEAP32[96441] = 0; //@line 45363
 HEAP32[96442] = 0; //@line 45363
 HEAP32[96443] = 0; //@line 45363
 HEAP32[96444] = 0; //@line 45363
 HEAP32[96442] = $38; //@line 45364
 HEAP32[96443] = $23 >>> 15 & 1; //@line 45367
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 45373
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45376
 return;
}
function __Z12op_30f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 36488
 $5 = $4 + 2 | 0; //@line 36489
 HEAP32[162769] = $5; //@line 36490
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 36492
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 36499
 HEAP32[162769] = $4 + 4; //@line 36501
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 36502
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 36508
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36509
 $24 = HEAP32[$23 >> 2] | 0; //@line 36510
 HEAP32[$23 >> 2] = $24 + 2; //@line 36512
 $26 = $22 << 16 >> 16; //@line 36514
 $28 = ($26 | 0) == 0 & 1; //@line 36516
 HEAP32[96441] = 0; //@line 36517
 HEAP32[96442] = 0; //@line 36517
 HEAP32[96443] = 0; //@line 36517
 HEAP32[96444] = 0; //@line 36517
 HEAP32[96442] = $28; //@line 36518
 HEAP32[96443] = $22 >>> 15 & 1; //@line 36521
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $26); //@line 36527
 return;
}
function __Z12op_21a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $32 = 0, $34 = 0, $36 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 33207
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 33218
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 33223
 $22 = HEAP32[162769] | 0; //@line 33224
 $23 = $22 + 4 | 0; //@line 33225
 HEAP32[162769] = $23; //@line 33226
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33228
 $32 = (HEAPU8[$23 >> 0] | 0) << 8 | (HEAPU8[$22 + 5 >> 0] | 0); //@line 33235
 HEAP32[162769] = $22 + 6; //@line 33237
 $34 = __Z15get_disp_ea_020jj($25, $32) | 0; //@line 33238
 $36 = ($21 | 0) == 0 & 1; //@line 33240
 HEAP32[96441] = 0; //@line 33241
 HEAP32[96442] = 0; //@line 33241
 HEAP32[96443] = 0; //@line 33241
 HEAP32[96444] = 0; //@line 33241
 HEAP32[96442] = $36; //@line 33242
 HEAP32[96443] = $21 >>> 31; //@line 33244
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $21); //@line 33250
 return;
}
function __Z12op_113a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $29 = 0, $30 = 0, $32 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 25241
 $4 = HEAP32[162769] | 0; //@line 25243
 $$cast = $4; //@line 25245
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 25259
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 25265
 $25 = 651040 + ($2 << 2) | 0; //@line 25266
 $29 = (HEAP32[$25 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 25270
 HEAP32[$25 >> 2] = $29; //@line 25271
 $30 = $24 << 24 >> 24; //@line 25273
 $32 = ($30 | 0) == 0 & 1; //@line 25275
 HEAP32[96441] = 0; //@line 25276
 HEAP32[96442] = 0; //@line 25276
 HEAP32[96443] = 0; //@line 25276
 HEAP32[96444] = 0; //@line 25276
 HEAP32[96442] = $32; //@line 25277
 HEAP32[96443] = $24 >>> 7 & 1; //@line 25280
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($29, $30); //@line 25286
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25289
 return;
}
function __Z11op_6a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit36 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $37 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13340
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13343
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13358
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 13359
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 13361
 $25 = 123608 + ($23 >>> 16 << 2) | 0; //@line 13363
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 13366
 HEAP32[$21 >> 2] = $23; //@line 13367
 $29 = $28 + $20 | 0; //@line 13368
 $$lobit36 = $29 >>> 31; //@line 13371
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 13374
 HEAP32[96444] = ($$lobit36 ^ $5 >>> 7) & ($$lobit36 ^ $28 >>> 31); //@line 13378
 $37 = $20 >>> 0 > ~$28 >>> 0 & 1; //@line 13381
 HEAP32[96441] = $37; //@line 13382
 HEAP32[96445] = $37; //@line 13383
 HEAP32[96443] = $$lobit36; //@line 13384
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 13388
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13391
 return;
}
function __Z12op_e060_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $18 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37937
 $7 = HEAP32[$6 >> 2] | 0; //@line 37938
 $8 = $7 & 65535; //@line 37939
 $10 = $7 >>> 15 & 1; //@line 37941
 $11 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37942
 $12 = $11 >>> 0 > 15; //@line 37943
 HEAP32[96441] = 0; //@line 37944
 HEAP32[96442] = 0; //@line 37944
 HEAP32[96443] = 0; //@line 37944
 HEAP32[96444] = 0; //@line 37944
 if ($12) {
  HEAP32[96441] = $10; //@line 37948
  HEAP32[96445] = $10; //@line 37949
  $$0 = 0 - $10 & 65535; //@line 37950
 } else {
  if (!$11) {
   $$0 = $8; //@line 37954
  } else {
   $17 = $8 >>> ($11 + -1 | 0); //@line 37957
   $18 = $17 & 1; //@line 37958
   HEAP32[96441] = $18; //@line 37959
   HEAP32[96445] = $18; //@line 37960
   $$0 = ($17 >>> 1 | 65535 << 16 - $11 & 0 - $10) & 65535; //@line 37968
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 37973
 HEAP32[96443] = $$0 >>> 15; //@line 37975
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 37978
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37981
 return;
}
function __Z12op_21fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $20 = 0, $21 = 0, $29 = 0, $31 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 34074
 $2 = $1 + 2 | 0; //@line 34075
 HEAP32[162769] = $2; //@line 34076
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 34081
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 34088
 HEAP32[162769] = $1 + 4; //@line 34090
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 34091
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 34096
 $21 = HEAP32[162769] | 0; //@line 34097
 $29 = ((HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$21 + 1 >> 0] | 0)) << 16 >> 16; //@line 34106
 $31 = ($20 | 0) == 0 & 1; //@line 34108
 HEAP32[96441] = 0; //@line 34109
 HEAP32[96442] = 0; //@line 34109
 HEAP32[96443] = 0; //@line 34109
 HEAP32[96444] = 0; //@line 34109
 HEAP32[96442] = $31; //@line 34110
 HEAP32[96443] = $20 >>> 31; //@line 34112
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($29, $20); //@line 34118
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34121
 return;
}
function __Z12op_11bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 31702
 $$cast = $4; //@line 31707
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 31716
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 31722
 $26 = HEAP32[162769] | 0; //@line 31725
 $35 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) | 0; //@line 31734
 $36 = $23 << 24 >> 24; //@line 31736
 $38 = ($36 | 0) == 0 & 1; //@line 31738
 HEAP32[96441] = 0; //@line 31739
 HEAP32[96442] = 0; //@line 31739
 HEAP32[96443] = 0; //@line 31739
 HEAP32[96444] = 0; //@line 31739
 HEAP32[96442] = $38; //@line 31740
 HEAP32[96443] = $23 >>> 7 & 1; //@line 31743
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 31749
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31752
 return;
}
function __Z11op_6b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $2 = 0, $20 = 0, $31 = 0, $33 = 0, $36 = 0, $37 = 0, $45 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 17225
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 17228
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 17243
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 17254
 $33 = 123608 + ($31 >>> 16 << 2) | 0; //@line 17256
 $36 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$33 >> 2] >> 2] & 127]($31) | 0; //@line 17259
 $37 = $36 + $20 | 0; //@line 17260
 $$lobit34 = $37 >>> 31; //@line 17263
 HEAP32[96442] = ($37 | 0) == 0 & 1; //@line 17266
 HEAP32[96444] = ($$lobit34 ^ $5 >>> 7) & ($$lobit34 ^ $36 >>> 31); //@line 17270
 $45 = $20 >>> 0 > ~$36 >>> 0 & 1; //@line 17273
 HEAP32[96441] = $45; //@line 17274
 HEAP32[96445] = $45; //@line 17275
 HEAP32[96443] = $$lobit34; //@line 17276
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$33 >> 2] | 0) + 12 >> 2] & 31]($31, $37); //@line 17280
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 17283
 return;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
 __stackBase__ = STACKTOP; //@line 4377
 STACKTOP = STACKTOP + 16 | 0; //@line 4378
 $rem = __stackBase__ | 0; //@line 4379
 $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 4380
 $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 4381
 $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 4382
 $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 4383
 $4$0 = _i64Subtract($1$0 ^ $a$0 | 0, $1$1 ^ $a$1 | 0, $1$0 | 0, $1$1 | 0) | 0; //@line 4384
 $4$1 = tempRet0; //@line 4385
 ___udivmoddi4($4$0, $4$1, _i64Subtract($2$0 ^ $b$0 | 0, $2$1 ^ $b$1 | 0, $2$0 | 0, $2$1 | 0) | 0, tempRet0, $rem) | 0; //@line 4387
 $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0 | 0, HEAP32[$rem + 4 >> 2] ^ $1$1 | 0, $1$0 | 0, $1$1 | 0) | 0; //@line 4388
 $10$1 = tempRet0; //@line 4389
 STACKTOP = __stackBase__; //@line 4390
 return (tempRet0 = $10$1, $10$0) | 0; //@line 4391
}
function __Z12op_d158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $21 = 0, $31 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext39$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34255
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 34256
 $7 = HEAP32[$6 >> 2] | 0; //@line 34257
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 34259
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 34263
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 34266
 $16 = $13 << 16 >> 16; //@line 34268
 $18 = $16 + ($5 << 16 >> 16) | 0; //@line 34271
 $21 = $18 >>> 15; //@line 34275
 $sext39$lobit = $21 & 1; //@line 34276
 HEAP32[96442] = ($18 & 65535 | 0) == 0 & 1; //@line 34280
 HEAP32[96444] = ($sext39$lobit ^ $13 >>> 15 & 1) & ($21 ^ $5 >>> 15); //@line 34284
 $31 = ($16 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 34289
 HEAP32[96441] = $31; //@line 34290
 HEAP32[96445] = $31; //@line 34291
 HEAP32[96443] = $sext39$lobit; //@line 34292
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $18); //@line 34296
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34299
 return;
}
function __Z12op_9130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $5 = 0, $8 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24137
 $8 = HEAP32[162769] | 0; //@line 24140
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 24149
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 24151
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 24155
 $26 = ($23 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 24160
 $28 = $23 >>> 7; //@line 24162
 $sext34$lobit = $26 >>> 7 & 1; //@line 24165
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 24169
 HEAP32[96444] = ($sext34$lobit ^ $28 & 1) & ($28 ^ $5 >>> 7); //@line 24173
 $38 = ($5 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 24177
 HEAP32[96441] = $38; //@line 24178
 HEAP32[96445] = $38; //@line 24179
 HEAP32[96443] = $sext34$lobit; //@line 24180
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 24184
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24187
 return;
}
function __ZN17driver_fullscreenD2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $2 = 0, $4 = 0, $6 = 0, $8 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 44029
 STACKTOP = STACKTOP + 16 | 0; //@line 44030
 $vararg_buffer = sp; //@line 44031
 HEAP32[$0 >> 2] = 4336; //@line 44032
 $1 = $0 + 16 | 0; //@line 44033
 $2 = HEAP32[$1 >> 2] | 0; //@line 44034
 if ($2 | 0) {
  _SDL_FreeSurface($2 | 0); //@line 44037
 }
 _SDL_ShowCursor(1) | 0; //@line 44039
 HEAP32[$0 >> 2] = 4248; //@line 44040
 $4 = HEAP32[$1 >> 2] | 0; //@line 44041
 if ($4 | 0) {
  _SDL_FreeSurface($4 | 0); //@line 44044
 }
 $6 = HEAP32[30852] | 0; //@line 44046
 if ($6 | 0) {
  $8 = HEAP32[30853] | 0; //@line 44049
  HEAP32[$vararg_buffer >> 2] = $6; //@line 44050
  HEAP32[$vararg_buffer + 4 >> 2] = $8; //@line 44052
  _printf(102326, $vararg_buffer) | 0; //@line 44053
  __Z10vm_releasePvj(HEAP32[30852] | 0, HEAP32[30853] | 0) | 0; //@line 44056
  HEAP32[30852] = 0; //@line 44057
 }
 $11 = HEAP32[30854] | 0; //@line 44059
 if (!$11) {
  STACKTOP = sp; //@line 44062
  return;
 }
 _free($11); //@line 44064
 HEAP32[30854] = 0; //@line 44065
 STACKTOP = sp; //@line 44066
 return;
}
function __Z12op_5130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $26 = 0, $28 = 0, $38 = 0, $4 = 0, $8 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 11525
 $8 = HEAP32[162769] | 0; //@line 11529
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 11538
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 11540
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 11544
 $26 = ($23 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 11549
 $28 = $23 >>> 7; //@line 11551
 $sext36$lobit = $26 >>> 7 & 1; //@line 11554
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 11558
 HEAP32[96444] = ($sext36$lobit ^ $28 & 1) & ($28 ^ $4 >>> 7); //@line 11562
 $38 = ($4 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 11566
 HEAP32[96441] = $38; //@line 11567
 HEAP32[96445] = $38; //@line 11568
 HEAP32[96443] = $sext36$lobit; //@line 11569
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 11573
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11576
 return;
}
function __Z12op_317b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $26 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44723
 $$cast = $4; //@line 44728
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44737
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 44743
 $26 = HEAP32[162769] | 0; //@line 44746
 $36 = (((HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 44757
 $37 = $23 << 16 >> 16; //@line 44759
 $39 = ($37 | 0) == 0 & 1; //@line 44761
 HEAP32[96441] = 0; //@line 44762
 HEAP32[96442] = 0; //@line 44762
 HEAP32[96443] = 0; //@line 44762
 HEAP32[96444] = 0; //@line 44762
 HEAP32[96442] = $39; //@line 44763
 HEAP32[96443] = $23 >>> 15 & 1; //@line 44766
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($36, $37); //@line 44772
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 44775
 return;
}
function __Z11op_c70_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $28 = 0, $29 = 0, $5 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19539
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19542
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19547
 $11 = $2 + 4 | 0; //@line 19548
 HEAP32[162769] = $11; //@line 19549
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19551
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 19558
 HEAP32[162769] = $2 + 6; //@line 19560
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 19561
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 19567
 $29 = $28 - $10 | 0; //@line 19568
 $sext$lobit = $28 >>> 15 & 1; //@line 19571
 $sext32$lobit = $29 >>> 15 & 1; //@line 19573
 HEAP32[96442] = ($29 & 65535 | 0) == 0 & 1; //@line 19577
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19582
 HEAP32[96441] = $10 >>> 0 > ($28 & 65535) >>> 0 & 1; //@line 19586
 HEAP32[96443] = $sext32$lobit; //@line 19587
 return;
}
function __Z12op_117b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $26 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 31135
 $$cast = $4; //@line 31140
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 31149
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 31155
 $26 = HEAP32[162769] | 0; //@line 31158
 $36 = (((HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 31169
 $37 = $23 << 24 >> 24; //@line 31171
 $39 = ($37 | 0) == 0 & 1; //@line 31173
 HEAP32[96441] = 0; //@line 31174
 HEAP32[96442] = 0; //@line 31174
 HEAP32[96443] = 0; //@line 31174
 HEAP32[96444] = 0; //@line 31174
 HEAP32[96442] = $39; //@line 31175
 HEAP32[96443] = $23 >>> 7 & 1; //@line 31178
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($36, $37); //@line 31184
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31187
 return;
}
function __Z12op_10fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $32 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 24706
 $4 = HEAP32[162769] | 0; //@line 24708
 $$cast = $4; //@line 24710
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 24724
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 24730
 $25 = 651040 + ($2 << 2) | 0; //@line 24731
 $26 = HEAP32[$25 >> 2] | 0; //@line 24732
 HEAP32[$25 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $26; //@line 24736
 $30 = $24 << 24 >> 24; //@line 24738
 $32 = ($30 | 0) == 0 & 1; //@line 24740
 HEAP32[96441] = 0; //@line 24741
 HEAP32[96442] = 0; //@line 24741
 HEAP32[96443] = 0; //@line 24741
 HEAP32[96444] = 0; //@line 24741
 HEAP32[96442] = $32; //@line 24742
 HEAP32[96443] = $24 >>> 7 & 1; //@line 24745
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $30); //@line 24751
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24754
 return;
}
function __Z11op_6a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $2 = 0, $20 = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $46 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13401
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13404
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13419
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 13432
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 13434
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0; //@line 13437
 $38 = $37 + $20 | 0; //@line 13438
 $$lobit34 = $38 >>> 31; //@line 13441
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 13444
 HEAP32[96444] = ($$lobit34 ^ $5 >>> 7) & ($$lobit34 ^ $37 >>> 31); //@line 13448
 $46 = $20 >>> 0 > ~$37 >>> 0 & 1; //@line 13451
 HEAP32[96441] = $46; //@line 13452
 HEAP32[96445] = $46; //@line 13453
 HEAP32[96443] = $$lobit34; //@line 13454
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 13458
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 13461
 return;
}
function __Z11op_4b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit29 = 0, $$lobit30 = 0, $1 = 0, $19 = 0, $28 = 0, $30 = 0, $33 = 0, $34 = 0, $4 = 0, $41 = 0;
 $1 = HEAP32[162769] | 0; //@line 11554
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 11557
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 11572
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 11582
 $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 11584
 $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0; //@line 11587
 $34 = $33 - $19 | 0; //@line 11588
 $$lobit29 = $33 >>> 31; //@line 11590
 $$lobit30 = $34 >>> 31; //@line 11591
 HEAP32[96442] = ($34 | 0) == 0 & 1; //@line 11594
 HEAP32[96444] = ($$lobit30 ^ $$lobit29) & ($$lobit29 ^ $4 >>> 7); //@line 11598
 $41 = $33 >>> 0 < $19 >>> 0 & 1; //@line 11600
 HEAP32[96441] = $41; //@line 11601
 HEAP32[96445] = $41; //@line 11602
 HEAP32[96443] = $$lobit30; //@line 11603
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, $34); //@line 11607
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 11610
 return;
}
function __Z12op_9128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $5 = 0, $8 = 0, $sext35$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20193
 $8 = HEAP32[162769] | 0; //@line 20196
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 20207
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 20209
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 20213
 $27 = ($24 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 20218
 $29 = $24 >>> 7; //@line 20220
 $sext35$lobit = $27 >>> 7 & 1; //@line 20223
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 20227
 HEAP32[96444] = ($sext35$lobit ^ $29 & 1) & ($29 ^ $5 >>> 7); //@line 20231
 $39 = ($5 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 20235
 HEAP32[96441] = $39; //@line 20236
 HEAP32[96445] = $39; //@line 20237
 HEAP32[96443] = $sext35$lobit; //@line 20238
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 20242
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 20245
 return;
}
function __Z12op_5118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $20 = 0, $22 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5106
 $5 = $0 & 7; //@line 5107
 $6 = 651040 + ($5 << 2) | 0; //@line 5108
 $7 = HEAP32[$6 >> 2] | 0; //@line 5109
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 5111
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 5115
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($5 << 2) >> 2] | 0); //@line 5120
 $20 = ($13 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5125
 $22 = $13 >>> 7; //@line 5127
 $sext38$lobit = $20 >>> 7 & 1; //@line 5130
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 5134
 HEAP32[96444] = ($sext38$lobit ^ $22 & 1) & ($22 ^ $4 >>> 7); //@line 5138
 $32 = ($4 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 5142
 HEAP32[96441] = $32; //@line 5143
 HEAP32[96445] = $32; //@line 5144
 HEAP32[96443] = $sext38$lobit; //@line 5145
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $20); //@line 5149
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5152
 return;
}
function __Z11op_650_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $18 = 0, $19 = 0, $2 = 0, $21 = 0, $24 = 0, $33 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 12716
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12719
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12724
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 12726
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 12728
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 12732
 $19 = $18 << 16 >> 16; //@line 12734
 $21 = $19 + ($10 << 16 >> 16) | 0; //@line 12737
 $24 = $21 >>> 15; //@line 12741
 $sext34$lobit = $24 & 1; //@line 12742
 HEAP32[96442] = ($21 & 65535 | 0) == 0 & 1; //@line 12746
 HEAP32[96444] = ($sext34$lobit ^ $18 >>> 15 & 1) & ($24 ^ $5 >>> 7); //@line 12750
 $33 = ($19 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 12754
 HEAP32[96441] = $33; //@line 12755
 HEAP32[96445] = $33; //@line 12756
 HEAP32[96443] = $sext34$lobit; //@line 12757
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $21); //@line 12761
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12764
 return;
}
function __Z12op_d178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $36 = 0, $4 = 0, $5 = 0, $sext35$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34497
 $5 = HEAP32[162769] | 0; //@line 34498
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 34508
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 34510
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 34514
 $21 = $20 << 16 >> 16; //@line 34516
 $23 = $21 + ($4 << 16 >> 16) | 0; //@line 34519
 $26 = $23 >>> 15; //@line 34523
 $sext35$lobit = $26 & 1; //@line 34524
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 34528
 HEAP32[96444] = ($sext35$lobit ^ $20 >>> 15 & 1) & ($26 ^ $4 >>> 15); //@line 34532
 $36 = ($21 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 34537
 HEAP32[96441] = $36; //@line 34538
 HEAP32[96445] = $36; //@line 34539
 HEAP32[96443] = $sext35$lobit; //@line 34540
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 34544
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 34547
 return;
}
function __Z12op_d160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $17 = 0, $20 = 0, $30 = 0, $5 = 0, $6 = 0, $8 = 0, $sext40$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34312
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 34313
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 34315
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 34317
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 34321
 HEAP32[$6 >> 2] = $8; //@line 34322
 $15 = $14 << 16 >> 16; //@line 34324
 $17 = $15 + ($5 << 16 >> 16) | 0; //@line 34327
 $20 = $17 >>> 15; //@line 34331
 $sext40$lobit = $20 & 1; //@line 34332
 HEAP32[96442] = ($17 & 65535 | 0) == 0 & 1; //@line 34336
 HEAP32[96444] = ($sext40$lobit ^ $14 >>> 15 & 1) & ($20 ^ $5 >>> 15); //@line 34340
 $30 = ($15 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 34345
 HEAP32[96441] = $30; //@line 34346
 HEAP32[96445] = $30; //@line 34347
 HEAP32[96443] = $sext40$lobit; //@line 34348
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $17); //@line 34352
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34355
 return;
}
function __Z12op_5120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $19 = 0, $21 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5164
 $5 = $0 & 7; //@line 5165
 $6 = 651040 + ($5 << 2) | 0; //@line 5166
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($5 << 2) >> 2] | 0) | 0; //@line 5170
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 5172
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 5176
 HEAP32[$6 >> 2] = $10; //@line 5177
 $19 = ($16 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5182
 $21 = $16 >>> 7; //@line 5184
 $sext39$lobit = $19 >>> 7 & 1; //@line 5187
 HEAP32[96442] = ($19 & 255 | 0) == 0 & 1; //@line 5191
 HEAP32[96444] = ($sext39$lobit ^ $21 & 1) & ($21 ^ $4 >>> 7); //@line 5195
 $31 = ($4 & 255) >>> 0 > ($16 & 255) >>> 0 & 1; //@line 5199
 HEAP32[96441] = $31; //@line 5200
 HEAP32[96445] = $31; //@line 5201
 HEAP32[96443] = $sext39$lobit; //@line 5202
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $19); //@line 5206
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5209
 return;
}
function __Z12op_31ba_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $27 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 45262
 $$cast = $4; //@line 45264
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 45278
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 45284
 $27 = HEAP32[162769] | 0; //@line 45287
 $36 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$27 + 4 >> 0] | 0) << 8 | (HEAPU8[$27 + 5 >> 0] | 0)) | 0; //@line 45296
 $37 = $24 << 16 >> 16; //@line 45298
 $39 = ($37 | 0) == 0 & 1; //@line 45300
 HEAP32[96441] = 0; //@line 45301
 HEAP32[96442] = 0; //@line 45301
 HEAP32[96443] = 0; //@line 45301
 HEAP32[96444] = 0; //@line 45301
 HEAP32[96442] = $39; //@line 45302
 HEAP32[96443] = $24 >>> 15 & 1; //@line 45305
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($36, $37); //@line 45311
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45314
 return;
}
function __Z12op_9060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $17 = 0, $19 = 0, $29 = 0, $4 = 0, $6 = 0, $sext41$lobit = 0, $sext41$mask = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 18477
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 18479
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 18485
 HEAP32[$4 >> 2] = $6; //@line 18486
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18487
 $14 = HEAP32[$13 >> 2] | 0; //@line 18488
 $17 = ($14 << 16 >> 16) - ($12 << 16 >> 16) | 0; //@line 18493
 $19 = $14 >>> 15; //@line 18495
 $sext41$lobit = $17 >>> 15 & 1; //@line 18498
 $sext41$mask = $17 & 65535; //@line 18499
 HEAP32[96442] = ($sext41$mask | 0) == 0 & 1; //@line 18502
 HEAP32[96444] = ($sext41$lobit ^ $19 & 1) & ($19 ^ $12 >>> 15); //@line 18506
 $29 = ($12 & 65535) >>> 0 > ($14 & 65535) >>> 0 & 1; //@line 18510
 HEAP32[96441] = $29; //@line 18511
 HEAP32[96445] = $29; //@line 18512
 HEAP32[96443] = $sext41$lobit; //@line 18513
 HEAP32[$13 >> 2] = $14 & -65536 | $sext41$mask; //@line 18516
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18519
 return;
}
function __Z12op_50b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $16 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $32 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4602
 $6 = HEAP32[162769] | 0; //@line 4604
 $7 = $6 + 2 | 0; //@line 4605
 HEAP32[162769] = $7; //@line 4606
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4608
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 4615
 HEAP32[162769] = $6 + 4; //@line 4617
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 4618
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 4620
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 4623
 $24 = $23 + $4 | 0; //@line 4624
 $$lobit38 = $24 >>> 31; //@line 4627
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 4630
 HEAP32[96444] = ($$lobit38 ^ $4 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 4634
 $32 = $4 >>> 0 > ~$23 >>> 0 & 1; //@line 4637
 HEAP32[96441] = $32; //@line 4638
 HEAP32[96445] = $32; //@line 4639
 HEAP32[96443] = $$lobit38; //@line 4640
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 4644
 return;
}
function __Z12op_21f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $19 = 0, $2 = 0, $20 = 0, $28 = 0, $3 = 0, $30 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 33857
 $3 = $2 + 2 | 0; //@line 33858
 HEAP32[162769] = $3; //@line 33859
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33861
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 33868
 HEAP32[162769] = $2 + 4; //@line 33870
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 33871
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 33876
 $20 = HEAP32[162769] | 0; //@line 33877
 $28 = ((HEAPU8[$20 >> 0] | 0) << 8 | (HEAPU8[$20 + 1 >> 0] | 0)) << 16 >> 16; //@line 33886
 $30 = ($19 | 0) == 0 & 1; //@line 33888
 HEAP32[96441] = 0; //@line 33889
 HEAP32[96442] = 0; //@line 33889
 HEAP32[96443] = 0; //@line 33889
 HEAP32[96444] = 0; //@line 33889
 HEAP32[96442] = $30; //@line 33890
 HEAP32[96443] = $19 >>> 31; //@line 33892
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $19); //@line 33898
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33901
 return;
}
function __Z12op_11ba_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $27 = 0, $36 = 0, $37 = 0, $39 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 31638
 $$cast = $4; //@line 31640
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 31654
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 31660
 $27 = HEAP32[162769] | 0; //@line 31663
 $36 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$27 + 4 >> 0] | 0) << 8 | (HEAPU8[$27 + 5 >> 0] | 0)) | 0; //@line 31672
 $37 = $24 << 24 >> 24; //@line 31674
 $39 = ($37 | 0) == 0 & 1; //@line 31676
 HEAP32[96441] = 0; //@line 31677
 HEAP32[96442] = 0; //@line 31677
 HEAP32[96443] = 0; //@line 31677
 HEAP32[96444] = 0; //@line 31677
 HEAP32[96442] = $39; //@line 31678
 HEAP32[96443] = $24 >>> 7 & 1; //@line 31681
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($36, $37); //@line 31687
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31690
 return;
}
function __Z14EtherInterruptv() {
 var $0 = 0, $1 = 0, $13 = 0, $15 = 0, $16 = 0, $2 = 0, $5 = 0, $7 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 47164
 STACKTOP = STACKTOP + 32 | 0; //@line 47165
 $0 = sp + 24 | 0; //@line 47166
 $1 = sp + 8 | 0; //@line 47167
 $2 = sp; //@line 47168
 if (!(HEAP8[659476] | 0)) {
  STACKTOP = sp; //@line 47172
  return;
 }
 __ZN14EthernetPacketC2Ev($0); //@line 47174
 $5 = HEAP32[$0 >> 2] | 0; //@line 47175
 $7 = 123608 + ($5 >>> 16 << 2) | 0; //@line 47177
 HEAP32[$2 >> 2] = 16; //@line 47178
 $8 = HEAP32[1310] | 0; //@line 47179
 $13 = _recvfrom($8, FUNCTION_TABLE_ii[HEAP32[(HEAP32[$7 >> 2] | 0) + 24 >> 2] & 127]($5) | 0, 1514, 0, $1, $2) | 0; //@line 47184
 if (($13 | 0) >= 14) {
  $15 = $13; //@line 47187
  do {
   __Z14ether_udp_readjiP11sockaddr_in($5, $15, $1); //@line 47189
   HEAP32[$2 >> 2] = 16; //@line 47190
   $16 = HEAP32[1310] | 0; //@line 47191
   $15 = _recvfrom($16, FUNCTION_TABLE_ii[HEAP32[(HEAP32[$7 >> 2] | 0) + 24 >> 2] & 127]($5) | 0, 1514, 0, $1, $2) | 0; //@line 47196
  } while (($15 | 0) >= 14);
 }
 __ZN14EthernetPacketD2Ev($0); //@line 47205
 STACKTOP = sp; //@line 47206
 return;
}
function __Z12op_9078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $25 = 0, $3 = 0, $35 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18656
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 18666
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 18672
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18673
 $20 = HEAP32[$19 >> 2] | 0; //@line 18674
 $23 = ($20 << 16 >> 16) - ($18 << 16 >> 16) | 0; //@line 18679
 $25 = $20 >>> 15; //@line 18681
 $sext36$lobit = $23 >>> 15 & 1; //@line 18684
 $sext36$mask = $23 & 65535; //@line 18685
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 18688
 HEAP32[96444] = ($sext36$lobit ^ $25 & 1) & ($25 ^ $18 >>> 15); //@line 18692
 $35 = ($18 & 65535) >>> 0 > ($20 & 65535) >>> 0 & 1; //@line 18696
 HEAP32[96441] = $35; //@line 18697
 HEAP32[96445] = $35; //@line 18698
 HEAP32[96443] = $sext36$lobit; //@line 18699
 HEAP32[$19 >> 2] = $20 & -65536 | $sext36$mask; //@line 18702
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18705
 return;
}
function __ZL15patch_idle_timePhji($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$01$i = 0, $$01$i1 = 0, $11 = 0, $12 = 0, $15 = 0, $3 = 0, $5 = 0, $8 = 0, label = 0;
 if (!(__Z13PrefsFindBoolPKc(105297) | 0)) {
  return;
 }
 $3 = $1 + -4 | 0; //@line 11066
 if (!$3) {
  return;
 } else {
  $$01$i = 0; //@line 11071
 }
 while (1) {
  $5 = $0 + $$01$i | 0; //@line 11074
  if (!(_memcmp($5, 92908, 4) | 0)) {
   break;
  }
  $8 = $$01$i + 1 | 0; //@line 11080
  if ($8 >>> 0 < $3 >>> 0) {
   $$01$i = $8; //@line 11083
  } else {
   label = 11; //@line 11085
   break;
  }
 }
 if ((label | 0) == 11) {
  return;
 }
 if (!$$01$i) {
  return;
 }
 $11 = $5 + -128 | 0; //@line 11096
 $$01$i1 = 0; //@line 11097
 while (1) {
  $12 = $11 + $$01$i1 | 0; //@line 11099
  if (!(_memcmp($12, 92912, 8) | 0)) {
   break;
  }
  $15 = $$01$i1 + 1 | 0; //@line 11105
  if ($15 >>> 0 < 120) {
   $$01$i1 = $15; //@line 11108
  } else {
   label = 11; //@line 11110
   break;
  }
 }
 if ((label | 0) == 11) {
  return;
 }
 if (!$$01$i1) {
  return;
 }
 HEAP16[$12 >> 1] = _htons(28983) | 0; //@line 11123
 HEAP16[$12 + 2 >> 1] = _htons(20081) | 0; //@line 11125
 return;
}
function __Z12op_e020_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $18 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37547
 $7 = HEAP32[$6 >> 2] | 0; //@line 37548
 $8 = $7 & 255; //@line 37549
 $10 = $7 >>> 7 & 1; //@line 37551
 $11 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37552
 $12 = $11 >>> 0 > 7; //@line 37553
 HEAP32[96441] = 0; //@line 37554
 HEAP32[96442] = 0; //@line 37554
 HEAP32[96443] = 0; //@line 37554
 HEAP32[96444] = 0; //@line 37554
 if ($12) {
  HEAP32[96441] = $10; //@line 37558
  HEAP32[96445] = $10; //@line 37559
  $$0 = 0 - $10 & 255; //@line 37560
 } else {
  if (!$11) {
   $$0 = $8; //@line 37564
  } else {
   $17 = $8 >>> ($11 + -1 | 0); //@line 37567
   $18 = $17 & 1; //@line 37568
   HEAP32[96441] = $18; //@line 37569
   HEAP32[96445] = $18; //@line 37570
   $$0 = ($17 >>> 1 | 255 << 8 - $11 & 0 - $10) & 255; //@line 37578
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 37583
 HEAP32[96443] = $$0 >>> 7; //@line 37585
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 37588
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37591
 return;
}
function __Z12op_4078_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $26 = 0, $sext28$lobit = 0, $sext29$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 40720
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 40730
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40732
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 40736
 $20 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($16 << 16 >> 16) | 0; //@line 40742
 $21 = $16 >>> 15; //@line 40743
 $sext28$lobit = $21 & 1; //@line 40744
 $22 = $20 >>> 15; //@line 40745
 $sext29$lobit = $22 & 1; //@line 40746
 HEAP32[96444] = $sext29$lobit & $21; //@line 40748
 $26 = ($sext29$lobit ^ $sext28$lobit) & $22 ^ $sext28$lobit; //@line 40751
 HEAP32[96441] = $26; //@line 40752
 HEAP32[96445] = $26; //@line 40753
 HEAP32[96442] = ($20 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40759
 HEAP32[96443] = $sext29$lobit; //@line 40760
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $20); //@line 40764
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40767
 return;
}
function __Z11op_430_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $22 = 0, $25 = 0, $27 = 0, $36 = 0, $4 = 0, $sext29$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 16902
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 16904
 $16 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16916
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 16918
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 16922
 $25 = ($22 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 16926
 $27 = $22 >>> 7; //@line 16929
 $sext29$lobit = $25 >>> 7 & 1; //@line 16932
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 16936
 HEAP32[96444] = ($sext29$lobit ^ $27 & 1) & ($27 ^ ($4 & 255) >>> 7 & 255); //@line 16940
 $36 = ($4 & 255) >>> 0 > ($22 & 255) >>> 0 & 1; //@line 16943
 HEAP32[96441] = $36; //@line 16944
 HEAP32[96445] = $36; //@line 16945
 HEAP32[96443] = $sext29$lobit; //@line 16946
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 16950
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16953
 return;
}
function __Z12op_317a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $27 = 0, $37 = 0, $38 = 0, $4 = 0, $40 = 0;
 $4 = HEAP32[162769] | 0; //@line 37836
 $$cast = $4; //@line 37838
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 37852
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 37858
 $27 = HEAP32[162769] | 0; //@line 37861
 $37 = (((HEAPU8[$27 + 4 >> 0] | 0) << 8 | (HEAPU8[$27 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37872
 $38 = $24 << 16 >> 16; //@line 37874
 $40 = ($38 | 0) == 0 & 1; //@line 37876
 HEAP32[96441] = 0; //@line 37877
 HEAP32[96442] = 0; //@line 37877
 HEAP32[96443] = 0; //@line 37877
 HEAP32[96444] = 0; //@line 37877
 HEAP32[96442] = $40; //@line 37878
 HEAP32[96443] = $24 >>> 15 & 1; //@line 37881
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($37, $38); //@line 37887
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37890
 return;
}
function __Z12op_5168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $8 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5705
 $8 = HEAP32[162769] | 0; //@line 5709
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 5720
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5722
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 5726
 $27 = ($24 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5731
 $29 = $24 >>> 15; //@line 5733
 $sext39$lobit = $27 >>> 15 & 1; //@line 5736
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 5740
 HEAP32[96444] = ($sext39$lobit ^ $29 & 1) & ($29 ^ $4 >>> 15); //@line 5744
 $39 = ($4 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 5748
 HEAP32[96441] = $39; //@line 5749
 HEAP32[96445] = $39; //@line 5750
 HEAP32[96443] = $sext39$lobit; //@line 5751
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 5755
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5758
 return;
}
function __Z12op_117a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $27 = 0, $37 = 0, $38 = 0, $4 = 0, $40 = 0;
 $4 = HEAP32[162769] | 0; //@line 25848
 $$cast = $4; //@line 25850
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 25864
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 25870
 $27 = HEAP32[162769] | 0; //@line 25873
 $37 = (((HEAPU8[$27 + 4 >> 0] | 0) << 8 | (HEAPU8[$27 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25884
 $38 = $24 << 24 >> 24; //@line 25886
 $40 = ($38 | 0) == 0 & 1; //@line 25888
 HEAP32[96441] = 0; //@line 25889
 HEAP32[96442] = 0; //@line 25889
 HEAP32[96443] = 0; //@line 25889
 HEAP32[96444] = 0; //@line 25889
 HEAP32[96442] = $40; //@line 25890
 HEAP32[96443] = $24 >>> 7 & 1; //@line 25893
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($37 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($37, $38); //@line 25899
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 25902
 return;
}
function __Z11op_a70_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 16055
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 16063
 $11 = $2 + 4 | 0; //@line 16064
 HEAP32[162769] = $11; //@line 16065
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16067
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 16074
 HEAP32[162769] = $2 + 6; //@line 16076
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 16077
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 16079
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0) ^ $10; //@line 16084
 $29 = $sext1617 << 16 >> 16; //@line 16086
 $31 = ($29 | 0) == 0 & 1; //@line 16088
 HEAP32[96441] = 0; //@line 16089
 HEAP32[96442] = 0; //@line 16089
 HEAP32[96443] = 0; //@line 16089
 HEAP32[96444] = 0; //@line 16089
 HEAP32[96442] = $31; //@line 16090
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 16093
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 16097
 return;
}
function __Z12op_4058_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $17 = 0, $2 = 0, $21 = 0, $3 = 0, $5 = 0, $9 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40503
 $3 = HEAP32[$2 >> 2] | 0; //@line 40504
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40506
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40510
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 40513
 $15 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($9 << 16 >> 16) | 0; //@line 40519
 $16 = $9 >>> 15; //@line 40520
 $sext$lobit = $16 & 1; //@line 40521
 $17 = $15 >>> 15; //@line 40522
 $sext33$lobit = $17 & 1; //@line 40523
 HEAP32[96444] = $sext33$lobit & $16; //@line 40525
 $21 = ($sext33$lobit ^ $sext$lobit) & $17 ^ $sext$lobit; //@line 40528
 HEAP32[96441] = $21; //@line 40529
 HEAP32[96445] = $21; //@line 40530
 HEAP32[96442] = ($15 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40536
 HEAP32[96443] = $sext33$lobit; //@line 40537
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $15); //@line 40541
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40544
 return;
}
function __Z12op_4038_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $26 = 0, $sext26$lobit = 0, $sext27$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 40296
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 40306
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40308
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 40312
 $20 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($16 << 24 >> 24) | 0; //@line 40318
 $21 = $16 >>> 7; //@line 40319
 $sext26$lobit = $21 & 1; //@line 40320
 $22 = $20 >>> 7; //@line 40321
 $sext27$lobit = $22 & 1; //@line 40322
 HEAP32[96444] = $sext27$lobit & $21; //@line 40324
 $26 = ($sext27$lobit ^ $sext26$lobit) & $22 ^ $sext26$lobit; //@line 40327
 HEAP32[96441] = $26; //@line 40328
 HEAP32[96445] = $26; //@line 40329
 HEAP32[96442] = ($20 & 255 | 0) == 0 & HEAP32[96442]; //@line 40335
 HEAP32[96443] = $sext27$lobit; //@line 40336
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $20); //@line 40340
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40343
 return;
}
function __Z12op_c07b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0, $sext2021 = 0;
 $3 = HEAP32[162769] | 0; //@line 28750
 $4 = $3 + 2 | 0; //@line 28751
 HEAP32[162769] = $4; //@line 28752
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 28757
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 28764
 HEAP32[162769] = $3 + 4; //@line 28766
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 28767
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 28773
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28774
 $25 = HEAP32[$24 >> 2] | 0; //@line 28775
 $sext2021 = $25 & $23; //@line 28776
 $26 = $sext2021 << 16 >> 16; //@line 28778
 $28 = ($26 | 0) == 0 & 1; //@line 28780
 HEAP32[96441] = 0; //@line 28781
 HEAP32[96442] = 0; //@line 28781
 HEAP32[96443] = 0; //@line 28781
 HEAP32[96444] = 0; //@line 28781
 HEAP32[96442] = $28; //@line 28782
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 28785
 HEAP32[$24 >> 2] = $25 & -65536 | $26 & 65535; //@line 28789
 return;
}
function __Z12op_807b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0, $sext2021 = 0;
 $3 = HEAP32[162769] | 0; //@line 14426
 $4 = $3 + 2 | 0; //@line 14427
 HEAP32[162769] = $4; //@line 14428
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 14433
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 14440
 HEAP32[162769] = $3 + 4; //@line 14442
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 14443
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 14449
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14450
 $25 = HEAP32[$24 >> 2] | 0; //@line 14451
 $sext2021 = $25 | $23; //@line 14452
 $26 = $sext2021 << 16 >> 16; //@line 14454
 $28 = ($26 | 0) == 0 & 1; //@line 14456
 HEAP32[96441] = 0; //@line 14457
 HEAP32[96442] = 0; //@line 14457
 HEAP32[96443] = 0; //@line 14457
 HEAP32[96444] = 0; //@line 14457
 HEAP32[96442] = $28; //@line 14458
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 14461
 HEAP32[$24 >> 2] = $25 & -65536 | $26 & 65535; //@line 14465
 return;
}
function __Z12op_13d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $23 = 0, $3 = 0, $32 = 0, $33 = 0, $35 = 0, $9 = 0;
 $1 = $0 & 7; //@line 27297
 $2 = 651040 + ($1 << 2) | 0; //@line 27298
 $3 = HEAP32[$2 >> 2] | 0; //@line 27299
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 27305
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 27310
 $14 = HEAP32[162769] | 0; //@line 27311
 $23 = (HEAPU8[$14 + 3 >> 0] | 0) << 16 | (HEAPU8[$14 + 2 >> 0] | 0) << 24; //@line 27320
 $32 = $23 | (HEAPU8[$14 + 4 >> 0] | 0) << 8 | (HEAPU8[$14 + 5 >> 0] | 0); //@line 27329
 $33 = $9 << 24 >> 24; //@line 27331
 $35 = ($33 | 0) == 0 & 1; //@line 27333
 HEAP32[96441] = 0; //@line 27334
 HEAP32[96442] = 0; //@line 27334
 HEAP32[96443] = 0; //@line 27334
 HEAP32[96444] = 0; //@line 27334
 HEAP32[96442] = $35; //@line 27335
 HEAP32[96443] = $9 >>> 7 & 1; //@line 27338
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($32, $33); //@line 27344
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27347
 return;
}
function __Z11op_428_0_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $2 = 0, $23 = 0, $26 = 0, $28 = 0, $37 = 0, $4 = 0, $sext30$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10446
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 10448
 $17 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 10462
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 10464
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 10468
 $26 = ($23 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10472
 $28 = $23 >>> 7; //@line 10475
 $sext30$lobit = $26 >>> 7 & 1; //@line 10478
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 10482
 HEAP32[96444] = ($sext30$lobit ^ $28 & 1) & ($28 ^ ($4 & 255) >>> 7 & 255); //@line 10486
 $37 = ($4 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 10489
 HEAP32[96441] = $37; //@line 10490
 HEAP32[96445] = $37; //@line 10491
 HEAP32[96443] = $sext30$lobit; //@line 10492
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $26); //@line 10496
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10499
 return;
}
function __Z12op_d138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $36 = 0, $4 = 0, $5 = 0, $sext31$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33948
 $5 = HEAP32[162769] | 0; //@line 33949
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 33959
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 33961
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 33965
 $21 = $20 << 24 >> 24; //@line 33967
 $23 = $21 + ($4 << 24 >> 24) | 0; //@line 33970
 $26 = $23 >>> 7; //@line 33974
 $sext31$lobit = $26 & 1; //@line 33975
 HEAP32[96442] = ($23 & 255 | 0) == 0 & 1; //@line 33979
 HEAP32[96444] = ($sext31$lobit ^ $20 >>> 7 & 1) & ($26 ^ $4 >>> 7); //@line 33983
 $36 = ($21 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 33988
 HEAP32[96441] = $36; //@line 33989
 HEAP32[96445] = $36; //@line 33990
 HEAP32[96443] = $sext31$lobit; //@line 33991
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $23); //@line 33995
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33998
 return;
}
function __Z12op_e0a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink26 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38350
 $7 = HEAP32[$6 >> 2] | 0; //@line 38351
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38352
 $9 = $8 >>> 0 > 31; //@line 38353
 HEAP32[96441] = 0; //@line 38354
 HEAP32[96442] = 0; //@line 38354
 HEAP32[96443] = 0; //@line 38354
 HEAP32[96444] = 0; //@line 38354
 if ($9) {
  $$0$ph = 0; //@line 38360
  $$sink26 = ($8 | 0) == 32 & $7 >>> 31; //@line 38360
  label = 4; //@line 38361
 } else {
  $16 = $7 >>> ($8 + -1 | 0); //@line 38365
  if (!$8) {
   $$0 = $7; //@line 38369
  } else {
   $$0$ph = $16 >>> 1; //@line 38371
   $$sink26 = $16 & 1; //@line 38371
   label = 4; //@line 38372
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink26; //@line 38376
  HEAP32[96445] = $$sink26; //@line 38377
  $$0 = $$0$ph; //@line 38378
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38382
 HEAP32[96443] = $$0 >>> 31; //@line 38384
 HEAP32[$6 >> 2] = $$0; //@line 38385
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38388
 return;
}
function __Z12op_5058_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $21 = 0, $31 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 3985
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 3987
 $7 = HEAP32[$6 >> 2] | 0; //@line 3988
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 3990
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 3994
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 3997
 $16 = $13 << 16 >> 16; //@line 3999
 $18 = $16 + ($4 << 16 >> 16) | 0; //@line 4002
 $21 = $18 >>> 15; //@line 4006
 $sext39$lobit = $21 & 1; //@line 4007
 HEAP32[96442] = ($18 & 65535 | 0) == 0 & 1; //@line 4011
 HEAP32[96444] = ($sext39$lobit ^ $13 >>> 15 & 1) & ($21 ^ $4 >>> 15); //@line 4015
 $31 = ($16 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4020
 HEAP32[96441] = $31; //@line 4021
 HEAP32[96445] = $31; //@line 4022
 HEAP32[96443] = $sext39$lobit; //@line 4023
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $18); //@line 4027
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4030
 return;
}
function __Z11op_478_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $38 = 0, $4 = 0, $9 = 0, $sext31$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 11054
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 11057
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 11062
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 11072
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 11074
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 11078
 $27 = ($24 << 16 >> 16) - ($9 << 16 >> 16) | 0; //@line 11083
 $29 = $24 >>> 15; //@line 11085
 $sext31$lobit = $27 >>> 15 & 1; //@line 11088
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 11092
 HEAP32[96444] = ($sext31$lobit ^ $29 & 1) & ($29 ^ $4 >>> 7); //@line 11096
 $38 = $9 >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 11099
 HEAP32[96441] = $38; //@line 11100
 HEAP32[96445] = $38; //@line 11101
 HEAP32[96443] = $sext31$lobit; //@line 11102
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $27); //@line 11106
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11109
 return;
}
function __Z9AudioInitv() {
 var $3 = 0, $4 = 0, $8 = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 47253
 STACKTOP = STACKTOP + 16 | 0; //@line 47254
 $vararg_buffer1 = sp + 8 | 0; //@line 47255
 _puts(104136) | 0; //@line 47257
 HEAP32[30817] = -1404829696; //@line 47258
 HEAP32[30818] = 16; //@line 47259
 HEAP32[30819] = 2; //@line 47260
 HEAP32[30820] = 0; //@line 47261
 HEAP32[30821] = 0; //@line 47262
 HEAP32[30823] = -2147480576; //@line 47263
 if (__Z13PrefsFindBoolPKc(104146) | 0) {
  STACKTOP = sp; //@line 47266
  return;
 }
 if ((_sem_init(123464, 0, 0) | 0) < 0) {
  STACKTOP = sp; //@line 47271
  return;
 }
 HEAP8[659477] = 1; //@line 47273
 $3 = __Z15PrefsFindStringPKci(105267, 0) | 0; //@line 47274
 $4 = _open($3, 2, sp) | 0; //@line 47275
 HEAP32[1311] = $4; //@line 47276
 if (($4 | 0) < 0) {
  $8 = _strerror(HEAP32[(___errno_location() | 0) >> 2] | 0) | 0; //@line 47281
  HEAP32[$vararg_buffer1 >> 2] = $3; //@line 47282
  HEAP32[$vararg_buffer1 + 4 >> 2] = $8; //@line 47284
  _printf(104154, $vararg_buffer1) | 0; //@line 47285
 }
 __ZL10open_audiov(); //@line 47287
 STACKTOP = sp; //@line 47288
 return;
}
function __Z12op_9038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $25 = 0, $3 = 0, $35 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 17977
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 17987
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 17993
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17994
 $20 = HEAP32[$19 >> 2] | 0; //@line 17995
 $23 = ($20 << 24 >> 24) - ($18 << 24 >> 24) | 0; //@line 18000
 $25 = $20 >>> 7; //@line 18002
 $sext32$lobit = $23 >>> 7 & 1; //@line 18005
 $sext32$mask = $23 & 255; //@line 18006
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 18009
 HEAP32[96444] = ($sext32$lobit ^ $25 & 1) & ($25 ^ $18 >>> 7); //@line 18013
 $35 = ($18 & 255) >>> 0 > ($20 & 255) >>> 0 & 1; //@line 18017
 HEAP32[96441] = $35; //@line 18018
 HEAP32[96445] = $35; //@line 18019
 HEAP32[96443] = $sext32$lobit; //@line 18020
 HEAP32[$19 >> 2] = $20 & -256 | $sext32$mask; //@line 18023
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18026
 return;
}
function __Z12op_c03b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0, $sext1617 = 0;
 $3 = HEAP32[162769] | 0; //@line 28275
 $4 = $3 + 2 | 0; //@line 28276
 HEAP32[162769] = $4; //@line 28277
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 28282
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 28289
 HEAP32[162769] = $3 + 4; //@line 28291
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 28292
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 28298
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28299
 $25 = HEAP32[$24 >> 2] | 0; //@line 28300
 $sext1617 = $25 & $23; //@line 28301
 $26 = $sext1617 << 24 >> 24; //@line 28303
 $28 = ($26 | 0) == 0 & 1; //@line 28305
 HEAP32[96441] = 0; //@line 28306
 HEAP32[96442] = 0; //@line 28306
 HEAP32[96443] = 0; //@line 28306
 HEAP32[96444] = 0; //@line 28306
 HEAP32[96442] = $28; //@line 28307
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 28310
 HEAP32[$24 >> 2] = $25 & -256 | $26 & 255; //@line 28314
 return;
}
function __Z12op_b07b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $8 = 0, $sext$lobit = 0, $sext35$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 24969
 $4 = $3 + 2 | 0; //@line 24970
 HEAP32[162769] = $4; //@line 24971
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 24976
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 24983
 HEAP32[162769] = $3 + 4; //@line 24985
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 24986
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 24992
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24994
 $26 = $25 - $23 | 0; //@line 24995
 $sext$lobit = $25 >>> 15 & 1; //@line 24999
 $sext35$lobit = $26 >>> 15 & 1; //@line 25001
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 25005
 HEAP32[96444] = ($23 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext35$lobit | 0) != ($sext$lobit | 0) & 1; //@line 25010
 HEAP32[96441] = ($23 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 25015
 HEAP32[96443] = $sext35$lobit; //@line 25016
 return;
}
function __Z12op_803b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0, $sext1617 = 0;
 $3 = HEAP32[162769] | 0; //@line 13950
 $4 = $3 + 2 | 0; //@line 13951
 HEAP32[162769] = $4; //@line 13952
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 13957
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 13964
 HEAP32[162769] = $3 + 4; //@line 13966
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 13967
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 13973
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13974
 $25 = HEAP32[$24 >> 2] | 0; //@line 13975
 $sext1617 = $25 | $23; //@line 13976
 $26 = $sext1617 << 24 >> 24; //@line 13978
 $28 = ($26 | 0) == 0 & 1; //@line 13980
 HEAP32[96441] = 0; //@line 13981
 HEAP32[96442] = 0; //@line 13981
 HEAP32[96443] = 0; //@line 13981
 HEAP32[96444] = 0; //@line 13981
 HEAP32[96442] = $28; //@line 13982
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 13985
 HEAP32[$24 >> 2] = $25 & -256 | $26 & 255; //@line 13989
 return;
}
function __Z12op_4828_0_ffj($0) {
 $0 = $0 | 0;
 var $$027$in = 0, $14 = 0, $16 = 0, $21 = 0, $25 = 0, $27 = 0, $30 = 0, $32 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49801
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 49812
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 49814
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 49820
 $25 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($21 & 15) | 0; //@line 49825
 $27 = $25 & 65535; //@line 49827
 $30 = ($27 >>> 0 > 9 ? $27 + -6 | 0 : $25) - ($21 & 240) | 0; //@line 49831
 $32 = ($30 & 496) >>> 0 > 144; //@line 49833
 $33 = $32 & 1; //@line 49834
 $$027$in = $32 ? ($30 & 65535) + -96 | 0 : $30; //@line 49837
 HEAP32[96441] = $33; //@line 49838
 HEAP32[96445] = $33; //@line 49839
 HEAP32[96442] = ($$027$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49845
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $$027$in & 65535); //@line 49850
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49853
 return;
}
function __Z11op_c3b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $16 = 0, $18 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $9 = 0, $sext$lobit = 0, $sext28$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19232
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 19234
 $4 = $3 & 255; //@line 19235
 $5 = $1 + 4 | 0; //@line 19236
 HEAP32[162769] = $5; //@line 19237
 $9 = (HEAP32[162768] | 0) + $5 - (HEAP32[162770] | 0) | 0; //@line 19242
 $16 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 19249
 HEAP32[162769] = $1 + 6; //@line 19251
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 19252
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 19258
 $25 = $24 - $4 | 0; //@line 19259
 $sext$lobit = $24 >>> 7 & 1; //@line 19263
 $sext28$lobit = $25 >>> 7 & 1; //@line 19265
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 19269
 HEAP32[96444] = (($3 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext28$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19274
 HEAP32[96441] = $4 >>> 0 > ($24 & 255) >>> 0 & 1; //@line 19278
 HEAP32[96443] = $sext28$lobit; //@line 19279
 return;
}
function __Z12op_e1a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ph = 0, $$sink27 = 0, $15 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39813
 $7 = HEAP32[$6 >> 2] | 0; //@line 39814
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39815
 $9 = $8 >>> 0 > 31; //@line 39816
 HEAP32[96441] = 0; //@line 39817
 HEAP32[96442] = 0; //@line 39817
 HEAP32[96443] = 0; //@line 39817
 HEAP32[96444] = 0; //@line 39817
 if ($9) {
  $$0$ph = 0; //@line 39822
  $$sink27 = ($8 | 0) == 32 ? $7 & 1 : 0; //@line 39822
  label = 4; //@line 39823
 } else {
  $15 = $7 << $8 + -1; //@line 39827
  if (!$8) {
   $$0 = $7; //@line 39831
  } else {
   $$0$ph = $15 << 1; //@line 39833
   $$sink27 = $15 >>> 31; //@line 39833
   label = 4; //@line 39834
  }
 }
 if ((label | 0) == 4) {
  HEAP32[96441] = $$sink27; //@line 39838
  HEAP32[96445] = $$sink27; //@line 39839
  $$0 = $$0$ph; //@line 39840
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39844
 HEAP32[96443] = $$0 >>> 31; //@line 39846
 HEAP32[$6 >> 2] = $$0; //@line 39847
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39850
 return;
}
function __Z12op_5128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $27 = 0, $29 = 0, $39 = 0, $4 = 0, $8 = 0, $sext37$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5221
 $8 = HEAP32[162769] | 0; //@line 5225
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 5236
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5238
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 5242
 $27 = ($24 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5247
 $29 = $24 >>> 7; //@line 5249
 $sext37$lobit = $27 >>> 7 & 1; //@line 5252
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 5256
 HEAP32[96444] = ($sext37$lobit ^ $29 & 1) & ($29 ^ $4 >>> 7); //@line 5260
 $39 = ($4 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 5264
 HEAP32[96441] = $39; //@line 5265
 HEAP32[96445] = $39; //@line 5266
 HEAP32[96443] = $sext37$lobit; //@line 5267
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $27); //@line 5271
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5274
 return;
}
function __Z12op_e040_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$in = 0, $10 = 0, $11 = 0, $12 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37763
 $7 = HEAP32[$6 >> 2] | 0; //@line 37764
 $9 = $7 >>> 15 & 1; //@line 37766
 $10 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37767
 $11 = $10 >>> 0 > 15; //@line 37768
 $12 = 0 - $9 | 0; //@line 37769
 HEAP32[96441] = 0; //@line 37770
 HEAP32[96442] = 0; //@line 37770
 HEAP32[96443] = 0; //@line 37770
 HEAP32[96444] = 0; //@line 37770
 if ($11) {
  HEAP32[96441] = $9; //@line 37772
  HEAP32[96445] = $9; //@line 37773
  $$0$in = $12; //@line 37774
 } else {
  $15 = ($7 & 65535) >>> ($10 + -1 | 0); //@line 37778
  $16 = $15 & 1; //@line 37779
  HEAP32[96441] = $16; //@line 37780
  HEAP32[96445] = $16; //@line 37781
  $$0$in = $15 >>> 1 | 65535 << 16 - $10 & $12; //@line 37787
 }
 $$0 = $$0$in & 65535; //@line 37789
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 37792
 HEAP32[96443] = $$0 >>> 15; //@line 37794
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 37797
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37800
 return;
}
function __Z12op_4060_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $20 = 0, $4 = 0, $6 = 0, $sext$lobit = 0, $sext34$lobit = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40553
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 40555
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40557
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 40561
 HEAP32[$2 >> 2] = $4; //@line 40562
 $14 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($10 << 16 >> 16) | 0; //@line 40568
 $15 = $10 >>> 15; //@line 40569
 $sext$lobit = $15 & 1; //@line 40570
 $16 = $14 >>> 15; //@line 40571
 $sext34$lobit = $16 & 1; //@line 40572
 HEAP32[96444] = $sext34$lobit & $15; //@line 40574
 $20 = ($sext34$lobit ^ $sext$lobit) & $16 ^ $sext$lobit; //@line 40577
 HEAP32[96441] = $20; //@line 40578
 HEAP32[96445] = $20; //@line 40579
 HEAP32[96442] = ($14 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40585
 HEAP32[96443] = $sext34$lobit; //@line 40586
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $14); //@line 40590
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40593
 return;
}
function __Z12op_d0bb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $15 = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $33 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 33032
 $4 = $3 + 2 | 0; //@line 33033
 HEAP32[162769] = $4; //@line 33034
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 33039
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 33046
 HEAP32[162769] = $3 + 4; //@line 33048
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 33049
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 33054
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 33055
 $24 = HEAP32[$23 >> 2] | 0; //@line 33056
 $25 = $24 + $22 | 0; //@line 33057
 $$lobit37 = $25 >>> 31; //@line 33060
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 33063
 HEAP32[96444] = ($$lobit37 ^ $22 >>> 31) & ($$lobit37 ^ $24 >>> 31); //@line 33067
 $33 = $22 >>> 0 > ~$24 >>> 0 & 1; //@line 33070
 HEAP32[96441] = $33; //@line 33071
 HEAP32[96445] = $33; //@line 33072
 HEAP32[96443] = $$lobit37; //@line 33073
 HEAP32[$23 >> 2] = $25; //@line 33074
 return;
}
function __Z12op_91b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $14 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $36 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21379
 $5 = HEAP32[162769] | 0; //@line 21380
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 21389
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 21398
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 21400
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 21403
 $29 = $28 - $4 | 0; //@line 21404
 $$lobit33 = $28 >>> 31; //@line 21406
 $$lobit34 = $29 >>> 31; //@line 21407
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 21410
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $4 >>> 31); //@line 21414
 $36 = $28 >>> 0 < $4 >>> 0 & 1; //@line 21416
 HEAP32[96441] = $36; //@line 21417
 HEAP32[96445] = $36; //@line 21418
 HEAP32[96443] = $$lobit34; //@line 21419
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 21423
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 21426
 return;
}
function __Z12op_5078_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $36 = 0, $4 = 0, $5 = 0, $sext35$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4228
 $5 = HEAP32[162769] | 0; //@line 4229
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 4239
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 4241
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 4245
 $21 = $20 << 16 >> 16; //@line 4247
 $23 = $21 + ($4 << 16 >> 16) | 0; //@line 4250
 $26 = $23 >>> 15; //@line 4254
 $sext35$lobit = $26 & 1; //@line 4255
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 4259
 HEAP32[96444] = ($sext35$lobit ^ $20 >>> 15 & 1) & ($26 ^ $4 >>> 15); //@line 4263
 $36 = ($21 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4268
 HEAP32[96441] = $36; //@line 4269
 HEAP32[96445] = $36; //@line 4270
 HEAP32[96443] = $sext35$lobit; //@line 4271
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 4275
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4278
 return;
}
function __Z12op_13e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $13 = 0, $2 = 0, $22 = 0, $31 = 0, $32 = 0, $34 = 0, $6 = 0;
 $1 = $0 & 7; //@line 27356
 $2 = 651040 + ($1 << 2) | 0; //@line 27357
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 27361
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 27367
 HEAP32[$2 >> 2] = $6; //@line 27368
 $13 = HEAP32[162769] | 0; //@line 27369
 $22 = (HEAPU8[$13 + 3 >> 0] | 0) << 16 | (HEAPU8[$13 + 2 >> 0] | 0) << 24; //@line 27378
 $31 = $22 | (HEAPU8[$13 + 4 >> 0] | 0) << 8 | (HEAPU8[$13 + 5 >> 0] | 0); //@line 27387
 $32 = $12 << 24 >> 24; //@line 27389
 $34 = ($32 | 0) == 0 & 1; //@line 27391
 HEAP32[96441] = 0; //@line 27392
 HEAP32[96442] = 0; //@line 27392
 HEAP32[96443] = 0; //@line 27392
 HEAP32[96444] = 0; //@line 27392
 HEAP32[96442] = $34; //@line 27393
 HEAP32[96443] = $12 >>> 7 & 1; //@line 27396
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($31, $32); //@line 27402
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27405
 return;
}
function _scalbn($0, $1) {
 $0 = +$0;
 $1 = $1 | 0;
 var $$0 = 0.0, $$020 = 0, $10 = 0.0, $11 = 0, $12 = 0, $14 = 0, $17 = 0, $18 = 0, $3 = 0.0, $4 = 0, $5 = 0, $7 = 0;
 if (($1 | 0) > 1023) {
  $3 = $0 * 8.98846567431158e+307; //@line 61497
  $4 = $1 + -1023 | 0; //@line 61498
  $5 = ($4 | 0) > 1023; //@line 61499
  $7 = $1 + -2046 | 0; //@line 61501
  $$0 = $5 ? $3 * 8.98846567431158e+307 : $3; //@line 61506
  $$020 = $5 ? ($7 | 0) < 1023 ? $7 : 1023 : $4; //@line 61506
 } else {
  if (($1 | 0) < -1022) {
   $10 = $0 * 2.2250738585072014e-308; //@line 61510
   $11 = $1 + 1022 | 0; //@line 61511
   $12 = ($11 | 0) < -1022; //@line 61512
   $14 = $1 + 2044 | 0; //@line 61514
   $$0 = $12 ? $10 * 2.2250738585072014e-308 : $10; //@line 61519
   $$020 = $12 ? ($14 | 0) > -1022 ? $14 : -1022 : $11; //@line 61519
  } else {
   $$0 = $0; //@line 61521
   $$020 = $1; //@line 61521
  }
 }
 $17 = _bitshift64Shl($$020 + 1023 | 0, 0, 52) | 0; //@line 61525
 $18 = tempRet0; //@line 61526
 HEAP32[tempDoublePtr >> 2] = $17; //@line 61527
 HEAP32[tempDoublePtr + 4 >> 2] = $18; //@line 61527
 return +($$0 * +HEAPF64[tempDoublePtr >> 3]);
}
function __Z12op_5060_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $17 = 0, $20 = 0, $30 = 0, $4 = 0, $6 = 0, $8 = 0, $sext40$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4042
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 4044
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 4046
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 4048
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 4052
 HEAP32[$6 >> 2] = $8; //@line 4053
 $15 = $14 << 16 >> 16; //@line 4055
 $17 = $15 + ($4 << 16 >> 16) | 0; //@line 4058
 $20 = $17 >>> 15; //@line 4062
 $sext40$lobit = $20 & 1; //@line 4063
 HEAP32[96442] = ($17 & 65535 | 0) == 0 & 1; //@line 4067
 HEAP32[96444] = ($sext40$lobit ^ $14 >>> 15 & 1) & ($20 ^ $4 >>> 15); //@line 4071
 $30 = ($15 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 4076
 HEAP32[96441] = $30; //@line 4077
 HEAP32[96445] = $30; //@line 4078
 HEAP32[96443] = $sext40$lobit; //@line 4079
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $17); //@line 4083
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4086
 return;
}
function __Z11op_4d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $19 = 0, $20 = 0, $25 = 0, $3 = 0, $35 = 0, $6 = 0, $9 = 0;
 $3 = HEAP32[162769] | 0; //@line 11694
 $6 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 11697
 $9 = HEAPU8[$3 + 2 >> 0] | 0; //@line 11701
 $11 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11703
 $14 = HEAP32[651008 + ($9 >>> 4 << 2) >> 2] | 0; //@line 11706
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($11 >>> 16 << 2) >> 2] >> 2] & 127]($11) | 0; //@line 11711
 $20 = $11 + 4 | 0; //@line 11712
 $25 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 11717
 HEAP32[96442] = (($19 | 0) == ($14 | 0) | ($25 | 0) == ($14 | 0)) & 1; //@line 11722
 if (($19 | 0) > ($25 | 0)) {
  $35 = ($14 | 0) < ($19 | 0) | ($14 | 0) > ($25 | 0); //@line 11728
 } else {
  $35 = ($14 | 0) < ($19 | 0) | ($14 | 0) > ($25 | 0); //@line 11733
 }
 HEAP32[96441] = $35 & 1; //@line 11736
 if (($9 & 8 | 0) != 0 & $35) {
  __Z9Exceptionij(6, $6); //@line 11741
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11746
  return;
 }
}
function __Z12op_c100_1_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$1$in = 0, $10 = 0, $16 = 0, $20 = 0, $24 = 0, $25 = 0, $6 = 0, $7 = 0, $8 = 0, $sext37$mask = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 35170
 $7 = HEAP32[$6 >> 2] | 0; //@line 35171
 $8 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << 24 >> 24; //@line 35173
 $10 = $7 << 24 >> 24; //@line 35176
 $16 = ($10 & 15) + ($8 & 15) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 35182
 $20 = ($10 & 240) + ($8 & 240) + $16 | 0; //@line 35186
 $$ = $16 >>> 0 > 9 ? $20 + 6 | 0 : $20; //@line 35189
 $24 = ($$ & 1008) >>> 0 > 144; //@line 35191
 $25 = $24 & 1; //@line 35192
 $$1$in = $24 ? ($$ & 65535) + 96 | 0 : $$; //@line 35195
 HEAP32[96441] = $25; //@line 35196
 HEAP32[96445] = $25; //@line 35197
 $sext37$mask = $$1$in & 255; //@line 35199
 HEAP32[96442] = ($sext37$mask | 0) == 0 & HEAP32[96442]; //@line 35203
 HEAP32[96443] = $$1$in >>> 7 & 1; //@line 35206
 HEAP32[96444] = ($20 & 128 | 0) == 0 & ($$1$in & 128 | 0) != 0 & 1; //@line 35213
 HEAP32[$6 >> 2] = $sext37$mask | $7 & -256; //@line 35216
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35219
 return;
}
function __Z12op_c070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0, $sext2122 = 0;
 $4 = HEAP32[162769] | 0; //@line 28552
 $5 = $4 + 2 | 0; //@line 28553
 HEAP32[162769] = $5; //@line 28554
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28556
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 28563
 HEAP32[162769] = $4 + 4; //@line 28565
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 28566
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 28572
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28573
 $24 = HEAP32[$23 >> 2] | 0; //@line 28574
 $sext2122 = $24 & $22; //@line 28575
 $25 = $sext2122 << 16 >> 16; //@line 28577
 $27 = ($25 | 0) == 0 & 1; //@line 28579
 HEAP32[96441] = 0; //@line 28580
 HEAP32[96442] = 0; //@line 28580
 HEAP32[96443] = 0; //@line 28580
 HEAP32[96444] = 0; //@line 28580
 HEAP32[96442] = $27; //@line 28581
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 28584
 HEAP32[$23 >> 2] = $24 & -65536 | $25 & 65535; //@line 28588
 return;
}
function __Z12op_8070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0, $sext2122 = 0;
 $4 = HEAP32[162769] | 0; //@line 14228
 $5 = $4 + 2 | 0; //@line 14229
 HEAP32[162769] = $5; //@line 14230
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14232
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 14239
 HEAP32[162769] = $4 + 4; //@line 14241
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 14242
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 14248
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14249
 $24 = HEAP32[$23 >> 2] | 0; //@line 14250
 $sext2122 = $24 | $22; //@line 14251
 $25 = $sext2122 << 16 >> 16; //@line 14253
 $27 = ($25 | 0) == 0 & 1; //@line 14255
 HEAP32[96441] = 0; //@line 14256
 HEAP32[96442] = 0; //@line 14256
 HEAP32[96443] = 0; //@line 14256
 HEAP32[96444] = 0; //@line 14256
 HEAP32[96442] = $27; //@line 14257
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 14260
 HEAP32[$23 >> 2] = $24 & -65536 | $25 & 65535; //@line 14264
 return;
}
function __Z12op_1118_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 24930
 $3 = $0 >>> 9 & 7; //@line 24932
 $4 = 651040 + ($1 << 2) | 0; //@line 24933
 $5 = HEAP32[$4 >> 2] | 0; //@line 24934
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 24940
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 24945
 $16 = 651040 + ($3 << 2) | 0; //@line 24946
 $20 = (HEAP32[$16 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 24950
 HEAP32[$16 >> 2] = $20; //@line 24951
 $21 = $11 << 24 >> 24; //@line 24953
 $23 = ($21 | 0) == 0 & 1; //@line 24955
 HEAP32[96441] = 0; //@line 24956
 HEAP32[96442] = 0; //@line 24956
 HEAP32[96443] = 0; //@line 24956
 HEAP32[96444] = 0; //@line 24956
 HEAP32[96442] = $23; //@line 24957
 HEAP32[96443] = $11 >>> 7 & 1; //@line 24960
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($20, $21); //@line 24966
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24969
 return;
}
function __Z12op_e048_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $16 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext$mask = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37813
 $7 = HEAP32[$6 >> 2] | 0; //@line 37814
 $8 = $7 & 65535; //@line 37815
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37816
 $10 = $9 >>> 0 > 15; //@line 37817
 HEAP32[96441] = 0; //@line 37818
 HEAP32[96442] = 0; //@line 37818
 HEAP32[96443] = 0; //@line 37818
 HEAP32[96444] = 0; //@line 37818
 if ($10) {
  $14 = ($9 | 0) == 16 & $8 >>> 15; //@line 37823
  HEAP32[96441] = $14; //@line 37824
  HEAP32[96445] = $14; //@line 37825
  $$0 = 0; //@line 37826
 } else {
  $16 = $8 >>> ($9 + -1 | 0); //@line 37829
  $17 = $16 & 1; //@line 37830
  HEAP32[96441] = $17; //@line 37831
  HEAP32[96445] = $17; //@line 37832
  $$0 = $16 >>> 1; //@line 37834
 }
 $sext$mask = $$0 & 65535; //@line 37836
 HEAP32[96442] = ($sext$mask | 0) == 0 & 1; //@line 37839
 HEAP32[96443] = $$0 >>> 15 & 1; //@line 37842
 HEAP32[$6 >> 2] = $sext$mask | $7 & -65536; //@line 37845
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37848
 return;
}
function __Z12op_23fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $20 = 0, $21 = 0, $30 = 0, $39 = 0, $41 = 0;
 $2 = HEAP32[162769] | 0; //@line 44121
 $$cast = $2; //@line 44126
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44135
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 44140
 $21 = HEAP32[162769] | 0; //@line 44141
 $30 = (HEAPU8[$21 + 5 >> 0] | 0) << 16 | (HEAPU8[$21 + 4 >> 0] | 0) << 24; //@line 44150
 $39 = $30 | (HEAPU8[$21 + 6 >> 0] | 0) << 8 | (HEAPU8[$21 + 7 >> 0] | 0); //@line 44159
 $41 = ($20 | 0) == 0 & 1; //@line 44161
 HEAP32[96441] = 0; //@line 44162
 HEAP32[96442] = 0; //@line 44162
 HEAP32[96443] = 0; //@line 44162
 HEAP32[96444] = 0; //@line 44162
 HEAP32[96442] = $41; //@line 44163
 HEAP32[96443] = $20 >>> 31; //@line 44165
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($39, $20); //@line 44171
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 44174
 return;
}
function __Z11op_638_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $19 = 0, $20 = 0, $22 = 0, $25 = 0, $3 = 0, $34 = 0, $sext26$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 12537
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 12539
 $13 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 12550
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 12552
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 12556
 $20 = $19 << 24 >> 24; //@line 12558
 $22 = $20 + ($3 << 24 >> 24) | 0; //@line 12560
 $25 = $22 >>> 7; //@line 12565
 $sext26$lobit = $25 & 1; //@line 12566
 HEAP32[96442] = ($22 & 255 | 0) == 0 & 1; //@line 12570
 HEAP32[96444] = ($sext26$lobit ^ $19 >>> 7 & 1) & ($25 ^ ($3 & 255) >>> 7 & 255); //@line 12574
 $34 = ($20 & 255 ^ 255) >>> 0 < ($3 & 255) >>> 0 & 1; //@line 12578
 HEAP32[96441] = $34; //@line 12579
 HEAP32[96445] = $34; //@line 12580
 HEAP32[96443] = $sext26$lobit; //@line 12581
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $22); //@line 12585
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 12588
 return;
}
function __Z12op_b03b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $8 = 0, $sext$lobit = 0, $sext31$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 22273
 $4 = $3 + 2 | 0; //@line 22274
 HEAP32[162769] = $4; //@line 22275
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 22280
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 22287
 HEAP32[162769] = $3 + 4; //@line 22289
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 22290
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 22296
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22298
 $26 = $25 - $23 | 0; //@line 22299
 $sext$lobit = $25 >>> 7 & 1; //@line 22303
 $sext31$lobit = $26 >>> 7 & 1; //@line 22305
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 22309
 HEAP32[96444] = ($23 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext31$lobit | 0) != ($sext$lobit | 0) & 1; //@line 22314
 HEAP32[96441] = ($23 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 22319
 HEAP32[96443] = $sext31$lobit; //@line 22320
 return;
}
function __Z11op_ab0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 18042
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 18060
 $21 = $2 + 6 | 0; //@line 18061
 HEAP32[162769] = $21; //@line 18062
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18064
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 18071
 HEAP32[162769] = $2 + 8; //@line 18073
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 18074
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 18076
 $38 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0) ^ $20; //@line 18080
 $40 = ($38 | 0) == 0 & 1; //@line 18082
 HEAP32[96441] = 0; //@line 18083
 HEAP32[96442] = 0; //@line 18083
 HEAP32[96443] = 0; //@line 18083
 HEAP32[96444] = 0; //@line 18083
 HEAP32[96442] = $40; //@line 18084
 HEAP32[96443] = $38 >>> 31; //@line 18086
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 18090
 return;
}
function __Z12op_33f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $20 = 0, $29 = 0, $38 = 0, $39 = 0, $4 = 0, $41 = 0;
 $4 = HEAP32[162769] | 0; //@line 45549
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 45558
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 45564
 $20 = HEAP32[162769] | 0; //@line 45565
 $29 = (HEAPU8[$20 + 5 >> 0] | 0) << 16 | (HEAPU8[$20 + 4 >> 0] | 0) << 24; //@line 45574
 $38 = $29 | (HEAPU8[$20 + 6 >> 0] | 0) << 8 | (HEAPU8[$20 + 7 >> 0] | 0); //@line 45583
 $39 = $19 << 16 >> 16; //@line 45585
 $41 = ($39 | 0) == 0 & 1; //@line 45587
 HEAP32[96441] = 0; //@line 45588
 HEAP32[96442] = 0; //@line 45588
 HEAP32[96443] = 0; //@line 45588
 HEAP32[96444] = 0; //@line 45588
 HEAP32[96442] = $41; //@line 45589
 HEAP32[96443] = $19 >>> 15 & 1; //@line 45592
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($38, $39); //@line 45598
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 45601
 return;
}
function __Z12op_c030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0, $sext1718 = 0;
 $4 = HEAP32[162769] | 0; //@line 28077
 $5 = $4 + 2 | 0; //@line 28078
 HEAP32[162769] = $5; //@line 28079
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28081
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 28088
 HEAP32[162769] = $4 + 4; //@line 28090
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 28091
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 28097
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28098
 $24 = HEAP32[$23 >> 2] | 0; //@line 28099
 $sext1718 = $24 & $22; //@line 28100
 $25 = $sext1718 << 24 >> 24; //@line 28102
 $27 = ($25 | 0) == 0 & 1; //@line 28104
 HEAP32[96441] = 0; //@line 28105
 HEAP32[96442] = 0; //@line 28105
 HEAP32[96443] = 0; //@line 28105
 HEAP32[96444] = 0; //@line 28105
 HEAP32[96442] = $27; //@line 28106
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 28109
 HEAP32[$23 >> 2] = $24 & -256 | $25 & 255; //@line 28113
 return;
}
function __Z12op_b070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0, $7 = 0, $sext$lobit = 0, $sext36$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 24737
 $5 = $4 + 2 | 0; //@line 24738
 HEAP32[162769] = $5; //@line 24739
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24741
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 24748
 HEAP32[162769] = $4 + 4; //@line 24750
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 24751
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 24757
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24759
 $25 = $24 - $22 | 0; //@line 24760
 $sext$lobit = $24 >>> 15 & 1; //@line 24764
 $sext36$lobit = $25 >>> 15 & 1; //@line 24766
 HEAP32[96442] = ($25 & 65535 | 0) == 0 & 1; //@line 24770
 HEAP32[96444] = ($22 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext36$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24775
 HEAP32[96441] = ($22 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 24780
 HEAP32[96443] = $sext36$lobit; //@line 24781
 return;
}
function __Z12op_8030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0, $sext1718 = 0;
 $4 = HEAP32[162769] | 0; //@line 13752
 $5 = $4 + 2 | 0; //@line 13753
 HEAP32[162769] = $5; //@line 13754
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13756
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 13763
 HEAP32[162769] = $4 + 4; //@line 13765
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 13766
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 13772
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13773
 $24 = HEAP32[$23 >> 2] | 0; //@line 13774
 $sext1718 = $24 | $22; //@line 13775
 $25 = $sext1718 << 24 >> 24; //@line 13777
 $27 = ($25 | 0) == 0 & 1; //@line 13779
 HEAP32[96441] = 0; //@line 13780
 HEAP32[96442] = 0; //@line 13780
 HEAP32[96443] = 0; //@line 13780
 HEAP32[96444] = 0; //@line 13780
 HEAP32[96442] = $27; //@line 13781
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 13784
 HEAP32[$23 >> 2] = $24 & -256 | $25 & 255; //@line 13788
 return;
}
function __Z12op_13f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $20 = 0, $29 = 0, $38 = 0, $39 = 0, $4 = 0, $41 = 0;
 $4 = HEAP32[162769] | 0; //@line 31919
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 31928
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 31934
 $20 = HEAP32[162769] | 0; //@line 31935
 $29 = (HEAPU8[$20 + 5 >> 0] | 0) << 16 | (HEAPU8[$20 + 4 >> 0] | 0) << 24; //@line 31944
 $38 = $29 | (HEAPU8[$20 + 6 >> 0] | 0) << 8 | (HEAPU8[$20 + 7 >> 0] | 0); //@line 31953
 $39 = $19 << 24 >> 24; //@line 31955
 $41 = ($39 | 0) == 0 & 1; //@line 31957
 HEAP32[96441] = 0; //@line 31958
 HEAP32[96442] = 0; //@line 31958
 HEAP32[96443] = 0; //@line 31958
 HEAP32[96444] = 0; //@line 31958
 HEAP32[96442] = $41; //@line 31959
 HEAP32[96443] = $19 >>> 7 & 1; //@line 31962
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($38, $39); //@line 31968
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 31971
 return;
}
function __Z11op_c30_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $sext$lobit = 0, $sext27$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19008
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 19010
 $5 = $4 & 255; //@line 19011
 $6 = $2 + 4 | 0; //@line 19012
 HEAP32[162769] = $6; //@line 19013
 $8 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19015
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 19022
 HEAP32[162769] = $2 + 6; //@line 19024
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 19025
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 19031
 $24 = $23 - $5 | 0; //@line 19032
 $sext$lobit = $23 >>> 7 & 1; //@line 19036
 $sext27$lobit = $24 >>> 7 & 1; //@line 19038
 HEAP32[96442] = ($24 & 255 | 0) == 0 & 1; //@line 19042
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext27$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19047
 HEAP32[96441] = $5 >>> 0 > ($23 & 255) >>> 0 & 1; //@line 19051
 HEAP32[96443] = $sext27$lobit; //@line 19052
 return;
}
function __Z12op_c170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30326
 $6 = HEAP32[162769] | 0; //@line 30327
 $7 = $6 + 2 | 0; //@line 30328
 HEAP32[162769] = $7; //@line 30329
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30331
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 30338
 HEAP32[162769] = $6 + 4; //@line 30340
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 30341
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 30343
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) & $5; //@line 30348
 $25 = $sext2021 << 16 >> 16; //@line 30350
 $27 = ($25 | 0) == 0 & 1; //@line 30352
 HEAP32[96441] = 0; //@line 30353
 HEAP32[96442] = 0; //@line 30353
 HEAP32[96443] = 0; //@line 30353
 HEAP32[96444] = 0; //@line 30353
 HEAP32[96442] = $27; //@line 30354
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 30357
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 30361
 return;
}
function __Z12op_b170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26841
 $6 = HEAP32[162769] | 0; //@line 26842
 $7 = $6 + 2 | 0; //@line 26843
 HEAP32[162769] = $7; //@line 26844
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26846
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 26853
 HEAP32[162769] = $6 + 4; //@line 26855
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 26856
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 26858
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) ^ $5; //@line 26863
 $25 = $sext2021 << 16 >> 16; //@line 26865
 $27 = ($25 | 0) == 0 & 1; //@line 26867
 HEAP32[96441] = 0; //@line 26868
 HEAP32[96442] = 0; //@line 26868
 HEAP32[96443] = 0; //@line 26868
 HEAP32[96444] = 0; //@line 26868
 HEAP32[96442] = $27; //@line 26869
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 26872
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 26876
 return;
}
function __Z12op_33f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $26 = 0, $35 = 0, $44 = 0, $45 = 0, $47 = 0;
 $1 = HEAP32[162769] | 0; //@line 39729
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 39738
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 39753
 $26 = HEAP32[162769] | 0; //@line 39754
 $35 = (HEAPU8[$26 + 7 >> 0] | 0) << 16 | (HEAPU8[$26 + 6 >> 0] | 0) << 24; //@line 39763
 $44 = $35 | (HEAPU8[$26 + 8 >> 0] | 0) << 8 | (HEAPU8[$26 + 9 >> 0] | 0); //@line 39772
 $45 = $25 << 16 >> 16; //@line 39774
 $47 = ($45 | 0) == 0 & 1; //@line 39776
 HEAP32[96441] = 0; //@line 39777
 HEAP32[96442] = 0; //@line 39777
 HEAP32[96443] = 0; //@line 39777
 HEAP32[96444] = 0; //@line 39777
 HEAP32[96442] = $47; //@line 39778
 HEAP32[96443] = $25 >>> 15 & 1; //@line 39781
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($44, $45); //@line 39787
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 39790
 return;
}
function __Z11op_490_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $27 = 0, $28 = 0, $35 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11240
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11243
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11258
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11260
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 11262
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 11265
 $28 = $27 - $20 | 0; //@line 11266
 $$lobit33 = $27 >>> 31; //@line 11268
 $$lobit34 = $28 >>> 31; //@line 11269
 HEAP32[96442] = ($28 | 0) == 0 & 1; //@line 11272
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $5 >>> 7); //@line 11276
 $35 = $27 >>> 0 < $20 >>> 0 & 1; //@line 11278
 HEAP32[96441] = $35; //@line 11279
 HEAP32[96445] = $35; //@line 11280
 HEAP32[96443] = $$lobit34; //@line 11281
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $28); //@line 11285
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11288
 return;
}
function __Z10op_70_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 5283
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 5291
 $11 = $2 + 4 | 0; //@line 5292
 HEAP32[162769] = $11; //@line 5293
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5295
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5302
 HEAP32[162769] = $2 + 6; //@line 5304
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 5305
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 5307
 $sext1617 = $10 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0); //@line 5312
 $29 = $sext1617 << 16 >> 16; //@line 5314
 $31 = ($29 | 0) == 0 & 1; //@line 5316
 HEAP32[96441] = 0; //@line 5317
 HEAP32[96442] = 0; //@line 5317
 HEAP32[96443] = 0; //@line 5317
 HEAP32[96444] = 0; //@line 5317
 HEAP32[96442] = $31; //@line 5318
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 5321
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 5325
 return;
}
function __Z12op_c130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29979
 $6 = HEAP32[162769] | 0; //@line 29980
 $7 = $6 + 2 | 0; //@line 29981
 HEAP32[162769] = $7; //@line 29982
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29984
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 29991
 HEAP32[162769] = $6 + 4; //@line 29993
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 29994
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 29996
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) & $5; //@line 30001
 $25 = $sext1617 << 24 >> 24; //@line 30003
 $27 = ($25 | 0) == 0 & 1; //@line 30005
 HEAP32[96441] = 0; //@line 30006
 HEAP32[96442] = 0; //@line 30006
 HEAP32[96443] = 0; //@line 30006
 HEAP32[96444] = 0; //@line 30006
 HEAP32[96442] = $27; //@line 30007
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 30010
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 30014
 return;
}
function __Z12op_b130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26441
 $6 = HEAP32[162769] | 0; //@line 26442
 $7 = $6 + 2 | 0; //@line 26443
 HEAP32[162769] = $7; //@line 26444
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26446
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 26453
 HEAP32[162769] = $6 + 4; //@line 26455
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 26456
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 26458
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) ^ $5; //@line 26463
 $25 = $sext1617 << 24 >> 24; //@line 26465
 $27 = ($25 | 0) == 0 & 1; //@line 26467
 HEAP32[96441] = 0; //@line 26468
 HEAP32[96442] = 0; //@line 26468
 HEAP32[96443] = 0; //@line 26468
 HEAP32[96444] = 0; //@line 26468
 HEAP32[96442] = $27; //@line 26469
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 26472
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 26476
 return;
}
function __Z12op_13f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $26 = 0, $35 = 0, $44 = 0, $45 = 0, $47 = 0;
 $1 = HEAP32[162769] | 0; //@line 27608
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 27617
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 27632
 $26 = HEAP32[162769] | 0; //@line 27633
 $35 = (HEAPU8[$26 + 7 >> 0] | 0) << 16 | (HEAPU8[$26 + 6 >> 0] | 0) << 24; //@line 27642
 $44 = $35 | (HEAPU8[$26 + 8 >> 0] | 0) << 8 | (HEAPU8[$26 + 9 >> 0] | 0); //@line 27651
 $45 = $25 << 24 >> 24; //@line 27653
 $47 = ($45 | 0) == 0 & 1; //@line 27655
 HEAP32[96441] = 0; //@line 27656
 HEAP32[96442] = 0; //@line 27656
 HEAP32[96443] = 0; //@line 27656
 HEAP32[96444] = 0; //@line 27656
 HEAP32[96442] = $47; //@line 27657
 HEAP32[96443] = $25 >>> 7 & 1; //@line 27660
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($44, $45); //@line 27666
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 27669
 return;
}
function __Z12op_10d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $21 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 24395
 $3 = $0 >>> 9 & 7; //@line 24397
 $4 = 651040 + ($1 << 2) | 0; //@line 24398
 $5 = HEAP32[$4 >> 2] | 0; //@line 24399
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 24405
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 24410
 $16 = 651040 + ($3 << 2) | 0; //@line 24411
 $17 = HEAP32[$16 >> 2] | 0; //@line 24412
 HEAP32[$16 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $17; //@line 24416
 $21 = $11 << 24 >> 24; //@line 24418
 $23 = ($21 | 0) == 0 & 1; //@line 24420
 HEAP32[96441] = 0; //@line 24421
 HEAP32[96442] = 0; //@line 24421
 HEAP32[96443] = 0; //@line 24421
 HEAP32[96444] = 0; //@line 24421
 HEAP32[96442] = $23; //@line 24422
 HEAP32[96443] = $11 >>> 7 & 1; //@line 24425
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, $21); //@line 24431
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24434
 return;
}
function __Z12op_e000_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$in = 0, $10 = 0, $11 = 0, $12 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37373
 $7 = HEAP32[$6 >> 2] | 0; //@line 37374
 $9 = $7 >>> 7 & 1; //@line 37376
 $10 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37377
 $11 = $10 >>> 0 > 7; //@line 37378
 $12 = 0 - $9 | 0; //@line 37379
 HEAP32[96441] = 0; //@line 37380
 HEAP32[96442] = 0; //@line 37380
 HEAP32[96443] = 0; //@line 37380
 HEAP32[96444] = 0; //@line 37380
 if ($11) {
  HEAP32[96441] = $9; //@line 37382
  HEAP32[96445] = $9; //@line 37383
  $$0$in = $12; //@line 37384
 } else {
  $15 = ($7 & 255) >>> ($10 + -1 | 0); //@line 37388
  $16 = $15 & 1; //@line 37389
  HEAP32[96441] = $16; //@line 37390
  HEAP32[96445] = $16; //@line 37391
  $$0$in = $15 >>> 1 | 255 << 8 - $10 & $12; //@line 37397
 }
 $$0 = $$0$in & 255; //@line 37399
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 37402
 HEAP32[96443] = $$0 >>> 7; //@line 37404
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 37407
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37410
 return;
}
function __Z12op_d0b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $14 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $32 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 32822
 $5 = $4 + 2 | 0; //@line 32823
 HEAP32[162769] = $5; //@line 32824
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 32826
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 32833
 HEAP32[162769] = $4 + 4; //@line 32835
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 32836
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 32841
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32842
 $23 = HEAP32[$22 >> 2] | 0; //@line 32843
 $24 = $23 + $21 | 0; //@line 32844
 $$lobit38 = $24 >>> 31; //@line 32847
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 32850
 HEAP32[96444] = ($$lobit38 ^ $21 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 32854
 $32 = $21 >>> 0 > ~$23 >>> 0 & 1; //@line 32857
 HEAP32[96441] = $32; //@line 32858
 HEAP32[96445] = $32; //@line 32859
 HEAP32[96443] = $$lobit38; //@line 32860
 HEAP32[$22 >> 2] = $24; //@line 32861
 return;
}
function __Z12op_8170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16338
 $6 = HEAP32[162769] | 0; //@line 16339
 $7 = $6 + 2 | 0; //@line 16340
 HEAP32[162769] = $7; //@line 16341
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16343
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 16350
 HEAP32[162769] = $6 + 4; //@line 16352
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 16353
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16355
 $sext2021 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0 | $5; //@line 16360
 $25 = $sext2021 << 16 >> 16; //@line 16362
 $27 = ($25 | 0) == 0 & 1; //@line 16364
 HEAP32[96441] = 0; //@line 16365
 HEAP32[96442] = 0; //@line 16365
 HEAP32[96443] = 0; //@line 16365
 HEAP32[96444] = 0; //@line 16365
 HEAP32[96442] = $27; //@line 16366
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 16369
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 16373
 return;
}
function __Z12op_2198_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $16 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 33111
 $5 = HEAP32[$4 >> 2] | 0; //@line 33112
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 33117
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 33120
 $13 = HEAP32[162769] | 0; //@line 33121
 $14 = $13 + 2 | 0; //@line 33122
 HEAP32[162769] = $14; //@line 33123
 $16 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33125
 $23 = (HEAPU8[$14 >> 0] | 0) << 8 | (HEAPU8[$13 + 3 >> 0] | 0); //@line 33132
 HEAP32[162769] = $13 + 4; //@line 33134
 $25 = __Z15get_disp_ea_020jj($16, $23) | 0; //@line 33135
 $27 = ($10 | 0) == 0 & 1; //@line 33137
 HEAP32[96441] = 0; //@line 33138
 HEAP32[96442] = 0; //@line 33138
 HEAP32[96443] = 0; //@line 33138
 HEAP32[96444] = 0; //@line 33138
 HEAP32[96442] = $27; //@line 33139
 HEAP32[96443] = $10 >>> 31; //@line 33141
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $10); //@line 33147
 return;
}
function __Z12op_8130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15929
 $6 = HEAP32[162769] | 0; //@line 15930
 $7 = $6 + 2 | 0; //@line 15931
 HEAP32[162769] = $7; //@line 15932
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15934
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 15941
 HEAP32[162769] = $6 + 4; //@line 15943
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 15944
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 15946
 $sext1617 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0 | $5; //@line 15951
 $25 = $sext1617 << 24 >> 24; //@line 15953
 $27 = ($25 | 0) == 0 & 1; //@line 15955
 HEAP32[96441] = 0; //@line 15956
 HEAP32[96442] = 0; //@line 15956
 HEAP32[96443] = 0; //@line 15956
 HEAP32[96444] = 0; //@line 15956
 HEAP32[96442] = $27; //@line 15957
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 15960
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 15964
 return;
}
function __Z12op_5038_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $26 = 0, $36 = 0, $4 = 0, $5 = 0, $sext33$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1543
 $5 = HEAP32[162769] | 0; //@line 1544
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 1554
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 1556
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 1560
 $21 = $20 << 24 >> 24; //@line 1562
 $23 = $21 + ($4 << 24 >> 24) | 0; //@line 1565
 $26 = $23 >>> 7; //@line 1569
 $sext33$lobit = $26 & 1; //@line 1570
 HEAP32[96442] = ($23 & 255 | 0) == 0 & 1; //@line 1574
 HEAP32[96444] = ($sext33$lobit ^ $20 >>> 7 & 1) & ($26 ^ $4 >>> 7); //@line 1578
 $36 = ($21 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1583
 HEAP32[96441] = $36; //@line 1584
 HEAP32[96445] = $36; //@line 1585
 HEAP32[96443] = $sext33$lobit; //@line 1586
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $23); //@line 1590
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 1593
 return;
}
function __Z12op_33e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $21 = 0, $30 = 0, $39 = 0, $4 = 0, $40 = 0, $42 = 0;
 $4 = HEAP32[162769] | 0; //@line 39538
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 39549
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 39555
 $21 = HEAP32[162769] | 0; //@line 39556
 $30 = (HEAPU8[$21 + 5 >> 0] | 0) << 16 | (HEAPU8[$21 + 4 >> 0] | 0) << 24; //@line 39565
 $39 = $30 | (HEAPU8[$21 + 6 >> 0] | 0) << 8 | (HEAPU8[$21 + 7 >> 0] | 0); //@line 39574
 $40 = $20 << 16 >> 16; //@line 39576
 $42 = ($40 | 0) == 0 & 1; //@line 39578
 HEAP32[96441] = 0; //@line 39579
 HEAP32[96442] = 0; //@line 39579
 HEAP32[96443] = 0; //@line 39579
 HEAP32[96444] = 0; //@line 39579
 HEAP32[96442] = $42; //@line 39580
 HEAP32[96443] = $20 >>> 15 & 1; //@line 39583
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($39, $40); //@line 39589
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 39592
 return;
}
function __Z11op_270_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 9020
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 9028
 $11 = $2 + 4 | 0; //@line 9029
 HEAP32[162769] = $11; //@line 9030
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9032
 $20 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9039
 HEAP32[162769] = $2 + 6; //@line 9041
 $22 = __Z15get_disp_ea_020jj($13, $20) | 0; //@line 9042
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 9044
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0) & $10; //@line 9049
 $29 = $sext1617 << 16 >> 16; //@line 9051
 $31 = ($29 | 0) == 0 & 1; //@line 9053
 HEAP32[96441] = 0; //@line 9054
 HEAP32[96442] = 0; //@line 9054
 HEAP32[96443] = 0; //@line 9054
 HEAP32[96444] = 0; //@line 9054
 HEAP32[96442] = $31; //@line 9055
 HEAP32[96443] = $sext1617 >>> 15; //@line 9057
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 9061
 return;
}
function __Z12op_13e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $21 = 0, $30 = 0, $39 = 0, $4 = 0, $40 = 0, $42 = 0;
 $4 = HEAP32[162769] | 0; //@line 27417
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 27428
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 27434
 $21 = HEAP32[162769] | 0; //@line 27435
 $30 = (HEAPU8[$21 + 5 >> 0] | 0) << 16 | (HEAPU8[$21 + 4 >> 0] | 0) << 24; //@line 27444
 $39 = $30 | (HEAPU8[$21 + 6 >> 0] | 0) << 8 | (HEAPU8[$21 + 7 >> 0] | 0); //@line 27453
 $40 = $20 << 24 >> 24; //@line 27455
 $42 = ($40 | 0) == 0 & 1; //@line 27457
 HEAP32[96441] = 0; //@line 27458
 HEAP32[96442] = 0; //@line 27458
 HEAP32[96443] = 0; //@line 27458
 HEAP32[96444] = 0; //@line 27458
 HEAP32[96442] = $42; //@line 27459
 HEAP32[96443] = $20 >>> 7 & 1; //@line 27462
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($39, $40); //@line 27468
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 27471
 return;
}
function __Z12op_4838_1_ffj($0) {
 $0 = $0 | 0;
 var $$024$in = 0, $1 = 0, $10 = 0, $12 = 0, $17 = 0, $21 = 0, $23 = 0, $26 = 0, $28 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 2024
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 2034
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 2036
 $17 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0) << 24 >> 24; //@line 2042
 $21 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($17 & 15) | 0; //@line 2047
 $23 = $21 & 65535; //@line 2049
 $26 = ($23 >>> 0 > 9 ? $23 + -6 | 0 : $21) - ($17 & 240) | 0; //@line 2053
 $28 = ($26 & 496) >>> 0 > 144; //@line 2055
 $29 = $28 & 1; //@line 2056
 $$024$in = $28 ? ($26 & 65535) + -96 | 0 : $26; //@line 2059
 HEAP32[96441] = $29; //@line 2060
 HEAP32[96445] = $29; //@line 2061
 HEAP32[96442] = ($$024$in & 255 | 0) == 0 & HEAP32[96442]; //@line 2067
 HEAP32[96443] = $$024$in >>> 7 & 1; //@line 2070
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $$024$in & 65535); //@line 2075
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2078
 return;
}
function __Z12op_e008_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $16 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext$mask = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37423
 $7 = HEAP32[$6 >> 2] | 0; //@line 37424
 $8 = $7 & 255; //@line 37425
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37426
 $10 = $9 >>> 0 > 7; //@line 37427
 HEAP32[96441] = 0; //@line 37428
 HEAP32[96442] = 0; //@line 37428
 HEAP32[96443] = 0; //@line 37428
 HEAP32[96444] = 0; //@line 37428
 if ($10) {
  $14 = ($9 | 0) == 8 & $8 >>> 7; //@line 37433
  HEAP32[96441] = $14; //@line 37434
  HEAP32[96445] = $14; //@line 37435
  $$0 = 0; //@line 37436
 } else {
  $16 = $8 >>> ($9 + -1 | 0); //@line 37439
  $17 = $16 & 1; //@line 37440
  HEAP32[96441] = $17; //@line 37441
  HEAP32[96445] = $17; //@line 37442
  $$0 = $16 >>> 1; //@line 37444
 }
 $sext$mask = $$0 & 255; //@line 37446
 HEAP32[96442] = ($sext$mask | 0) == 0 & 1; //@line 37449
 HEAP32[96443] = $$0 >>> 7 & 1; //@line 37452
 HEAP32[$6 >> 2] = $sext$mask | $7 & -256; //@line 37455
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37458
 return;
}
function __Z12op_9158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $30 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext39$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20623
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 20624
 $7 = HEAP32[$6 >> 2] | 0; //@line 20625
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 20627
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 20631
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 20634
 $18 = ($13 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 20639
 $20 = $13 >>> 15; //@line 20641
 $sext39$lobit = $18 >>> 15 & 1; //@line 20644
 HEAP32[96442] = ($18 & 65535 | 0) == 0 & 1; //@line 20648
 HEAP32[96444] = ($sext39$lobit ^ $20 & 1) & ($20 ^ $5 >>> 15); //@line 20652
 $30 = ($5 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 20656
 HEAP32[96441] = $30; //@line 20657
 HEAP32[96445] = $30; //@line 20658
 HEAP32[96443] = $sext39$lobit; //@line 20659
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $18); //@line 20663
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20666
 return;
}
function __Z12op_213b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 30019
 $4 = $3 + 2 | 0; //@line 30020
 HEAP32[162769] = $4; //@line 30021
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 30026
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 30033
 HEAP32[162769] = $3 + 4; //@line 30035
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 30036
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 30041
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 30042
 $25 = (HEAP32[$23 >> 2] | 0) + -4 | 0; //@line 30044
 HEAP32[$23 >> 2] = $25; //@line 30045
 $27 = ($22 | 0) == 0 & 1; //@line 30047
 HEAP32[96441] = 0; //@line 30048
 HEAP32[96442] = 0; //@line 30048
 HEAP32[96443] = 0; //@line 30048
 HEAP32[96444] = 0; //@line 30048
 HEAP32[96442] = $27; //@line 30049
 HEAP32[96443] = $22 >>> 31; //@line 30051
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $22); //@line 30057
 return;
}
function __Z12op_4470_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $30 = 0, $5 = 0, $sext28$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 47401
 $3 = $2 + 2 | 0; //@line 47402
 HEAP32[162769] = $3; //@line 47403
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47405
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 47412
 HEAP32[162769] = $2 + 4; //@line 47414
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 47415
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 47417
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 47421
 $22 = 0 - ($20 << 16 >> 16) | 0; //@line 47424
 $sext28$lobit = $22 >>> 15 & 1; //@line 47427
 HEAP32[96442] = ($22 & 65535 | 0) == 0 & 1; //@line 47431
 HEAP32[96444] = $sext28$lobit & $20 >>> 15; //@line 47433
 $30 = ($20 & 65535 | 0) != 0 & 1; //@line 47436
 HEAP32[96441] = $30; //@line 47437
 HEAP32[96445] = $30; //@line 47438
 HEAP32[96443] = $sext28$lobit; //@line 47439
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22); //@line 47443
 return;
}
function __Z12op_23fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $40 = 0, $42 = 0;
 $2 = HEAP32[162769] | 0; //@line 34672
 $$cast = $2; //@line 34674
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 34688
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 34693
 $22 = HEAP32[162769] | 0; //@line 34694
 $31 = (HEAPU8[$22 + 5 >> 0] | 0) << 16 | (HEAPU8[$22 + 4 >> 0] | 0) << 24; //@line 34703
 $40 = $31 | (HEAPU8[$22 + 6 >> 0] | 0) << 8 | (HEAPU8[$22 + 7 >> 0] | 0); //@line 34712
 $42 = ($21 | 0) == 0 & 1; //@line 34714
 HEAP32[96441] = 0; //@line 34715
 HEAP32[96442] = 0; //@line 34715
 HEAP32[96443] = 0; //@line 34715
 HEAP32[96444] = 0; //@line 34715
 HEAP32[96442] = $42; //@line 34716
 HEAP32[96443] = $21 >>> 31; //@line 34718
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($40, $21); //@line 34724
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 34727
 return;
}
function __Z12op_1198_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $18 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 31286
 $4 = 651040 + ($1 << 2) | 0; //@line 31289
 $5 = HEAP32[$4 >> 2] | 0; //@line 31290
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 31296
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 31301
 $18 = HEAP32[162769] | 0; //@line 31304
 $27 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$18 + 2 >> 0] | 0) << 8 | (HEAPU8[$18 + 3 >> 0] | 0)) | 0; //@line 31313
 $28 = $11 << 24 >> 24; //@line 31315
 $30 = ($28 | 0) == 0 & 1; //@line 31317
 HEAP32[96441] = 0; //@line 31318
 HEAP32[96442] = 0; //@line 31318
 HEAP32[96443] = 0; //@line 31318
 HEAP32[96444] = 0; //@line 31318
 HEAP32[96442] = $30; //@line 31319
 HEAP32[96443] = $11 >>> 7 & 1; //@line 31322
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($27, $28); //@line 31328
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31331
 return;
}
function __Z12op_b030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0, $7 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 22041
 $5 = $4 + 2 | 0; //@line 22042
 HEAP32[162769] = $5; //@line 22043
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 22045
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 22052
 HEAP32[162769] = $4 + 4; //@line 22054
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 22055
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 22061
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22063
 $25 = $24 - $22 | 0; //@line 22064
 $sext$lobit = $24 >>> 7 & 1; //@line 22068
 $sext32$lobit = $25 >>> 7 & 1; //@line 22070
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 22074
 HEAP32[96444] = ($22 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 22079
 HEAP32[96441] = ($22 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 22084
 HEAP32[96443] = $sext32$lobit; //@line 22085
 return;
}
function __Z12op_90bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit36 = 0, $$lobit37 = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $32 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 24006
 $$cast = $4; //@line 24011
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 24020
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 24025
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 24026
 $24 = HEAP32[$23 >> 2] | 0; //@line 24027
 $25 = $24 - $22 | 0; //@line 24028
 $$lobit36 = $24 >>> 31; //@line 24030
 $$lobit37 = $25 >>> 31; //@line 24031
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 24034
 HEAP32[96444] = ($$lobit37 ^ $$lobit36) & ($$lobit36 ^ $22 >>> 31); //@line 24038
 $32 = $24 >>> 0 < $22 >>> 0 & 1; //@line 24040
 HEAP32[96441] = $32; //@line 24041
 HEAP32[96445] = $32; //@line 24042
 HEAP32[96443] = $$lobit37; //@line 24043
 HEAP32[$23 >> 2] = $25; //@line 24044
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24047
 return;
}
function __Z12op_8100_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$neg = 0, $10 = 0, $14 = 0, $16 = 0, $20 = 0, $22 = 0, $26 = 0, $35 = 0, $37 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 15613
 $7 = HEAP32[$6 >> 2] | 0; //@line 15614
 $8 = $7 << 24 >> 24; //@line 15616
 $10 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << 24 >> 24; //@line 15619
 $14 = (HEAP32[96445] | 0) != 0; //@line 15623
 $$neg = $14 << 31 >> 31; //@line 15625
 $16 = ($8 & 15) - ($10 & 15) + $$neg | 0; //@line 15626
 $20 = $16 + (($8 & 240) - ($10 & 240)) | 0; //@line 15630
 $22 = ($16 & 240 | 0) == 0; //@line 15632
 $$ = $22 ? $20 : $20 + -6 | 0; //@line 15634
 $26 = ($8 & 255) - ($10 & 255) | 0; //@line 15637
 $35 = ($26 + $$neg + ($22 ? 0 : 1018) & 768 | 0) != 0 & 1; //@line 15648
 HEAP32[96441] = $35; //@line 15649
 HEAP32[96445] = $35; //@line 15650
 $37 = (($26 - ($14 & 1) & 256 | 0) == 0 ? $$ : $$ + 160 | 0) & 255; //@line 15652
 HEAP32[96442] = ($37 | 0) == 0 & HEAP32[96442]; //@line 15656
 HEAP32[$6 >> 2] = $37 | $7 & -256; //@line 15659
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15662
 return;
}
function __Z12op_1120_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $19 = 0, $20 = 0, $22 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 24977
 $3 = $0 >>> 9 & 7; //@line 24979
 $4 = 651040 + ($1 << 2) | 0; //@line 24980
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 24984
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 24990
 HEAP32[$4 >> 2] = $8; //@line 24991
 $15 = 651040 + ($3 << 2) | 0; //@line 24992
 $19 = (HEAP32[$15 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 24996
 HEAP32[$15 >> 2] = $19; //@line 24997
 $20 = $14 << 24 >> 24; //@line 24999
 $22 = ($20 | 0) == 0 & 1; //@line 25001
 HEAP32[96441] = 0; //@line 25002
 HEAP32[96442] = 0; //@line 25002
 HEAP32[96443] = 0; //@line 25002
 HEAP32[96444] = 0; //@line 25002
 HEAP32[96442] = $22; //@line 25003
 HEAP32[96443] = $14 >>> 7 & 1; //@line 25006
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($19, $20); //@line 25012
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25015
 return;
}
function __Z12op_b0fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit34 = 0, $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 26083
 $4 = $3 + 2 | 0; //@line 26084
 HEAP32[162769] = $4; //@line 26085
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 26090
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 26097
 HEAP32[162769] = $3 + 4; //@line 26099
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 26100
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 26106
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26108
 $26 = $23 << 16 >> 16; //@line 26110
 $27 = $25 - $26 | 0; //@line 26111
 $$lobit = $25 >>> 31; //@line 26114
 $$lobit34 = $27 >>> 31; //@line 26115
 HEAP32[96442] = ($27 | 0) == 0 & 1; //@line 26118
 HEAP32[96444] = ($23 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit34 | 0) != ($$lobit | 0) & 1; //@line 26123
 HEAP32[96441] = $25 >>> 0 < $26 >>> 0 & 1; //@line 26126
 HEAP32[96443] = $$lobit34; //@line 26127
 return;
}
function __Z12op_51b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $14 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $36 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6303
 $5 = HEAP32[162769] | 0; //@line 6304
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 6313
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 6322
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 6324
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 6327
 $29 = $28 - $4 | 0; //@line 6328
 $$lobit33 = $28 >>> 31; //@line 6330
 $$lobit34 = $29 >>> 31; //@line 6331
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 6334
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $4 >>> 31); //@line 6338
 $36 = $28 >>> 0 < $4 >>> 0 & 1; //@line 6340
 HEAP32[96441] = $36; //@line 6341
 HEAP32[96445] = $36; //@line 6342
 HEAP32[96443] = $$lobit34; //@line 6343
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 6347
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6350
 return;
}
function __Z12op_1158_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $18 = 0, $28 = 0, $29 = 0, $31 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 25482
 $4 = 651040 + ($1 << 2) | 0; //@line 25485
 $5 = HEAP32[$4 >> 2] | 0; //@line 25486
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 25492
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 25497
 $18 = HEAP32[162769] | 0; //@line 25500
 $28 = (((HEAPU8[$18 + 2 >> 0] | 0) << 8 | (HEAPU8[$18 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25511
 $29 = $11 << 24 >> 24; //@line 25513
 $31 = ($29 | 0) == 0 & 1; //@line 25515
 HEAP32[96441] = 0; //@line 25516
 HEAP32[96442] = 0; //@line 25516
 HEAP32[96443] = 0; //@line 25516
 HEAP32[96444] = 0; //@line 25516
 HEAP32[96442] = $31; //@line 25517
 HEAP32[96443] = $11 >>> 7 & 1; //@line 25520
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, $29); //@line 25526
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25529
 return;
}
function __Z11op_450_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $21 = 0, $23 = 0, $32 = 0, $5 = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 10745
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10748
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10753
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10755
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 10757
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 10761
 $21 = ($18 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 10766
 $23 = $18 >>> 15; //@line 10768
 $sext34$lobit = $21 >>> 15 & 1; //@line 10771
 HEAP32[96442] = ($21 & 65535 | 0) == 0 & 1; //@line 10775
 HEAP32[96444] = ($sext34$lobit ^ $23 & 1) & ($23 ^ $5 >>> 7); //@line 10779
 $32 = $10 >>> 0 > ($18 & 65535) >>> 0 & 1; //@line 10782
 HEAP32[96441] = $32; //@line 10783
 HEAP32[96445] = $32; //@line 10784
 HEAP32[96443] = $sext34$lobit; //@line 10785
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $21); //@line 10789
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10792
 return;
}
function __Z12op_4430_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $30 = 0, $5 = 0, $sext26$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 47027
 $3 = $2 + 2 | 0; //@line 47028
 HEAP32[162769] = $3; //@line 47029
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47031
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 47038
 HEAP32[162769] = $2 + 4; //@line 47040
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 47041
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 47043
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 47047
 $22 = 0 - ($20 << 24 >> 24) | 0; //@line 47050
 $sext26$lobit = $22 >>> 7 & 1; //@line 47053
 HEAP32[96442] = ($22 & 255 | 0) == 0 & 1; //@line 47057
 HEAP32[96444] = $sext26$lobit & $20 >>> 7; //@line 47059
 $30 = ($20 & 255 | 0) != 0 & 1; //@line 47062
 HEAP32[96441] = $30; //@line 47063
 HEAP32[96445] = $30; //@line 47064
 HEAP32[96443] = $sext26$lobit; //@line 47065
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $22); //@line 47069
 return;
}
function __Z12op_20fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 29509
 $4 = $3 + 2 | 0; //@line 29510
 HEAP32[162769] = $4; //@line 29511
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 29516
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 29523
 HEAP32[162769] = $3 + 4; //@line 29525
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 29526
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 29531
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29532
 $24 = HEAP32[$23 >> 2] | 0; //@line 29533
 HEAP32[$23 >> 2] = $24 + 4; //@line 29535
 $27 = ($22 | 0) == 0 & 1; //@line 29537
 HEAP32[96441] = 0; //@line 29538
 HEAP32[96442] = 0; //@line 29538
 HEAP32[96443] = 0; //@line 29538
 HEAP32[96444] = 0; //@line 29538
 HEAP32[96442] = $27; //@line 29539
 HEAP32[96443] = $22 >>> 31; //@line 29541
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $22); //@line 29547
 return;
}
function __Z12op_9178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $23 = 0, $25 = 0, $35 = 0, $4 = 0, $5 = 0, $sext35$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20861
 $5 = HEAP32[162769] | 0; //@line 20862
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 20872
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 20874
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 20878
 $23 = ($20 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 20883
 $25 = $20 >>> 15; //@line 20885
 $sext35$lobit = $23 >>> 15 & 1; //@line 20888
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 20892
 HEAP32[96444] = ($sext35$lobit ^ $25 & 1) & ($25 ^ $4 >>> 15); //@line 20896
 $35 = ($4 & 65535) >>> 0 > ($20 & 65535) >>> 0 & 1; //@line 20900
 HEAP32[96441] = $35; //@line 20901
 HEAP32[96445] = $35; //@line 20902
 HEAP32[96443] = $sext35$lobit; //@line 20903
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 20907
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 20910
 return;
}
function __Z12op_9160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $17 = 0, $19 = 0, $29 = 0, $5 = 0, $6 = 0, $8 = 0, $sext40$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20679
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 20680
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 20682
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 20684
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 20688
 HEAP32[$6 >> 2] = $8; //@line 20689
 $17 = ($14 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 20694
 $19 = $14 >>> 15; //@line 20696
 $sext40$lobit = $17 >>> 15 & 1; //@line 20699
 HEAP32[96442] = ($17 & 65535 | 0) == 0 & 1; //@line 20703
 HEAP32[96444] = ($sext40$lobit ^ $19 & 1) & ($19 ^ $5 >>> 15); //@line 20707
 $29 = ($5 & 65535) >>> 0 > ($14 & 65535) >>> 0 & 1; //@line 20711
 HEAP32[96441] = $29; //@line 20712
 HEAP32[96445] = $29; //@line 20713
 HEAP32[96443] = $sext40$lobit; //@line 20714
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $17); //@line 20718
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20721
 return;
}
function __Z12op_313b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44608
 $$cast = $4; //@line 44613
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44622
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 44628
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 44629
 $26 = (HEAP32[$24 >> 2] | 0) + -2 | 0; //@line 44631
 HEAP32[$24 >> 2] = $26; //@line 44632
 $27 = $23 << 16 >> 16; //@line 44634
 $29 = ($27 | 0) == 0 & 1; //@line 44636
 HEAP32[96441] = 0; //@line 44637
 HEAP32[96442] = 0; //@line 44637
 HEAP32[96443] = 0; //@line 44637
 HEAP32[96444] = 0; //@line 44637
 HEAP32[96442] = $29; //@line 44638
 HEAP32[96443] = $23 >>> 15 & 1; //@line 44641
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 44647
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44650
 return;
}
function __Z12op_21a0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 33158
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 33160
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 33165
 HEAP32[$4 >> 2] = $6; //@line 33166
 $12 = HEAP32[162769] | 0; //@line 33167
 $13 = $12 + 2 | 0; //@line 33168
 HEAP32[162769] = $13; //@line 33169
 $15 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33171
 $22 = (HEAPU8[$13 >> 0] | 0) << 8 | (HEAPU8[$12 + 3 >> 0] | 0); //@line 33178
 HEAP32[162769] = $12 + 4; //@line 33180
 $24 = __Z15get_disp_ea_020jj($15, $22) | 0; //@line 33181
 $26 = ($11 | 0) == 0 & 1; //@line 33183
 HEAP32[96441] = 0; //@line 33184
 HEAP32[96442] = 0; //@line 33184
 HEAP32[96443] = 0; //@line 33184
 HEAP32[96444] = 0; //@line 33184
 HEAP32[96442] = $26; //@line 33185
 HEAP32[96443] = $11 >>> 31; //@line 33187
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $11); //@line 33193
 return;
}
function __Z12op_10e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $20 = 0, $22 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 24442
 $3 = $0 >>> 9 & 7; //@line 24444
 $4 = 651040 + ($1 << 2) | 0; //@line 24445
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 24449
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 24455
 HEAP32[$4 >> 2] = $8; //@line 24456
 $15 = 651040 + ($3 << 2) | 0; //@line 24457
 $16 = HEAP32[$15 >> 2] | 0; //@line 24458
 HEAP32[$15 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $16; //@line 24462
 $20 = $14 << 24 >> 24; //@line 24464
 $22 = ($20 | 0) == 0 & 1; //@line 24466
 HEAP32[96441] = 0; //@line 24467
 HEAP32[96442] = 0; //@line 24467
 HEAP32[96443] = 0; //@line 24467
 HEAP32[96444] = 0; //@line 24467
 HEAP32[96442] = $22; //@line 24468
 HEAP32[96443] = $14 >>> 7 & 1; //@line 24471
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, $20); //@line 24477
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24480
 return;
}
function __Z12op_21b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $19 = 0, $21 = 0, $28 = 0, $3 = 0, $30 = 0, $32 = 0;
 $3 = HEAP32[162769] | 0; //@line 33317
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 33327
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 33332
 $18 = HEAP32[162769] | 0; //@line 33333
 $19 = $18 + 4 | 0; //@line 33334
 HEAP32[162769] = $19; //@line 33335
 $21 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33337
 $28 = (HEAPU8[$19 >> 0] | 0) << 8 | (HEAPU8[$18 + 5 >> 0] | 0); //@line 33344
 HEAP32[162769] = $18 + 6; //@line 33346
 $30 = __Z15get_disp_ea_020jj($21, $28) | 0; //@line 33347
 $32 = ($17 | 0) == 0 & 1; //@line 33349
 HEAP32[96441] = 0; //@line 33350
 HEAP32[96442] = 0; //@line 33350
 HEAP32[96443] = 0; //@line 33350
 HEAP32[96444] = 0; //@line 33350
 HEAP32[96442] = $32; //@line 33351
 HEAP32[96443] = $17 >>> 31; //@line 33353
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, $17); //@line 33359
 return;
}
function __Z12op_1130_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 30964
 $6 = HEAP32[162769] | 0; //@line 30967
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 30976
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 30982
 $22 = 651040 + ($3 << 2) | 0; //@line 30983
 $26 = (HEAP32[$22 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 30987
 HEAP32[$22 >> 2] = $26; //@line 30988
 $27 = $21 << 24 >> 24; //@line 30990
 $29 = ($27 | 0) == 0 & 1; //@line 30992
 HEAP32[96441] = 0; //@line 30993
 HEAP32[96442] = 0; //@line 30993
 HEAP32[96443] = 0; //@line 30993
 HEAP32[96444] = 0; //@line 30993
 HEAP32[96442] = $29; //@line 30994
 HEAP32[96443] = $21 >>> 7 & 1; //@line 30997
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $27); //@line 31003
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31006
 return;
}
function __Z11op_2b0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 9457
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9475
 $21 = $2 + 6 | 0; //@line 9476
 HEAP32[162769] = $21; //@line 9477
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9479
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 9486
 HEAP32[162769] = $2 + 8; //@line 9488
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 9489
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 9491
 $38 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0) & $20; //@line 9495
 $40 = ($38 | 0) == 0 & 1; //@line 9497
 HEAP32[96441] = 0; //@line 9498
 HEAP32[96442] = 0; //@line 9498
 HEAP32[96443] = 0; //@line 9498
 HEAP32[96444] = 0; //@line 9498
 HEAP32[96442] = $40; //@line 9499
 HEAP32[96443] = $38 >>> 31; //@line 9501
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 9505
 return;
}
function __Z10op_b0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 5723
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5741
 $21 = $2 + 6 | 0; //@line 5742
 HEAP32[162769] = $21; //@line 5743
 $23 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5745
 $30 = (HEAPU8[$21 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0); //@line 5752
 HEAP32[162769] = $2 + 8; //@line 5754
 $32 = __Z15get_disp_ea_020jj($23, $30) | 0; //@line 5755
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 5757
 $38 = $20 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0); //@line 5761
 $40 = ($38 | 0) == 0 & 1; //@line 5763
 HEAP32[96441] = 0; //@line 5764
 HEAP32[96442] = 0; //@line 5764
 HEAP32[96443] = 0; //@line 5764
 HEAP32[96444] = 0; //@line 5764
 HEAP32[96442] = $40; //@line 5765
 HEAP32[96443] = $38 >>> 31; //@line 5767
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 5771
 return;
}
function __Z12op_2130_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 29826
 $5 = $4 + 2 | 0; //@line 29827
 HEAP32[162769] = $5; //@line 29828
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29830
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 29837
 HEAP32[162769] = $4 + 4; //@line 29839
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 29840
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 29845
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29846
 $24 = (HEAP32[$22 >> 2] | 0) + -4 | 0; //@line 29848
 HEAP32[$22 >> 2] = $24; //@line 29849
 $26 = ($21 | 0) == 0 & 1; //@line 29851
 HEAP32[96441] = 0; //@line 29852
 HEAP32[96442] = 0; //@line 29852
 HEAP32[96443] = 0; //@line 29852
 HEAP32[96444] = 0; //@line 29852
 HEAP32[96442] = $26; //@line 29853
 HEAP32[96443] = $21 >>> 31; //@line 29855
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $21); //@line 29861
 return;
}
function __Z12op_d050_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $5 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 31971
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 31977
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31978
 $13 = HEAP32[$12 >> 2] | 0; //@line 31979
 $14 = $13 << 16 >> 16; //@line 31981
 $16 = $14 + ($11 << 16 >> 16) | 0; //@line 31984
 $19 = $16 >>> 15; //@line 31988
 $sext39$lobit = $19 & 1; //@line 31989
 $sext39$mask = $16 & 65535; //@line 31990
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 31993
 HEAP32[96444] = ($sext39$lobit ^ $13 >>> 15 & 1) & ($19 ^ $11 >>> 15); //@line 31997
 $29 = ($14 & 65535 ^ 65535) >>> 0 < ($11 & 65535) >>> 0 & 1; //@line 32002
 HEAP32[96441] = $29; //@line 32003
 HEAP32[96445] = $29; //@line 32004
 HEAP32[96443] = $sext39$lobit; //@line 32005
 HEAP32[$12 >> 2] = $13 & -65536 | $sext39$mask; //@line 32008
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32011
 return;
}
function __Z12op_1139_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $27 = 0, $28 = 0, $3 = 0, $32 = 0, $33 = 0, $35 = 0;
 $2 = $0 >>> 9 & 7; //@line 25182
 $3 = HEAP32[162769] | 0; //@line 25183
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 25192
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 25207
 $28 = 651040 + ($2 << 2) | 0; //@line 25208
 $32 = (HEAP32[$28 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 25212
 HEAP32[$28 >> 2] = $32; //@line 25213
 $33 = $27 << 24 >> 24; //@line 25215
 $35 = ($33 | 0) == 0 & 1; //@line 25217
 HEAP32[96441] = 0; //@line 25218
 HEAP32[96442] = 0; //@line 25218
 HEAP32[96443] = 0; //@line 25218
 HEAP32[96444] = 0; //@line 25218
 HEAP32[96442] = $35; //@line 25219
 HEAP32[96443] = $27 >>> 7 & 1; //@line 25222
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($32, $33); //@line 25228
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 25231
 return;
}
function __Z12op_b188_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit40 = 0, $$lobit41 = 0, $10 = 0, $13 = 0, $14 = 0, $19 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 27010
 $5 = HEAP32[$4 >> 2] | 0; //@line 27011
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27016
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 27019
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 27020
 $14 = HEAP32[$13 >> 2] | 0; //@line 27021
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 27026
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 4; //@line 27029
 $22 = $19 - $10 | 0; //@line 27030
 $$lobit40 = $19 >>> 31; //@line 27032
 $$lobit41 = $22 >>> 31; //@line 27033
 HEAP32[96442] = ($22 | 0) == 0 & 1; //@line 27036
 HEAP32[96444] = ($10 >>> 31 | 0) != ($$lobit40 | 0) & ($$lobit41 | 0) != ($$lobit40 | 0) & 1; //@line 27041
 HEAP32[96441] = $19 >>> 0 < $10 >>> 0 & 1; //@line 27044
 HEAP32[96443] = $$lobit41; //@line 27045
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27048
 return;
}
function __Z12op_90ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit34 = 0, $$lobit35 = 0, $18 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 19359
 $$cast = $4; //@line 19361
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 19375
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 19380
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19381
 $25 = HEAP32[$24 >> 2] | 0; //@line 19382
 $26 = $25 - $23 | 0; //@line 19383
 $$lobit34 = $25 >>> 31; //@line 19385
 $$lobit35 = $26 >>> 31; //@line 19386
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 19389
 HEAP32[96444] = ($$lobit35 ^ $$lobit34) & ($$lobit34 ^ $23 >>> 31); //@line 19393
 $33 = $25 >>> 0 < $23 >>> 0 & 1; //@line 19395
 HEAP32[96441] = $33; //@line 19396
 HEAP32[96445] = $33; //@line 19397
 HEAP32[96443] = $$lobit35; //@line 19398
 HEAP32[$24 >> 2] = $26; //@line 19399
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19402
 return;
}
function __Z12op_b0f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit35 = 0, $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 25864
 $5 = $4 + 2 | 0; //@line 25865
 HEAP32[162769] = $5; //@line 25866
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25868
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 25875
 HEAP32[162769] = $4 + 4; //@line 25877
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 25878
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 25884
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25886
 $25 = $22 << 16 >> 16; //@line 25888
 $26 = $24 - $25 | 0; //@line 25889
 $$lobit = $24 >>> 31; //@line 25892
 $$lobit35 = $26 >>> 31; //@line 25893
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 25896
 HEAP32[96444] = ($22 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit35 | 0) != ($$lobit | 0) & 1; //@line 25901
 HEAP32[96441] = $24 >>> 0 < $25 >>> 0 & 1; //@line 25904
 HEAP32[96443] = $$lobit35; //@line 25905
 return;
}
function __Z12op_11a0_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $17 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 31340
 $4 = 651040 + ($1 << 2) | 0; //@line 31343
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 31347
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 31353
 HEAP32[$4 >> 2] = $8; //@line 31354
 $17 = HEAP32[162769] | 0; //@line 31357
 $26 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$17 + 2 >> 0] | 0) << 8 | (HEAPU8[$17 + 3 >> 0] | 0)) | 0; //@line 31366
 $27 = $14 << 24 >> 24; //@line 31368
 $29 = ($27 | 0) == 0 & 1; //@line 31370
 HEAP32[96441] = 0; //@line 31371
 HEAP32[96442] = 0; //@line 31371
 HEAP32[96443] = 0; //@line 31371
 HEAP32[96444] = 0; //@line 31371
 HEAP32[96442] = $29; //@line 31372
 HEAP32[96443] = $14 >>> 7 & 1; //@line 31375
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $27); //@line 31381
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31384
 return;
}
function __Z12op_1128_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 25026
 $6 = HEAP32[162769] | 0; //@line 25029
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 25040
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 25046
 $23 = 651040 + ($3 << 2) | 0; //@line 25047
 $27 = (HEAP32[$23 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 25051
 HEAP32[$23 >> 2] = $27; //@line 25052
 $28 = $22 << 24 >> 24; //@line 25054
 $30 = ($28 | 0) == 0 & 1; //@line 25056
 HEAP32[96441] = 0; //@line 25057
 HEAP32[96442] = 0; //@line 25057
 HEAP32[96443] = 0; //@line 25057
 HEAP32[96444] = 0; //@line 25057
 HEAP32[96442] = $30; //@line 25058
 HEAP32[96443] = $22 >>> 7 & 1; //@line 25061
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($27, $28); //@line 25067
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25070
 return;
}
function __Z12op_ebc0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $30 = 0, $33 = 0, $36 = 0, $5 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 44390
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 44393
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 44399
 $11 = $sext >> 16; //@line 44400
 $14 = $sext >> 22; //@line 44403
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 44406
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 44411
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 44416
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 44421
 }
 $26 = $25 + 31 & 31; //@line 44424
 $33 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << ($30 & 31) >>> ($26 ^ 31); //@line 44430
 $36 = ($33 & 1 << $26 | 0) != 0; //@line 44433
 HEAP32[96443] = $36 & 1; //@line 44435
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 44438
 HEAP32[96444] = 0; //@line 44439
 HEAP32[96441] = 0; //@line 44440
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = ($36 ? -2 << $26 : 0) | $33; //@line 44447
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44450
 return;
}
function __Z12op_30fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44504
 $$cast = $4; //@line 44509
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44518
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 44524
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 44525
 $25 = HEAP32[$24 >> 2] | 0; //@line 44526
 HEAP32[$24 >> 2] = $25 + 2; //@line 44528
 $27 = $23 << 16 >> 16; //@line 44530
 $29 = ($27 | 0) == 0 & 1; //@line 44532
 HEAP32[96441] = 0; //@line 44533
 HEAP32[96442] = 0; //@line 44533
 HEAP32[96443] = 0; //@line 44533
 HEAP32[96444] = 0; //@line 44533
 HEAP32[96442] = $29; //@line 44534
 HEAP32[96443] = $23 >>> 15 & 1; //@line 44537
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $27); //@line 44543
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44546
 return;
}
function __Z12op_10f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $27 = 0, $29 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 30855
 $6 = HEAP32[162769] | 0; //@line 30858
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 30867
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 30873
 $22 = 651040 + ($3 << 2) | 0; //@line 30874
 $23 = HEAP32[$22 >> 2] | 0; //@line 30875
 HEAP32[$22 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $23; //@line 30879
 $27 = $21 << 24 >> 24; //@line 30881
 $29 = ($27 | 0) == 0 & 1; //@line 30883
 HEAP32[96441] = 0; //@line 30884
 HEAP32[96442] = 0; //@line 30884
 HEAP32[96443] = 0; //@line 30884
 HEAP32[96444] = 0; //@line 30884
 HEAP32[96442] = $29; //@line 30885
 HEAP32[96443] = $21 >>> 7 & 1; //@line 30888
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, $27); //@line 30894
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30897
 return;
}
function __Z11op_6b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit30 = 0, $1 = 0, $19 = 0, $28 = 0, $30 = 0, $33 = 0, $34 = 0, $4 = 0, $42 = 0;
 $1 = HEAP32[162769] | 0; //@line 13538
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 13541
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 13556
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 13566
 $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 13568
 $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0; //@line 13571
 $34 = $33 + $19 | 0; //@line 13572
 $$lobit30 = $34 >>> 31; //@line 13575
 HEAP32[96442] = ($34 | 0) == 0 & 1; //@line 13578
 HEAP32[96444] = ($$lobit30 ^ $4 >>> 7) & ($$lobit30 ^ $33 >>> 31); //@line 13582
 $42 = $19 >>> 0 > ~$33 >>> 0 & 1; //@line 13585
 HEAP32[96441] = $42; //@line 13586
 HEAP32[96445] = $42; //@line 13587
 HEAP32[96443] = $$lobit30; //@line 13588
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, $34); //@line 13592
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 13595
 return;
}
function __Z12op_91b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $17 = 0, $19 = 0, $22 = 0, $23 = 0, $30 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24262
 $8 = HEAP32[162769] | 0; //@line 24265
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 24274
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 24276
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0; //@line 24279
 $23 = $22 - $5 | 0; //@line 24280
 $$lobit37 = $22 >>> 31; //@line 24282
 $$lobit38 = $23 >>> 31; //@line 24283
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 24286
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $5 >>> 31); //@line 24290
 $30 = $22 >>> 0 < $5 >>> 0 & 1; //@line 24292
 HEAP32[96441] = $30; //@line 24293
 HEAP32[96445] = $30; //@line 24294
 HEAP32[96443] = $$lobit38; //@line 24295
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 24299
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24302
 return;
}
function __Z12op_9138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $23 = 0, $25 = 0, $35 = 0, $4 = 0, $5 = 0, $sext31$lobit = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20320
 $5 = HEAP32[162769] | 0; //@line 20321
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 20331
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 20333
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 20337
 $23 = ($20 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 20342
 $25 = $20 >>> 7; //@line 20344
 $sext31$lobit = $23 >>> 7 & 1; //@line 20347
 HEAP32[96442] = ($23 & 255 | 0) == 0 & 1; //@line 20351
 HEAP32[96444] = ($sext31$lobit ^ $25 & 1) & ($25 ^ $4 >>> 7); //@line 20355
 $35 = ($4 & 255) >>> 0 > ($20 & 255) >>> 0 & 1; //@line 20359
 HEAP32[96441] = $35; //@line 20360
 HEAP32[96445] = $35; //@line 20361
 HEAP32[96443] = $sext31$lobit; //@line 20362
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $23); //@line 20366
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 20369
 return;
}
function __Z12op_21bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $25 = 0, $34 = 0, $36 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 43843
 $$cast = $4; //@line 43848
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 43857
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 43862
 $25 = HEAP32[162769] | 0; //@line 43865
 $34 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) | 0; //@line 43874
 $36 = ($22 | 0) == 0 & 1; //@line 43876
 HEAP32[96441] = 0; //@line 43877
 HEAP32[96442] = 0; //@line 43877
 HEAP32[96443] = 0; //@line 43877
 HEAP32[96444] = 0; //@line 43877
 HEAP32[96442] = $36; //@line 43878
 HEAP32[96443] = $22 >>> 31; //@line 43880
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $22); //@line 43886
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43889
 return;
}
function __Z12op_20f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 29316
 $5 = $4 + 2 | 0; //@line 29317
 HEAP32[162769] = $5; //@line 29318
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29320
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 29327
 HEAP32[162769] = $4 + 4; //@line 29329
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 29330
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 29335
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29336
 $23 = HEAP32[$22 >> 2] | 0; //@line 29337
 HEAP32[$22 >> 2] = $23 + 4; //@line 29339
 $26 = ($21 | 0) == 0 & 1; //@line 29341
 HEAP32[96441] = 0; //@line 29342
 HEAP32[96442] = 0; //@line 29342
 HEAP32[96443] = 0; //@line 29342
 HEAP32[96444] = 0; //@line 29342
 HEAP32[96442] = $26; //@line 29343
 HEAP32[96443] = $21 >>> 31; //@line 29345
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 29351
 return;
}
function __Z12op_10f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $33 = 0, $35 = 0;
 $2 = $0 >>> 9 & 7; //@line 24647
 $3 = HEAP32[162769] | 0; //@line 24648
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 24657
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 24672
 $28 = 651040 + ($2 << 2) | 0; //@line 24673
 $29 = HEAP32[$28 >> 2] | 0; //@line 24674
 HEAP32[$28 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $29; //@line 24678
 $33 = $27 << 24 >> 24; //@line 24680
 $35 = ($33 | 0) == 0 & 1; //@line 24682
 HEAP32[96441] = 0; //@line 24683
 HEAP32[96442] = 0; //@line 24683
 HEAP32[96443] = 0; //@line 24683
 HEAP32[96444] = 0; //@line 24683
 HEAP32[96442] = $35; //@line 24684
 HEAP32[96443] = $27 >>> 7 & 1; //@line 24687
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($29, $33); //@line 24693
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 24696
 return;
}
function _fclose($0) {
 $0 = $0 | 0;
 var $$pre = 0, $10 = 0, $15 = 0, $20 = 0, $24 = 0, $26 = 0, $29 = 0, $7 = 0, $8 = 0;
 if ((HEAP32[$0 + 76 >> 2] | 0) > -1) {
  $29 = ___lockfile($0) | 0; //@line 244
 } else {
  $29 = 0; //@line 246
 }
 ___unlist_locked_file($0); //@line 248
 $7 = (HEAP32[$0 >> 2] & 1 | 0) != 0; //@line 251
 if (!$7) {
  $8 = ___ofl_lock() | 0; //@line 253
  $10 = HEAP32[$0 + 52 >> 2] | 0; //@line 255
  $$pre = $0 + 56 | 0; //@line 258
  if ($10 | 0) {
   HEAP32[$10 + 56 >> 2] = HEAP32[$$pre >> 2]; //@line 262
  }
  $15 = HEAP32[$$pre >> 2] | 0; //@line 264
  if ($15 | 0) {
   HEAP32[$15 + 52 >> 2] = $10; //@line 268
  }
  if ((HEAP32[$8 >> 2] | 0) == ($0 | 0)) {
   HEAP32[$8 >> 2] = $15; //@line 273
  }
  ___ofl_unlock(); //@line 275
 }
 $20 = _fflush($0) | 0; //@line 277
 $24 = FUNCTION_TABLE_ii[HEAP32[$0 + 12 >> 2] & 127]($0) | 0 | $20; //@line 281
 $26 = HEAP32[$0 + 92 >> 2] | 0; //@line 283
 if ($26 | 0) {
  _free($26); //@line 286
 }
 if ($7) {
  if ($29 | 0) {
   ___unlockfile($0); //@line 291
  }
 } else {
  _free($0); //@line 294
 }
 return $24 | 0; //@line 296
}
function __Z12op_51b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $17 = 0, $19 = 0, $22 = 0, $23 = 0, $30 = 0, $4 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 11650
 $8 = HEAP32[162769] | 0; //@line 11654
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 11663
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 11665
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0; //@line 11668
 $23 = $22 - $4 | 0; //@line 11669
 $$lobit37 = $22 >>> 31; //@line 11671
 $$lobit38 = $23 >>> 31; //@line 11672
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 11675
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $4 >>> 31); //@line 11679
 $30 = $22 >>> 0 < $4 >>> 0 & 1; //@line 11681
 HEAP32[96441] = $30; //@line 11682
 HEAP32[96445] = $30; //@line 11683
 HEAP32[96443] = $$lobit38; //@line 11684
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 11688
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11691
 return;
}
function __Z12op_5158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $30 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0, $sext39$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5594
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 5596
 $7 = HEAP32[$6 >> 2] | 0; //@line 5597
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 5599
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 5603
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 5606
 $18 = ($13 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5611
 $20 = $13 >>> 15; //@line 5613
 $sext39$lobit = $18 >>> 15 & 1; //@line 5616
 HEAP32[96442] = ($18 & 65535 | 0) == 0 & 1; //@line 5620
 HEAP32[96444] = ($sext39$lobit ^ $20 & 1) & ($20 ^ $4 >>> 15); //@line 5624
 $30 = ($4 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 5628
 HEAP32[96441] = $30; //@line 5629
 HEAP32[96445] = $30; //@line 5630
 HEAP32[96443] = $sext39$lobit; //@line 5631
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $18); //@line 5635
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5638
 return;
}
function __Z12op_313a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 37192
 $$cast = $4; //@line 37194
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 37208
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 37214
 $25 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37215
 $27 = (HEAP32[$25 >> 2] | 0) + -2 | 0; //@line 37217
 HEAP32[$25 >> 2] = $27; //@line 37218
 $28 = $24 << 16 >> 16; //@line 37220
 $30 = ($28 | 0) == 0 & 1; //@line 37222
 HEAP32[96441] = 0; //@line 37223
 HEAP32[96442] = 0; //@line 37223
 HEAP32[96443] = 0; //@line 37223
 HEAP32[96444] = 0; //@line 37223
 HEAP32[96442] = $30; //@line 37224
 HEAP32[96443] = $24 >>> 15 & 1; //@line 37227
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($27, $28); //@line 37233
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37236
 return;
}
function __Z12op_1160_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $17 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 25538
 $4 = 651040 + ($1 << 2) | 0; //@line 25541
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 25545
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 25551
 HEAP32[$4 >> 2] = $8; //@line 25552
 $17 = HEAP32[162769] | 0; //@line 25555
 $27 = (((HEAPU8[$17 + 2 >> 0] | 0) << 8 | (HEAPU8[$17 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25566
 $28 = $14 << 24 >> 24; //@line 25568
 $30 = ($28 | 0) == 0 & 1; //@line 25570
 HEAP32[96441] = 0; //@line 25571
 HEAP32[96442] = 0; //@line 25571
 HEAP32[96443] = 0; //@line 25571
 HEAP32[96444] = 0; //@line 25571
 HEAP32[96442] = $30; //@line 25572
 HEAP32[96443] = $14 >>> 7 & 1; //@line 25575
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($27, $28); //@line 25581
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25584
 return;
}
function __Z12op_31fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $32 = 0, $34 = 0;
 $2 = HEAP32[162769] | 0; //@line 45488
 $$cast = $2; //@line 45493
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45502
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 45508
 $22 = HEAP32[162769] | 0; //@line 45509
 $31 = ((HEAPU8[$22 + 4 >> 0] | 0) << 8 | (HEAPU8[$22 + 5 >> 0] | 0)) << 16 >> 16; //@line 45519
 $32 = $21 << 16 >> 16; //@line 45521
 $34 = ($32 | 0) == 0 & 1; //@line 45523
 HEAP32[96441] = 0; //@line 45524
 HEAP32[96442] = 0; //@line 45524
 HEAP32[96443] = 0; //@line 45524
 HEAP32[96444] = 0; //@line 45524
 HEAP32[96442] = $34; //@line 45525
 HEAP32[96443] = $21 >>> 15 & 1; //@line 45528
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($31, $32); //@line 45534
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45537
 return;
}
function __Z12op_31b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $24 = 0, $33 = 0, $34 = 0, $36 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 45083
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 45092
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 45098
 $24 = HEAP32[162769] | 0; //@line 45101
 $33 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) | 0; //@line 45110
 $34 = $21 << 16 >> 16; //@line 45112
 $36 = ($34 | 0) == 0 & 1; //@line 45114
 HEAP32[96441] = 0; //@line 45115
 HEAP32[96442] = 0; //@line 45115
 HEAP32[96443] = 0; //@line 45115
 HEAP32[96444] = 0; //@line 45115
 HEAP32[96442] = $36; //@line 45116
 HEAP32[96443] = $21 >>> 15 & 1; //@line 45119
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($33, $34); //@line 45125
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45128
 return;
}
function __Z12op_10e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $3 = 0, $30 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 24491
 $6 = HEAP32[162769] | 0; //@line 24494
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 24505
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 24511
 $23 = 651040 + ($3 << 2) | 0; //@line 24512
 $24 = HEAP32[$23 >> 2] | 0; //@line 24513
 HEAP32[$23 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $24; //@line 24517
 $28 = $22 << 24 >> 24; //@line 24519
 $30 = ($28 | 0) == 0 & 1; //@line 24521
 HEAP32[96441] = 0; //@line 24522
 HEAP32[96442] = 0; //@line 24522
 HEAP32[96443] = 0; //@line 24522
 HEAP32[96444] = 0; //@line 24522
 HEAP32[96442] = $30; //@line 24523
 HEAP32[96443] = $22 >>> 7 & 1; //@line 24526
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $28); //@line 24532
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24535
 return;
}
function __Z12op_11fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $32 = 0, $34 = 0;
 $2 = HEAP32[162769] | 0; //@line 31858
 $$cast = $2; //@line 31863
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 31872
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 31878
 $22 = HEAP32[162769] | 0; //@line 31879
 $31 = ((HEAPU8[$22 + 4 >> 0] | 0) << 8 | (HEAPU8[$22 + 5 >> 0] | 0)) << 16 >> 16; //@line 31889
 $32 = $21 << 24 >> 24; //@line 31891
 $34 = ($32 | 0) == 0 & 1; //@line 31893
 HEAP32[96441] = 0; //@line 31894
 HEAP32[96442] = 0; //@line 31894
 HEAP32[96443] = 0; //@line 31894
 HEAP32[96444] = 0; //@line 31894
 HEAP32[96442] = $34; //@line 31895
 HEAP32[96443] = $21 >>> 7 & 1; //@line 31898
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($31, $32); //@line 31904
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31907
 return;
}
function __Z12op_11b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $24 = 0, $33 = 0, $34 = 0, $36 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 31459
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 31468
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 31474
 $24 = HEAP32[162769] | 0; //@line 31477
 $33 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) | 0; //@line 31486
 $34 = $21 << 24 >> 24; //@line 31488
 $36 = ($34 | 0) == 0 & 1; //@line 31490
 HEAP32[96441] = 0; //@line 31491
 HEAP32[96442] = 0; //@line 31491
 HEAP32[96443] = 0; //@line 31491
 HEAP32[96444] = 0; //@line 31491
 HEAP32[96442] = $36; //@line 31492
 HEAP32[96443] = $21 >>> 7 & 1; //@line 31495
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($33, $34); //@line 31501
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31504
 return;
}
function __Z12op_91a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $31 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21223
 $8 = HEAP32[162769] | 0; //@line 21226
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 21237
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 21239
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 21242
 $24 = $23 - $5 | 0; //@line 21243
 $$lobit37 = $23 >>> 31; //@line 21245
 $$lobit38 = $24 >>> 31; //@line 21246
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 21249
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $5 >>> 31); //@line 21253
 $31 = $23 >>> 0 < $5 >>> 0 & 1; //@line 21255
 HEAP32[96441] = $31; //@line 21256
 HEAP32[96445] = $31; //@line 21257
 HEAP32[96443] = $$lobit38; //@line 21258
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 21262
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21265
 return;
}
function __Z12op_31b9_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $3 = 0, $30 = 0, $39 = 0, $40 = 0, $42 = 0;
 $3 = HEAP32[162769] | 0; //@line 45196
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 45205
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 45220
 $30 = HEAP32[162769] | 0; //@line 45223
 $39 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$30 + 6 >> 0] | 0) << 8 | (HEAPU8[$30 + 7 >> 0] | 0)) | 0; //@line 45232
 $40 = $27 << 16 >> 16; //@line 45234
 $42 = ($40 | 0) == 0 & 1; //@line 45236
 HEAP32[96441] = 0; //@line 45237
 HEAP32[96442] = 0; //@line 45237
 HEAP32[96443] = 0; //@line 45237
 HEAP32[96444] = 0; //@line 45237
 HEAP32[96442] = $42; //@line 45238
 HEAP32[96443] = $27 >>> 15 & 1; //@line 45241
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($39, $40); //@line 45247
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 45250
 return;
}
function __Z12op_217b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $25 = 0, $35 = 0, $37 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 43282
 $$cast = $4; //@line 43287
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 43296
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 43301
 $25 = HEAP32[162769] | 0; //@line 43304
 $35 = (((HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 43315
 $37 = ($22 | 0) == 0 & 1; //@line 43317
 HEAP32[96441] = 0; //@line 43318
 HEAP32[96442] = 0; //@line 43318
 HEAP32[96443] = 0; //@line 43318
 HEAP32[96444] = 0; //@line 43318
 HEAP32[96442] = $37; //@line 43319
 HEAP32[96443] = $22 >>> 31; //@line 43321
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($35, $22); //@line 43327
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43330
 return;
}
function __Z12op_e1b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$035 = 0, $11 = 0, $14 = 0, $15 = 0, $21 = 0, $22 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39863
 $7 = HEAP32[$6 >> 2] | 0; //@line 39864
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39865
 $$ = $8 >>> 0 > 32 ? $8 + -33 | 0 : $8; //@line 39868
 $11 = ($$ | 0) > 0; //@line 39869
 HEAP32[96441] = 0; //@line 39870
 HEAP32[96442] = 0; //@line 39870
 HEAP32[96443] = 0; //@line 39870
 HEAP32[96444] = 0; //@line 39870
 if ($11) {
  $14 = $7 >>> (32 - $$ | 0); //@line 39874
  $15 = $14 & 1; //@line 39875
  $21 = (HEAP32[96445] | $7 << 1) << $$ + -1 | $14 >>> 1; //@line 39881
  HEAP32[96445] = $15; //@line 39882
  $$035 = $21; //@line 39883
  $22 = $15; //@line 39883
 } else {
  $$035 = $7; //@line 39886
  $22 = HEAP32[96445] | 0; //@line 39886
 }
 HEAP32[96441] = $22; //@line 39888
 HEAP32[96442] = ($$035 | 0) == 0 & 1; //@line 39891
 HEAP32[96443] = $$035 >>> 31; //@line 39893
 HEAP32[$6 >> 2] = $$035; //@line 39894
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39897
 return;
}
function __Z12op_e0b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$038 = 0, $11 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38401
 $7 = HEAP32[$6 >> 2] | 0; //@line 38402
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38403
 $$ = $8 >>> 0 > 32 ? $8 + -33 | 0 : $8; //@line 38406
 $11 = ($$ | 0) > 0; //@line 38407
 HEAP32[96441] = 0; //@line 38408
 HEAP32[96442] = 0; //@line 38408
 HEAP32[96443] = 0; //@line 38408
 HEAP32[96444] = 0; //@line 38408
 if ($11) {
  $18 = $7 >>> ($$ + -1 | 0); //@line 38416
  $19 = $18 & 1; //@line 38417
  $21 = (HEAP32[96445] | $7 << 1) << 32 - $$ | $18 >>> 1; //@line 38419
  HEAP32[96445] = $19; //@line 38420
  $$038 = $21; //@line 38421
  $22 = $19; //@line 38421
 } else {
  $$038 = $7; //@line 38424
  $22 = HEAP32[96445] | 0; //@line 38424
 }
 HEAP32[96441] = $22; //@line 38426
 HEAP32[96442] = ($$038 | 0) == 0 & 1; //@line 38429
 HEAP32[96443] = $$038 >>> 31; //@line 38431
 HEAP32[$6 >> 2] = $$038; //@line 38432
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38435
 return;
}
function __Z12op_11b9_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $3 = 0, $30 = 0, $39 = 0, $40 = 0, $42 = 0;
 $3 = HEAP32[162769] | 0; //@line 31572
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 31581
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 31596
 $30 = HEAP32[162769] | 0; //@line 31599
 $39 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$30 + 6 >> 0] | 0) << 8 | (HEAPU8[$30 + 7 >> 0] | 0)) | 0; //@line 31608
 $40 = $27 << 24 >> 24; //@line 31610
 $42 = ($40 | 0) == 0 & 1; //@line 31612
 HEAP32[96441] = 0; //@line 31613
 HEAP32[96442] = 0; //@line 31613
 HEAP32[96443] = 0; //@line 31613
 HEAP32[96444] = 0; //@line 31613
 HEAP32[96442] = $42; //@line 31614
 HEAP32[96443] = $27 >>> 7 & 1; //@line 31617
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($39, $40); //@line 31623
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 31626
 return;
}
function __Z12op_d010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $5 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 31275
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 31281
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31282
 $13 = HEAP32[$12 >> 2] | 0; //@line 31283
 $14 = $13 << 24 >> 24; //@line 31285
 $16 = $14 + ($11 << 24 >> 24) | 0; //@line 31288
 $19 = $16 >>> 7; //@line 31292
 $sext35$lobit = $19 & 1; //@line 31293
 $sext35$mask = $16 & 255; //@line 31294
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 31297
 HEAP32[96444] = ($sext35$lobit ^ $13 >>> 7 & 1) & ($19 ^ $11 >>> 7); //@line 31301
 $29 = ($14 & 255 ^ 255) >>> 0 < ($11 & 255) >>> 0 & 1; //@line 31306
 HEAP32[96441] = $29; //@line 31307
 HEAP32[96445] = $29; //@line 31308
 HEAP32[96443] = $sext35$lobit; //@line 31309
 HEAP32[$12 >> 2] = $13 & -256 | $sext35$mask; //@line 31312
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31315
 return;
}
function __Z12op_31a8_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $25 = 0, $34 = 0, $35 = 0, $37 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 45022
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 45033
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 45039
 $25 = HEAP32[162769] | 0; //@line 45042
 $34 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) | 0; //@line 45051
 $35 = $22 << 16 >> 16; //@line 45053
 $37 = ($35 | 0) == 0 & 1; //@line 45055
 HEAP32[96441] = 0; //@line 45056
 HEAP32[96442] = 0; //@line 45056
 HEAP32[96443] = 0; //@line 45056
 HEAP32[96444] = 0; //@line 45056
 HEAP32[96442] = $37; //@line 45057
 HEAP32[96443] = $22 >>> 15 & 1; //@line 45060
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($34, $35); //@line 45066
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45069
 return;
}
function __Z12op_3170_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $24 = 0, $34 = 0, $35 = 0, $37 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 44664
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44673
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 44679
 $24 = HEAP32[162769] | 0; //@line 44682
 $34 = (((HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 44693
 $35 = $21 << 16 >> 16; //@line 44695
 $37 = ($35 | 0) == 0 & 1; //@line 44697
 HEAP32[96441] = 0; //@line 44698
 HEAP32[96442] = 0; //@line 44698
 HEAP32[96443] = 0; //@line 44698
 HEAP32[96444] = 0; //@line 44698
 HEAP32[96442] = $37; //@line 44699
 HEAP32[96443] = $21 >>> 15 & 1; //@line 44702
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($34, $35); //@line 44708
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 44711
 return;
}
function __Z12op_5178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $23 = 0, $25 = 0, $35 = 0, $4 = 0, $5 = 0, $sext35$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5833
 $5 = HEAP32[162769] | 0; //@line 5834
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 5844
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 5846
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 5850
 $23 = ($20 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5855
 $25 = $20 >>> 15; //@line 5857
 $sext35$lobit = $23 >>> 15 & 1; //@line 5860
 HEAP32[96442] = ($23 & 65535 | 0) == 0 & 1; //@line 5864
 HEAP32[96444] = ($sext35$lobit ^ $25 & 1) & ($25 ^ $4 >>> 15); //@line 5868
 $35 = ($4 & 65535) >>> 0 > ($20 & 65535) >>> 0 & 1; //@line 5872
 HEAP32[96441] = $35; //@line 5873
 HEAP32[96445] = $35; //@line 5874
 HEAP32[96443] = $sext35$lobit; //@line 5875
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 5879
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5882
 return;
}
function __Z12op_30fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $30 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36644
 $$cast = $4; //@line 36646
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 36660
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 36666
 $25 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36667
 $26 = HEAP32[$25 >> 2] | 0; //@line 36668
 HEAP32[$25 >> 2] = $26 + 2; //@line 36670
 $28 = $24 << 16 >> 16; //@line 36672
 $30 = ($28 | 0) == 0 & 1; //@line 36674
 HEAP32[96441] = 0; //@line 36675
 HEAP32[96442] = 0; //@line 36675
 HEAP32[96443] = 0; //@line 36675
 HEAP32[96444] = 0; //@line 36675
 HEAP32[96442] = $30; //@line 36676
 HEAP32[96443] = $24 >>> 15 & 1; //@line 36679
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $28); //@line 36685
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36688
 return;
}
function __Z12op_11a8_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $25 = 0, $34 = 0, $35 = 0, $37 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 31398
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 31409
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 31415
 $25 = HEAP32[162769] | 0; //@line 31418
 $34 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) | 0; //@line 31427
 $35 = $22 << 24 >> 24; //@line 31429
 $37 = ($35 | 0) == 0 & 1; //@line 31431
 HEAP32[96441] = 0; //@line 31432
 HEAP32[96442] = 0; //@line 31432
 HEAP32[96443] = 0; //@line 31432
 HEAP32[96444] = 0; //@line 31432
 HEAP32[96442] = $37; //@line 31433
 HEAP32[96443] = $22 >>> 7 & 1; //@line 31436
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, $35); //@line 31442
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31445
 return;
}
function __Z12op_1170_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $24 = 0, $34 = 0, $35 = 0, $37 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 31076
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 31085
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 31091
 $24 = HEAP32[162769] | 0; //@line 31094
 $34 = (((HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 31105
 $35 = $21 << 24 >> 24; //@line 31107
 $37 = ($35 | 0) == 0 & 1; //@line 31109
 HEAP32[96441] = 0; //@line 31110
 HEAP32[96442] = 0; //@line 31110
 HEAP32[96443] = 0; //@line 31110
 HEAP32[96444] = 0; //@line 31110
 HEAP32[96442] = $37; //@line 31111
 HEAP32[96443] = $21 >>> 7 & 1; //@line 31114
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($34, $35); //@line 31120
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31123
 return;
}
function __Z12op_5160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $17 = 0, $19 = 0, $29 = 0, $4 = 0, $6 = 0, $8 = 0, $sext40$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5650
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 5652
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 5654
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 5656
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 5660
 HEAP32[$6 >> 2] = $8; //@line 5661
 $17 = ($14 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5666
 $19 = $14 >>> 15; //@line 5668
 $sext40$lobit = $17 >>> 15 & 1; //@line 5671
 HEAP32[96442] = ($17 & 65535 | 0) == 0 & 1; //@line 5675
 HEAP32[96444] = ($sext40$lobit ^ $19 & 1) & ($19 ^ $4 >>> 15); //@line 5679
 $29 = ($4 & 65535) >>> 0 > ($14 & 65535) >>> 0 & 1; //@line 5683
 HEAP32[96441] = $29; //@line 5684
 HEAP32[96445] = $29; //@line 5685
 HEAP32[96443] = $sext40$lobit; //@line 5686
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $17); //@line 5690
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5693
 return;
}
function __Z12op_3179_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $3 = 0, $30 = 0, $40 = 0, $41 = 0, $43 = 0;
 $3 = HEAP32[162769] | 0; //@line 37768
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 37777
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 37792
 $30 = HEAP32[162769] | 0; //@line 37795
 $40 = (((HEAPU8[$30 + 6 >> 0] | 0) << 8 | (HEAPU8[$30 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37806
 $41 = $27 << 16 >> 16; //@line 37808
 $43 = ($41 | 0) == 0 & 1; //@line 37810
 HEAP32[96441] = 0; //@line 37811
 HEAP32[96442] = 0; //@line 37811
 HEAP32[96443] = 0; //@line 37811
 HEAP32[96444] = 0; //@line 37811
 HEAP32[96442] = $43; //@line 37812
 HEAP32[96443] = $27 >>> 15 & 1; //@line 37815
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($40, $41); //@line 37821
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 37824
 return;
}
function __Z12op_30bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 36154
 $4 = $3 + 2 | 0; //@line 36155
 HEAP32[162769] = $4; //@line 36156
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 36161
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 36168
 HEAP32[162769] = $3 + 4; //@line 36170
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 36171
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36177
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36179
 $26 = $23 << 16 >> 16; //@line 36181
 $28 = ($26 | 0) == 0 & 1; //@line 36183
 HEAP32[96441] = 0; //@line 36184
 HEAP32[96442] = 0; //@line 36184
 HEAP32[96443] = 0; //@line 36184
 HEAP32[96444] = 0; //@line 36184
 HEAP32[96442] = $28; //@line 36185
 HEAP32[96443] = $23 >>> 15 & 1; //@line 36188
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 36194
 return;
}
function __Z12op_21ba_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $26 = 0, $35 = 0, $37 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 43783
 $$cast = $4; //@line 43785
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 43799
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 43804
 $26 = HEAP32[162769] | 0; //@line 43807
 $35 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) | 0; //@line 43816
 $37 = ($23 | 0) == 0 & 1; //@line 43818
 HEAP32[96441] = 0; //@line 43819
 HEAP32[96442] = 0; //@line 43819
 HEAP32[96443] = 0; //@line 43819
 HEAP32[96444] = 0; //@line 43819
 HEAP32[96442] = $37; //@line 43820
 HEAP32[96443] = $23 >>> 31; //@line 43822
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($35, $23); //@line 43828
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43831
 return;
}
function __Z12op_1179_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $3 = 0, $30 = 0, $40 = 0, $41 = 0, $43 = 0;
 $3 = HEAP32[162769] | 0; //@line 25780
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 25789
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 25804
 $30 = HEAP32[162769] | 0; //@line 25807
 $40 = (((HEAPU8[$30 + 6 >> 0] | 0) << 8 | (HEAPU8[$30 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25818
 $41 = $27 << 24 >> 24; //@line 25820
 $43 = ($41 | 0) == 0 & 1; //@line 25822
 HEAP32[96441] = 0; //@line 25823
 HEAP32[96442] = 0; //@line 25823
 HEAP32[96443] = 0; //@line 25823
 HEAP32[96444] = 0; //@line 25823
 HEAP32[96442] = $43; //@line 25824
 HEAP32[96443] = $27 >>> 7 & 1; //@line 25827
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($40 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($40, $41); //@line 25833
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 25836
 return;
}
function __Z12op_10bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 24238
 $4 = $3 + 2 | 0; //@line 24239
 HEAP32[162769] = $4; //@line 24240
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 24245
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 24252
 HEAP32[162769] = $3 + 4; //@line 24254
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 24255
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 24261
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24263
 $26 = $23 << 24 >> 24; //@line 24265
 $28 = ($26 | 0) == 0 & 1; //@line 24267
 HEAP32[96441] = 0; //@line 24268
 HEAP32[96442] = 0; //@line 24268
 HEAP32[96443] = 0; //@line 24268
 HEAP32[96444] = 0; //@line 24268
 HEAP32[96442] = $28; //@line 24269
 HEAP32[96443] = $23 >>> 7 & 1; //@line 24272
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $26); //@line 24278
 return;
}
function __Z11op_438_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $19 = 0, $22 = 0, $24 = 0, $3 = 0, $33 = 0, $sext26$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 10569
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 10571
 $13 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 10582
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 10584
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 10588
 $22 = ($19 << 24 >> 24) - ($3 << 24 >> 24) | 0; //@line 10592
 $24 = $19 >>> 7; //@line 10595
 $sext26$lobit = $22 >>> 7 & 1; //@line 10598
 HEAP32[96442] = ($22 & 255 | 0) == 0 & 1; //@line 10602
 HEAP32[96444] = ($sext26$lobit ^ $24 & 1) & ($24 ^ ($3 & 255) >>> 7 & 255); //@line 10606
 $33 = ($3 & 255) >>> 0 > ($19 & 255) >>> 0 & 1; //@line 10609
 HEAP32[96441] = $33; //@line 10610
 HEAP32[96445] = $33; //@line 10611
 HEAP32[96443] = $sext26$lobit; //@line 10612
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $22); //@line 10616
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10619
 return;
}
function ___fseeko_unlocked($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$019 = 0, $10 = 0, $12 = 0, label = 0;
 if (($2 | 0) == 1) {
  $$019 = $1 - (HEAP32[$0 + 8 >> 2] | 0) + (HEAP32[$0 + 4 >> 2] | 0) | 0; //@line 1744
 } else {
  $$019 = $1; //@line 1746
 }
 $10 = $0 + 20 | 0; //@line 1748
 $12 = $0 + 28 | 0; //@line 1750
 if ((HEAP32[$10 >> 2] | 0) >>> 0 > (HEAP32[$12 >> 2] | 0) >>> 0) {
  FUNCTION_TABLE_iiii[HEAP32[$0 + 36 >> 2] & 15]($0, 0, 0) | 0; //@line 1756
  if (!(HEAP32[$10 >> 2] | 0)) {
   $$0 = -1; //@line 1760
  } else {
   label = 5; //@line 1762
  }
 } else {
  label = 5; //@line 1765
 }
 if ((label | 0) == 5) {
  HEAP32[$0 + 16 >> 2] = 0; //@line 1769
  HEAP32[$12 >> 2] = 0; //@line 1770
  HEAP32[$10 >> 2] = 0; //@line 1771
  if ((FUNCTION_TABLE_iiii[HEAP32[$0 + 40 >> 2] & 15]($0, $$019, $2) | 0) < 0) {
   $$0 = -1; //@line 1777
  } else {
   HEAP32[$0 + 8 >> 2] = 0; //@line 1780
   HEAP32[$0 + 4 >> 2] = 0; //@line 1782
   HEAP32[$0 >> 2] = HEAP32[$0 >> 2] & -17; //@line 1785
   $$0 = 0; //@line 1786
  }
 }
 return $$0 | 0; //@line 1789
}
function __Z12op_3168_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $25 = 0, $35 = 0, $36 = 0, $38 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 37586
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 37597
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 37603
 $25 = HEAP32[162769] | 0; //@line 37606
 $35 = (((HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37617
 $36 = $22 << 16 >> 16; //@line 37619
 $38 = ($36 | 0) == 0 & 1; //@line 37621
 HEAP32[96441] = 0; //@line 37622
 HEAP32[96442] = 0; //@line 37622
 HEAP32[96443] = 0; //@line 37622
 HEAP32[96444] = 0; //@line 37622
 HEAP32[96442] = $38; //@line 37623
 HEAP32[96443] = $22 >>> 15 & 1; //@line 37626
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 37632
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37635
 return;
}
function __Z12op_e4f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 41051
 $3 = $2 + 2 | 0; //@line 41052
 HEAP32[162769] = $3; //@line 41053
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41055
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 41062
 HEAP32[162769] = $2 + 4; //@line 41064
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 41065
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41067
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41071
 $21 = $20 & 1; //@line 41072
 $22 = $20 >>> 1; //@line 41073
 $$ = (HEAP32[96445] | 0) == 0 ? $22 & 32767 : $22 | 32768; //@line 41078
 HEAP32[96444] = 0; //@line 41082
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41083
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41086
 HEAP32[96441] = $21; //@line 41087
 HEAP32[96445] = $21; //@line 41088
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41093
 return;
}
function __Z12op_e1f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 40121
 $3 = $2 + 2 | 0; //@line 40122
 HEAP32[162769] = $3; //@line 40123
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40125
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 40132
 HEAP32[162769] = $2 + 4; //@line 40134
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 40135
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40137
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40141
 $21 = $20 & 32768; //@line 40142
 $22 = $20 << 1; //@line 40143
 HEAP32[96442] = ($20 & 32767 | 0) == 0 & 1; //@line 40148
 HEAP32[96443] = $20 >>> 14 & 1; //@line 40151
 $$lobit = $21 >>> 15; //@line 40153
 HEAP32[96441] = $$lobit; //@line 40154
 HEAP32[96445] = $$lobit; //@line 40155
 HEAP32[96444] = ($22 & 32768 ^ $21) >>> 15; //@line 40158
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22 & 131070); //@line 40162
 return;
}
function __Z12op_31fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $32 = 0, $33 = 0, $35 = 0;
 $2 = HEAP32[162769] | 0; //@line 39111
 $$cast = $2; //@line 39113
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 39127
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 39133
 $23 = HEAP32[162769] | 0; //@line 39134
 $32 = ((HEAPU8[$23 + 4 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0)) << 16 >> 16; //@line 39144
 $33 = $22 << 16 >> 16; //@line 39146
 $35 = ($33 | 0) == 0 & 1; //@line 39148
 HEAP32[96441] = 0; //@line 39149
 HEAP32[96442] = 0; //@line 39149
 HEAP32[96443] = 0; //@line 39149
 HEAP32[96444] = 0; //@line 39149
 HEAP32[96442] = $35; //@line 39150
 HEAP32[96443] = $22 >>> 15 & 1; //@line 39153
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($32, $33); //@line 39159
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39162
 return;
}
function __Z12op_3190_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38099
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 38105
 $12 = HEAP32[162769] | 0; //@line 38106
 $13 = $12 + 2 | 0; //@line 38107
 HEAP32[162769] = $13; //@line 38108
 $15 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38110
 $22 = (HEAPU8[$13 >> 0] | 0) << 8 | (HEAPU8[$12 + 3 >> 0] | 0); //@line 38117
 HEAP32[162769] = $12 + 4; //@line 38119
 $24 = __Z15get_disp_ea_020jj($15, $22) | 0; //@line 38120
 $25 = $11 << 16 >> 16; //@line 38122
 $27 = ($25 | 0) == 0 & 1; //@line 38124
 HEAP32[96441] = 0; //@line 38125
 HEAP32[96442] = 0; //@line 38125
 HEAP32[96443] = 0; //@line 38125
 HEAP32[96444] = 0; //@line 38125
 HEAP32[96442] = $27; //@line 38126
 HEAP32[96443] = $11 >>> 15 & 1; //@line 38129
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 38135
 return;
}
function __Z12op_1168_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $25 = 0, $35 = 0, $36 = 0, $38 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 25598
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 25609
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 25615
 $25 = HEAP32[162769] | 0; //@line 25618
 $35 = (((HEAPU8[$25 + 4 >> 0] | 0) << 8 | (HEAPU8[$25 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25629
 $36 = $22 << 24 >> 24; //@line 25631
 $38 = ($36 | 0) == 0 & 1; //@line 25633
 HEAP32[96441] = 0; //@line 25634
 HEAP32[96442] = 0; //@line 25634
 HEAP32[96443] = 0; //@line 25634
 HEAP32[96444] = 0; //@line 25634
 HEAP32[96442] = $38; //@line 25635
 HEAP32[96443] = $22 >>> 7 & 1; //@line 25638
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 25644
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 25647
 return;
}
function __Z12op_11fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $23 = 0, $32 = 0, $33 = 0, $35 = 0;
 $2 = HEAP32[162769] | 0; //@line 27039
 $$cast = $2; //@line 27041
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 27055
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 27061
 $23 = HEAP32[162769] | 0; //@line 27062
 $32 = ((HEAPU8[$23 + 4 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0)) << 16 >> 16; //@line 27072
 $33 = $22 << 24 >> 24; //@line 27074
 $35 = ($33 | 0) == 0 & 1; //@line 27076
 HEAP32[96441] = 0; //@line 27077
 HEAP32[96442] = 0; //@line 27077
 HEAP32[96443] = 0; //@line 27077
 HEAP32[96444] = 0; //@line 27077
 HEAP32[96442] = $35; //@line 27078
 HEAP32[96443] = $22 >>> 7 & 1; //@line 27081
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($32, $33); //@line 27087
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27090
 return;
}
function __Z12op_1190_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26063
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 26069
 $12 = HEAP32[162769] | 0; //@line 26070
 $13 = $12 + 2 | 0; //@line 26071
 HEAP32[162769] = $13; //@line 26072
 $15 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26074
 $22 = (HEAPU8[$13 >> 0] | 0) << 8 | (HEAPU8[$12 + 3 >> 0] | 0); //@line 26081
 HEAP32[162769] = $12 + 4; //@line 26083
 $24 = __Z15get_disp_ea_020jj($15, $22) | 0; //@line 26084
 $25 = $11 << 24 >> 24; //@line 26086
 $27 = ($25 | 0) == 0 & 1; //@line 26088
 HEAP32[96441] = 0; //@line 26089
 HEAP32[96442] = 0; //@line 26089
 HEAP32[96443] = 0; //@line 26089
 HEAP32[96444] = 0; //@line 26089
 HEAP32[96442] = $27; //@line 26090
 HEAP32[96443] = $11 >>> 7 & 1; //@line 26093
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $25); //@line 26099
 return;
}
function __Z12op_4838_0_ffj($0) {
 $0 = $0 | 0;
 var $$023$in = 0, $1 = 0, $10 = 0, $12 = 0, $17 = 0, $21 = 0, $23 = 0, $26 = 0, $28 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 49924
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 49934
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 49936
 $17 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0) << 24 >> 24; //@line 49942
 $21 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($17 & 15) | 0; //@line 49947
 $23 = $21 & 65535; //@line 49949
 $26 = ($23 >>> 0 > 9 ? $23 + -6 | 0 : $21) - ($17 & 240) | 0; //@line 49953
 $28 = ($26 & 496) >>> 0 > 144; //@line 49955
 $29 = $28 & 1; //@line 49956
 $$023$in = $28 ? ($26 & 65535) + -96 | 0 : $26; //@line 49959
 HEAP32[96441] = $29; //@line 49960
 HEAP32[96445] = $29; //@line 49961
 HEAP32[96442] = ($$023$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49967
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $$023$in & 65535); //@line 49972
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49975
 return;
}
function __Z12op_217a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $26 = 0, $36 = 0, $38 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32810
 $$cast = $4; //@line 32812
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 32826
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 32831
 $26 = HEAP32[162769] | 0; //@line 32834
 $36 = (((HEAPU8[$26 + 4 >> 0] | 0) << 8 | (HEAPU8[$26 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32845
 $38 = ($23 | 0) == 0 & 1; //@line 32847
 HEAP32[96441] = 0; //@line 32848
 HEAP32[96442] = 0; //@line 32848
 HEAP32[96443] = 0; //@line 32848
 HEAP32[96444] = 0; //@line 32848
 HEAP32[96442] = $38; //@line 32849
 HEAP32[96443] = $23 >>> 31; //@line 32851
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($36 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($36, $23); //@line 32857
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 32860
 return;
}
function __Z12op_5138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $23 = 0, $25 = 0, $35 = 0, $4 = 0, $5 = 0, $sext33$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5349
 $5 = HEAP32[162769] | 0; //@line 5350
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 5360
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 5362
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 5366
 $23 = ($20 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5371
 $25 = $20 >>> 7; //@line 5373
 $sext33$lobit = $23 >>> 7 & 1; //@line 5376
 HEAP32[96442] = ($23 & 255 | 0) == 0 & 1; //@line 5380
 HEAP32[96444] = ($sext33$lobit ^ $25 & 1) & ($25 ^ $4 >>> 7); //@line 5384
 $35 = ($4 & 255) >>> 0 > ($20 & 255) >>> 0 & 1; //@line 5388
 HEAP32[96441] = $35; //@line 5389
 HEAP32[96445] = $35; //@line 5390
 HEAP32[96443] = $sext33$lobit; //@line 5391
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $23); //@line 5395
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5398
 return;
}
function __ZN8tinyxml28MemPoolTILi52EED2Ev($0) {
 $0 = $0 | 0;
 var $$04 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2336; //@line 40430
 $1 = $0 + 52 | 0; //@line 40431
 $2 = HEAP32[$1 >> 2] | 0; //@line 40432
 $4 = $0 + 4 | 0; //@line 40434
 $5 = HEAP32[$4 >> 2] | 0; //@line 40435
 if (($2 | 0) > 0) {
  $$04 = 0; //@line 40437
  $10 = $5; //@line 40437
  $16 = $2; //@line 40437
  while (1) {
   $11 = HEAP32[$10 + ($$04 << 2) >> 2] | 0; //@line 40440
   if (!$11) {
    $15 = $16; //@line 40443
    $17 = $10; //@line 40443
   } else {
    __ZdlPv($11); //@line 40445
    $15 = HEAP32[$1 >> 2] | 0; //@line 40448
    $17 = HEAP32[$4 >> 2] | 0; //@line 40448
   }
   $$04 = $$04 + 1 | 0; //@line 40450
   if (($$04 | 0) >= ($15 | 0)) {
    $$lcssa = $17; //@line 40455
    break;
   } else {
    $10 = $17; //@line 40453
    $16 = $15; //@line 40453
   }
  }
 } else {
  $$lcssa = $5; //@line 40460
 }
 if (($$lcssa | 0) == ($0 + 8 | 0) | ($$lcssa | 0) == 0) {
  return;
 }
 __ZdaPv($$lcssa); //@line 40469
 return;
}
function __ZN8tinyxml28MemPoolTILi48EED2Ev($0) {
 $0 = $0 | 0;
 var $$04 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2272; //@line 40692
 $1 = $0 + 52 | 0; //@line 40693
 $2 = HEAP32[$1 >> 2] | 0; //@line 40694
 $4 = $0 + 4 | 0; //@line 40696
 $5 = HEAP32[$4 >> 2] | 0; //@line 40697
 if (($2 | 0) > 0) {
  $$04 = 0; //@line 40699
  $10 = $5; //@line 40699
  $16 = $2; //@line 40699
  while (1) {
   $11 = HEAP32[$10 + ($$04 << 2) >> 2] | 0; //@line 40702
   if (!$11) {
    $15 = $16; //@line 40705
    $17 = $10; //@line 40705
   } else {
    __ZdlPv($11); //@line 40707
    $15 = HEAP32[$1 >> 2] | 0; //@line 40710
    $17 = HEAP32[$4 >> 2] | 0; //@line 40710
   }
   $$04 = $$04 + 1 | 0; //@line 40712
   if (($$04 | 0) >= ($15 | 0)) {
    $$lcssa = $17; //@line 40717
    break;
   } else {
    $10 = $17; //@line 40715
    $16 = $15; //@line 40715
   }
  }
 } else {
  $$lcssa = $5; //@line 40722
 }
 if (($$lcssa | 0) == ($0 + 8 | 0) | ($$lcssa | 0) == 0) {
  return;
 }
 __ZdaPv($$lcssa); //@line 40731
 return;
}
function __ZN8tinyxml28MemPoolTILi44EED2Ev($0) {
 $0 = $0 | 0;
 var $$04 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2240; //@line 40823
 $1 = $0 + 52 | 0; //@line 40824
 $2 = HEAP32[$1 >> 2] | 0; //@line 40825
 $4 = $0 + 4 | 0; //@line 40827
 $5 = HEAP32[$4 >> 2] | 0; //@line 40828
 if (($2 | 0) > 0) {
  $$04 = 0; //@line 40830
  $10 = $5; //@line 40830
  $16 = $2; //@line 40830
  while (1) {
   $11 = HEAP32[$10 + ($$04 << 2) >> 2] | 0; //@line 40833
   if (!$11) {
    $15 = $16; //@line 40836
    $17 = $10; //@line 40836
   } else {
    __ZdlPv($11); //@line 40838
    $15 = HEAP32[$1 >> 2] | 0; //@line 40841
    $17 = HEAP32[$4 >> 2] | 0; //@line 40841
   }
   $$04 = $$04 + 1 | 0; //@line 40843
   if (($$04 | 0) >= ($15 | 0)) {
    $$lcssa = $17; //@line 40848
    break;
   } else {
    $10 = $17; //@line 40846
    $16 = $15; //@line 40846
   }
  }
 } else {
  $$lcssa = $5; //@line 40853
 }
 if (($$lcssa | 0) == ($0 + 8 | 0) | ($$lcssa | 0) == 0) {
  return;
 }
 __ZdaPv($$lcssa); //@line 40862
 return;
}
function __ZN8tinyxml28MemPoolTILi36EED2Ev($0) {
 $0 = $0 | 0;
 var $$04 = 0, $$lcssa = 0, $1 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2304; //@line 40561
 $1 = $0 + 52 | 0; //@line 40562
 $2 = HEAP32[$1 >> 2] | 0; //@line 40563
 $4 = $0 + 4 | 0; //@line 40565
 $5 = HEAP32[$4 >> 2] | 0; //@line 40566
 if (($2 | 0) > 0) {
  $$04 = 0; //@line 40568
  $10 = $5; //@line 40568
  $16 = $2; //@line 40568
  while (1) {
   $11 = HEAP32[$10 + ($$04 << 2) >> 2] | 0; //@line 40571
   if (!$11) {
    $15 = $16; //@line 40574
    $17 = $10; //@line 40574
   } else {
    __ZdlPv($11); //@line 40576
    $15 = HEAP32[$1 >> 2] | 0; //@line 40579
    $17 = HEAP32[$4 >> 2] | 0; //@line 40579
   }
   $$04 = $$04 + 1 | 0; //@line 40581
   if (($$04 | 0) >= ($15 | 0)) {
    $$lcssa = $17; //@line 40586
    break;
   } else {
    $10 = $17; //@line 40584
    $16 = $15; //@line 40584
   }
  }
 } else {
  $$lcssa = $5; //@line 40591
 }
 if (($$lcssa | 0) == ($0 + 8 | 0) | ($$lcssa | 0) == 0) {
  return;
 }
 __ZdaPv($$lcssa); //@line 40600
 return;
}
function __Z12op_d1b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $14 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $37 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35023
 $5 = HEAP32[162769] | 0; //@line 35024
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 35033
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 35042
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 35044
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 35047
 $29 = $28 + $4 | 0; //@line 35048
 $$lobit34 = $29 >>> 31; //@line 35051
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 35054
 HEAP32[96444] = ($$lobit34 ^ $4 >>> 31) & ($$lobit34 ^ $28 >>> 31); //@line 35058
 $37 = $4 >>> 0 > ~$28 >>> 0 & 1; //@line 35061
 HEAP32[96441] = $37; //@line 35062
 HEAP32[96445] = $37; //@line 35063
 HEAP32[96443] = $$lobit34; //@line 35064
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 35068
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 35071
 return;
}
function __Z12op_30b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 35952
 $5 = $4 + 2 | 0; //@line 35953
 HEAP32[162769] = $5; //@line 35954
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35956
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 35963
 HEAP32[162769] = $4 + 4; //@line 35965
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 35966
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 35972
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35974
 $25 = $22 << 16 >> 16; //@line 35976
 $27 = ($25 | 0) == 0 & 1; //@line 35978
 HEAP32[96441] = 0; //@line 35979
 HEAP32[96442] = 0; //@line 35979
 HEAP32[96443] = 0; //@line 35979
 HEAP32[96444] = 0; //@line 35979
 HEAP32[96442] = $27; //@line 35980
 HEAP32[96443] = $22 >>> 15 & 1; //@line 35983
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 35989
 return;
}
function __Z11op_a30_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 15671
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 15673
 $5 = $2 + 4 | 0; //@line 15674
 HEAP32[162769] = $5; //@line 15675
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15677
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 15684
 HEAP32[162769] = $2 + 6; //@line 15686
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 15687
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 15689
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) ^ $4 & 255; //@line 15695
 $25 = $24 << 24 >> 24; //@line 15697
 $27 = ($25 | 0) == 0 & 1; //@line 15699
 HEAP32[96441] = 0; //@line 15700
 HEAP32[96442] = 0; //@line 15700
 HEAP32[96443] = 0; //@line 15700
 HEAP32[96444] = 0; //@line 15700
 HEAP32[96442] = $27; //@line 15701
 HEAP32[96443] = $24 >>> 7 & 1; //@line 15704
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 15708
 return;
}
function ___procfdname($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$02324 = 0, $$027 = 0, $$126 = 0, $$225 = 0, dest = 0, src = 0, stop = 0;
 dest = $0; //@line 59388
 src = 112484; //@line 59388
 stop = dest + 15 | 0; //@line 59388
 do {
  HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 59388
  dest = dest + 1 | 0; //@line 59388
  src = src + 1 | 0; //@line 59388
 } while ((dest | 0) < (stop | 0));
 if (!$1) {
  HEAP8[$0 + 14 >> 0] = 48; //@line 59392
  HEAP8[$0 + 15 >> 0] = 0; //@line 59394
 } else {
  $$027 = $1; //@line 59396
  $$126 = 14; //@line 59396
  while (1) {
   $$126 = $$126 + 1 | 0; //@line 59399
   if ($$027 >>> 0 < 10) {
    break;
   } else {
    $$027 = ($$027 >>> 0) / 10 | 0; //@line 59404
   }
  }
  HEAP8[$0 + $$126 >> 0] = 0; //@line 59408
  $$02324 = $1; //@line 59409
  $$225 = $$126; //@line 59409
  while (1) {
   $$225 = $$225 + -1 | 0; //@line 59414
   HEAP8[$0 + $$225 >> 0] = ($$02324 >>> 0) % 10 | 0 | 48; //@line 59416
   if ($$02324 >>> 0 < 10) {
    break;
   } else {
    $$02324 = ($$02324 >>> 0) / 10 | 0; //@line 59422
   }
  }
 }
 return;
}
function __Z12op_51a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $31 = 0, $4 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6146
 $8 = HEAP32[162769] | 0; //@line 6150
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6161
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 6163
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 6166
 $24 = $23 - $4 | 0; //@line 6167
 $$lobit37 = $23 >>> 31; //@line 6169
 $$lobit38 = $24 >>> 31; //@line 6170
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 6173
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $4 >>> 31); //@line 6177
 $31 = $23 >>> 0 < $4 >>> 0 & 1; //@line 6179
 HEAP32[96441] = $31; //@line 6180
 HEAP32[96445] = $31; //@line 6181
 HEAP32[96443] = $$lobit38; //@line 6182
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 6186
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6189
 return;
}
function __Z12op_40b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit28 = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $24 = 0, $27 = 0, $31 = 0;
 $1 = HEAP32[162769] | 0; //@line 41155
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 41164
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 41173
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41175
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$21 >> 2] >> 2] & 127]($19) | 0; //@line 41178
 $27 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $24 | 0; //@line 41182
 $$lobit = $24 >>> 31; //@line 41183
 $$lobit28 = $27 >>> 31; //@line 41184
 HEAP32[96444] = $$lobit28 & $$lobit; //@line 41186
 $31 = $$lobit28 & ~$$lobit ^ $$lobit; //@line 41189
 HEAP32[96441] = $31; //@line 41190
 HEAP32[96445] = $31; //@line 41191
 HEAP32[96442] = ($27 | 0) == 0 & HEAP32[96442]; //@line 41196
 HEAP32[96443] = $$lobit28; //@line 41197
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 12 >> 2] & 31]($19, $27); //@line 41201
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41204
 return;
}
function __Z12op_33d8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $21 = 0, $3 = 0, $30 = 0, $31 = 0, $33 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 39423
 $3 = HEAP32[$2 >> 2] | 0; //@line 39424
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 39430
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 39433
 $12 = HEAP32[162769] | 0; //@line 39434
 $21 = (HEAPU8[$12 + 3 >> 0] | 0) << 16 | (HEAPU8[$12 + 2 >> 0] | 0) << 24; //@line 39443
 $30 = $21 | (HEAPU8[$12 + 4 >> 0] | 0) << 8 | (HEAPU8[$12 + 5 >> 0] | 0); //@line 39452
 $31 = $9 << 16 >> 16; //@line 39454
 $33 = ($31 | 0) == 0 & 1; //@line 39456
 HEAP32[96441] = 0; //@line 39457
 HEAP32[96442] = 0; //@line 39457
 HEAP32[96443] = 0; //@line 39457
 HEAP32[96444] = 0; //@line 39457
 HEAP32[96442] = $33; //@line 39458
 HEAP32[96443] = $9 >>> 15 & 1; //@line 39461
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, $31); //@line 39467
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39470
 return;
}
function __Z12op_10b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 24036
 $5 = $4 + 2 | 0; //@line 24037
 HEAP32[162769] = $5; //@line 24038
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24040
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 24047
 HEAP32[162769] = $4 + 4; //@line 24049
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 24050
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 24056
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24058
 $25 = $22 << 24 >> 24; //@line 24060
 $27 = ($25 | 0) == 0 & 1; //@line 24062
 HEAP32[96441] = 0; //@line 24063
 HEAP32[96442] = 0; //@line 24063
 HEAP32[96443] = 0; //@line 24063
 HEAP32[96444] = 0; //@line 24063
 HEAP32[96442] = $27; //@line 24064
 HEAP32[96443] = $22 >>> 7 & 1; //@line 24067
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $25); //@line 24073
 return;
}
function __Z11op_ea8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $26 = 0, $4 = 0, $41 = 0, $46 = 0, $50 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22455
  return;
 }
 $4 = HEAP32[162769] | 0; //@line 22459
 $7 = HEAPU8[$4 + 2 >> 0] | 0; //@line 22462
 $9 = $7 << 24 >> 16; //@line 22464
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 22468
 if (!($9 & 2048)) {
  $41 = ((HEAPU8[$4 + 6 >> 0] << 8 | HEAPU8[$4 + 7 >> 0]) << 16 >> 16) + $13 | 0; //@line 22480
  $46 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($41 >>> 16 << 2) >> 2] >> 2] & 127]($41) | 0; //@line 22485
  $50 = $7 >>> 4 & 7; //@line 22489
  HEAP32[($9 & 32768 | 0 ? 651040 + ($50 << 2) | 0 : 651008 + ($50 << 2) | 0) >> 2] = $46; //@line 22493
 } else {
  $26 = ((HEAPU8[$4 + 4 >> 0] << 8 | HEAPU8[$4 + 5 >> 0]) << 16 >> 16) + $13 | 0; //@line 22508
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($26, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 22514
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 22518
 return;
}
function __Z12op_4630_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0, $5 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 48438
 $3 = $2 + 2 | 0; //@line 48439
 HEAP32[162769] = $3; //@line 48440
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48442
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 48449
 HEAP32[162769] = $2 + 4; //@line 48451
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 48452
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 48454
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24; //@line 48459
 $21 = $sext >> 24; //@line 48460
 $22 = ~$21; //@line 48461
 $24 = ($21 | 0) == -1 & 1; //@line 48463
 HEAP32[96441] = 0; //@line 48464
 HEAP32[96442] = 0; //@line 48464
 HEAP32[96443] = 0; //@line 48464
 HEAP32[96444] = 0; //@line 48464
 HEAP32[96442] = $24; //@line 48465
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48468
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $22); //@line 48472
 return;
}
function __Z12op_e0a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $15 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38299
 $7 = HEAP32[$6 >> 2] | 0; //@line 38300
 $8 = $7 >>> 31; //@line 38301
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38302
 $10 = $9 >>> 0 > 31; //@line 38303
 HEAP32[96441] = 0; //@line 38304
 HEAP32[96442] = 0; //@line 38304
 HEAP32[96443] = 0; //@line 38304
 HEAP32[96444] = 0; //@line 38304
 if ($10) {
  HEAP32[96441] = $8; //@line 38307
  HEAP32[96445] = $8; //@line 38308
  $$0 = $7 >> 31; //@line 38309
 } else {
  if (!$9) {
   $$0 = $7; //@line 38313
  } else {
   $14 = $7 >>> ($9 + -1 | 0); //@line 38316
   $15 = $14 & 1; //@line 38317
   HEAP32[96441] = $15; //@line 38318
   HEAP32[96445] = $15; //@line 38319
   $$0 = $14 >>> 1 | -1 << 32 - $9 & $7 >> 31; //@line 38326
  }
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38331
 HEAP32[96443] = $$0 >>> 31; //@line 38333
 HEAP32[$6 >> 2] = $$0; //@line 38334
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38337
 return;
}
function __Z12op_c07b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $sext2021 = 0;
 $4 = HEAP32[162769] | 0; //@line 36021
 $$cast = $4; //@line 36026
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36035
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36041
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36042
 $25 = HEAP32[$24 >> 2] | 0; //@line 36043
 $sext2021 = $25 & $23; //@line 36044
 $26 = $sext2021 << 16 >> 16; //@line 36046
 $28 = ($26 | 0) == 0 & 1; //@line 36048
 HEAP32[96441] = 0; //@line 36049
 HEAP32[96442] = 0; //@line 36049
 HEAP32[96443] = 0; //@line 36049
 HEAP32[96444] = 0; //@line 36049
 HEAP32[96442] = $28; //@line 36050
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 36053
 HEAP32[$24 >> 2] = $25 & -65536 | $26 & 65535; //@line 36057
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36060
 return;
}
function __Z12op_807b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $sext2021 = 0;
 $4 = HEAP32[162769] | 0; //@line 23153
 $$cast = $4; //@line 23158
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23167
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 23173
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23174
 $25 = HEAP32[$24 >> 2] | 0; //@line 23175
 $sext2021 = $25 | $23; //@line 23176
 $26 = $sext2021 << 16 >> 16; //@line 23178
 $28 = ($26 | 0) == 0 & 1; //@line 23180
 HEAP32[96441] = 0; //@line 23181
 HEAP32[96442] = 0; //@line 23181
 HEAP32[96443] = 0; //@line 23181
 HEAP32[96444] = 0; //@line 23181
 HEAP32[96442] = $28; //@line 23182
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 23185
 HEAP32[$24 >> 2] = $25 & -65536 | $26 & 65535; //@line 23189
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23192
 return;
}
function __Z11op_690_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $2 = 0, $20 = 0, $22 = 0, $24 = 0, $27 = 0, $28 = 0, $36 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13219
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13222
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13237
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13239
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 13241
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 13244
 $28 = $27 + $20 | 0; //@line 13245
 $$lobit34 = $28 >>> 31; //@line 13248
 HEAP32[96442] = ($28 | 0) == 0 & 1; //@line 13251
 HEAP32[96444] = ($$lobit34 ^ $5 >>> 7) & ($$lobit34 ^ $27 >>> 31); //@line 13255
 $36 = $20 >>> 0 > ~$27 >>> 0 & 1; //@line 13258
 HEAP32[96441] = $36; //@line 13259
 HEAP32[96445] = $36; //@line 13260
 HEAP32[96443] = $$lobit34; //@line 13261
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $28); //@line 13265
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13268
 return;
}
function __Z12op_4670_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0, $5 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 48746
 $3 = $2 + 2 | 0; //@line 48747
 HEAP32[162769] = $3; //@line 48748
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48750
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 48757
 HEAP32[162769] = $2 + 4; //@line 48759
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 48760
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 48762
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0) << 16; //@line 48767
 $21 = $sext >> 16; //@line 48768
 $22 = ~$21; //@line 48769
 $24 = ($21 | 0) == -1 & 1; //@line 48771
 HEAP32[96441] = 0; //@line 48772
 HEAP32[96442] = 0; //@line 48772
 HEAP32[96443] = 0; //@line 48772
 HEAP32[96444] = 0; //@line 48772
 HEAP32[96442] = $24; //@line 48773
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48776
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22); //@line 48780
 return;
}
function __Z12op_33e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $2 = 0, $20 = 0, $29 = 0, $30 = 0, $32 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 39480
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 39482
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 39488
 HEAP32[$2 >> 2] = $4; //@line 39489
 $11 = HEAP32[162769] | 0; //@line 39490
 $20 = (HEAPU8[$11 + 3 >> 0] | 0) << 16 | (HEAPU8[$11 + 2 >> 0] | 0) << 24; //@line 39499
 $29 = $20 | (HEAPU8[$11 + 4 >> 0] | 0) << 8 | (HEAPU8[$11 + 5 >> 0] | 0); //@line 39508
 $30 = $10 << 16 >> 16; //@line 39510
 $32 = ($30 | 0) == 0 & 1; //@line 39512
 HEAP32[96441] = 0; //@line 39513
 HEAP32[96442] = 0; //@line 39513
 HEAP32[96443] = 0; //@line 39513
 HEAP32[96444] = 0; //@line 39513
 HEAP32[96442] = $32; //@line 39514
 HEAP32[96443] = $10 >>> 15 & 1; //@line 39517
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, $30); //@line 39523
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39526
 return;
}
function __Z12op_33f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $17 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 39667
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 39677
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 39683
 $17 = HEAP32[162769] | 0; //@line 39684
 $26 = (HEAPU8[$17 + 5 >> 0] | 0) << 16 | (HEAPU8[$17 + 4 >> 0] | 0) << 24; //@line 39693
 $35 = $26 | (HEAPU8[$17 + 6 >> 0] | 0) << 8 | (HEAPU8[$17 + 7 >> 0] | 0); //@line 39702
 $36 = $16 << 16 >> 16; //@line 39704
 $38 = ($36 | 0) == 0 & 1; //@line 39706
 HEAP32[96441] = 0; //@line 39707
 HEAP32[96442] = 0; //@line 39707
 HEAP32[96443] = 0; //@line 39707
 HEAP32[96444] = 0; //@line 39707
 HEAP32[96442] = $38; //@line 39708
 HEAP32[96443] = $16 >>> 15 & 1; //@line 39711
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 39717
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 39720
 return;
}
function __Z12op_9140_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 20450
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 20451
 $7 = HEAP32[$6 >> 2] | 0; //@line 20452
 $13 = ($7 << 16 >> 16) - ($5 << 16 >> 16) + (((HEAP32[96445] | 0) != 0) << 31 >> 31) | 0; //@line 20461
 $14 = $5 >>> 15; //@line 20462
 $15 = $7 >>> 15; //@line 20464
 $16 = $13 >>> 15; //@line 20466
 $sext39$lobit = $16 & 1; //@line 20467
 $18 = $sext39$lobit ^ $15 & 1; //@line 20469
 HEAP32[96444] = $18 & ($15 ^ $14); //@line 20471
 $22 = $18 & ($16 ^ $14) ^ $14 & 1; //@line 20474
 HEAP32[96441] = $22; //@line 20475
 HEAP32[96445] = $22; //@line 20476
 $sext39$mask = $13 & 65535; //@line 20478
 HEAP32[96442] = ($sext39$mask | 0) == 0 & HEAP32[96442]; //@line 20482
 HEAP32[96443] = $sext39$lobit; //@line 20483
 HEAP32[$6 >> 2] = $sext39$mask | $7 & -65536; //@line 20486
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20489
 return;
}
function __Z12op_13f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $17 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 27546
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 27556
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 27562
 $17 = HEAP32[162769] | 0; //@line 27563
 $26 = (HEAPU8[$17 + 5 >> 0] | 0) << 16 | (HEAPU8[$17 + 4 >> 0] | 0) << 24; //@line 27572
 $35 = $26 | (HEAPU8[$17 + 6 >> 0] | 0) << 8 | (HEAPU8[$17 + 7 >> 0] | 0); //@line 27581
 $36 = $16 << 24 >> 24; //@line 27583
 $38 = ($36 | 0) == 0 & 1; //@line 27585
 HEAP32[96441] = 0; //@line 27586
 HEAP32[96442] = 0; //@line 27586
 HEAP32[96443] = 0; //@line 27586
 HEAP32[96444] = 0; //@line 27586
 HEAP32[96442] = $38; //@line 27587
 HEAP32[96443] = $16 >>> 7 & 1; //@line 27590
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 27596
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 27599
 return;
}
function __Z12op_c03b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $sext1617 = 0;
 $4 = HEAP32[162769] | 0; //@line 35924
 $$cast = $4; //@line 35929
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 35938
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 35944
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 35945
 $25 = HEAP32[$24 >> 2] | 0; //@line 35946
 $sext1617 = $25 & $23; //@line 35947
 $26 = $sext1617 << 24 >> 24; //@line 35949
 $28 = ($26 | 0) == 0 & 1; //@line 35951
 HEAP32[96441] = 0; //@line 35952
 HEAP32[96442] = 0; //@line 35952
 HEAP32[96443] = 0; //@line 35952
 HEAP32[96444] = 0; //@line 35952
 HEAP32[96442] = $28; //@line 35953
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 35956
 HEAP32[$24 >> 2] = $25 & -256 | $26 & 255; //@line 35960
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35963
 return;
}
function __Z12op_b07b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $4 = 0, $sext$lobit = 0, $sext35$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 35373
 $$cast = $4; //@line 35378
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 35387
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 35393
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35395
 $26 = $25 - $23 | 0; //@line 35396
 $sext$lobit = $25 >>> 15 & 1; //@line 35400
 $sext35$lobit = $26 >>> 15 & 1; //@line 35402
 HEAP32[96442] = ($26 & 65535 | 0) == 0 & 1; //@line 35406
 HEAP32[96444] = ($23 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext35$lobit | 0) != ($sext$lobit | 0) & 1; //@line 35411
 HEAP32[96441] = ($23 & 65535) >>> 0 > ($25 & 65535) >>> 0 & 1; //@line 35416
 HEAP32[96443] = $sext35$lobit; //@line 35417
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35420
 return;
}
function __Z12op_803b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $sext1617 = 0;
 $4 = HEAP32[162769] | 0; //@line 23056
 $$cast = $4; //@line 23061
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23070
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 23076
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23077
 $25 = HEAP32[$24 >> 2] | 0; //@line 23078
 $sext1617 = $25 | $23; //@line 23079
 $26 = $sext1617 << 24 >> 24; //@line 23081
 $28 = ($26 | 0) == 0 & 1; //@line 23083
 HEAP32[96441] = 0; //@line 23084
 HEAP32[96442] = 0; //@line 23084
 HEAP32[96443] = 0; //@line 23084
 HEAP32[96444] = 0; //@line 23084
 HEAP32[96442] = $28; //@line 23085
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 23088
 HEAP32[$24 >> 2] = $25 & -256 | $26 & 255; //@line 23092
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23095
 return;
}
function __Z12op_303b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 35274
 $3 = HEAP32[162769] | 0; //@line 35275
 $4 = $3 + 2 | 0; //@line 35276
 HEAP32[162769] = $4; //@line 35277
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 35282
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 35289
 HEAP32[162769] = $3 + 4; //@line 35291
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 35292
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 35298
 $24 = $23 << 16 >> 16; //@line 35300
 $26 = ($24 | 0) == 0 & 1; //@line 35302
 HEAP32[96441] = 0; //@line 35303
 HEAP32[96442] = 0; //@line 35303
 HEAP32[96443] = 0; //@line 35303
 HEAP32[96444] = 0; //@line 35303
 HEAP32[96442] = $26; //@line 35304
 HEAP32[96443] = $23 >>> 15 & 1; //@line 35307
 $28 = 651008 + ($2 << 2) | 0; //@line 35308
 HEAP32[$28 >> 2] = HEAP32[$28 >> 2] & -65536 | $24 & 65535; //@line 35313
 return;
}
function __Z11op_eb9_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $45 = 0, $59 = 0, $6 = 0, $63 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22675
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 22678
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 22681
 $8 = $6 << 24 >> 16; //@line 22683
 if (!($8 & 2048)) {
  $45 = HEAPU8[$3 + 9 >> 0] << 16 | HEAPU8[$3 + 8 >> 0] << 24; //@line 22695
  $59 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($45 >>> 16 << 2) >> 2] >> 2] & 127]($45 | HEAPU8[$3 + 10 >> 0] << 8 | HEAPU8[$3 + 11 >> 0]) | 0; //@line 22709
  $63 = $6 >>> 4 & 7; //@line 22713
  HEAP32[($8 & 32768 | 0 ? 651040 + ($63 << 2) | 0 : 651008 + ($63 << 2) | 0) >> 2] = $59; //@line 22717
 } else {
  $22 = HEAPU8[$3 + 5 >> 0] << 16 | HEAPU8[$3 + 4 >> 0] << 24; //@line 22730
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22 | HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0], HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 22745
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 12; //@line 22749
 return;
}
function _gethostname($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$ = 0, $$0$lcssa = 0, $$013 = 0, $$014 = 0, $11 = 0, $2 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 3015
 STACKTOP = STACKTOP + 400 | 0; //@line 3016
 $2 = sp; //@line 3017
 if (!(_uname($2) | 0)) {
  $$ = $1 >>> 0 < 65 ? $1 : 65; //@line 3022
  L3 : do {
   if (!$$) {
    $$0$lcssa = 0; //@line 3026
   } else {
    $$014 = 0; //@line 3028
    while (1) {
     $8 = HEAP8[$2 + 65 + $$014 >> 0] | 0; //@line 3031
     HEAP8[$0 + $$014 >> 0] = $8; //@line 3033
     if (!($8 << 24 >> 24)) {
      $$0$lcssa = $$014; //@line 3036
      break L3;
     }
     $11 = $$014 + 1 | 0; //@line 3039
     if ($11 >>> 0 < $$ >>> 0) {
      $$014 = $11; //@line 3042
     } else {
      $$0$lcssa = $11; //@line 3044
      break;
     }
    }
   }
  } while (0);
  if (($$0$lcssa | 0) == ($$ | 0)) {
   HEAP8[$0 + ($$ + -1) >> 0] = 0; //@line 3054
   $$013 = 0; //@line 3055
  } else {
   $$013 = 0; //@line 3057
  }
 } else {
  $$013 = -1; //@line 3060
 }
 STACKTOP = sp; //@line 3062
 return $$013 | 0; //@line 3062
}
function __Z12op_d07c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $19 = 0, $28 = 0, $3 = 0, $6 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 32523
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 32526
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 32531
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32532
 $13 = HEAP32[$12 >> 2] | 0; //@line 32533
 $14 = $13 << 16 >> 16; //@line 32535
 $16 = ($11 << 16 >> 16) + $14 | 0; //@line 32538
 $19 = $16 >>> 15; //@line 32542
 $sext32$lobit = $19 & 1; //@line 32543
 $sext32$mask = $16 & 65535; //@line 32544
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 32547
 HEAP32[96444] = ($sext32$lobit ^ $13 >>> 15 & 1) & ($19 ^ $6 >>> 7); //@line 32551
 $28 = ($14 & 65535 ^ 65535) >>> 0 < $11 >>> 0 & 1; //@line 32555
 HEAP32[96441] = $28; //@line 32556
 HEAP32[96445] = $28; //@line 32557
 HEAP32[96443] = $sext32$lobit; //@line 32558
 HEAP32[$12 >> 2] = $13 & -65536 | $sext32$mask; //@line 32561
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32564
 return;
}
function __Z12op_9050_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $16 = 0, $18 = 0, $28 = 0, $5 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18372
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 18378
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18379
 $13 = HEAP32[$12 >> 2] | 0; //@line 18380
 $16 = ($13 << 16 >> 16) - ($11 << 16 >> 16) | 0; //@line 18385
 $18 = $13 >>> 15; //@line 18387
 $sext39$lobit = $16 >>> 15 & 1; //@line 18390
 $sext39$mask = $16 & 65535; //@line 18391
 HEAP32[96442] = ($sext39$mask | 0) == 0 & 1; //@line 18394
 HEAP32[96444] = ($sext39$lobit ^ $18 & 1) & ($18 ^ $11 >>> 15); //@line 18398
 $28 = ($11 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 18402
 HEAP32[96441] = $28; //@line 18403
 HEAP32[96445] = $28; //@line 18404
 HEAP32[96443] = $sext39$lobit; //@line 18405
 HEAP32[$12 >> 2] = $13 & -65536 | $sext39$mask; //@line 18408
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18411
 return;
}
function __Z12op_23f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44063
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 44072
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 44077
 $19 = HEAP32[162769] | 0; //@line 44078
 $28 = (HEAPU8[$19 + 5 >> 0] | 0) << 16 | (HEAPU8[$19 + 4 >> 0] | 0) << 24; //@line 44087
 $37 = $28 | (HEAPU8[$19 + 6 >> 0] | 0) << 8 | (HEAPU8[$19 + 7 >> 0] | 0); //@line 44096
 $39 = ($18 | 0) == 0 & 1; //@line 44098
 HEAP32[96441] = 0; //@line 44099
 HEAP32[96442] = 0; //@line 44099
 HEAP32[96443] = 0; //@line 44099
 HEAP32[96444] = 0; //@line 44099
 HEAP32[96442] = $39; //@line 44100
 HEAP32[96443] = $18 >>> 31; //@line 44102
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($37, $18); //@line 44108
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 44111
 return;
}
function __Z12op_d0bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit37 = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36782
 $$cast = $4; //@line 36787
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36796
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 36801
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36802
 $24 = HEAP32[$23 >> 2] | 0; //@line 36803
 $25 = $24 + $22 | 0; //@line 36804
 $$lobit37 = $25 >>> 31; //@line 36807
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 36810
 HEAP32[96444] = ($$lobit37 ^ $22 >>> 31) & ($$lobit37 ^ $24 >>> 31); //@line 36814
 $33 = $22 >>> 0 > ~$24 >>> 0 & 1; //@line 36817
 HEAP32[96441] = $33; //@line 36818
 HEAP32[96445] = $33; //@line 36819
 HEAP32[96443] = $$lobit37; //@line 36820
 HEAP32[$23 >> 2] = $25; //@line 36821
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36824
 return;
}
function __Z12op_b07a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $4 = 0, $sext32$lobit = 0, $sext34$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 24909
 $$cast = $4; //@line 24911
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 24925
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 24931
 $26 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24933
 $27 = $26 - $24 | 0; //@line 24934
 $sext32$lobit = $26 >>> 15 & 1; //@line 24938
 $sext34$lobit = $27 >>> 15 & 1; //@line 24940
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 24944
 HEAP32[96444] = ($24 >>> 15 & 1 | 0) != ($sext32$lobit | 0) & ($sext34$lobit | 0) != ($sext32$lobit | 0) & 1; //@line 24949
 HEAP32[96441] = ($24 & 65535) >>> 0 > ($26 & 65535) >>> 0 & 1; //@line 24954
 HEAP32[96443] = $sext34$lobit; //@line 24955
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24958
 return;
}
function __Z12op_d150_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $5 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34201
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34203
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 34205
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 34209
 $14 = $13 << 16 >> 16; //@line 34211
 $16 = $14 + ($5 << 16 >> 16) | 0; //@line 34214
 $19 = $16 >>> 15; //@line 34218
 $sext38$lobit = $19 & 1; //@line 34219
 HEAP32[96442] = ($16 & 65535 | 0) == 0 & 1; //@line 34223
 HEAP32[96444] = ($sext38$lobit ^ $13 >>> 15 & 1) & ($19 ^ $5 >>> 15); //@line 34227
 $29 = ($14 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 34232
 HEAP32[96441] = $29; //@line 34233
 HEAP32[96445] = $29; //@line 34234
 HEAP32[96443] = $sext38$lobit; //@line 34235
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 34239
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34242
 return;
}
function __Z12op_50b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $14 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $37 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4707
 $5 = HEAP32[162769] | 0; //@line 4708
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 4717
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 4726
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 4728
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 4731
 $29 = $28 + $4 | 0; //@line 4732
 $$lobit34 = $29 >>> 31; //@line 4735
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 4738
 HEAP32[96444] = ($$lobit34 ^ $4 >>> 31) & ($$lobit34 ^ $28 >>> 31); //@line 4742
 $37 = $4 >>> 0 > ~$28 >>> 0 & 1; //@line 4745
 HEAP32[96441] = $37; //@line 4746
 HEAP32[96445] = $37; //@line 4747
 HEAP32[96443] = $$lobit34; //@line 4748
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 4752
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 4755
 return;
}
function __Z12op_23f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $24 = 0, $25 = 0, $34 = 0, $43 = 0, $45 = 0;
 $1 = HEAP32[162769] | 0; //@line 34605
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 34614
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 34628
 $25 = HEAP32[162769] | 0; //@line 34629
 $34 = (HEAPU8[$25 + 7 >> 0] | 0) << 16 | (HEAPU8[$25 + 6 >> 0] | 0) << 24; //@line 34638
 $43 = $34 | (HEAPU8[$25 + 8 >> 0] | 0) << 8 | (HEAPU8[$25 + 9 >> 0] | 0); //@line 34647
 $45 = ($24 | 0) == 0 & 1; //@line 34649
 HEAP32[96441] = 0; //@line 34650
 HEAP32[96442] = 0; //@line 34650
 HEAP32[96443] = 0; //@line 34650
 HEAP32[96444] = 0; //@line 34650
 HEAP32[96442] = $45; //@line 34651
 HEAP32[96443] = $24 >>> 31; //@line 34653
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($43, $24); //@line 34659
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 34662
 return;
}
function __Z12op_b1fb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $15 = 0, $17 = 0, $22 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 27778
 $4 = $3 + 2 | 0; //@line 27779
 HEAP32[162769] = $4; //@line 27780
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 27785
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 27792
 HEAP32[162769] = $3 + 4; //@line 27794
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 27795
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 27800
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27802
 $25 = $24 - $22 | 0; //@line 27803
 $$lobit34 = $24 >>> 31; //@line 27805
 $$lobit35 = $25 >>> 31; //@line 27806
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 27809
 HEAP32[96444] = ($22 >>> 31 | 0) != ($$lobit34 | 0) & ($$lobit35 | 0) != ($$lobit34 | 0) & 1; //@line 27814
 HEAP32[96441] = $24 >>> 0 < $22 >>> 0 & 1; //@line 27817
 HEAP32[96443] = $$lobit35; //@line 27818
 return;
}
function __Z12op_b0bb_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $15 = 0, $17 = 0, $22 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 25506
 $4 = $3 + 2 | 0; //@line 25507
 HEAP32[162769] = $4; //@line 25508
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 25513
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 25520
 HEAP32[162769] = $3 + 4; //@line 25522
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 25523
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 25528
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25530
 $25 = $24 - $22 | 0; //@line 25531
 $$lobit34 = $24 >>> 31; //@line 25533
 $$lobit35 = $25 >>> 31; //@line 25534
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 25537
 HEAP32[96444] = ($22 >>> 31 | 0) != ($$lobit34 | 0) & ($$lobit35 | 0) != ($$lobit34 | 0) & 1; //@line 25542
 HEAP32[96441] = $24 >>> 0 < $22 >>> 0 & 1; //@line 25545
 HEAP32[96443] = $$lobit35; //@line 25546
 return;
}
function __Z12op_103b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 23754
 $3 = HEAP32[162769] | 0; //@line 23755
 $4 = $3 + 2 | 0; //@line 23756
 HEAP32[162769] = $4; //@line 23757
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 23762
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 23769
 HEAP32[162769] = $3 + 4; //@line 23771
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 23772
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 23778
 $24 = $23 << 24 >> 24; //@line 23780
 $26 = ($24 | 0) == 0 & 1; //@line 23782
 HEAP32[96441] = 0; //@line 23783
 HEAP32[96442] = 0; //@line 23783
 HEAP32[96443] = 0; //@line 23783
 HEAP32[96444] = 0; //@line 23783
 HEAP32[96442] = $26; //@line 23784
 HEAP32[96443] = $23 >>> 7 & 1; //@line 23787
 $28 = 651008 + ($2 << 2) | 0; //@line 23788
 HEAP32[$28 >> 2] = HEAP32[$28 >> 2] & -256 | $24 & 255; //@line 23793
 return;
}
function __Z11op_a58_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $21 = 0, $23 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 15912
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 15920
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 15921
 $12 = HEAP32[$11 >> 2] | 0; //@line 15922
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15924
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 15928
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 15931
 $sext1718 = $18 ^ $10; //@line 15932
 $21 = $sext1718 << 16 >> 16; //@line 15934
 $23 = ($21 | 0) == 0 & 1; //@line 15936
 HEAP32[96441] = 0; //@line 15937
 HEAP32[96442] = 0; //@line 15937
 HEAP32[96443] = 0; //@line 15937
 HEAP32[96444] = 0; //@line 15937
 HEAP32[96442] = $23; //@line 15938
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 15941
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $21); //@line 15945
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15948
 return;
}
function _frexp($0, $1) {
 $0 = +$0;
 $1 = $1 | 0;
 var $$0 = 0.0, $$016 = 0.0, $2 = 0, $3 = 0, $4 = 0, $9 = 0.0, $storemerge = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 58777
 $2 = HEAP32[tempDoublePtr >> 2] | 0; //@line 58777
 $3 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 58778
 $4 = _bitshift64Lshr($2 | 0, $3 | 0, 52) | 0; //@line 58779
 switch ($4 & 2047) {
 case 0:
  {
   if ($0 != 0.0) {
    $9 = +_frexp($0 * 18446744073709552000.0, $1); //@line 58788
    $$016 = $9; //@line 58791
    $storemerge = (HEAP32[$1 >> 2] | 0) + -64 | 0; //@line 58791
   } else {
    $$016 = $0; //@line 58793
    $storemerge = 0; //@line 58793
   }
   HEAP32[$1 >> 2] = $storemerge; //@line 58795
   $$0 = $$016; //@line 58796
   break;
  }
 case 2047:
  {
   $$0 = $0; //@line 58800
   break;
  }
 default:
  {
   HEAP32[$1 >> 2] = ($4 & 2047) + -1022; //@line 58806
   HEAP32[tempDoublePtr >> 2] = $2; //@line 58809
   HEAP32[tempDoublePtr + 4 >> 2] = $3 & -2146435073 | 1071644672; //@line 58809
   $$0 = +HEAPF64[tempDoublePtr >> 3]; //@line 58810
  }
 }
 return +$$0;
}
function __Z12op_c07a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $sext1920 = 0;
 $4 = HEAP32[162769] | 0; //@line 28699
 $$cast = $4; //@line 28701
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 28715
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 28721
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28722
 $26 = HEAP32[$25 >> 2] | 0; //@line 28723
 $sext1920 = $26 & $24; //@line 28724
 $27 = $sext1920 << 16 >> 16; //@line 28726
 $29 = ($27 | 0) == 0 & 1; //@line 28728
 HEAP32[96441] = 0; //@line 28729
 HEAP32[96442] = 0; //@line 28729
 HEAP32[96443] = 0; //@line 28729
 HEAP32[96444] = 0; //@line 28729
 HEAP32[96442] = $29; //@line 28730
 HEAP32[96443] = $sext1920 >>> 15 & 1; //@line 28733
 HEAP32[$25 >> 2] = $26 & -65536 | $27 & 65535; //@line 28737
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28740
 return;
}
function __Z12op_9100_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 19901
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19902
 $7 = HEAP32[$6 >> 2] | 0; //@line 19903
 $13 = ($7 << 24 >> 24) - ($5 << 24 >> 24) + (((HEAP32[96445] | 0) != 0) << 31 >> 31) | 0; //@line 19912
 $14 = $5 >>> 7; //@line 19913
 $15 = $7 >>> 7; //@line 19915
 $16 = $13 >>> 7; //@line 19917
 $sext35$lobit = $16 & 1; //@line 19918
 $18 = $sext35$lobit ^ $15 & 1; //@line 19920
 HEAP32[96444] = $18 & ($15 ^ $14); //@line 19922
 $22 = $18 & ($16 ^ $14) ^ $14 & 1; //@line 19925
 HEAP32[96441] = $22; //@line 19926
 HEAP32[96445] = $22; //@line 19927
 $sext35$mask = $13 & 255; //@line 19929
 HEAP32[96442] = ($sext35$mask | 0) == 0 & HEAP32[96442]; //@line 19933
 HEAP32[96443] = $sext35$lobit; //@line 19934
 HEAP32[$6 >> 2] = $sext35$mask | $7 & -256; //@line 19937
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19940
 return;
}
function __Z12op_807a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $sext1920 = 0;
 $4 = HEAP32[162769] | 0; //@line 14375
 $$cast = $4; //@line 14377
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 14391
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 14397
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14398
 $26 = HEAP32[$25 >> 2] | 0; //@line 14399
 $sext1920 = $26 | $24; //@line 14400
 $27 = $sext1920 << 16 >> 16; //@line 14402
 $29 = ($27 | 0) == 0 & 1; //@line 14404
 HEAP32[96441] = 0; //@line 14405
 HEAP32[96442] = 0; //@line 14405
 HEAP32[96443] = 0; //@line 14405
 HEAP32[96444] = 0; //@line 14405
 HEAP32[96442] = $29; //@line 14406
 HEAP32[96443] = $sext1920 >>> 15 & 1; //@line 14409
 HEAP32[$25 >> 2] = $26 & -65536 | $27 & 65535; //@line 14413
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14416
 return;
}
function __Z12op_23e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $19 = 0, $20 = 0, $29 = 0, $38 = 0, $4 = 0, $40 = 0;
 $4 = HEAP32[162769] | 0; //@line 34426
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 34437
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 34442
 $20 = HEAP32[162769] | 0; //@line 34443
 $29 = (HEAPU8[$20 + 5 >> 0] | 0) << 16 | (HEAPU8[$20 + 4 >> 0] | 0) << 24; //@line 34452
 $38 = $29 | (HEAPU8[$20 + 6 >> 0] | 0) << 8 | (HEAPU8[$20 + 7 >> 0] | 0); //@line 34461
 $40 = ($19 | 0) == 0 & 1; //@line 34463
 HEAP32[96441] = 0; //@line 34464
 HEAP32[96442] = 0; //@line 34464
 HEAP32[96443] = 0; //@line 34464
 HEAP32[96444] = 0; //@line 34464
 HEAP32[96442] = $40; //@line 34465
 HEAP32[96443] = $19 >>> 31; //@line 34467
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($38, $19); //@line 34473
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 34476
 return;
}
function __Z12WarningAlertPKc($0) {
 $0 = $0 | 0;
 var $1 = 0, $5 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, sp = 0;
 sp = STACKTOP; //@line 48596
 STACKTOP = STACKTOP + 32 | 0; //@line 48597
 $vararg_buffer6 = sp + 24 | 0; //@line 48598
 $vararg_buffer3 = sp + 16 | 0; //@line 48599
 $vararg_buffer = sp; //@line 48600
 $1 = HEAP32[30886] | 0; //@line 48601
 if ($1 | 0) {
  HEAP32[$vararg_buffer >> 2] = -2004; //@line 48604
  HEAP32[$vararg_buffer + 4 >> 2] = $0; //@line 48606
  HEAP32[$vararg_buffer + 8 >> 2] = 0; //@line 48608
  if (!(__Z17rpc_method_invokeP16rpc_connection_tiz($1, 2, $vararg_buffer) | 0)) {
   $5 = HEAP32[30886] | 0; //@line 48612
   HEAP32[$vararg_buffer3 >> 2] = 0; //@line 48613
   if (!(__Z25rpc_method_wait_for_replyP16rpc_connection_tz($5, $vararg_buffer3) | 0)) {
    STACKTOP = sp; //@line 48617
    return;
   }
  }
 }
 $8 = __Z9GetStringi(6) | 0; //@line 48621
 HEAP32[$vararg_buffer6 >> 2] = $0; //@line 48622
 _printf($8, $vararg_buffer6) | 0; //@line 48623
 STACKTOP = sp; //@line 48624
 return;
}
function __Z12op_d140_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $sext39$lobit = 0, $sext39$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 34080
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 34081
 $7 = HEAP32[$6 >> 2] | 0; //@line 34082
 $14 = ($7 << 16 >> 16) + ($5 << 16 >> 16) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 34091
 $15 = $5 >>> 15; //@line 34092
 $16 = $7 >>> 15; //@line 34094
 $17 = $14 >>> 15; //@line 34096
 $sext39$lobit = $17 & 1; //@line 34097
 $19 = $sext39$lobit ^ $16 & 1; //@line 34099
 HEAP32[96444] = $19 & ($17 ^ $15); //@line 34101
 $23 = $19 & ($16 ^ $15) ^ $15 & 1; //@line 34104
 HEAP32[96441] = $23; //@line 34105
 HEAP32[96445] = $23; //@line 34106
 $sext39$mask = $14 & 65535; //@line 34108
 HEAP32[96442] = ($sext39$mask | 0) == 0 & HEAP32[96442]; //@line 34112
 HEAP32[96443] = $sext39$lobit; //@line 34113
 HEAP32[$6 >> 2] = $sext39$mask | $7 & -65536; //@line 34116
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34119
 return;
}
function __Z12op_b03b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $4 = 0, $sext$lobit = 0, $sext31$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 24441
 $$cast = $4; //@line 24446
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 24455
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 24461
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24463
 $26 = $25 - $23 | 0; //@line 24464
 $sext$lobit = $25 >>> 7 & 1; //@line 24468
 $sext31$lobit = $26 >>> 7 & 1; //@line 24470
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 24474
 HEAP32[96444] = ($23 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext31$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24479
 HEAP32[96441] = ($23 & 255) >>> 0 > ($25 & 255) >>> 0 & 1; //@line 24484
 HEAP32[96443] = $sext31$lobit; //@line 24485
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24488
 return;
}
function __Z11op_640_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $15 = 0, $18 = 0, $2 = 0, $27 = 0, $5 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $2 = HEAP32[162769] | 0; //@line 12665
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 12668
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 12673
 $11 = 651008 + (($0 & 7) << 2) | 0; //@line 12674
 $12 = HEAP32[$11 >> 2] | 0; //@line 12675
 $13 = $12 << 16 >> 16; //@line 12677
 $15 = ($10 << 16 >> 16) + $13 | 0; //@line 12680
 $18 = $15 >>> 15; //@line 12684
 $sext32$lobit = $18 & 1; //@line 12685
 $sext32$mask = $15 & 65535; //@line 12686
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 12689
 HEAP32[96444] = ($sext32$lobit ^ $12 >>> 15 & 1) & ($18 ^ $5 >>> 7); //@line 12693
 $27 = ($13 & 65535 ^ 65535) >>> 0 < $10 >>> 0 & 1; //@line 12697
 HEAP32[96441] = $27; //@line 12698
 HEAP32[96445] = $27; //@line 12699
 HEAP32[96443] = $sext32$lobit; //@line 12700
 HEAP32[$11 >> 2] = $12 & -65536 | $sext32$mask; //@line 12703
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12706
 return;
}
function __Z11op_610_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $19 = 0, $28 = 0, $4 = 0, $7 = 0, $9 = 0, $sext29$lobit = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 12246
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 12249
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 12251
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 12255
 $14 = $13 << 24 >> 24; //@line 12257
 $16 = $14 + ($4 << 24 >> 24) | 0; //@line 12259
 $19 = $16 >>> 7; //@line 12264
 $sext29$lobit = $19 & 1; //@line 12265
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 12269
 HEAP32[96444] = ($sext29$lobit ^ $13 >>> 7 & 1) & ($19 ^ ($4 & 255) >>> 7 & 255); //@line 12273
 $28 = ($14 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12277
 HEAP32[96441] = $28; //@line 12278
 HEAP32[96445] = $28; //@line 12279
 HEAP32[96443] = $sext29$lobit; //@line 12280
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 12284
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12287
 return;
}
function __Z11op_230_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 8643
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 8645
 $5 = $2 + 4 | 0; //@line 8646
 HEAP32[162769] = $5; //@line 8647
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8649
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 8656
 HEAP32[162769] = $2 + 6; //@line 8658
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 8659
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 8661
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) & ($4 & 255); //@line 8667
 $25 = $24 << 24 >> 24; //@line 8669
 $27 = ($25 | 0) == 0 & 1; //@line 8671
 HEAP32[96441] = 0; //@line 8672
 HEAP32[96442] = 0; //@line 8672
 HEAP32[96443] = 0; //@line 8672
 HEAP32[96444] = 0; //@line 8672
 HEAP32[96442] = $27; //@line 8673
 HEAP32[96443] = $24 >>> 7; //@line 8675
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 8679
 return;
}
function __Z10op_30_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 4899
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 4901
 $5 = $2 + 4 | 0; //@line 4902
 HEAP32[162769] = $5; //@line 4903
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4905
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 4912
 HEAP32[162769] = $2 + 6; //@line 4914
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 4915
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 4917
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0 | $4 & 255; //@line 4923
 $25 = $24 << 24 >> 24; //@line 4925
 $27 = ($25 | 0) == 0 & 1; //@line 4927
 HEAP32[96441] = 0; //@line 4928
 HEAP32[96442] = 0; //@line 4928
 HEAP32[96443] = 0; //@line 4928
 HEAP32[96444] = 0; //@line 4928
 HEAP32[96442] = $27; //@line 4929
 HEAP32[96443] = $24 >>> 7 & 1; //@line 4932
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 4936
 return;
}
function __Z10ErrorAlertPKc($0) {
 $0 = $0 | 0;
 var $1 = 0, $5 = 0, $8 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, sp = 0;
 sp = STACKTOP; //@line 48683
 STACKTOP = STACKTOP + 32 | 0; //@line 48684
 $vararg_buffer6 = sp + 24 | 0; //@line 48685
 $vararg_buffer3 = sp + 16 | 0; //@line 48686
 $vararg_buffer = sp; //@line 48687
 $1 = HEAP32[30886] | 0; //@line 48688
 if ($1 | 0) {
  HEAP32[$vararg_buffer >> 2] = -2004; //@line 48691
  HEAP32[$vararg_buffer + 4 >> 2] = $0; //@line 48693
  HEAP32[$vararg_buffer + 8 >> 2] = 0; //@line 48695
  if (!(__Z17rpc_method_invokeP16rpc_connection_tiz($1, 1, $vararg_buffer) | 0)) {
   $5 = HEAP32[30886] | 0; //@line 48699
   HEAP32[$vararg_buffer3 >> 2] = 0; //@line 48700
   if (!(__Z25rpc_method_wait_for_replyP16rpc_connection_tz($5, $vararg_buffer3) | 0)) {
    STACKTOP = sp; //@line 48704
    return;
   }
  }
 }
 $8 = __Z9GetStringi(3) | 0; //@line 48708
 HEAP32[$vararg_buffer6 >> 2] = $0; //@line 48709
 _printf($8, $vararg_buffer6) | 0; //@line 48710
 STACKTOP = sp; //@line 48711
 return;
}
function __Z12op_c03a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $sext1516 = 0;
 $4 = HEAP32[162769] | 0; //@line 28224
 $$cast = $4; //@line 28226
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 28240
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 28246
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28247
 $26 = HEAP32[$25 >> 2] | 0; //@line 28248
 $sext1516 = $26 & $24; //@line 28249
 $27 = $sext1516 << 24 >> 24; //@line 28251
 $29 = ($27 | 0) == 0 & 1; //@line 28253
 HEAP32[96441] = 0; //@line 28254
 HEAP32[96442] = 0; //@line 28254
 HEAP32[96443] = 0; //@line 28254
 HEAP32[96444] = 0; //@line 28254
 HEAP32[96442] = $29; //@line 28255
 HEAP32[96443] = $sext1516 >>> 7 & 1; //@line 28258
 HEAP32[$25 >> 2] = $26 & -256 | $27 & 255; //@line 28262
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28265
 return;
}
function __Z12op_803a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $sext1516 = 0;
 $4 = HEAP32[162769] | 0; //@line 13899
 $$cast = $4; //@line 13901
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 13915
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 13921
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13922
 $26 = HEAP32[$25 >> 2] | 0; //@line 13923
 $sext1516 = $26 | $24; //@line 13924
 $27 = $sext1516 << 24 >> 24; //@line 13926
 $29 = ($27 | 0) == 0 & 1; //@line 13928
 HEAP32[96441] = 0; //@line 13929
 HEAP32[96442] = 0; //@line 13929
 HEAP32[96443] = 0; //@line 13929
 HEAP32[96444] = 0; //@line 13929
 HEAP32[96442] = $29; //@line 13930
 HEAP32[96443] = $sext1516 >>> 7 & 1; //@line 13933
 HEAP32[$25 >> 2] = $26 & -256 | $27 & 255; //@line 13937
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13940
 return;
}
function __Z12op_3030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 35080
 $4 = HEAP32[162769] | 0; //@line 35081
 $5 = $4 + 2 | 0; //@line 35082
 HEAP32[162769] = $5; //@line 35083
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35085
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 35092
 HEAP32[162769] = $4 + 4; //@line 35094
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 35095
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 35101
 $23 = $22 << 16 >> 16; //@line 35103
 $25 = ($23 | 0) == 0 & 1; //@line 35105
 HEAP32[96441] = 0; //@line 35106
 HEAP32[96442] = 0; //@line 35106
 HEAP32[96443] = 0; //@line 35106
 HEAP32[96444] = 0; //@line 35106
 HEAP32[96442] = $25; //@line 35107
 HEAP32[96443] = $22 >>> 15 & 1; //@line 35110
 $27 = 651008 + ($3 << 2) | 0; //@line 35111
 HEAP32[$27 >> 2] = HEAP32[$27 >> 2] & -65536 | $23 & 65535; //@line 35116
 return;
}
function __Z12op_b03a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $4 = 0, $sext28$lobit = 0, $sext30$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 22213
 $$cast = $4; //@line 22215
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 22229
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 22235
 $26 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22237
 $27 = $26 - $24 | 0; //@line 22238
 $sext28$lobit = $26 >>> 7 & 1; //@line 22242
 $sext30$lobit = $27 >>> 7 & 1; //@line 22244
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 22248
 HEAP32[96444] = ($24 >>> 7 & 1 | 0) != ($sext28$lobit | 0) & ($sext30$lobit | 0) != ($sext28$lobit | 0) & 1; //@line 22253
 HEAP32[96441] = ($24 & 255) >>> 0 > ($26 & 255) >>> 0 & 1; //@line 22258
 HEAP32[96443] = $sext30$lobit; //@line 22259
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22262
 return;
}
function __Z12op_9010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $16 = 0, $18 = 0, $28 = 0, $5 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 17688
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 17694
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17695
 $13 = HEAP32[$12 >> 2] | 0; //@line 17696
 $16 = ($13 << 24 >> 24) - ($11 << 24 >> 24) | 0; //@line 17701
 $18 = $13 >>> 7; //@line 17703
 $sext35$lobit = $16 >>> 7 & 1; //@line 17706
 $sext35$mask = $16 & 255; //@line 17707
 HEAP32[96442] = ($sext35$mask | 0) == 0 & 1; //@line 17710
 HEAP32[96444] = ($sext35$lobit ^ $18 & 1) & ($18 ^ $11 >>> 7); //@line 17714
 $28 = ($11 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 17718
 HEAP32[96441] = $28; //@line 17719
 HEAP32[96445] = $28; //@line 17720
 HEAP32[96443] = $sext35$lobit; //@line 17721
 HEAP32[$12 >> 2] = $13 & -256 | $sext35$mask; //@line 17724
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17727
 return;
}
function __Z12op_3198_3_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $16 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 44918
 $5 = HEAP32[$4 >> 2] | 0; //@line 44919
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 44925
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 44928
 $16 = HEAP32[162769] | 0; //@line 44931
 $25 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$16 + 2 >> 0] | 0) << 8 | (HEAPU8[$16 + 3 >> 0] | 0)) | 0; //@line 44940
 $26 = $11 << 16 >> 16; //@line 44942
 $28 = ($26 | 0) == 0 & 1; //@line 44944
 HEAP32[96441] = 0; //@line 44945
 HEAP32[96442] = 0; //@line 44945
 HEAP32[96443] = 0; //@line 44945
 HEAP32[96444] = 0; //@line 44945
 HEAP32[96442] = $28; //@line 44946
 HEAP32[96443] = $11 >>> 15 & 1; //@line 44949
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 44955
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44958
 return;
}
function __Z12op_d0ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit35 = 0, $18 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $34 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32978
 $$cast = $4; //@line 32980
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 32994
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 32999
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 33000
 $25 = HEAP32[$24 >> 2] | 0; //@line 33001
 $26 = $25 + $23 | 0; //@line 33002
 $$lobit35 = $26 >>> 31; //@line 33005
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 33008
 HEAP32[96444] = ($$lobit35 ^ $23 >>> 31) & ($$lobit35 ^ $25 >>> 31); //@line 33012
 $34 = $23 >>> 0 > ~$25 >>> 0 & 1; //@line 33015
 HEAP32[96441] = $34; //@line 33016
 HEAP32[96445] = $34; //@line 33017
 HEAP32[96443] = $$lobit35; //@line 33018
 HEAP32[$24 >> 2] = $26; //@line 33019
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33022
 return;
}
function __Z12op_90b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $15 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $30 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 23959
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23968
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 23973
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23974
 $22 = HEAP32[$21 >> 2] | 0; //@line 23975
 $23 = $22 - $20 | 0; //@line 23976
 $$lobit37 = $22 >>> 31; //@line 23978
 $$lobit38 = $23 >>> 31; //@line 23979
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 23982
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $20 >>> 31); //@line 23986
 $30 = $22 >>> 0 < $20 >>> 0 & 1; //@line 23988
 HEAP32[96441] = $30; //@line 23989
 HEAP32[96445] = $30; //@line 23990
 HEAP32[96443] = $$lobit38; //@line 23991
 HEAP32[$21 >> 2] = $23; //@line 23992
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23995
 return;
}
function __Z12op_d110_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $5 = 0, $7 = 0, $9 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33648
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33650
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 33652
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 33656
 $14 = $13 << 24 >> 24; //@line 33658
 $16 = $14 + ($5 << 24 >> 24) | 0; //@line 33661
 $19 = $16 >>> 7; //@line 33665
 $sext34$lobit = $19 & 1; //@line 33666
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 33670
 HEAP32[96444] = ($sext34$lobit ^ $13 >>> 7 & 1) & ($19 ^ $5 >>> 7); //@line 33674
 $29 = ($14 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 33679
 HEAP32[96441] = $29; //@line 33680
 HEAP32[96445] = $29; //@line 33681
 HEAP32[96443] = $sext34$lobit; //@line 33682
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 33686
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33689
 return;
}
function __Z12op_9198_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $$lobit39 = 0, $12 = 0, $15 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21133
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 21134
 $7 = HEAP32[$6 >> 2] | 0; //@line 21135
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 21137
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 21140
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 21143
 $15 = $12 - $5 | 0; //@line 21144
 $$lobit38 = $12 >>> 31; //@line 21146
 $$lobit39 = $15 >>> 31; //@line 21147
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 21150
 HEAP32[96444] = ($$lobit39 ^ $$lobit38) & ($$lobit38 ^ $5 >>> 31); //@line 21154
 $22 = $12 >>> 0 < $5 >>> 0 & 1; //@line 21156
 HEAP32[96441] = $22; //@line 21157
 HEAP32[96445] = $22; //@line 21158
 HEAP32[96443] = $$lobit39; //@line 21159
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 21163
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21166
 return;
}
function __Z12op_1138_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 25131
 $3 = HEAP32[162769] | 0; //@line 25132
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 25142
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 25148
 $19 = 651040 + ($2 << 2) | 0; //@line 25149
 $23 = (HEAP32[$19 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 25153
 HEAP32[$19 >> 2] = $23; //@line 25154
 $24 = $18 << 24 >> 24; //@line 25156
 $26 = ($24 | 0) == 0 & 1; //@line 25158
 HEAP32[96441] = 0; //@line 25159
 HEAP32[96442] = 0; //@line 25159
 HEAP32[96443] = 0; //@line 25159
 HEAP32[96444] = 0; //@line 25159
 HEAP32[96442] = $26; //@line 25160
 HEAP32[96443] = $18 >>> 7 & 1; //@line 25163
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, $24); //@line 25169
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25172
 return;
}
function __Z12op_d100_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $sext35$lobit = 0, $sext35$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 33523
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 33524
 $7 = HEAP32[$6 >> 2] | 0; //@line 33525
 $14 = ($7 << 24 >> 24) + ($5 << 24 >> 24) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 33534
 $15 = $5 >>> 7; //@line 33535
 $16 = $7 >>> 7; //@line 33537
 $17 = $14 >>> 7; //@line 33539
 $sext35$lobit = $17 & 1; //@line 33540
 $19 = $sext35$lobit ^ $16 & 1; //@line 33542
 HEAP32[96444] = $19 & ($17 ^ $15); //@line 33544
 $23 = $19 & ($16 ^ $15) ^ $15 & 1; //@line 33547
 HEAP32[96441] = $23; //@line 33548
 HEAP32[96445] = $23; //@line 33549
 $sext35$mask = $14 & 255; //@line 33551
 HEAP32[96442] = ($sext35$mask | 0) == 0 & HEAP32[96442]; //@line 33555
 HEAP32[96443] = $sext35$lobit; //@line 33556
 HEAP32[$6 >> 2] = $sext35$mask | $7 & -256; //@line 33559
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33562
 return;
}
function __Z12op_b1f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $14 = 0, $16 = 0, $21 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 27576
 $5 = $4 + 2 | 0; //@line 27577
 HEAP32[162769] = $5; //@line 27578
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27580
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 27587
 HEAP32[162769] = $4 + 4; //@line 27589
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 27590
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 27595
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27597
 $24 = $23 - $21 | 0; //@line 27598
 $$lobit35 = $23 >>> 31; //@line 27600
 $$lobit36 = $24 >>> 31; //@line 27601
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 27604
 HEAP32[96444] = ($21 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 27609
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 27612
 HEAP32[96443] = $$lobit36; //@line 27613
 return;
}
function __Z12op_b0b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $14 = 0, $16 = 0, $21 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 25304
 $5 = $4 + 2 | 0; //@line 25305
 HEAP32[162769] = $5; //@line 25306
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25308
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 25315
 HEAP32[162769] = $4 + 4; //@line 25317
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 25318
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 25323
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25325
 $24 = $23 - $21 | 0; //@line 25326
 $$lobit35 = $23 >>> 31; //@line 25328
 $$lobit36 = $24 >>> 31; //@line 25329
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 25332
 HEAP32[96444] = ($21 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 25337
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 25340
 HEAP32[96443] = $$lobit36; //@line 25341
 return;
}
function __Z12op_1030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 23560
 $4 = HEAP32[162769] | 0; //@line 23561
 $5 = $4 + 2 | 0; //@line 23562
 HEAP32[162769] = $5; //@line 23563
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 23565
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 23572
 HEAP32[162769] = $4 + 4; //@line 23574
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 23575
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 23581
 $23 = $22 << 24 >> 24; //@line 23583
 $25 = ($23 | 0) == 0 & 1; //@line 23585
 HEAP32[96441] = 0; //@line 23586
 HEAP32[96442] = 0; //@line 23586
 HEAP32[96443] = 0; //@line 23586
 HEAP32[96444] = 0; //@line 23586
 HEAP32[96442] = $25; //@line 23587
 HEAP32[96443] = $22 >>> 7 & 1; //@line 23590
 $27 = 651008 + ($3 << 2) | 0; //@line 23591
 HEAP32[$27 >> 2] = HEAP32[$27 >> 2] & -256 | $23 & 255; //@line 23596
 return;
}
function __Z11op_cbb_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $1 = 0, $19 = 0, $34 = 0, $39 = 0, $4 = 0, $40 = 0;
 $1 = HEAP32[162769] | 0; //@line 30592
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 30595
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 30610
 $34 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 6 + $1 - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 30625
 $39 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($34 >>> 16 << 2) >> 2] >> 2] & 127]($34) | 0; //@line 30630
 $40 = $39 - $19 | 0; //@line 30631
 $$lobit32 = $39 >>> 31; //@line 30633
 $$lobit33 = $40 >>> 31; //@line 30634
 HEAP32[96442] = ($40 | 0) == 0 & 1; //@line 30637
 HEAP32[96444] = ($4 >>> 7 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 30642
 HEAP32[96441] = $39 >>> 0 < $19 >>> 0 & 1; //@line 30645
 HEAP32[96443] = $$lobit33; //@line 30646
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 30649
 return;
}
function __Z12op_c118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1819 = 0;
 $3 = $0 & 7; //@line 29845
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29847
 $6 = 651040 + ($3 << 2) | 0; //@line 29848
 $7 = HEAP32[$6 >> 2] | 0; //@line 29849
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 29851
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 29855
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 29860
 $sext1819 = $13 & $5; //@line 29861
 $18 = $sext1819 << 24 >> 24; //@line 29863
 $20 = ($18 | 0) == 0 & 1; //@line 29865
 HEAP32[96441] = 0; //@line 29866
 HEAP32[96442] = 0; //@line 29866
 HEAP32[96443] = 0; //@line 29866
 HEAP32[96444] = 0; //@line 29866
 HEAP32[96442] = $20; //@line 29867
 HEAP32[96443] = $sext1819 >>> 7 & 1; //@line 29870
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $18); //@line 29874
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29877
 return;
}
function __Z12op_b118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1819 = 0;
 $3 = $0 & 7; //@line 26307
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26309
 $6 = 651040 + ($3 << 2) | 0; //@line 26310
 $7 = HEAP32[$6 >> 2] | 0; //@line 26311
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 26313
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 26317
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 26322
 $sext1819 = $13 ^ $5; //@line 26323
 $18 = $sext1819 << 24 >> 24; //@line 26325
 $20 = ($18 | 0) == 0 & 1; //@line 26327
 HEAP32[96441] = 0; //@line 26328
 HEAP32[96442] = 0; //@line 26328
 HEAP32[96443] = 0; //@line 26328
 HEAP32[96444] = 0; //@line 26328
 HEAP32[96442] = $20; //@line 26329
 HEAP32[96443] = $sext1819 >>> 7 & 1; //@line 26332
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $18); //@line 26336
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26339
 return;
}
function __Z12op_90b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $12 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $36 = 0;
 $3 = HEAP32[162769] | 0; //@line 19302
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 19311
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 19325
 $27 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19326
 $28 = HEAP32[$27 >> 2] | 0; //@line 19327
 $29 = $28 - $26 | 0; //@line 19328
 $$lobit33 = $28 >>> 31; //@line 19330
 $$lobit34 = $29 >>> 31; //@line 19331
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 19334
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $26 >>> 31); //@line 19338
 $36 = $28 >>> 0 < $26 >>> 0 & 1; //@line 19340
 HEAP32[96441] = $36; //@line 19341
 HEAP32[96445] = $36; //@line 19342
 HEAP32[96443] = $$lobit34; //@line 19343
 HEAP32[$27 >> 2] = $29; //@line 19344
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19347
 return;
}
function __Z12op_8118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext1819 = 0;
 $3 = $0 & 7; //@line 15795
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15797
 $6 = 651040 + ($3 << 2) | 0; //@line 15798
 $7 = HEAP32[$6 >> 2] | 0; //@line 15799
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 15801
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 15805
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 15810
 $sext1819 = $13 | $5; //@line 15811
 $18 = $sext1819 << 24 >> 24; //@line 15813
 $20 = ($18 | 0) == 0 & 1; //@line 15815
 HEAP32[96441] = 0; //@line 15816
 HEAP32[96442] = 0; //@line 15816
 HEAP32[96443] = 0; //@line 15816
 HEAP32[96444] = 0; //@line 15816
 HEAP32[96442] = $20; //@line 15817
 HEAP32[96443] = $sext1819 >>> 7 & 1; //@line 15820
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $18); //@line 15824
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15827
 return;
}
function __Z12op_11d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $3 = 0, $9 = 0;
 $1 = $0 & 7; //@line 26706
 $2 = 651040 + ($1 << 2) | 0; //@line 26707
 $3 = HEAP32[$2 >> 2] | 0; //@line 26708
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 26714
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 26719
 $14 = HEAP32[162769] | 0; //@line 26720
 $23 = ((HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) << 16 >> 16; //@line 26730
 $24 = $9 << 24 >> 24; //@line 26732
 $26 = ($24 | 0) == 0 & 1; //@line 26734
 HEAP32[96441] = 0; //@line 26735
 HEAP32[96442] = 0; //@line 26735
 HEAP32[96443] = 0; //@line 26735
 HEAP32[96444] = 0; //@line 26735
 HEAP32[96442] = $26; //@line 26736
 HEAP32[96443] = $9 >>> 7 & 1; //@line 26739
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, $24); //@line 26745
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26748
 return;
}
function __Z11op_a60_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $sext1819 = 0;
 $2 = HEAP32[162769] | 0; //@line 15957
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 15965
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 15966
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 15968
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 15970
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 15974
 HEAP32[$11 >> 2] = $13; //@line 15975
 $sext1819 = $19 ^ $10; //@line 15976
 $20 = $sext1819 << 16 >> 16; //@line 15978
 $22 = ($20 | 0) == 0 & 1; //@line 15980
 HEAP32[96441] = 0; //@line 15981
 HEAP32[96442] = 0; //@line 15981
 HEAP32[96443] = 0; //@line 15981
 HEAP32[96444] = 0; //@line 15981
 HEAP32[96442] = $22; //@line 15982
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 15985
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $20); //@line 15989
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15992
 return;
}
function __Z12op_d1b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $17 = 0, $19 = 0, $22 = 0, $23 = 0, $31 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 37042
 $8 = HEAP32[162769] | 0; //@line 37045
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 37054
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 37056
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0; //@line 37059
 $23 = $22 + $5 | 0; //@line 37060
 $$lobit38 = $23 >>> 31; //@line 37063
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 37066
 HEAP32[96444] = ($$lobit38 ^ $5 >>> 31) & ($$lobit38 ^ $22 >>> 31); //@line 37070
 $31 = $5 >>> 0 > ~$22 >>> 0 & 1; //@line 37073
 HEAP32[96441] = $31; //@line 37074
 HEAP32[96445] = $31; //@line 37075
 HEAP32[96443] = $$lobit38; //@line 37076
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 37080
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37083
 return;
}
function __Z12op_3158_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $16 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 37477
 $5 = HEAP32[$4 >> 2] | 0; //@line 37478
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 37484
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 37487
 $16 = HEAP32[162769] | 0; //@line 37490
 $26 = (((HEAPU8[$16 + 2 >> 0] | 0) << 8 | (HEAPU8[$16 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37501
 $27 = $11 << 16 >> 16; //@line 37503
 $29 = ($27 | 0) == 0 & 1; //@line 37505
 HEAP32[96441] = 0; //@line 37506
 HEAP32[96442] = 0; //@line 37506
 HEAP32[96443] = 0; //@line 37506
 HEAP32[96444] = 0; //@line 37506
 HEAP32[96442] = $29; //@line 37507
 HEAP32[96443] = $11 >>> 15 & 1; //@line 37510
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 37516
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37519
 return;
}
function __Z12op_213b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32427
 $$cast = $4; //@line 32432
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 32441
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32446
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 32447
 $25 = (HEAP32[$23 >> 2] | 0) + -4 | 0; //@line 32449
 HEAP32[$23 >> 2] = $25; //@line 32450
 $27 = ($22 | 0) == 0 & 1; //@line 32452
 HEAP32[96441] = 0; //@line 32453
 HEAP32[96442] = 0; //@line 32453
 HEAP32[96443] = 0; //@line 32453
 HEAP32[96444] = 0; //@line 32453
 HEAP32[96442] = $27; //@line 32454
 HEAP32[96443] = $22 >>> 31; //@line 32456
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $22); //@line 32462
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32465
 return;
}
function __Z11op_c98_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 19941
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19944
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 19959
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 19960
 $22 = HEAP32[$21 >> 2] | 0; //@line 19961
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($22 >>> 16 << 2) >> 2] >> 2] & 127]($22) | 0; //@line 19966
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 19969
 $30 = $27 - $20 | 0; //@line 19970
 $$lobit32 = $27 >>> 31; //@line 19972
 $$lobit33 = $30 >>> 31; //@line 19973
 HEAP32[96442] = ($30 | 0) == 0 & 1; //@line 19976
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 19981
 HEAP32[96441] = $27 >>> 0 < $20 >>> 0 & 1; //@line 19984
 HEAP32[96443] = $$lobit33; //@line 19985
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19988
 return;
}
function __Z12op_90a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $31 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 19157
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 19168
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 19173
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19174
 $23 = HEAP32[$22 >> 2] | 0; //@line 19175
 $24 = $23 - $21 | 0; //@line 19176
 $$lobit37 = $23 >>> 31; //@line 19178
 $$lobit38 = $24 >>> 31; //@line 19179
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 19182
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $21 >>> 31); //@line 19186
 $31 = $23 >>> 0 < $21 >>> 0 & 1; //@line 19188
 HEAP32[96441] = $31; //@line 19189
 HEAP32[96445] = $31; //@line 19190
 HEAP32[96443] = $$lobit38; //@line 19191
 HEAP32[$22 >> 2] = $24; //@line 19192
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19195
 return;
}
function __Z12op_c120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0, $6 = 0, $sext1920 = 0;
 $3 = $0 & 7; //@line 29887
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29889
 $6 = 651040 + ($3 << 2) | 0; //@line 29890
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 29894
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 29896
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 29900
 HEAP32[$6 >> 2] = $10; //@line 29901
 $sext1920 = $16 & $5; //@line 29902
 $17 = $sext1920 << 24 >> 24; //@line 29904
 $19 = ($17 | 0) == 0 & 1; //@line 29906
 HEAP32[96441] = 0; //@line 29907
 HEAP32[96442] = 0; //@line 29907
 HEAP32[96443] = 0; //@line 29907
 HEAP32[96444] = 0; //@line 29907
 HEAP32[96442] = $19; //@line 29908
 HEAP32[96443] = $sext1920 >>> 7 & 1; //@line 29911
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $17); //@line 29915
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29918
 return;
}
function __Z12op_b120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0, $6 = 0, $sext1920 = 0;
 $3 = $0 & 7; //@line 26349
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26351
 $6 = 651040 + ($3 << 2) | 0; //@line 26352
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 26356
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 26358
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 26362
 HEAP32[$6 >> 2] = $10; //@line 26363
 $sext1920 = $16 ^ $5; //@line 26364
 $17 = $sext1920 << 24 >> 24; //@line 26366
 $19 = ($17 | 0) == 0 & 1; //@line 26368
 HEAP32[96441] = 0; //@line 26369
 HEAP32[96442] = 0; //@line 26369
 HEAP32[96443] = 0; //@line 26369
 HEAP32[96444] = 0; //@line 26369
 HEAP32[96442] = $19; //@line 26370
 HEAP32[96443] = $sext1920 >>> 7 & 1; //@line 26373
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $17); //@line 26377
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26380
 return;
}
function __Z12op_8120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0, $6 = 0, $sext1920 = 0;
 $3 = $0 & 7; //@line 15837
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15839
 $6 = 651040 + ($3 << 2) | 0; //@line 15840
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 15844
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 15846
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 15850
 HEAP32[$6 >> 2] = $10; //@line 15851
 $sext1920 = $16 | $5; //@line 15852
 $17 = $sext1920 << 24 >> 24; //@line 15854
 $19 = ($17 | 0) == 0 & 1; //@line 15856
 HEAP32[96441] = 0; //@line 15857
 HEAP32[96442] = 0; //@line 15857
 HEAP32[96443] = 0; //@line 15857
 HEAP32[96444] = 0; //@line 15857
 HEAP32[96442] = $19; //@line 15858
 HEAP32[96443] = $sext1920 >>> 7 & 1; //@line 15861
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $17); //@line 15865
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15868
 return;
}
function __Z12op_50b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $17 = 0, $19 = 0, $22 = 0, $23 = 0, $31 = 0, $4 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 11442
 $8 = HEAP32[162769] | 0; //@line 11446
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 11455
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 11457
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0; //@line 11460
 $23 = $22 + $4 | 0; //@line 11461
 $$lobit38 = $23 >>> 31; //@line 11464
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 11467
 HEAP32[96444] = ($$lobit38 ^ $4 >>> 31) & ($$lobit38 ^ $22 >>> 31); //@line 11471
 $31 = $4 >>> 0 > ~$22 >>> 0 & 1; //@line 11474
 HEAP32[96441] = $31; //@line 11475
 HEAP32[96445] = $31; //@line 11476
 HEAP32[96443] = $$lobit38; //@line 11477
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 11481
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11484
 return;
}
function __Z12op_3130_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 44559
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44568
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 44574
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 44575
 $24 = (HEAP32[$22 >> 2] | 0) + -2 | 0; //@line 44577
 HEAP32[$22 >> 2] = $24; //@line 44578
 $25 = $21 << 16 >> 16; //@line 44580
 $27 = ($25 | 0) == 0 & 1; //@line 44582
 HEAP32[96441] = 0; //@line 44583
 HEAP32[96442] = 0; //@line 44583
 HEAP32[96443] = 0; //@line 44583
 HEAP32[96444] = 0; //@line 44583
 HEAP32[96442] = $27; //@line 44584
 HEAP32[96443] = $21 >>> 15 & 1; //@line 44587
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 44593
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44596
 return;
}
function __Z12op_b0fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit = 0, $$lobit34 = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 35585
 $$cast = $4; //@line 35590
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 35599
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 35605
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35607
 $26 = $23 << 16 >> 16; //@line 35609
 $27 = $25 - $26 | 0; //@line 35610
 $$lobit = $25 >>> 31; //@line 35613
 $$lobit34 = $27 >>> 31; //@line 35614
 HEAP32[96442] = ($27 | 0) == 0 & 1; //@line 35617
 HEAP32[96444] = ($23 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit34 | 0) != ($$lobit | 0) & 1; //@line 35622
 HEAP32[96441] = $25 >>> 0 < $26 >>> 0 & 1; //@line 35625
 HEAP32[96443] = $$lobit34; //@line 35626
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35629
 return;
}
function __Z12op_40b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $13 = 0, $15 = 0, $18 = 0, $21 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 45795
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 45804
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 45806
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($13) | 0; //@line 45809
 $21 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $18 | 0; //@line 45813
 $$lobit = $18 >>> 31; //@line 45814
 $$lobit32 = $21 >>> 31; //@line 45815
 HEAP32[96444] = $$lobit32 & $$lobit; //@line 45817
 $25 = $$lobit32 & ~$$lobit ^ $$lobit; //@line 45820
 HEAP32[96441] = $25; //@line 45821
 HEAP32[96445] = $25; //@line 45822
 HEAP32[96442] = ($21 | 0) == 0 & HEAP32[96442]; //@line 45827
 HEAP32[96443] = $$lobit32; //@line 45828
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 12 >> 2] & 31]($13, $21); //@line 45832
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45835
 return;
}
function __Z12op_4050_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $15 = 0, $19 = 0, $3 = 0, $5 = 0, $9 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40457
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40459
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40463
 $13 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($9 << 16 >> 16) | 0; //@line 40469
 $14 = $9 >>> 15; //@line 40470
 $sext$lobit = $14 & 1; //@line 40471
 $15 = $13 >>> 15; //@line 40472
 $sext32$lobit = $15 & 1; //@line 40473
 HEAP32[96444] = $sext32$lobit & $14; //@line 40475
 $19 = ($sext32$lobit ^ $sext$lobit) & $15 ^ $sext$lobit; //@line 40478
 HEAP32[96441] = $19; //@line 40479
 HEAP32[96445] = $19; //@line 40480
 HEAP32[96442] = ($13 & 65535 | 0) == 0 & HEAP32[96442]; //@line 40486
 HEAP32[96443] = $sext32$lobit; //@line 40487
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $13); //@line 40491
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40494
 return;
}
function __Z12op_10f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $24 = 0, $26 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 24596
 $3 = HEAP32[162769] | 0; //@line 24597
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 24607
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 24613
 $19 = 651040 + ($2 << 2) | 0; //@line 24614
 $20 = HEAP32[$19 >> 2] | 0; //@line 24615
 HEAP32[$19 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $20; //@line 24619
 $24 = $18 << 24 >> 24; //@line 24621
 $26 = ($24 | 0) == 0 & 1; //@line 24623
 HEAP32[96441] = 0; //@line 24624
 HEAP32[96442] = 0; //@line 24624
 HEAP32[96443] = 0; //@line 24624
 HEAP32[96444] = 0; //@line 24624
 HEAP32[96442] = $26; //@line 24625
 HEAP32[96443] = $18 >>> 7 & 1; //@line 24628
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($20, $24); //@line 24634
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24637
 return;
}
function __Z9op_illg_1j($0) {
 $0 = $0 | 0;
 var $6 = 0, $trunc$i = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 50432
 STACKTOP = STACKTOP + 16 | 0; //@line 50433
 $vararg_buffer = sp; //@line 50434
 $trunc$i = $0 & 61440; //@line 50436
 L1 : do {
  if ($trunc$i << 16 >> 16 < -4096) {
   switch ($trunc$i << 16 >> 16) {
   case -24576:
    {
     break;
    }
   default:
    {
     break L1;
    }
   }
   __Z9Exceptionij(10, 0); //@line 50448
   STACKTOP = sp; //@line 50449
   return;
  } else {
   switch ($trunc$i << 16 >> 16) {
   case -4096:
    {
     break;
    }
   default:
    {
     break L1;
    }
   }
   __Z9Exceptionij(11, 0); //@line 50459
   STACKTOP = sp; //@line 50460
   return;
  }
 } while (0);
 $6 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 50467
 HEAP32[$vararg_buffer >> 2] = $0; //@line 50468
 HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 50470
 _printf(105458, $vararg_buffer) | 0; //@line 50471
 __Z9Exceptionij(4, 0); //@line 50472
 STACKTOP = sp; //@line 50473
 return;
}
function __Z12op_5050_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $4 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 3931
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 3934
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 3936
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 3940
 $14 = $13 << 16 >> 16; //@line 3942
 $16 = $14 + ($4 << 16 >> 16) | 0; //@line 3945
 $19 = $16 >>> 15; //@line 3949
 $sext38$lobit = $19 & 1; //@line 3950
 HEAP32[96442] = ($16 & 65535 | 0) == 0 & 1; //@line 3954
 HEAP32[96444] = ($sext38$lobit ^ $13 >>> 15 & 1) & ($19 ^ $4 >>> 15); //@line 3958
 $29 = ($14 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 3963
 HEAP32[96441] = $29; //@line 3964
 HEAP32[96445] = $29; //@line 3965
 HEAP32[96443] = $sext38$lobit; //@line 3966
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 3970
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 3973
 return;
}
function __Z11op_a98_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $27 = 0, $30 = 0, $32 = 0;
 $2 = HEAP32[162769] | 0; //@line 17880
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 17898
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 17899
 $22 = HEAP32[$21 >> 2] | 0; //@line 17900
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 17902
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 17905
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 17908
 $30 = $27 ^ $20; //@line 17909
 $32 = ($30 | 0) == 0 & 1; //@line 17911
 HEAP32[96441] = 0; //@line 17912
 HEAP32[96442] = 0; //@line 17912
 HEAP32[96443] = 0; //@line 17912
 HEAP32[96444] = 0; //@line 17912
 HEAP32[96442] = $32; //@line 17913
 HEAP32[96443] = $30 >>> 31; //@line 17915
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $30); //@line 17919
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17922
 return;
}
function __Z11op_a79_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $29 = 0, $34 = 0, $36 = 0, $9 = 0, $sext1213 = 0;
 $1 = HEAP32[162769] | 0; //@line 16155
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 16163
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 16172
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 16181
 $29 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16183
 $sext1213 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0) ^ $9; //@line 16188
 $34 = $sext1213 << 16 >> 16; //@line 16190
 $36 = ($34 | 0) == 0 & 1; //@line 16192
 HEAP32[96441] = 0; //@line 16193
 HEAP32[96442] = 0; //@line 16193
 HEAP32[96443] = 0; //@line 16193
 HEAP32[96444] = 0; //@line 16193
 HEAP32[96442] = $36; //@line 16194
 HEAP32[96443] = $sext1213 >>> 15 & 1; //@line 16197
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $34); //@line 16201
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 16204
 return;
}
function __ZL18find_hfs_partitionR16cdrom_drive_info($0) {
 $0 = $0 | 0;
 var $$028 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0;
 $1 = $0 + 16 | 0; //@line 19959
 HEAP32[$1 >> 2] = 0; //@line 19960
 $2 = __Znaj(512) | 0; //@line 19961
 $3 = $0 + 4 | 0; //@line 19962
 $4 = $2 + 1 | 0; //@line 19963
 $5 = $2 + 48 | 0; //@line 19964
 $$028 = 0; //@line 19965
 while (1) {
  if ((__Z8Sys_readPvS_ij(HEAP32[$3 >> 2] | 0, $2, $$028 << 9, 512) | 0) != 512) {
   label = 7; //@line 19972
   break;
  }
  if (((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$4 >> 0] | 0) | 0) == 20557) {
   if (!(_strcmp($5, 95147) | 0)) {
    label = 5; //@line 19986
    break;
   }
  }
  $$028 = $$028 + 1 | 0; //@line 19990
  if (($$028 | 0) >= 64) {
   label = 7; //@line 19995
   break;
  }
 }
 if ((label | 0) == 5) {
  HEAP32[$1 >> 2] = ((HEAPU8[$2 + 10 >> 0] | 0) << 8 | (HEAPU8[$2 + 9 >> 0] | 0) << 16 | (HEAPU8[$2 + 11 >> 0] | 0)) << 9; //@line 20014
  __ZdaPv($2); //@line 20015
  return;
 } else if ((label | 0) == 7) {
  __ZdaPv($2); //@line 20019
  return;
 }
}
function __Z12op_e9c0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $30 = 0, $33 = 0, $5 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 42910
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 42913
 $sext = ($5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 42919
 $11 = $sext >> 16; //@line 42920
 $14 = $sext >> 22; //@line 42923
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 42926
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 42931
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 42936
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 42941
 }
 $26 = $25 + 31 & 31; //@line 42944
 $33 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << ($30 & 31) >>> ($26 ^ 31); //@line 42950
 HEAP32[96443] = ($33 & 1 << $26 | 0) != 0 & 1; //@line 42955
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 42958
 HEAP32[96444] = 0; //@line 42959
 HEAP32[96441] = 0; //@line 42960
 HEAP32[651008 + (($5 >>> 4 & 7) << 2) >> 2] = $33; //@line 42964
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42967
 return;
}
function __Z12op_d1a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $32 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34864
 $8 = HEAP32[162769] | 0; //@line 34867
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 34878
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 34880
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 34883
 $24 = $23 + $5 | 0; //@line 34884
 $$lobit38 = $24 >>> 31; //@line 34887
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 34890
 HEAP32[96444] = ($$lobit38 ^ $5 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 34894
 $32 = $5 >>> 0 > ~$23 >>> 0 & 1; //@line 34897
 HEAP32[96441] = $32; //@line 34898
 HEAP32[96445] = $32; //@line 34899
 HEAP32[96443] = $$lobit38; //@line 34900
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 34904
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 34907
 return;
}
function __Z12op_91b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $14 = 0, $16 = 0, $19 = 0, $20 = 0, $27 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21328
 $5 = HEAP32[162769] | 0; //@line 21329
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 21339
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 21341
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 21344
 $20 = $19 - $4 | 0; //@line 21345
 $$lobit33 = $19 >>> 31; //@line 21347
 $$lobit34 = $20 >>> 31; //@line 21348
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 21351
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $4 >>> 31); //@line 21355
 $27 = $19 >>> 0 < $4 >>> 0 & 1; //@line 21357
 HEAP32[96441] = $27; //@line 21358
 HEAP32[96445] = $27; //@line 21359
 HEAP32[96443] = $$lobit34; //@line 21360
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 21364
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21367
 return;
}
function __Z12op_91a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $$lobit40 = 0, $10 = 0, $13 = 0, $14 = 0, $21 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21178
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 21179
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 21181
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 21183
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 21186
 HEAP32[$6 >> 2] = $8; //@line 21187
 $14 = $13 - $5 | 0; //@line 21188
 $$lobit39 = $13 >>> 31; //@line 21190
 $$lobit40 = $14 >>> 31; //@line 21191
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 21194
 HEAP32[96444] = ($$lobit40 ^ $$lobit39) & ($$lobit39 ^ $5 >>> 31); //@line 21198
 $21 = $13 >>> 0 < $5 >>> 0 & 1; //@line 21200
 HEAP32[96441] = $21; //@line 21201
 HEAP32[96445] = $21; //@line 21202
 HEAP32[96443] = $$lobit40; //@line 21203
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 21207
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21210
 return;
}
function __Z12op_3139_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $31 = 0, $33 = 0;
 $3 = HEAP32[162769] | 0; //@line 37134
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 37143
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 37158
 $28 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37159
 $30 = (HEAP32[$28 >> 2] | 0) + -2 | 0; //@line 37161
 HEAP32[$28 >> 2] = $30; //@line 37162
 $31 = $27 << 16 >> 16; //@line 37164
 $33 = ($31 | 0) == 0 & 1; //@line 37166
 HEAP32[96441] = 0; //@line 37167
 HEAP32[96442] = 0; //@line 37167
 HEAP32[96443] = 0; //@line 37167
 HEAP32[96444] = 0; //@line 37167
 HEAP32[96442] = $33; //@line 37168
 HEAP32[96443] = $27 >>> 15 & 1; //@line 37171
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, $31); //@line 37177
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37180
 return;
}
function __Z15VideoDriverOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$sink13$i = 0, $10 = 0, $11 = 0, $15 = 0, $2 = 0, $9 = 0, label = 0;
 $2 = $1 + 41 | 0; //@line 24409
 $9 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($2) | 0) & 255; //@line 24416
 $10 = HEAP32[30549] | 0; //@line 24417
 $11 = HEAP32[30548] | 0; //@line 24418
 if (($11 | 0) == ($10 | 0)) {
  $$0 = -56; //@line 24421
  return $$0 | 0; //@line 24422
 } else {
  $$sink13$i = $11; //@line 24424
 }
 while (1) {
  $15 = HEAP32[$$sink13$i >> 2] | 0; //@line 24427
  $$sink13$i = $$sink13$i + 4 | 0; //@line 24431
  if ((HEAP8[$15 + 24 >> 0] | 0) == $9 << 24 >> 24) {
   break;
  }
  if (($$sink13$i | 0) == ($10 | 0)) {
   $$0 = -56; //@line 24437
   label = 6; //@line 24438
   break;
  }
 }
 if ((label | 0) == 6) {
  return $$0 | 0; //@line 24445
 }
 if (!$15) {
  $$0 = -56; //@line 24449
  return $$0 | 0; //@line 24450
 }
 $$0 = __ZN12monitor_desc11driver_openEv($15) | 0; //@line 24453
 return $$0 | 0; //@line 24454
}
function __Z12QuitEmulatorv() {
 var $1 = 0, $5 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 48556
 STACKTOP = STACKTOP + 16 | 0; //@line 48557
 $vararg_buffer1 = sp + 8 | 0; //@line 48558
 $vararg_buffer = sp; //@line 48559
 __Z9Exit680x0v(); //@line 48560
 __Z13GetTicks_usecv() | 0; //@line 48561
 __Z7ExitAllv(); //@line 48563
 $1 = HEAP32[30894] | 0; //@line 48564
 if ($1 | 0) {
  __Z10vm_releasePvj($1, (HEAP32[30895] | 0) + 1048576 | 0) | 0; //@line 48569
  HEAP32[30894] = 0; //@line 48570
  HEAP32[30897] = 0; //@line 48571
 }
 __Z9PrefsExitv(); //@line 48573
 $5 = HEAP32[30886] | 0; //@line 48574
 if (!$5) {
  _exit(0); //@line 48577
 }
 HEAP32[$vararg_buffer >> 2] = 0; //@line 48580
 if (__Z17rpc_method_invokeP16rpc_connection_tiz($5, 3, $vararg_buffer) | 0) {
  _exit(0); //@line 48584
 }
 $9 = HEAP32[30886] | 0; //@line 48587
 HEAP32[$vararg_buffer1 >> 2] = 0; //@line 48588
 __Z25rpc_method_wait_for_replyP16rpc_connection_tz($9, $vararg_buffer1) | 0; //@line 48589
 _exit(0); //@line 48590
}
function __Z10op_58_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $21 = 0, $23 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 5140
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 5148
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 5149
 $12 = HEAP32[$11 >> 2] | 0; //@line 5150
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 5152
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 5156
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 5159
 $sext1718 = $10 | $18; //@line 5160
 $21 = $sext1718 << 16 >> 16; //@line 5162
 $23 = ($21 | 0) == 0 & 1; //@line 5164
 HEAP32[96441] = 0; //@line 5165
 HEAP32[96442] = 0; //@line 5165
 HEAP32[96443] = 0; //@line 5165
 HEAP32[96444] = 0; //@line 5165
 HEAP32[96442] = $23; //@line 5166
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 5169
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $21); //@line 5173
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5176
 return;
}
function __Z12op_c1fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 31145
 $4 = $3 + 2 | 0; //@line 31146
 HEAP32[162769] = $4; //@line 31147
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 31152
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 31159
 HEAP32[162769] = $3 + 4; //@line 31161
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 31162
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 31168
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31169
 $28 = Math_imul(HEAP32[$24 >> 2] << 16 >> 16, $23 << 16 >> 16) | 0; //@line 31175
 $30 = ($28 | 0) == 0 & 1; //@line 31177
 HEAP32[96441] = 0; //@line 31178
 HEAP32[96442] = 0; //@line 31178
 HEAP32[96443] = 0; //@line 31178
 HEAP32[96444] = 0; //@line 31178
 HEAP32[96442] = $30; //@line 31179
 HEAP32[96443] = $28 >>> 31; //@line 31181
 HEAP32[$24 >> 2] = $28; //@line 31182
 return;
}
function __Z12op_4010_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $15 = 0, $19 = 0, $3 = 0, $5 = 0, $9 = 0, $sext$lobit = 0, $sext30$lobit = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40029
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40031
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 40035
 $13 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($9 << 24 >> 24) | 0; //@line 40041
 $14 = $9 >>> 7; //@line 40042
 $sext$lobit = $14 & 1; //@line 40043
 $15 = $13 >>> 7; //@line 40044
 $sext30$lobit = $15 & 1; //@line 40045
 HEAP32[96444] = $sext30$lobit & $14; //@line 40047
 $19 = ($sext30$lobit ^ $sext$lobit) & $15 ^ $sext$lobit; //@line 40050
 HEAP32[96441] = $19; //@line 40051
 HEAP32[96445] = $19; //@line 40052
 HEAP32[96442] = ($13 & 255 | 0) == 0 & HEAP32[96442]; //@line 40058
 HEAP32[96443] = $sext30$lobit; //@line 40059
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $13); //@line 40063
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40066
 return;
}
function __Z12op_31a0_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 44969
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 44971
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 44977
 HEAP32[$4 >> 2] = $6; //@line 44978
 $15 = HEAP32[162769] | 0; //@line 44981
 $24 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$15 + 2 >> 0] | 0) << 8 | (HEAPU8[$15 + 3 >> 0] | 0)) | 0; //@line 44990
 $25 = $12 << 16 >> 16; //@line 44992
 $27 = ($25 | 0) == 0 & 1; //@line 44994
 HEAP32[96441] = 0; //@line 44995
 HEAP32[96442] = 0; //@line 44995
 HEAP32[96443] = 0; //@line 44995
 HEAP32[96444] = 0; //@line 44995
 HEAP32[96442] = $27; //@line 44996
 HEAP32[96443] = $12 >>> 15 & 1; //@line 44999
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 45005
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45008
 return;
}
function __Z12op_3128_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36986
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 36997
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 37003
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37004
 $25 = (HEAP32[$23 >> 2] | 0) + -2 | 0; //@line 37006
 HEAP32[$23 >> 2] = $25; //@line 37007
 $26 = $22 << 16 >> 16; //@line 37009
 $28 = ($26 | 0) == 0 & 1; //@line 37011
 HEAP32[96441] = 0; //@line 37012
 HEAP32[96442] = 0; //@line 37012
 HEAP32[96443] = 0; //@line 37012
 HEAP32[96444] = 0; //@line 37012
 HEAP32[96442] = $28; //@line 37013
 HEAP32[96443] = $22 >>> 15 & 1; //@line 37016
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 37022
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37025
 return;
}
function __Z12op_20fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $24 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32332
 $$cast = $4; //@line 32337
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 32346
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32351
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 32352
 $24 = HEAP32[$23 >> 2] | 0; //@line 32353
 HEAP32[$23 >> 2] = $24 + 4; //@line 32355
 $27 = ($22 | 0) == 0 & 1; //@line 32357
 HEAP32[96441] = 0; //@line 32358
 HEAP32[96442] = 0; //@line 32358
 HEAP32[96443] = 0; //@line 32358
 HEAP32[96444] = 0; //@line 32358
 HEAP32[96442] = $27; //@line 32359
 HEAP32[96443] = $22 >>> 31; //@line 32361
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $22); //@line 32367
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32370
 return;
}
function __Z11op_c18_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $18 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $sext$lobit = 0, $sext29$lobit = 0;
 $1 = $0 & 7; //@line 18853
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 18856
 $5 = $4 & 255; //@line 18857
 $6 = 651040 + ($1 << 2) | 0; //@line 18858
 $7 = HEAP32[$6 >> 2] | 0; //@line 18859
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 18865
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 18870
 $18 = $13 - $5 | 0; //@line 18871
 $sext$lobit = $13 >>> 7 & 1; //@line 18875
 $sext29$lobit = $18 >>> 7 & 1; //@line 18877
 HEAP32[96442] = ($18 & 255 | 0) == 0 & 1; //@line 18881
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext29$lobit | 0) != ($sext$lobit | 0) & 1; //@line 18886
 HEAP32[96441] = $5 >>> 0 > ($13 & 255) >>> 0 & 1; //@line 18890
 HEAP32[96443] = $sext29$lobit; //@line 18891
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18894
 return;
}
function __Z12op_e6f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 41722
 $3 = $2 + 2 | 0; //@line 41723
 HEAP32[162769] = $3; //@line 41724
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41726
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 41733
 HEAP32[162769] = $2 + 4; //@line 41735
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 41736
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41738
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41742
 $21 = $20 & 1; //@line 41743
 $22 = $20 >>> 1; //@line 41744
 $$ = ($21 | 0) == 0 ? $22 & 32767 : $22 | 32768; //@line 41748
 HEAP32[96444] = 0; //@line 41752
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41753
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41756
 HEAP32[96441] = $21; //@line 41757
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41762
 return;
}
function __Z12op_e080_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38146
 $7 = HEAP32[$6 >> 2] | 0; //@line 38147
 $8 = $7 >>> 31; //@line 38148
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38149
 $10 = $9 >>> 0 > 31; //@line 38150
 $11 = $7 >> 31; //@line 38151
 HEAP32[96441] = 0; //@line 38152
 HEAP32[96442] = 0; //@line 38152
 HEAP32[96443] = 0; //@line 38152
 HEAP32[96444] = 0; //@line 38152
 if ($10) {
  HEAP32[96441] = $8; //@line 38154
  HEAP32[96445] = $8; //@line 38155
  $$0 = $11; //@line 38156
 } else {
  $13 = $7 >>> ($9 + -1 | 0); //@line 38159
  $14 = $13 & 1; //@line 38160
  HEAP32[96441] = $14; //@line 38161
  HEAP32[96445] = $14; //@line 38162
  $$0 = $13 >>> 1 | -1 << 32 - $9 & $11; //@line 38168
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38172
 HEAP32[96443] = $$0 >>> 31; //@line 38174
 HEAP32[$6 >> 2] = $$0; //@line 38175
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38178
 return;
}
function __Z12op_40a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $14 = 0, $16 = 0, $19 = 0, $22 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 41004
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41015
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41017
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 41020
 $22 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $19 | 0; //@line 41024
 $$lobit = $19 >>> 31; //@line 41025
 $$lobit32 = $22 >>> 31; //@line 41026
 HEAP32[96444] = $$lobit32 & $$lobit; //@line 41028
 $26 = $$lobit32 & ~$$lobit ^ $$lobit; //@line 41031
 HEAP32[96441] = $26; //@line 41032
 HEAP32[96445] = $26; //@line 41033
 HEAP32[96442] = ($22 | 0) == 0 & HEAP32[96442]; //@line 41038
 HEAP32[96443] = $$lobit32; //@line 41039
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $22); //@line 41043
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41046
 return;
}
function __Z12op_31b8_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $21 = 0, $3 = 0, $30 = 0, $31 = 0, $33 = 0;
 $3 = HEAP32[162769] | 0; //@line 45139
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 45149
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 45155
 $21 = HEAP32[162769] | 0; //@line 45158
 $30 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) | 0; //@line 45167
 $31 = $18 << 16 >> 16; //@line 45169
 $33 = ($31 | 0) == 0 & 1; //@line 45171
 HEAP32[96441] = 0; //@line 45172
 HEAP32[96442] = 0; //@line 45172
 HEAP32[96443] = 0; //@line 45172
 HEAP32[96444] = 0; //@line 45172
 HEAP32[96442] = $33; //@line 45173
 HEAP32[96443] = $18 >>> 15 & 1; //@line 45176
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, $31); //@line 45182
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45185
 return;
}
function __Z12op_11e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $13 = 0, $2 = 0, $22 = 0, $23 = 0, $25 = 0, $6 = 0;
 $1 = $0 & 7; //@line 26756
 $2 = 651040 + ($1 << 2) | 0; //@line 26757
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 26761
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 26767
 HEAP32[$2 >> 2] = $6; //@line 26768
 $13 = HEAP32[162769] | 0; //@line 26769
 $22 = ((HEAPU8[$13 + 2 >> 0] | 0) << 8 | (HEAPU8[$13 + 3 >> 0] | 0)) << 16 >> 16; //@line 26779
 $23 = $12 << 24 >> 24; //@line 26781
 $25 = ($23 | 0) == 0 & 1; //@line 26783
 HEAP32[96441] = 0; //@line 26784
 HEAP32[96442] = 0; //@line 26784
 HEAP32[96443] = 0; //@line 26784
 HEAP32[96444] = 0; //@line 26784
 HEAP32[96442] = $25; //@line 26785
 HEAP32[96443] = $12 >>> 7 & 1; //@line 26788
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($22, $23); //@line 26794
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26797
 return;
}
function __Z11op_c58_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $18 = 0, $2 = 0, $21 = 0, $5 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19377
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19380
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19385
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 19386
 $12 = HEAP32[$11 >> 2] | 0; //@line 19387
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 19393
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 19396
 $21 = $18 - $10 | 0; //@line 19397
 $sext$lobit = $18 >>> 15 & 1; //@line 19400
 $sext33$lobit = $21 >>> 15 & 1; //@line 19402
 HEAP32[96442] = ($21 & 65535 | 0) == 0 & 1; //@line 19406
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext33$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19411
 HEAP32[96441] = $10 >>> 0 > ($18 & 65535) >>> 0 & 1; //@line 19415
 HEAP32[96443] = $sext33$lobit; //@line 19416
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19419
 return;
}
function __Z12op_30f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 44455
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44464
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 44470
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 44471
 $23 = HEAP32[$22 >> 2] | 0; //@line 44472
 HEAP32[$22 >> 2] = $23 + 2; //@line 44474
 $25 = $21 << 16 >> 16; //@line 44476
 $27 = ($25 | 0) == 0 & 1; //@line 44478
 HEAP32[96441] = 0; //@line 44479
 HEAP32[96442] = 0; //@line 44479
 HEAP32[96443] = 0; //@line 44479
 HEAP32[96444] = 0; //@line 44479
 HEAP32[96442] = $27; //@line 44480
 HEAP32[96443] = $21 >>> 15 & 1; //@line 44483
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($23, $25); //@line 44489
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44492
 return;
}
function __Z12op_11b8_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $21 = 0, $3 = 0, $30 = 0, $31 = 0, $33 = 0;
 $3 = HEAP32[162769] | 0; //@line 31515
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 31525
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 31531
 $21 = HEAP32[162769] | 0; //@line 31534
 $30 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) | 0; //@line 31543
 $31 = $18 << 24 >> 24; //@line 31545
 $33 = ($31 | 0) == 0 & 1; //@line 31547
 HEAP32[96441] = 0; //@line 31548
 HEAP32[96442] = 0; //@line 31548
 HEAP32[96443] = 0; //@line 31548
 HEAP32[96444] = 0; //@line 31548
 HEAP32[96442] = $33; //@line 31549
 HEAP32[96443] = $18 >>> 7 & 1; //@line 31552
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($30, $31); //@line 31558
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31561
 return;
}
function __Z11op_cba_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit30 = 0, $$lobit31 = 0, $1 = 0, $19 = 0, $35 = 0, $4 = 0, $40 = 0, $41 = 0;
 $1 = HEAP32[162769] | 0; //@line 20311
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 20314
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 20329
 $35 = (HEAP32[162768] | 0) + 6 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16) | 0; //@line 20346
 $40 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($35 >>> 16 << 2) >> 2] >> 2] & 127]($35) | 0; //@line 20351
 $41 = $40 - $19 | 0; //@line 20352
 $$lobit30 = $40 >>> 31; //@line 20354
 $$lobit31 = $41 >>> 31; //@line 20355
 HEAP32[96442] = ($41 | 0) == 0 & 1; //@line 20358
 HEAP32[96444] = ($4 >>> 7 | 0) != ($$lobit30 | 0) & ($$lobit31 | 0) != ($$lobit30 | 0) & 1; //@line 20363
 HEAP32[96441] = $40 >>> 0 < $19 >>> 0 & 1; //@line 20366
 HEAP32[96443] = $$lobit31; //@line 20367
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 20370
 return;
}
function __Z11op_258_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $18 = 0, $2 = 0, $21 = 0, $23 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 8880
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8888
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 8889
 $12 = HEAP32[$11 >> 2] | 0; //@line 8890
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 8892
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 8896
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 8899
 $sext1718 = $18 & $10; //@line 8900
 $21 = $sext1718 << 16 >> 16; //@line 8902
 $23 = ($21 | 0) == 0 & 1; //@line 8904
 HEAP32[96441] = 0; //@line 8905
 HEAP32[96442] = 0; //@line 8905
 HEAP32[96443] = 0; //@line 8905
 HEAP32[96444] = 0; //@line 8905
 HEAP32[96442] = $23; //@line 8906
 HEAP32[96443] = $sext1718 >>> 15; //@line 8908
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $21); //@line 8912
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8915
 return;
}
function __Z12op_c1b0_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30639
 $6 = HEAP32[162769] | 0; //@line 30640
 $7 = $6 + 2 | 0; //@line 30641
 HEAP32[162769] = $7; //@line 30642
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30644
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 30651
 HEAP32[162769] = $6 + 4; //@line 30653
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 30654
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 30656
 $24 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0) & $5; //@line 30660
 $26 = ($24 | 0) == 0 & 1; //@line 30662
 HEAP32[96441] = 0; //@line 30663
 HEAP32[96442] = 0; //@line 30663
 HEAP32[96443] = 0; //@line 30663
 HEAP32[96444] = 0; //@line 30663
 HEAP32[96442] = $26; //@line 30664
 HEAP32[96443] = $24 >>> 31; //@line 30666
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 30670
 return;
}
function __Z12op_b1b0_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27209
 $6 = HEAP32[162769] | 0; //@line 27210
 $7 = $6 + 2 | 0; //@line 27211
 HEAP32[162769] = $7; //@line 27212
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27214
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 27221
 HEAP32[162769] = $6 + 4; //@line 27223
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 27224
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 27226
 $24 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0) ^ $5; //@line 27230
 $26 = ($24 | 0) == 0 & 1; //@line 27232
 HEAP32[96441] = 0; //@line 27233
 HEAP32[96442] = 0; //@line 27233
 HEAP32[96443] = 0; //@line 27233
 HEAP32[96444] = 0; //@line 27233
 HEAP32[96442] = $26; //@line 27234
 HEAP32[96443] = $24 >>> 31; //@line 27236
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 27240
 return;
}
function __Z12op_4af0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $5 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 52746
 $3 = $2 + 2 | 0; //@line 52747
 HEAP32[162769] = $3; //@line 52748
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52750
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 52757
 HEAP32[162769] = $2 + 4; //@line 52759
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 52760
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 52762
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 52766
 $sext = $20 << 24; //@line 52767
 $22 = ($sext | 0) == 0 & 1; //@line 52769
 HEAP32[96441] = 0; //@line 52770
 HEAP32[96442] = 0; //@line 52770
 HEAP32[96443] = 0; //@line 52770
 HEAP32[96444] = 0; //@line 52770
 HEAP32[96442] = $22; //@line 52771
 HEAP32[96443] = $20 >>> 7 & 1; //@line 52774
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, ($sext | -2147483648) >> 24); //@line 52780
 return;
}
function __Z11op_c7b_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $24 = 0, $30 = 0, $31 = 0, $4 = 0, $9 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 30468
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 30471
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 30476
 $24 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 30491
 $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($24) | 0; //@line 30497
 $31 = $30 - $9 | 0; //@line 30498
 $sext$lobit = $30 >>> 15 & 1; //@line 30501
 $sext33$lobit = $31 >>> 15 & 1; //@line 30503
 HEAP32[96442] = ($31 & 65535 | 0) == 0 & 1; //@line 30507
 HEAP32[96444] = ($4 >>> 7 | 0) != ($sext$lobit | 0) & ($sext33$lobit | 0) != ($sext$lobit | 0) & 1; //@line 30512
 HEAP32[96441] = $9 >>> 0 > ($30 & 65535) >>> 0 & 1; //@line 30516
 HEAP32[96443] = $sext33$lobit; //@line 30517
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30520
 return;
}
function __Z12op_213a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 29969
 $$cast = $4; //@line 29971
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 29985
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 29990
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29991
 $26 = (HEAP32[$24 >> 2] | 0) + -4 | 0; //@line 29993
 HEAP32[$24 >> 2] = $26; //@line 29994
 $28 = ($23 | 0) == 0 & 1; //@line 29996
 HEAP32[96441] = 0; //@line 29997
 HEAP32[96442] = 0; //@line 29997
 HEAP32[96443] = 0; //@line 29997
 HEAP32[96444] = 0; //@line 29997
 HEAP32[96442] = $28; //@line 29998
 HEAP32[96443] = $23 >>> 31; //@line 30000
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($26, $23); //@line 30006
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30009
 return;
}
function __Z11op_e50_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $30 = 0, $32 = 0, $34 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21722
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21729
 $9 = $7 << 24 >> 16; //@line 21731
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21735
 do {
  if (!($9 & 2048)) {
   $30 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0) << 16 >> 16; //@line 21747
   $32 = $7 >>> 4 & 7; //@line 21749
   if (!($9 & 32768)) {
    $34 = 651008 + ($32 << 2) | 0; //@line 21751
    HEAP32[$34 >> 2] = HEAP32[$34 >> 2] & -65536 | $30 & 65535; //@line 21756
    break;
   } else {
    HEAP32[651040 + ($32 << 2) >> 2] = $30; //@line 21760
    break;
   }
  } else {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 21772
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21777
 return;
}
function __Z12op_e5f0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $29 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 41391
 $3 = $2 + 2 | 0; //@line 41392
 HEAP32[162769] = $3; //@line 41393
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41395
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 41402
 HEAP32[162769] = $2 + 4; //@line 41404
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 41405
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41407
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41411
 $$ = (HEAP32[96445] | 0) != 0 | $20 << 1; //@line 41416
 HEAP32[96444] = 0; //@line 41420
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41421
 HEAP32[96443] = $20 >>> 14 & 1; //@line 41424
 $29 = $20 >>> 15 & 1; //@line 41426
 HEAP32[96441] = $29; //@line 41427
 HEAP32[96445] = $29; //@line 41428
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41433
 return;
}
function __Z12op_e0f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 38643
 $3 = $2 + 2 | 0; //@line 38644
 HEAP32[162769] = $3; //@line 38645
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38647
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 38654
 HEAP32[162769] = $2 + 4; //@line 38656
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 38657
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 38659
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 38663
 $21 = $20 & 32768; //@line 38664
 $22 = $20 & 1; //@line 38665
 $25 = $20 >>> 1 & 32767 | $21; //@line 38668
 HEAP32[96444] = 0; //@line 38671
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 38672
 HEAP32[96443] = $21 >>> 15; //@line 38674
 HEAP32[96441] = $22; //@line 38675
 HEAP32[96445] = $22; //@line 38676
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $25); //@line 38680
 return;
}
function __Z12op_81b0_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16732
 $6 = HEAP32[162769] | 0; //@line 16733
 $7 = $6 + 2 | 0; //@line 16734
 HEAP32[162769] = $7; //@line 16735
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16737
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 16744
 HEAP32[162769] = $6 + 4; //@line 16746
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 16747
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16749
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0 | $5; //@line 16753
 $26 = ($24 | 0) == 0 & 1; //@line 16755
 HEAP32[96441] = 0; //@line 16756
 HEAP32[96442] = 0; //@line 16756
 HEAP32[96443] = 0; //@line 16756
 HEAP32[96444] = 0; //@line 16756
 HEAP32[96442] = $26; //@line 16757
 HEAP32[96443] = $24 >>> 31; //@line 16759
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 16763
 return;
}
function __Z12op_3160_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 37531
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 37533
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 37539
 HEAP32[$4 >> 2] = $6; //@line 37540
 $15 = HEAP32[162769] | 0; //@line 37543
 $25 = (((HEAPU8[$15 + 2 >> 0] | 0) << 8 | (HEAPU8[$15 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37554
 $26 = $12 << 16 >> 16; //@line 37556
 $28 = ($26 | 0) == 0 & 1; //@line 37558
 HEAP32[96441] = 0; //@line 37559
 HEAP32[96442] = 0; //@line 37559
 HEAP32[96443] = 0; //@line 37559
 HEAP32[96444] = 0; //@line 37559
 HEAP32[96442] = $28; //@line 37560
 HEAP32[96443] = $12 >>> 15 & 1; //@line 37563
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 37569
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37572
 return;
}
function __Z12op_30f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $33 = 0;
 $3 = HEAP32[162769] | 0; //@line 36586
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 36595
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 36610
 $28 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36611
 $29 = HEAP32[$28 >> 2] | 0; //@line 36612
 HEAP32[$28 >> 2] = $29 + 2; //@line 36614
 $31 = $27 << 16 >> 16; //@line 36616
 $33 = ($31 | 0) == 0 & 1; //@line 36618
 HEAP32[96441] = 0; //@line 36619
 HEAP32[96442] = 0; //@line 36619
 HEAP32[96443] = 0; //@line 36619
 HEAP32[96444] = 0; //@line 36619
 HEAP32[96442] = $33; //@line 36620
 HEAP32[96443] = $27 >>> 15 & 1; //@line 36623
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, $31); //@line 36629
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 36632
 return;
}
function __Z12op_21fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $20 = 0, $21 = 0, $30 = 0, $32 = 0;
 $2 = HEAP32[162769] | 0; //@line 44006
 $$cast = $2; //@line 44011
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44020
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 44025
 $21 = HEAP32[162769] | 0; //@line 44026
 $30 = ((HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) << 16 >> 16; //@line 44036
 $32 = ($20 | 0) == 0 & 1; //@line 44038
 HEAP32[96441] = 0; //@line 44039
 HEAP32[96442] = 0; //@line 44039
 HEAP32[96443] = 0; //@line 44039
 HEAP32[96444] = 0; //@line 44039
 HEAP32[96442] = $32; //@line 44040
 HEAP32[96443] = $20 >>> 31; //@line 44042
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, $20); //@line 44048
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 44051
 return;
}
function __Z12op_21b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $23 = 0, $32 = 0, $34 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 43616
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 43625
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 43630
 $23 = HEAP32[162769] | 0; //@line 43633
 $32 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$23 + 4 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0)) | 0; //@line 43642
 $34 = ($20 | 0) == 0 & 1; //@line 43644
 HEAP32[96441] = 0; //@line 43645
 HEAP32[96442] = 0; //@line 43645
 HEAP32[96443] = 0; //@line 43645
 HEAP32[96444] = 0; //@line 43645
 HEAP32[96442] = $34; //@line 43646
 HEAP32[96443] = $20 >>> 31; //@line 43648
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($32, $20); //@line 43654
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43657
 return;
}
function __Z11op_ca0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $28 = 0, $29 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 19998
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 20001
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 20016
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 20017
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 20019
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($23 >>> 16 << 2) >> 2] >> 2] & 127]($23) | 0; //@line 20024
 HEAP32[$21 >> 2] = $23; //@line 20025
 $29 = $28 - $20 | 0; //@line 20026
 $$lobit33 = $28 >>> 31; //@line 20028
 $$lobit34 = $29 >>> 31; //@line 20029
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 20032
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit33 | 0) & ($$lobit34 | 0) != ($$lobit33 | 0) & 1; //@line 20037
 HEAP32[96441] = $28 >>> 0 < $20 >>> 0 & 1; //@line 20040
 HEAP32[96443] = $$lobit34; //@line 20041
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 20044
 return;
}
function __Z12op_3178_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $21 = 0, $3 = 0, $31 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 37709
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 37719
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 37725
 $21 = HEAP32[162769] | 0; //@line 37728
 $31 = (((HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37739
 $32 = $18 << 16 >> 16; //@line 37741
 $34 = ($32 | 0) == 0 & 1; //@line 37743
 HEAP32[96441] = 0; //@line 37744
 HEAP32[96442] = 0; //@line 37744
 HEAP32[96443] = 0; //@line 37744
 HEAP32[96444] = 0; //@line 37744
 HEAP32[96442] = $34; //@line 37745
 HEAP32[96443] = $18 >>> 15 & 1; //@line 37748
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($31, $32); //@line 37754
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37757
 return;
}
function __Z11op_cb0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $2 = 0, $20 = 0, $31 = 0, $36 = 0, $37 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 30530
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 30533
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 30548
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 30559
 $36 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($31 >>> 16 << 2) >> 2] >> 2] & 127]($31) | 0; //@line 30564
 $37 = $36 - $20 | 0; //@line 30565
 $$lobit31 = $36 >>> 31; //@line 30567
 $$lobit32 = $37 >>> 31; //@line 30568
 HEAP32[96442] = ($37 | 0) == 0 & 1; //@line 30571
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 30576
 HEAP32[96441] = $36 >>> 0 < $20 >>> 0 & 1; //@line 30579
 HEAP32[96443] = $$lobit32; //@line 30580
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 30583
 return;
}
function __Z11op_c7a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $25 = 0, $31 = 0, $32 = 0, $4 = 0, $9 = 0, $sext30$lobit = 0, $sext32$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19716
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 19719
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 19724
 $25 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 19741
 $31 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($25) | 0; //@line 19747
 $32 = $31 - $9 | 0; //@line 19748
 $sext30$lobit = $31 >>> 15 & 1; //@line 19751
 $sext32$lobit = $32 >>> 15 & 1; //@line 19753
 HEAP32[96442] = ($32 & 65535 | 0) == 0 & 1; //@line 19757
 HEAP32[96444] = ($4 >>> 7 | 0) != ($sext30$lobit | 0) & ($sext32$lobit | 0) != ($sext30$lobit | 0) & 1; //@line 19762
 HEAP32[96441] = $9 >>> 0 > ($31 & 65535) >>> 0 & 1; //@line 19766
 HEAP32[96443] = $sext32$lobit; //@line 19767
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19770
 return;
}
function __Z12op_c179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1617 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30418
 $5 = HEAP32[162769] | 0; //@line 30419
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 30428
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 30437
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30439
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0) & $4; //@line 30444
 $30 = $sext1617 << 16 >> 16; //@line 30446
 $32 = ($30 | 0) == 0 & 1; //@line 30448
 HEAP32[96441] = 0; //@line 30449
 HEAP32[96442] = 0; //@line 30449
 HEAP32[96443] = 0; //@line 30449
 HEAP32[96444] = 0; //@line 30449
 HEAP32[96442] = $32; //@line 30450
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 30453
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $30); //@line 30457
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30460
 return;
}
function __Z12op_b179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1617 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26933
 $5 = HEAP32[162769] | 0; //@line 26934
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 26943
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 26952
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 26954
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0) ^ $4; //@line 26959
 $30 = $sext1617 << 16 >> 16; //@line 26961
 $32 = ($30 | 0) == 0 & 1; //@line 26963
 HEAP32[96441] = 0; //@line 26964
 HEAP32[96442] = 0; //@line 26964
 HEAP32[96443] = 0; //@line 26964
 HEAP32[96444] = 0; //@line 26964
 HEAP32[96442] = $32; //@line 26965
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 26968
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $30); //@line 26972
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26975
 return;
}
function __Z12op_b0fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit = 0, $$lobit33 = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 26026
 $$cast = $4; //@line 26028
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 26042
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 26048
 $26 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26050
 $27 = $24 << 16 >> 16; //@line 26052
 $28 = $26 - $27 | 0; //@line 26053
 $$lobit = $26 >>> 31; //@line 26056
 $$lobit33 = $28 >>> 31; //@line 26057
 HEAP32[96442] = ($28 | 0) == 0 & 1; //@line 26060
 HEAP32[96444] = ($24 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit33 | 0) != ($$lobit | 0) & 1; //@line 26065
 HEAP32[96441] = $26 >>> 0 < $27 >>> 0 & 1; //@line 26068
 HEAP32[96443] = $$lobit33; //@line 26069
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26072
 return;
}
function __Z12op_31f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $20 = 0, $29 = 0, $30 = 0, $32 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 45434
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 45443
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 45449
 $20 = HEAP32[162769] | 0; //@line 45450
 $29 = ((HEAPU8[$20 + 4 >> 0] | 0) << 8 | (HEAPU8[$20 + 5 >> 0] | 0)) << 16 >> 16; //@line 45460
 $30 = $19 << 16 >> 16; //@line 45462
 $32 = ($30 | 0) == 0 & 1; //@line 45464
 HEAP32[96441] = 0; //@line 45465
 HEAP32[96442] = 0; //@line 45465
 HEAP32[96443] = 0; //@line 45465
 HEAP32[96444] = 0; //@line 45465
 HEAP32[96442] = $32; //@line 45466
 HEAP32[96443] = $19 >>> 15 & 1; //@line 45469
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, $30); //@line 45475
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45478
 return;
}
function __Z12op_30e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36438
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 36449
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 36455
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36456
 $24 = HEAP32[$23 >> 2] | 0; //@line 36457
 HEAP32[$23 >> 2] = $24 + 2; //@line 36459
 $26 = $22 << 16 >> 16; //@line 36461
 $28 = ($26 | 0) == 0 & 1; //@line 36463
 HEAP32[96441] = 0; //@line 36464
 HEAP32[96442] = 0; //@line 36464
 HEAP32[96443] = 0; //@line 36464
 HEAP32[96444] = 0; //@line 36464
 HEAP32[96442] = $28; //@line 36465
 HEAP32[96443] = $22 >>> 15 & 1; //@line 36468
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $26); //@line 36474
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36477
 return;
}
function __Z12op_1178_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $21 = 0, $3 = 0, $31 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 25721
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 25731
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 25737
 $21 = HEAP32[162769] | 0; //@line 25740
 $31 = (((HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25751
 $32 = $18 << 24 >> 24; //@line 25753
 $34 = ($32 | 0) == 0 & 1; //@line 25755
 HEAP32[96441] = 0; //@line 25756
 HEAP32[96442] = 0; //@line 25756
 HEAP32[96443] = 0; //@line 25756
 HEAP32[96444] = 0; //@line 25756
 HEAP32[96442] = $34; //@line 25757
 HEAP32[96443] = $18 >>> 7 & 1; //@line 25760
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($31, $32); //@line 25766
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 25769
 return;
}
function __Z12op_c139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1213 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30071
 $5 = HEAP32[162769] | 0; //@line 30072
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 30081
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 30090
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30092
 $sext1213 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0) & $4; //@line 30097
 $30 = $sext1213 << 24 >> 24; //@line 30099
 $32 = ($30 | 0) == 0 & 1; //@line 30101
 HEAP32[96441] = 0; //@line 30102
 HEAP32[96442] = 0; //@line 30102
 HEAP32[96443] = 0; //@line 30102
 HEAP32[96444] = 0; //@line 30102
 HEAP32[96442] = $32; //@line 30103
 HEAP32[96443] = $sext1213 >>> 7 & 1; //@line 30106
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $30); //@line 30110
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30113
 return;
}
function __Z12op_c0fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $28 = 0, $3 = 0, $30 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 29603
 $4 = $3 + 2 | 0; //@line 29604
 HEAP32[162769] = $4; //@line 29605
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 29610
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 29617
 HEAP32[162769] = $3 + 4; //@line 29619
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 29620
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 29626
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29627
 $28 = Math_imul(HEAP32[$24 >> 2] & 65535, $23 & 65535) | 0; //@line 29631
 $30 = ($28 | 0) == 0 & 1; //@line 29633
 HEAP32[96441] = 0; //@line 29634
 HEAP32[96442] = 0; //@line 29634
 HEAP32[96443] = 0; //@line 29634
 HEAP32[96444] = 0; //@line 29634
 HEAP32[96442] = $30; //@line 29635
 HEAP32[96443] = $28 >>> 31; //@line 29637
 HEAP32[$24 >> 2] = $28; //@line 29638
 return;
}
function __Z12op_b139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1213 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26533
 $5 = HEAP32[162769] | 0; //@line 26534
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 26543
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 26552
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 26554
 $sext1213 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0) ^ $4; //@line 26559
 $30 = $sext1213 << 24 >> 24; //@line 26561
 $32 = ($30 | 0) == 0 & 1; //@line 26563
 HEAP32[96441] = 0; //@line 26564
 HEAP32[96442] = 0; //@line 26564
 HEAP32[96443] = 0; //@line 26564
 HEAP32[96444] = 0; //@line 26564
 HEAP32[96442] = $32; //@line 26565
 HEAP32[96443] = $sext1213 >>> 7 & 1; //@line 26568
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $30); //@line 26572
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26575
 return;
}
function __Z12op_5010_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $19 = 0, $29 = 0, $4 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1242
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1245
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 1247
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 1251
 $14 = $13 << 24 >> 24; //@line 1253
 $16 = $14 + ($4 << 24 >> 24) | 0; //@line 1256
 $19 = $16 >>> 7; //@line 1260
 $sext36$lobit = $19 & 1; //@line 1261
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 1265
 HEAP32[96444] = ($sext36$lobit ^ $13 >>> 7 & 1) & ($19 ^ $4 >>> 7); //@line 1269
 $29 = ($14 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1274
 HEAP32[96441] = $29; //@line 1275
 HEAP32[96445] = $29; //@line 1276
 HEAP32[96443] = $sext36$lobit; //@line 1277
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 1281
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1284
 return;
}
function __Z12op_21b9_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $29 = 0, $3 = 0, $38 = 0, $40 = 0;
 $3 = HEAP32[162769] | 0; //@line 43721
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 43730
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 43744
 $29 = HEAP32[162769] | 0; //@line 43747
 $38 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$29 + 6 >> 0] | 0) << 8 | (HEAPU8[$29 + 7 >> 0] | 0)) | 0; //@line 43756
 $40 = ($26 | 0) == 0 & 1; //@line 43758
 HEAP32[96441] = 0; //@line 43759
 HEAP32[96442] = 0; //@line 43759
 HEAP32[96443] = 0; //@line 43759
 HEAP32[96444] = 0; //@line 43759
 HEAP32[96442] = $40; //@line 43760
 HEAP32[96443] = $26 >>> 31; //@line 43762
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($38 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($38, $26); //@line 43768
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 43771
 return;
}
function __Z12op_11f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $20 = 0, $29 = 0, $30 = 0, $32 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 31804
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 31813
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 31819
 $20 = HEAP32[162769] | 0; //@line 31820
 $29 = ((HEAPU8[$20 + 4 >> 0] | 0) << 8 | (HEAPU8[$20 + 5 >> 0] | 0)) << 16 >> 16; //@line 31830
 $30 = $19 << 24 >> 24; //@line 31832
 $32 = ($30 | 0) == 0 & 1; //@line 31834
 HEAP32[96441] = 0; //@line 31835
 HEAP32[96442] = 0; //@line 31835
 HEAP32[96443] = 0; //@line 31835
 HEAP32[96444] = 0; //@line 31835
 HEAP32[96442] = $32; //@line 31836
 HEAP32[96443] = $19 >>> 7 & 1; //@line 31839
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($29, $30); //@line 31845
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31848
 return;
}
function __Z11op_e10_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $30 = 0, $32 = 0, $34 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 21147
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 21154
 $9 = $7 << 24 >> 16; //@line 21156
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21160
 do {
  if (!($9 & 2048)) {
   $30 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0) << 24 >> 24; //@line 21172
   $32 = $7 >>> 4 & 7; //@line 21174
   if (!($9 & 32768)) {
    $34 = 651008 + ($32 << 2) | 0; //@line 21176
    HEAP32[$34 >> 2] = HEAP32[$34 >> 2] & -256 | $30 & 255; //@line 21181
    break;
   } else {
    HEAP32[651040 + ($32 << 2) >> 2] = $30; //@line 21185
    break;
   }
  } else {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 21197
  }
 } while (0);
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21202
 return;
}
function __Z11op_cb9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit27 = 0, $$lobit28 = 0, $1 = 0, $19 = 0, $28 = 0, $4 = 0, $42 = 0, $43 = 0;
 $1 = HEAP32[162769] | 0; //@line 20242
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 20245
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 20260
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 20269
 $42 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($28 >>> 16 << 2) >> 2] >> 2] & 127]($28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0)) | 0; //@line 20283
 $43 = $42 - $19 | 0; //@line 20284
 $$lobit27 = $42 >>> 31; //@line 20286
 $$lobit28 = $43 >>> 31; //@line 20287
 HEAP32[96442] = ($43 | 0) == 0 & 1; //@line 20290
 HEAP32[96444] = ($4 >>> 7 | 0) != ($$lobit27 | 0) & ($$lobit28 | 0) != ($$lobit27 | 0) & 1; //@line 20295
 HEAP32[96441] = $42 >>> 0 < $19 >>> 0 & 1; //@line 20298
 HEAP32[96443] = $$lobit28; //@line 20299
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 20302
 return;
}
function __Z11op_c20_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0, $6 = 0, $sext$lobit = 0, $sext30$lobit = 0;
 $1 = $0 & 7; //@line 18902
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 18905
 $5 = $4 & 255; //@line 18906
 $6 = 651040 + ($1 << 2) | 0; //@line 18907
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 18911
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 18917
 HEAP32[$6 >> 2] = $10; //@line 18918
 $17 = $16 - $5 | 0; //@line 18919
 $sext$lobit = $16 >>> 7 & 1; //@line 18923
 $sext30$lobit = $17 >>> 7 & 1; //@line 18925
 HEAP32[96442] = ($17 & 255 | 0) == 0 & 1; //@line 18929
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext30$lobit | 0) != ($sext$lobit | 0) & 1; //@line 18934
 HEAP32[96441] = $5 >>> 0 > ($16 & 255) >>> 0 & 1; //@line 18938
 HEAP32[96443] = $sext30$lobit; //@line 18939
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18942
 return;
}
function __Z7op_illgj($0) {
 $0 = $0 | 0;
 var $6 = 0, $trunc = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 50874
 STACKTOP = STACKTOP + 16 | 0; //@line 50875
 $vararg_buffer = sp; //@line 50876
 $trunc = $0 & 61440; //@line 50878
 L1 : do {
  if ($trunc << 16 >> 16 < -4096) {
   switch ($trunc << 16 >> 16) {
   case -24576:
    {
     break;
    }
   default:
    {
     break L1;
    }
   }
   __Z9Exceptionij(10, 0); //@line 50890
   STACKTOP = sp; //@line 50891
   return;
  } else {
   switch ($trunc << 16 >> 16) {
   case -4096:
    {
     break;
    }
   default:
    {
     break L1;
    }
   }
   __Z9Exceptionij(11, 0); //@line 50901
   STACKTOP = sp; //@line 50902
   return;
  }
 } while (0);
 $6 = (HEAP32[162768] | 0) + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 50909
 HEAP32[$vararg_buffer >> 2] = $0; //@line 50910
 HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 50912
 _printf(105458, $vararg_buffer) | 0; //@line 50913
 __Z9Exceptionij(4, 0); //@line 50914
 STACKTOP = sp; //@line 50915
 return;
}
function __Z12op_8179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1617 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16430
 $5 = HEAP32[162769] | 0; //@line 16431
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 16440
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 16449
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 16451
 $sext1617 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 4 >> 2] & 127]($23) | 0 | $4; //@line 16456
 $30 = $sext1617 << 16 >> 16; //@line 16458
 $32 = ($30 | 0) == 0 & 1; //@line 16460
 HEAP32[96441] = 0; //@line 16461
 HEAP32[96442] = 0; //@line 16461
 HEAP32[96443] = 0; //@line 16461
 HEAP32[96444] = 0; //@line 16461
 HEAP32[96442] = $32; //@line 16462
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 16465
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 16 >> 2] & 31]($23, $30); //@line 16469
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16472
 return;
}
function __Z12op_5198_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $$lobit39 = 0, $12 = 0, $15 = 0, $22 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6056
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 6058
 $7 = HEAP32[$6 >> 2] | 0; //@line 6059
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 6061
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 6064
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 6067
 $15 = $12 - $4 | 0; //@line 6068
 $$lobit38 = $12 >>> 31; //@line 6070
 $$lobit39 = $15 >>> 31; //@line 6071
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 6074
 HEAP32[96444] = ($$lobit39 ^ $$lobit38) & ($$lobit38 ^ $4 >>> 31); //@line 6078
 $22 = $12 >>> 0 < $4 >>> 0 & 1; //@line 6080
 HEAP32[96441] = $22; //@line 6081
 HEAP32[96445] = $22; //@line 6082
 HEAP32[96443] = $$lobit39; //@line 6083
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 6087
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6090
 return;
}
function __Z11op_aa0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $31 = 0;
 $2 = HEAP32[162769] | 0; //@line 17931
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 17949
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 17950
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 17952
 $25 = 123608 + ($23 >>> 16 << 2) | 0; //@line 17954
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 17957
 HEAP32[$21 >> 2] = $23; //@line 17958
 $29 = $28 ^ $20; //@line 17959
 $31 = ($29 | 0) == 0 & 1; //@line 17961
 HEAP32[96441] = 0; //@line 17962
 HEAP32[96442] = 0; //@line 17962
 HEAP32[96443] = 0; //@line 17962
 HEAP32[96444] = 0; //@line 17962
 HEAP32[96442] = $31; //@line 17963
 HEAP32[96443] = $29 >>> 31; //@line 17965
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 17969
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17972
 return;
}
function __Z12op_8139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $32 = 0, $4 = 0, $5 = 0, $sext1213 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16021
 $5 = HEAP32[162769] | 0; //@line 16022
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 16031
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 16040
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 16042
 $sext1213 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0 | $4; //@line 16047
 $30 = $sext1213 << 24 >> 24; //@line 16049
 $32 = ($30 | 0) == 0 & 1; //@line 16051
 HEAP32[96441] = 0; //@line 16052
 HEAP32[96442] = 0; //@line 16052
 HEAP32[96443] = 0; //@line 16052
 HEAP32[96444] = 0; //@line 16052
 HEAP32[96442] = $32; //@line 16053
 HEAP32[96443] = $sext1213 >>> 7 & 1; //@line 16056
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $30); //@line 16060
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16063
 return;
}
function __Z12op_4810_1_ffj($0) {
 $0 = $0 | 0;
 var $$028$in = 0, $10 = 0, $14 = 0, $16 = 0, $19 = 0, $21 = 0, $22 = 0, $3 = 0, $5 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1720
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 1722
 $10 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0) << 24 >> 24; //@line 1728
 $14 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($10 & 15) | 0; //@line 1733
 $16 = $14 & 65535; //@line 1735
 $19 = ($16 >>> 0 > 9 ? $16 + -6 | 0 : $14) - ($10 & 240) | 0; //@line 1739
 $21 = ($19 & 496) >>> 0 > 144; //@line 1741
 $22 = $21 & 1; //@line 1742
 $$028$in = $21 ? ($19 & 65535) + -96 | 0 : $19; //@line 1745
 HEAP32[96441] = $22; //@line 1746
 HEAP32[96445] = $22; //@line 1747
 HEAP32[96442] = ($$028$in & 255 | 0) == 0 & HEAP32[96442]; //@line 1753
 HEAP32[96443] = $$028$in >>> 7 & 1; //@line 1756
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $$028$in & 65535); //@line 1761
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1764
 return;
}
function __Z12op_31f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 39048
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 39057
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 39072
 $26 = HEAP32[162769] | 0; //@line 39073
 $35 = ((HEAPU8[$26 + 6 >> 0] | 0) << 8 | (HEAPU8[$26 + 7 >> 0] | 0)) << 16 >> 16; //@line 39083
 $36 = $25 << 16 >> 16; //@line 39085
 $38 = ($36 | 0) == 0 & 1; //@line 39087
 HEAP32[96441] = 0; //@line 39088
 HEAP32[96442] = 0; //@line 39088
 HEAP32[96443] = 0; //@line 39088
 HEAP32[96444] = 0; //@line 39088
 HEAP32[96442] = $38; //@line 39089
 HEAP32[96443] = $25 >>> 15 & 1; //@line 39092
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($35, $36); //@line 39098
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 39101
 return;
}
function __Z12op_21a8_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $24 = 0, $33 = 0, $35 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 43559
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 43570
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 43575
 $24 = HEAP32[162769] | 0; //@line 43578
 $33 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) | 0; //@line 43587
 $35 = ($21 | 0) == 0 & 1; //@line 43589
 HEAP32[96441] = 0; //@line 43590
 HEAP32[96442] = 0; //@line 43590
 HEAP32[96443] = 0; //@line 43590
 HEAP32[96444] = 0; //@line 43590
 HEAP32[96442] = $35; //@line 43591
 HEAP32[96443] = $21 >>> 31; //@line 43593
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $21); //@line 43599
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43602
 return;
}
function __Z12op_2170_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $23 = 0, $33 = 0, $35 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 43227
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 43236
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 43241
 $23 = HEAP32[162769] | 0; //@line 43244
 $33 = (((HEAPU8[$23 + 4 >> 0] | 0) << 8 | (HEAPU8[$23 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 43255
 $35 = ($20 | 0) == 0 & 1; //@line 43257
 HEAP32[96441] = 0; //@line 43258
 HEAP32[96442] = 0; //@line 43258
 HEAP32[96443] = 0; //@line 43258
 HEAP32[96444] = 0; //@line 43258
 HEAP32[96442] = $35; //@line 43259
 HEAP32[96443] = $20 >>> 31; //@line 43261
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $20); //@line 43267
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43270
 return;
}
function __Z11op_ab9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $43 = 0, $45 = 0;
 $1 = HEAP32[162769] | 0; //@line 18155
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 18173
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 18182
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 18191
 $39 = 123608 + ($28 >>> 16 << 2) | 0; //@line 18193
 $43 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$39 >> 2] >> 2] & 127]($37) | 0) ^ $19; //@line 18197
 $45 = ($43 | 0) == 0 & 1; //@line 18199
 HEAP32[96441] = 0; //@line 18200
 HEAP32[96442] = 0; //@line 18200
 HEAP32[96443] = 0; //@line 18200
 HEAP32[96444] = 0; //@line 18200
 HEAP32[96442] = $45; //@line 18201
 HEAP32[96443] = $43 >>> 31; //@line 18203
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$39 >> 2] | 0) + 12 >> 2] & 31]($37, $43); //@line 18207
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 18210
 return;
}
function __Z12op_c1f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $27 = 0, $29 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 30956
 $5 = $4 + 2 | 0; //@line 30957
 HEAP32[162769] = $5; //@line 30958
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30960
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 30967
 HEAP32[162769] = $4 + 4; //@line 30969
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 30970
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 30976
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30977
 $27 = Math_imul(HEAP32[$23 >> 2] << 16 >> 16, $22 << 16 >> 16) | 0; //@line 30983
 $29 = ($27 | 0) == 0 & 1; //@line 30985
 HEAP32[96441] = 0; //@line 30986
 HEAP32[96442] = 0; //@line 30986
 HEAP32[96443] = 0; //@line 30986
 HEAP32[96444] = 0; //@line 30986
 HEAP32[96442] = $29; //@line 30987
 HEAP32[96443] = $27 >>> 31; //@line 30989
 HEAP32[$23 >> 2] = $27; //@line 30990
 return;
}
function __Z12op_20fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 29459
 $$cast = $4; //@line 29461
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 29475
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 29480
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29481
 $25 = HEAP32[$24 >> 2] | 0; //@line 29482
 HEAP32[$24 >> 2] = $25 + 4; //@line 29484
 $28 = ($23 | 0) == 0 & 1; //@line 29486
 HEAP32[96441] = 0; //@line 29487
 HEAP32[96442] = 0; //@line 29487
 HEAP32[96443] = 0; //@line 29487
 HEAP32[96444] = 0; //@line 29487
 HEAP32[96442] = $28; //@line 29488
 HEAP32[96443] = $23 >>> 31; //@line 29490
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $23); //@line 29496
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29499
 return;
}
function __Z12op_11f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $26 = 0, $35 = 0, $36 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 26976
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 26985
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 27000
 $26 = HEAP32[162769] | 0; //@line 27001
 $35 = ((HEAPU8[$26 + 6 >> 0] | 0) << 8 | (HEAPU8[$26 + 7 >> 0] | 0)) << 16 >> 16; //@line 27011
 $36 = $25 << 24 >> 24; //@line 27013
 $38 = ($36 | 0) == 0 & 1; //@line 27015
 HEAP32[96441] = 0; //@line 27016
 HEAP32[96442] = 0; //@line 27016
 HEAP32[96443] = 0; //@line 27016
 HEAP32[96444] = 0; //@line 27016
 HEAP32[96442] = $38; //@line 27017
 HEAP32[96443] = $25 >>> 7 & 1; //@line 27020
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($35 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($35, $36); //@line 27026
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 27029
 return;
}
function __Z11op_ca8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $2 = 0, $20 = 0, $32 = 0, $37 = 0, $38 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 20054
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 20057
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 20072
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 20085
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($32 >>> 16 << 2) >> 2] >> 2] & 127]($32) | 0; //@line 20090
 $38 = $37 - $20 | 0; //@line 20091
 $$lobit31 = $37 >>> 31; //@line 20093
 $$lobit32 = $38 >>> 31; //@line 20094
 HEAP32[96442] = ($38 | 0) == 0 & 1; //@line 20097
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 20102
 HEAP32[96441] = $37 >>> 0 < $20 >>> 0 & 1; //@line 20105
 HEAP32[96443] = $$lobit32; //@line 20106
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 20109
 return;
}
function __Z11op_c68_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $28 = 0, $29 = 0, $5 = 0, $sext31$lobit = 0, $sext33$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19479
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19482
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19487
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 19500
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($22) | 0; //@line 19506
 $29 = $28 - $10 | 0; //@line 19507
 $sext31$lobit = $28 >>> 15 & 1; //@line 19510
 $sext33$lobit = $29 >>> 15 & 1; //@line 19512
 HEAP32[96442] = ($29 & 65535 | 0) == 0 & 1; //@line 19516
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext31$lobit | 0) & ($sext33$lobit | 0) != ($sext31$lobit | 0) & 1; //@line 19521
 HEAP32[96441] = $10 >>> 0 > ($28 & 65535) >>> 0 & 1; //@line 19525
 HEAP32[96443] = $sext33$lobit; //@line 19526
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19529
 return;
}
function __Z11op_148_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $23 = 0, $24 = 0, $32 = 0, $33 = 0, $41 = 0, $42 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 6974
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6985
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24; //@line 6992
 $24 = $16 + 2 | 0; //@line 6993
 $32 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($24) | 0) << 16) + $23 | 0; //@line 7001
 $33 = $16 + 4 | 0; //@line 7002
 $41 = $32 + ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($33) | 0) << 8) | 0; //@line 7010
 $42 = $16 + 6 | 0; //@line 7011
 HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] = $41 + (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($42 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($42) | 0); //@line 7020
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7023
 return;
}
function __Z10op_60_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $sext1819 = 0;
 $2 = HEAP32[162769] | 0; //@line 5185
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 5193
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 5194
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 5196
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 5198
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 5202
 HEAP32[$11 >> 2] = $13; //@line 5203
 $sext1819 = $10 | $19; //@line 5204
 $20 = $sext1819 << 16 >> 16; //@line 5206
 $22 = ($20 | 0) == 0 & 1; //@line 5208
 HEAP32[96441] = 0; //@line 5209
 HEAP32[96442] = 0; //@line 5209
 HEAP32[96443] = 0; //@line 5209
 HEAP32[96444] = 0; //@line 5209
 HEAP32[96442] = $22; //@line 5210
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 5213
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $20); //@line 5217
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5220
 return;
}
function __Z12op_31e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $21 = 0, $30 = 0, $31 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 38881
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 38892
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 38898
 $21 = HEAP32[162769] | 0; //@line 38899
 $30 = ((HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) << 16 >> 16; //@line 38909
 $31 = $20 << 16 >> 16; //@line 38911
 $33 = ($31 | 0) == 0 & 1; //@line 38913
 HEAP32[96441] = 0; //@line 38914
 HEAP32[96442] = 0; //@line 38914
 HEAP32[96443] = 0; //@line 38914
 HEAP32[96444] = 0; //@line 38914
 HEAP32[96442] = $33; //@line 38915
 HEAP32[96443] = $20 >>> 15 & 1; //@line 38918
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($30, $31); //@line 38924
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 38927
 return;
}
function __Z15PrefsFindStringPKci($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, $$017$i = 0, $$1$i = 0, label = 0;
 $$01416$i = HEAP32[28198] | 0; //@line 1322
 if (!$$01416$i) {
  $$0 = 0; //@line 1325
  return $$0 | 0; //@line 1326
 } else {
  $$01418$i = $$01416$i; //@line 1328
  $$017$i = 0; //@line 1328
 }
 while (1) {
  if (!(HEAP32[$$01418$i + 8 >> 2] | 0)) {
   if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
    if (($$017$i | 0) == ($1 | 0)) {
     break;
    }
    $$1$i = $$017$i + 1 | 0; //@line 1345
   } else {
    $$1$i = $$017$i; //@line 1347
   }
  } else {
   $$1$i = $$017$i; //@line 1350
  }
  $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 1352
  if (!$$014$i) {
   $$0 = 0; //@line 1355
   label = 8; //@line 1356
   break;
  } else {
   $$01418$i = $$014$i; //@line 1359
   $$017$i = $$1$i; //@line 1359
  }
 }
 if ((label | 0) == 8) {
  return $$0 | 0; //@line 1363
 }
 $$0 = HEAP32[$$01418$i + 12 >> 2] | 0; //@line 1367
 return $$0 | 0; //@line 1368
}
function __Z12op_2179_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $29 = 0, $3 = 0, $39 = 0, $41 = 0;
 $3 = HEAP32[162769] | 0; //@line 32746
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 32755
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 32769
 $29 = HEAP32[162769] | 0; //@line 32772
 $39 = (((HEAPU8[$29 + 6 >> 0] | 0) << 8 | (HEAPU8[$29 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32783
 $41 = ($26 | 0) == 0 & 1; //@line 32785
 HEAP32[96441] = 0; //@line 32786
 HEAP32[96442] = 0; //@line 32786
 HEAP32[96443] = 0; //@line 32786
 HEAP32[96444] = 0; //@line 32786
 HEAP32[96442] = $41; //@line 32787
 HEAP32[96443] = $26 >>> 31; //@line 32789
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($39, $26); //@line 32795
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 32798
 return;
}
function __Z12op_20bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $24 = 0, $26 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 29003
 $4 = $3 + 2 | 0; //@line 29004
 HEAP32[162769] = $4; //@line 29005
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 29010
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 29017
 HEAP32[162769] = $3 + 4; //@line 29019
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 29020
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 29025
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29027
 $26 = ($22 | 0) == 0 & 1; //@line 29029
 HEAP32[96441] = 0; //@line 29030
 HEAP32[96442] = 0; //@line 29030
 HEAP32[96443] = 0; //@line 29030
 HEAP32[96444] = 0; //@line 29030
 HEAP32[96442] = $26; //@line 29031
 HEAP32[96443] = $22 >>> 31; //@line 29033
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $22); //@line 29039
 return;
}
function __Z12op_11e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $21 = 0, $30 = 0, $31 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 26809
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 26820
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 26826
 $21 = HEAP32[162769] | 0; //@line 26827
 $30 = ((HEAPU8[$21 + 4 >> 0] | 0) << 8 | (HEAPU8[$21 + 5 >> 0] | 0)) << 16 >> 16; //@line 26837
 $31 = $20 << 24 >> 24; //@line 26839
 $33 = ($31 | 0) == 0 & 1; //@line 26841
 HEAP32[96441] = 0; //@line 26842
 HEAP32[96442] = 0; //@line 26842
 HEAP32[96443] = 0; //@line 26842
 HEAP32[96444] = 0; //@line 26842
 HEAP32[96442] = $33; //@line 26843
 HEAP32[96443] = $20 >>> 7 & 1; //@line 26846
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($30, $31); //@line 26852
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26855
 return;
}
function __Z11op_c60_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $19 = 0, $2 = 0, $20 = 0, $5 = 0, $sext$lobit = 0, $sext34$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19428
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19431
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19436
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 19437
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 19439
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 19445
 HEAP32[$11 >> 2] = $13; //@line 19446
 $20 = $19 - $10 | 0; //@line 19447
 $sext$lobit = $19 >>> 15 & 1; //@line 19450
 $sext34$lobit = $20 >>> 15 & 1; //@line 19452
 HEAP32[96442] = ($20 & 65535 | 0) == 0 & 1; //@line 19456
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext34$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19461
 HEAP32[96441] = $10 >>> 0 > ($19 & 65535) >>> 0 & 1; //@line 19465
 HEAP32[96443] = $sext34$lobit; //@line 19466
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19469
 return;
}
function __Z12op_e148_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $12 = 0, $15 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39253
 $7 = HEAP32[$6 >> 2] | 0; //@line 39254
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39255
 $9 = $8 >>> 0 > 15; //@line 39256
 HEAP32[96441] = 0; //@line 39257
 HEAP32[96442] = 0; //@line 39257
 HEAP32[96443] = 0; //@line 39257
 HEAP32[96444] = 0; //@line 39257
 if ($9) {
  $12 = ($8 | 0) == 16 ? $7 & 1 : 0; //@line 39261
  HEAP32[96441] = $12; //@line 39262
  HEAP32[96445] = $12; //@line 39263
  $$0 = 0; //@line 39264
 } else {
  $15 = ($7 & 65535) << $8 + -1; //@line 39268
  $17 = $15 >>> 15 & 1; //@line 39270
  HEAP32[96441] = $17; //@line 39271
  HEAP32[96445] = $17; //@line 39272
  $$0 = $15 << 1 & 65534; //@line 39275
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39279
 HEAP32[96443] = $$0 >>> 15; //@line 39281
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 39284
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39287
 return;
}
function __Z12op_4479_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $27 = 0, $35 = 0, $sext24$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 47501
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 47510
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 47519
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47521
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 47525
 $27 = 0 - ($25 << 16 >> 16) | 0; //@line 47528
 $sext24$lobit = $27 >>> 15 & 1; //@line 47531
 HEAP32[96442] = ($27 & 65535 | 0) == 0 & 1; //@line 47535
 HEAP32[96444] = $sext24$lobit & $25 >>> 15; //@line 47537
 $35 = ($25 & 65535 | 0) != 0 & 1; //@line 47540
 HEAP32[96441] = $35; //@line 47541
 HEAP32[96445] = $35; //@line 47542
 HEAP32[96443] = $sext24$lobit; //@line 47543
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $27); //@line 47547
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 47550
 return;
}
function __Z12op_41bb_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $19 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $sext = 0;
 $3 = HEAP32[162768] | 0; //@line 42443
 $4 = HEAP32[162769] | 0; //@line 42444
 $5 = HEAP32[162770] | 0; //@line 42445
 $7 = $4 + $3 - $5 | 0; //@line 42447
 $$cast = $4; //@line 42448
 $8 = $$cast + 2 | 0; //@line 42449
 HEAP32[162769] = $8; //@line 42450
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 42460
 HEAP32[162769] = $$cast + 4; //@line 42462
 $19 = __Z15get_disp_ea_020jj($8 + $3 - $5 | 0, $17) | 0; //@line 42463
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 42469
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42472
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42475
  __Z9Exceptionij(6, $7); //@line 42476
  return;
 }
 if (($sext | 0) <= ($25 << 16 | 0)) {
  return;
 }
 HEAP32[96443] = 0; //@line 42484
 __Z9Exceptionij(6, $7); //@line 42485
 return;
}
function __Z12op_41b0_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $11 = 0, $18 = 0, $20 = 0, $26 = 0, $5 = 0, $8 = 0, $9 = 0, $sext = 0;
 $5 = HEAP32[162769] | 0; //@line 42229
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42232
 $$cast = $5; //@line 42233
 $9 = $$cast + 2 | 0; //@line 42234
 HEAP32[162769] = $9; //@line 42235
 $11 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42237
 $18 = (HEAPU8[$9 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 42244
 HEAP32[162769] = $$cast + 4; //@line 42246
 $20 = __Z15get_disp_ea_020jj($11, $18) | 0; //@line 42247
 $26 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($20) | 0; //@line 42253
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42256
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42259
  __Z9Exceptionij(6, $8); //@line 42260
  return;
 }
 if (($sext | 0) <= ($26 << 16 | 0)) {
  return;
 }
 HEAP32[96443] = 0; //@line 42268
 __Z9Exceptionij(6, $8); //@line 42269
 return;
}
function __Z11op_c70_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $27 = 0, $28 = 0, $5 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 30411
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 30414
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 30419
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 30430
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($21) | 0; //@line 30436
 $28 = $27 - $10 | 0; //@line 30437
 $sext$lobit = $27 >>> 15 & 1; //@line 30440
 $sext32$lobit = $28 >>> 15 & 1; //@line 30442
 HEAP32[96442] = ($28 & 65535 | 0) == 0 & 1; //@line 30446
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 30451
 HEAP32[96441] = $10 >>> 0 > ($27 & 65535) >>> 0 & 1; //@line 30455
 HEAP32[96443] = $sext32$lobit; //@line 30456
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30459
 return;
}
function __Z11op_298_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $27 = 0, $30 = 0, $32 = 0;
 $2 = HEAP32[162769] | 0; //@line 9295
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9313
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 9314
 $22 = HEAP32[$21 >> 2] | 0; //@line 9315
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 9317
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 9320
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 9323
 $30 = $27 & $20; //@line 9324
 $32 = ($30 | 0) == 0 & 1; //@line 9326
 HEAP32[96441] = 0; //@line 9327
 HEAP32[96442] = 0; //@line 9327
 HEAP32[96443] = 0; //@line 9327
 HEAP32[96444] = 0; //@line 9327
 HEAP32[96442] = $32; //@line 9328
 HEAP32[96443] = $30 >>> 31; //@line 9330
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $30); //@line 9334
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9337
 return;
}
function __Z11op_260_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $sext1819 = 0;
 $2 = HEAP32[162769] | 0; //@line 8924
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8932
 $11 = 651040 + (($0 & 7) << 2) | 0; //@line 8933
 $13 = (HEAP32[$11 >> 2] | 0) + -2 | 0; //@line 8935
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 8937
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 8941
 HEAP32[$11 >> 2] = $13; //@line 8942
 $sext1819 = $19 & $10; //@line 8943
 $20 = $sext1819 << 16 >> 16; //@line 8945
 $22 = ($20 | 0) == 0 & 1; //@line 8947
 HEAP32[96441] = 0; //@line 8948
 HEAP32[96442] = 0; //@line 8948
 HEAP32[96443] = 0; //@line 8948
 HEAP32[96444] = 0; //@line 8948
 HEAP32[96442] = $22; //@line 8949
 HEAP32[96443] = $sext1819 >>> 15; //@line 8951
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $20); //@line 8955
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8958
 return;
}
function __Z10op_79_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $29 = 0, $34 = 0, $36 = 0, $9 = 0, $sext1213 = 0;
 $1 = HEAP32[162769] | 0; //@line 5383
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 5391
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 5400
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 5409
 $29 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5411
 $sext1213 = $9 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0); //@line 5416
 $34 = $sext1213 << 16 >> 16; //@line 5418
 $36 = ($34 | 0) == 0 & 1; //@line 5420
 HEAP32[96441] = 0; //@line 5421
 HEAP32[96442] = 0; //@line 5421
 HEAP32[96443] = 0; //@line 5421
 HEAP32[96444] = 0; //@line 5421
 HEAP32[96442] = $36; //@line 5422
 HEAP32[96443] = $sext1213 >>> 15 & 1; //@line 5425
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $34); //@line 5429
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 5432
 return;
}
function __Z12op_50a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $32 = 0, $4 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4547
 $8 = HEAP32[162769] | 0; //@line 4551
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 4562
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 4564
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0; //@line 4567
 $24 = $23 + $4 | 0; //@line 4568
 $$lobit38 = $24 >>> 31; //@line 4571
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 4574
 HEAP32[96444] = ($$lobit38 ^ $4 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 4578
 $32 = $4 >>> 0 > ~$23 >>> 0 & 1; //@line 4581
 HEAP32[96441] = $32; //@line 4582
 HEAP32[96445] = $32; //@line 4583
 HEAP32[96443] = $$lobit38; //@line 4584
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 4588
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4591
 return;
}
function __Z12op_2168_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $24 = 0, $34 = 0, $36 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32576
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 32587
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 32592
 $24 = HEAP32[162769] | 0; //@line 32595
 $34 = (((HEAPU8[$24 + 4 >> 0] | 0) << 8 | (HEAPU8[$24 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32606
 $36 = ($21 | 0) == 0 & 1; //@line 32608
 HEAP32[96441] = 0; //@line 32609
 HEAP32[96442] = 0; //@line 32609
 HEAP32[96443] = 0; //@line 32609
 HEAP32[96444] = 0; //@line 32609
 HEAP32[96442] = $36; //@line 32610
 HEAP32[96443] = $21 >>> 31; //@line 32612
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $21); //@line 32618
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 32621
 return;
}
function __Z10op_98_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $27 = 0, $30 = 0, $32 = 0;
 $2 = HEAP32[162769] | 0; //@line 5561
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5579
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 5580
 $22 = HEAP32[$21 >> 2] | 0; //@line 5581
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 5583
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0; //@line 5586
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 5589
 $30 = $20 | $27; //@line 5590
 $32 = ($30 | 0) == 0 & 1; //@line 5592
 HEAP32[96441] = 0; //@line 5593
 HEAP32[96442] = 0; //@line 5593
 HEAP32[96443] = 0; //@line 5593
 HEAP32[96444] = 0; //@line 5593
 HEAP32[96442] = $32; //@line 5594
 HEAP32[96443] = $30 >>> 31; //@line 5596
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $30); //@line 5600
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5603
 return;
}
function __Z12op_51b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $14 = 0, $16 = 0, $19 = 0, $20 = 0, $27 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6252
 $5 = HEAP32[162769] | 0; //@line 6253
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 6263
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 6265
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 6268
 $20 = $19 - $4 | 0; //@line 6269
 $$lobit33 = $19 >>> 31; //@line 6271
 $$lobit34 = $20 >>> 31; //@line 6272
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 6275
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $4 >>> 31); //@line 6279
 $27 = $19 >>> 0 < $4 >>> 0 & 1; //@line 6281
 HEAP32[96441] = $27; //@line 6282
 HEAP32[96445] = $27; //@line 6283
 HEAP32[96443] = $$lobit34; //@line 6284
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 6288
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6291
 return;
}
function __Z12op_21fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $21 = 0, $22 = 0, $31 = 0, $33 = 0;
 $2 = HEAP32[162769] | 0; //@line 34018
 $$cast = $2; //@line 34020
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 34034
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 34039
 $22 = HEAP32[162769] | 0; //@line 34040
 $31 = ((HEAPU8[$22 + 4 >> 0] | 0) << 8 | (HEAPU8[$22 + 5 >> 0] | 0)) << 16 >> 16; //@line 34050
 $33 = ($21 | 0) == 0 & 1; //@line 34052
 HEAP32[96441] = 0; //@line 34053
 HEAP32[96442] = 0; //@line 34053
 HEAP32[96443] = 0; //@line 34053
 HEAP32[96444] = 0; //@line 34053
 HEAP32[96442] = $33; //@line 34054
 HEAP32[96443] = $21 >>> 31; //@line 34056
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($31 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($31, $21); //@line 34062
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34065
 return;
}
function __Z12op_2190_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $21 = 0, $23 = 0, $25 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33068
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 33073
 $11 = HEAP32[162769] | 0; //@line 33074
 $12 = $11 + 2 | 0; //@line 33075
 HEAP32[162769] = $12; //@line 33076
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33078
 $21 = (HEAPU8[$12 >> 0] | 0) << 8 | (HEAPU8[$11 + 3 >> 0] | 0); //@line 33085
 HEAP32[162769] = $11 + 4; //@line 33087
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 33088
 $25 = ($10 | 0) == 0 & 1; //@line 33090
 HEAP32[96441] = 0; //@line 33091
 HEAP32[96442] = 0; //@line 33091
 HEAP32[96443] = 0; //@line 33091
 HEAP32[96444] = 0; //@line 33091
 HEAP32[96442] = $25; //@line 33092
 HEAP32[96443] = $10 >>> 31; //@line 33094
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $10); //@line 33100
 return;
}
function __Z12op_51a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $$lobit40 = 0, $10 = 0, $13 = 0, $14 = 0, $21 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6101
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 6103
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 6105
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 6107
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 6110
 HEAP32[$6 >> 2] = $8; //@line 6111
 $14 = $13 - $4 | 0; //@line 6112
 $$lobit39 = $13 >>> 31; //@line 6114
 $$lobit40 = $14 >>> 31; //@line 6115
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 6118
 HEAP32[96444] = ($$lobit40 ^ $$lobit39) & ($$lobit39 ^ $4 >>> 31); //@line 6122
 $21 = $13 >>> 0 < $4 >>> 0 & 1; //@line 6124
 HEAP32[96441] = $21; //@line 6125
 HEAP32[96445] = $21; //@line 6126
 HEAP32[96443] = $$lobit40; //@line 6127
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 6131
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6134
 return;
}
function __Z11op_279_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $29 = 0, $34 = 0, $36 = 0, $9 = 0, $sext1213 = 0;
 $1 = HEAP32[162769] | 0; //@line 9118
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 9126
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 9135
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 9144
 $29 = 123608 + ($18 >>> 16 << 2) | 0; //@line 9146
 $sext1213 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$29 >> 2] | 0) + 4 >> 2] & 127]($27) | 0) & $9; //@line 9151
 $34 = $sext1213 << 16 >> 16; //@line 9153
 $36 = ($34 | 0) == 0 & 1; //@line 9155
 HEAP32[96441] = 0; //@line 9156
 HEAP32[96442] = 0; //@line 9156
 HEAP32[96443] = 0; //@line 9156
 HEAP32[96444] = 0; //@line 9156
 HEAP32[96442] = $36; //@line 9157
 HEAP32[96443] = $sext1213 >>> 15; //@line 9159
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$29 >> 2] | 0) + 16 >> 2] & 31]($27, $34); //@line 9163
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 9166
 return;
}
function __Z12op_c018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $sext1920 = 0;
 $1 = $0 & 7; //@line 27942
 $4 = 651040 + ($1 << 2) | 0; //@line 27945
 $5 = HEAP32[$4 >> 2] | 0; //@line 27946
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 27952
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 27957
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 27958
 $17 = HEAP32[$16 >> 2] | 0; //@line 27959
 $sext1920 = $17 & $11; //@line 27960
 $18 = $sext1920 << 24 >> 24; //@line 27962
 $20 = ($18 | 0) == 0 & 1; //@line 27964
 HEAP32[96441] = 0; //@line 27965
 HEAP32[96442] = 0; //@line 27965
 HEAP32[96443] = 0; //@line 27965
 HEAP32[96444] = 0; //@line 27965
 HEAP32[96442] = $20; //@line 27966
 HEAP32[96443] = $sext1920 >>> 7 & 1; //@line 27969
 HEAP32[$16 >> 2] = $17 & -256 | $18 & 255; //@line 27973
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27976
 return;
}
function __Z12op_907c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $16 = 0, $18 = 0, $27 = 0, $3 = 0, $6 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $3 = HEAP32[162769] | 0; //@line 18914
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 18917
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 18922
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18923
 $13 = HEAP32[$12 >> 2] | 0; //@line 18924
 $16 = ($13 << 16 >> 16) - ($11 << 16 >> 16) | 0; //@line 18929
 $18 = $13 >>> 15; //@line 18931
 $sext32$lobit = $16 >>> 15 & 1; //@line 18934
 $sext32$mask = $16 & 65535; //@line 18935
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 18938
 HEAP32[96444] = ($sext32$lobit ^ $18 & 1) & ($18 ^ $6 >>> 7); //@line 18942
 $27 = $11 >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 18945
 HEAP32[96441] = $27; //@line 18946
 HEAP32[96445] = $27; //@line 18947
 HEAP32[96443] = $sext32$lobit; //@line 18948
 HEAP32[$12 >> 2] = $13 & -65536 | $sext32$mask; //@line 18951
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18954
 return;
}
function __Z12op_8018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $sext1920 = 0;
 $1 = $0 & 7; //@line 13617
 $4 = 651040 + ($1 << 2) | 0; //@line 13620
 $5 = HEAP32[$4 >> 2] | 0; //@line 13621
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 13627
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 13632
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13633
 $17 = HEAP32[$16 >> 2] | 0; //@line 13634
 $sext1920 = $17 | $11; //@line 13635
 $18 = $sext1920 << 24 >> 24; //@line 13637
 $20 = ($18 | 0) == 0 & 1; //@line 13639
 HEAP32[96441] = 0; //@line 13640
 HEAP32[96442] = 0; //@line 13640
 HEAP32[96443] = 0; //@line 13640
 HEAP32[96444] = 0; //@line 13640
 HEAP32[96442] = $20; //@line 13641
 HEAP32[96443] = $sext1920 >>> 7 & 1; //@line 13644
 HEAP32[$16 >> 2] = $17 & -256 | $18 & 255; //@line 13648
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13651
 return;
}
function __Z11op_a18_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 15539
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15542
 $5 = 651040 + ($1 << 2) | 0; //@line 15543
 $6 = HEAP32[$5 >> 2] | 0; //@line 15544
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 15546
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 15550
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 15555
 $18 = $12 ^ $4 & 255; //@line 15557
 $19 = $18 << 24 >> 24; //@line 15559
 $21 = ($19 | 0) == 0 & 1; //@line 15561
 HEAP32[96441] = 0; //@line 15562
 HEAP32[96442] = 0; //@line 15562
 HEAP32[96443] = 0; //@line 15562
 HEAP32[96444] = 0; //@line 15562
 HEAP32[96442] = $21; //@line 15563
 HEAP32[96443] = $18 >>> 7 & 1; //@line 15566
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $19); //@line 15570
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15573
 return;
}
function __Z12op_c0f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $27 = 0, $29 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 29423
 $5 = $4 + 2 | 0; //@line 29424
 HEAP32[162769] = $5; //@line 29425
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29427
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 29434
 HEAP32[162769] = $4 + 4; //@line 29436
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 29437
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 29443
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29444
 $27 = Math_imul(HEAP32[$23 >> 2] & 65535, $22 & 65535) | 0; //@line 29448
 $29 = ($27 | 0) == 0 & 1; //@line 29450
 HEAP32[96441] = 0; //@line 29451
 HEAP32[96442] = 0; //@line 29451
 HEAP32[96443] = 0; //@line 29451
 HEAP32[96444] = 0; //@line 29451
 HEAP32[96442] = $29; //@line 29452
 HEAP32[96443] = $27 >>> 31; //@line 29454
 HEAP32[$23 >> 2] = $27; //@line 29455
 return;
}
function __Z12op_9150_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $28 = 0, $5 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20570
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20572
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 20574
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 20578
 $16 = ($13 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 20583
 $18 = $13 >>> 15; //@line 20585
 $sext38$lobit = $16 >>> 15 & 1; //@line 20588
 HEAP32[96442] = ($16 & 65535 | 0) == 0 & 1; //@line 20592
 HEAP32[96444] = ($sext38$lobit ^ $18 & 1) & ($18 ^ $5 >>> 15); //@line 20596
 $28 = ($5 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 20600
 HEAP32[96441] = $28; //@line 20601
 HEAP32[96445] = $28; //@line 20602
 HEAP32[96443] = $sext38$lobit; //@line 20603
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 20607
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20610
 return;
}
function __Z12op_4439_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $27 = 0, $35 = 0, $sext22$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 47127
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 47136
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 47145
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47147
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 47151
 $27 = 0 - ($25 << 24 >> 24) | 0; //@line 47154
 $sext22$lobit = $27 >>> 7 & 1; //@line 47157
 HEAP32[96442] = ($27 & 255 | 0) == 0 & 1; //@line 47161
 HEAP32[96444] = $sext22$lobit & $25 >>> 7; //@line 47163
 $35 = ($25 & 255 | 0) != 0 & 1; //@line 47166
 HEAP32[96441] = $35; //@line 47167
 HEAP32[96445] = $35; //@line 47168
 HEAP32[96443] = $sext22$lobit; //@line 47169
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $27); //@line 47173
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 47176
 return;
}
function __Z12op_30bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44402
 $$cast = $4; //@line 44407
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44416
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 44422
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 44424
 $26 = $23 << 16 >> 16; //@line 44426
 $28 = ($26 | 0) == 0 & 1; //@line 44428
 HEAP32[96441] = 0; //@line 44429
 HEAP32[96442] = 0; //@line 44429
 HEAP32[96443] = 0; //@line 44429
 HEAP32[96444] = 0; //@line 44429
 HEAP32[96442] = $28; //@line 44430
 HEAP32[96443] = $23 >>> 15 & 1; //@line 44433
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($25, $26); //@line 44439
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44442
 return;
}
function __Z11op_c79_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $33 = 0, $34 = 0, $4 = 0, $9 = 0, $sext$lobit = 0, $sext28$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19652
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 19655
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 19660
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 19669
 $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 19684
 $34 = $33 - $9 | 0; //@line 19685
 $sext$lobit = $33 >>> 15 & 1; //@line 19688
 $sext28$lobit = $34 >>> 15 & 1; //@line 19690
 HEAP32[96442] = ($34 & 65535 | 0) == 0 & 1; //@line 19694
 HEAP32[96444] = ($4 >>> 7 | 0) != ($sext$lobit | 0) & ($sext28$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19699
 HEAP32[96441] = $9 >>> 0 > ($33 & 65535) >>> 0 & 1; //@line 19703
 HEAP32[96443] = $sext28$lobit; //@line 19704
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 19707
 return;
}
function __Z12op_21bc_0_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $22 = 0, $24 = 0, $3 = 0, $31 = 0, $33 = 0, $35 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 33549
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 33552
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 33567
 $22 = $3 + 6 | 0; //@line 33568
 HEAP32[162769] = $22; //@line 33569
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33571
 $31 = (HEAPU8[$22 >> 0] | 0) << 8 | (HEAPU8[$3 + 7 >> 0] | 0); //@line 33578
 HEAP32[162769] = $3 + 8; //@line 33580
 $33 = __Z15get_disp_ea_020jj($24, $31) | 0; //@line 33581
 $35 = ($21 | 0) == 0 & 1; //@line 33583
 HEAP32[96441] = 0; //@line 33584
 HEAP32[96442] = 0; //@line 33584
 HEAP32[96443] = 0; //@line 33584
 HEAP32[96444] = 0; //@line 33584
 HEAP32[96442] = $35; //@line 33585
 HEAP32[96443] = $6 >>> 7; //@line 33587
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $21); //@line 33593
 return;
}
function __Z12op_10bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 30804
 $$cast = $4; //@line 30809
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 30818
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 30824
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30826
 $26 = $23 << 24 >> 24; //@line 30828
 $28 = ($26 | 0) == 0 & 1; //@line 30830
 HEAP32[96441] = 0; //@line 30831
 HEAP32[96442] = 0; //@line 30831
 HEAP32[96443] = 0; //@line 30831
 HEAP32[96444] = 0; //@line 30831
 HEAP32[96442] = $28; //@line 30832
 HEAP32[96443] = $23 >>> 7 & 1; //@line 30835
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $26); //@line 30841
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30844
 return;
}
function __Z11op_c3b_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $sext$lobit = 0, $sext28$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 30353
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 30355
 $4 = $3 & 255; //@line 30356
 $18 = __Z15get_disp_ea_000jj($1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 30371
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 30377
 $25 = $24 - $4 | 0; //@line 30378
 $sext$lobit = $24 >>> 7 & 1; //@line 30382
 $sext28$lobit = $25 >>> 7 & 1; //@line 30384
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 30388
 HEAP32[96444] = (($3 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext28$lobit | 0) != ($sext$lobit | 0) & 1; //@line 30393
 HEAP32[96441] = $4 >>> 0 > ($24 & 255) >>> 0 & 1; //@line 30397
 HEAP32[96443] = $sext28$lobit; //@line 30398
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30401
 return;
}
function __Z11op_410_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $27 = 0, $4 = 0, $7 = 0, $9 = 0, $sext29$lobit = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 10283
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10286
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 10288
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 10292
 $16 = ($13 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10296
 $18 = $13 >>> 7; //@line 10299
 $sext29$lobit = $16 >>> 7 & 1; //@line 10302
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 10306
 HEAP32[96444] = ($sext29$lobit ^ $18 & 1) & ($18 ^ ($4 & 255) >>> 7 & 255); //@line 10310
 $27 = ($4 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 10313
 HEAP32[96441] = $27; //@line 10314
 HEAP32[96445] = $27; //@line 10315
 HEAP32[96443] = $sext29$lobit; //@line 10316
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 10320
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10323
 return;
}
function __Z12op_e108_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $12 = 0, $15 = 0, $17 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38848
 $7 = HEAP32[$6 >> 2] | 0; //@line 38849
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38850
 $9 = $8 >>> 0 > 7; //@line 38851
 HEAP32[96441] = 0; //@line 38852
 HEAP32[96442] = 0; //@line 38852
 HEAP32[96443] = 0; //@line 38852
 HEAP32[96444] = 0; //@line 38852
 if ($9) {
  $12 = ($8 | 0) == 8 ? $7 & 1 : 0; //@line 38856
  HEAP32[96441] = $12; //@line 38857
  HEAP32[96445] = $12; //@line 38858
  $$0 = 0; //@line 38859
 } else {
  $15 = ($7 & 255) << $8 + -1; //@line 38863
  $17 = $15 >>> 7 & 1; //@line 38865
  HEAP32[96441] = $17; //@line 38866
  HEAP32[96445] = $17; //@line 38867
  $$0 = $15 << 1 & 254; //@line 38870
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38874
 HEAP32[96443] = $$0 >>> 7; //@line 38876
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 38879
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38882
 return;
}
function __Z12op_20b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $25 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 28819
 $5 = $4 + 2 | 0; //@line 28820
 HEAP32[162769] = $5; //@line 28821
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28823
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 28830
 HEAP32[162769] = $4 + 4; //@line 28832
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 28833
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28838
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28840
 $25 = ($21 | 0) == 0 & 1; //@line 28842
 HEAP32[96441] = 0; //@line 28843
 HEAP32[96442] = 0; //@line 28843
 HEAP32[96443] = 0; //@line 28843
 HEAP32[96444] = 0; //@line 28843
 HEAP32[96442] = $25; //@line 28844
 HEAP32[96443] = $21 >>> 31; //@line 28846
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 28852
 return;
}
function __Z11op_e98_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $16 = 0, $27 = 0, $33 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22342
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 22349
 $9 = $7 << 24 >> 16; //@line 22351
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 22354
 $13 = HEAP32[$12 >> 2] | 0; //@line 22355
 if (!($9 & 2048)) {
  $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 22361
  HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 4; //@line 22364
  $33 = $7 >>> 4 & 7; //@line 22368
  HEAP32[($9 & 32768 | 0 ? 651040 + ($33 << 2) | 0 : 651008 + ($33 << 2) | 0) >> 2] = $27; //@line 22372
 } else {
  $16 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 22376
  HEAP32[$12 >> 2] = $13 + 4; //@line 22378
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $16); //@line 22384
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22388
 return;
}
function __Z11op_440_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $15 = 0, $17 = 0, $2 = 0, $26 = 0, $5 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $2 = HEAP32[162769] | 0; //@line 10695
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 10698
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10703
 $11 = 651008 + (($0 & 7) << 2) | 0; //@line 10704
 $12 = HEAP32[$11 >> 2] | 0; //@line 10705
 $15 = ($12 << 16 >> 16) - ($10 << 16 >> 16) | 0; //@line 10710
 $17 = $12 >>> 15; //@line 10712
 $sext32$lobit = $15 >>> 15 & 1; //@line 10715
 $sext32$mask = $15 & 65535; //@line 10716
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 10719
 HEAP32[96444] = ($sext32$lobit ^ $17 & 1) & ($17 ^ $5 >>> 7); //@line 10723
 $26 = $10 >>> 0 > ($12 & 65535) >>> 0 & 1; //@line 10726
 HEAP32[96441] = $26; //@line 10727
 HEAP32[96445] = $26; //@line 10728
 HEAP32[96443] = $sext32$lobit; //@line 10729
 HEAP32[$11 >> 2] = $12 & -65536 | $sext32$mask; //@line 10732
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10735
 return;
}
function __Z11op_2b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $43 = 0, $45 = 0;
 $1 = HEAP32[162769] | 0; //@line 9570
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 9588
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 9597
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 9606
 $39 = 123608 + ($28 >>> 16 << 2) | 0; //@line 9608
 $43 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$39 >> 2] >> 2] & 127]($37) | 0) & $19; //@line 9612
 $45 = ($43 | 0) == 0 & 1; //@line 9614
 HEAP32[96441] = 0; //@line 9615
 HEAP32[96442] = 0; //@line 9615
 HEAP32[96443] = 0; //@line 9615
 HEAP32[96444] = 0; //@line 9615
 HEAP32[96442] = $45; //@line 9616
 HEAP32[96443] = $43 >>> 31; //@line 9618
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$39 >> 2] | 0) + 12 >> 2] & 31]($37, $43); //@line 9622
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 9625
 return;
}
function __Z12op_23d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $20 = 0, $29 = 0, $3 = 0, $31 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 34320
 $3 = HEAP32[$2 >> 2] | 0; //@line 34321
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 34326
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 34329
 $11 = HEAP32[162769] | 0; //@line 34330
 $20 = (HEAPU8[$11 + 3 >> 0] | 0) << 16 | (HEAPU8[$11 + 2 >> 0] | 0) << 24; //@line 34339
 $29 = $20 | (HEAPU8[$11 + 4 >> 0] | 0) << 8 | (HEAPU8[$11 + 5 >> 0] | 0); //@line 34348
 $31 = ($8 | 0) == 0 & 1; //@line 34350
 HEAP32[96441] = 0; //@line 34351
 HEAP32[96442] = 0; //@line 34351
 HEAP32[96443] = 0; //@line 34351
 HEAP32[96444] = 0; //@line 34351
 HEAP32[96442] = $31; //@line 34352
 HEAP32[96443] = $8 >>> 31; //@line 34354
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($29, $8); //@line 34360
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34363
 return;
}
function __Z11op_c3a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $sext26$lobit = 0, $sext27$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19173
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 19175
 $4 = $3 & 255; //@line 19176
 $19 = $1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 19193
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 19199
 $26 = $25 - $4 | 0; //@line 19200
 $sext26$lobit = $25 >>> 7 & 1; //@line 19204
 $sext27$lobit = $26 >>> 7 & 1; //@line 19206
 HEAP32[96442] = ($26 & 255 | 0) == 0 & 1; //@line 19210
 HEAP32[96444] = (($3 & 255) >>> 7 & 255 | 0) != ($sext26$lobit | 0) & ($sext27$lobit | 0) != ($sext26$lobit | 0) & 1; //@line 19215
 HEAP32[96441] = $4 >>> 0 > ($25 & 255) >>> 0 & 1; //@line 19219
 HEAP32[96443] = $sext27$lobit; //@line 19220
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19223
 return;
}
function __Z11op_a70_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $23 = 0, $28 = 0, $30 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 17709
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 17717
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17728
 $23 = 123608 + ($21 >>> 16 << 2) | 0; //@line 17730
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 4 >> 2] & 127]($21) | 0) ^ $10; //@line 17735
 $28 = $sext1617 << 16 >> 16; //@line 17737
 $30 = ($28 | 0) == 0 & 1; //@line 17739
 HEAP32[96441] = 0; //@line 17740
 HEAP32[96442] = 0; //@line 17740
 HEAP32[96443] = 0; //@line 17740
 HEAP32[96444] = 0; //@line 17740
 HEAP32[96442] = $30; //@line 17741
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 17744
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($21, $28); //@line 17748
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17751
 return;
}
function __Z11op_2a0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $31 = 0;
 $2 = HEAP32[162769] | 0; //@line 9346
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9364
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 9365
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 9367
 $25 = 123608 + ($23 >>> 16 << 2) | 0; //@line 9369
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 9372
 HEAP32[$21 >> 2] = $23; //@line 9373
 $29 = $28 & $20; //@line 9374
 $31 = ($29 | 0) == 0 & 1; //@line 9376
 HEAP32[96441] = 0; //@line 9377
 HEAP32[96442] = 0; //@line 9377
 HEAP32[96443] = 0; //@line 9377
 HEAP32[96444] = 0; //@line 9377
 HEAP32[96442] = $31; //@line 9378
 HEAP32[96443] = $29 >>> 31; //@line 9380
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 9384
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9387
 return;
}
function __Z10op_b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $43 = 0, $45 = 0;
 $1 = HEAP32[162769] | 0; //@line 5836
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 5854
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 5863
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 5872
 $39 = 123608 + ($28 >>> 16 << 2) | 0; //@line 5874
 $43 = $19 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$39 >> 2] >> 2] & 127]($37) | 0); //@line 5878
 $45 = ($43 | 0) == 0 & 1; //@line 5880
 HEAP32[96441] = 0; //@line 5881
 HEAP32[96442] = 0; //@line 5881
 HEAP32[96443] = 0; //@line 5881
 HEAP32[96444] = 0; //@line 5881
 HEAP32[96442] = $45; //@line 5882
 HEAP32[96443] = $43 >>> 31; //@line 5884
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$39 >> 2] | 0) + 12 >> 2] & 31]($37, $43); //@line 5888
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 5891
 return;
}
function __Z12op_b018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $sext$lobit = 0, $sext34$lobit = 0;
 $1 = $0 & 7; //@line 21880
 $4 = 651040 + ($1 << 2) | 0; //@line 21883
 $5 = HEAP32[$4 >> 2] | 0; //@line 21884
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 21890
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 21895
 $17 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21897
 $18 = $17 - $11 | 0; //@line 21898
 $sext$lobit = $17 >>> 7 & 1; //@line 21902
 $sext34$lobit = $18 >>> 7 & 1; //@line 21904
 HEAP32[96442] = ($18 & 255 | 0) == 0 & 1; //@line 21908
 HEAP32[96444] = ($11 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext34$lobit | 0) != ($sext$lobit | 0) & 1; //@line 21913
 HEAP32[96441] = ($11 & 255) >>> 0 > ($17 & 255) >>> 0 & 1; //@line 21918
 HEAP32[96443] = $sext34$lobit; //@line 21919
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21922
 return;
}
function __Z11op_a20_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 15581
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15584
 $5 = 651040 + ($1 << 2) | 0; //@line 15585
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 15589
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 15591
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 15595
 HEAP32[$5 >> 2] = $9; //@line 15596
 $17 = $15 ^ $4 & 255; //@line 15598
 $18 = $17 << 24 >> 24; //@line 15600
 $20 = ($18 | 0) == 0 & 1; //@line 15602
 HEAP32[96441] = 0; //@line 15603
 HEAP32[96442] = 0; //@line 15603
 HEAP32[96443] = 0; //@line 15603
 HEAP32[96444] = 0; //@line 15603
 HEAP32[96442] = $20; //@line 15604
 HEAP32[96443] = $17 >>> 7 & 1; //@line 15607
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, $18); //@line 15611
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15614
 return;
}
function __Z10op_a0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $28 = 0, $29 = 0, $31 = 0;
 $2 = HEAP32[162769] | 0; //@line 5612
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5630
 $21 = 651040 + (($0 & 7) << 2) | 0; //@line 5631
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 5633
 $25 = 123608 + ($23 >>> 16 << 2) | 0; //@line 5635
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0; //@line 5638
 HEAP32[$21 >> 2] = $23; //@line 5639
 $29 = $20 | $28; //@line 5640
 $31 = ($29 | 0) == 0 & 1; //@line 5642
 HEAP32[96441] = 0; //@line 5643
 HEAP32[96442] = 0; //@line 5643
 HEAP32[96443] = 0; //@line 5643
 HEAP32[96444] = 0; //@line 5643
 HEAP32[96442] = $31; //@line 5644
 HEAP32[96443] = $29 >>> 31; //@line 5646
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 5650
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5653
 return;
}
function __Z10op_70_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $23 = 0, $28 = 0, $30 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 16260
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 16268
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16279
 $23 = 123608 + ($21 >>> 16 << 2) | 0; //@line 16281
 $sext1617 = $10 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 4 >> 2] & 127]($21) | 0); //@line 16286
 $28 = $sext1617 << 16 >> 16; //@line 16288
 $30 = ($28 | 0) == 0 & 1; //@line 16290
 HEAP32[96441] = 0; //@line 16291
 HEAP32[96442] = 0; //@line 16291
 HEAP32[96443] = 0; //@line 16291
 HEAP32[96444] = 0; //@line 16291
 HEAP32[96442] = $30; //@line 16292
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 16295
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($21, $28); //@line 16299
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16302
 return;
}
function __Z12op_9110_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $28 = 0, $5 = 0, $7 = 0, $9 = 0, $sext34$lobit = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 20025
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 20027
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 20029
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 20033
 $16 = ($13 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 20038
 $18 = $13 >>> 7; //@line 20040
 $sext34$lobit = $16 >>> 7 & 1; //@line 20043
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 20047
 HEAP32[96444] = ($sext34$lobit ^ $18 & 1) & ($18 ^ $5 >>> 7); //@line 20051
 $28 = ($5 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 20055
 HEAP32[96441] = $28; //@line 20056
 HEAP32[96445] = $28; //@line 20057
 HEAP32[96443] = $sext34$lobit; //@line 20058
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 20062
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 20065
 return;
}
function __Z11op_270_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $21 = 0, $23 = 0, $28 = 0, $30 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 16793
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 16801
 $21 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16812
 $23 = 123608 + ($21 >>> 16 << 2) | 0; //@line 16814
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 4 >> 2] & 127]($21) | 0) & $10; //@line 16819
 $28 = $sext1617 << 16 >> 16; //@line 16821
 $30 = ($28 | 0) == 0 & 1; //@line 16823
 HEAP32[96441] = 0; //@line 16824
 HEAP32[96442] = 0; //@line 16824
 HEAP32[96443] = 0; //@line 16824
 HEAP32[96444] = 0; //@line 16824
 HEAP32[96442] = $30; //@line 16825
 HEAP32[96443] = $sext1617 >>> 15; //@line 16827
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 16 >> 2] & 31]($21, $28); //@line 16831
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16834
 return;
}
function __Z12op_c020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $4 = 0, $8 = 0, $sext2021 = 0;
 $1 = $0 & 7; //@line 27984
 $4 = 651040 + ($1 << 2) | 0; //@line 27987
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 27991
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 27997
 HEAP32[$4 >> 2] = $8; //@line 27998
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 27999
 $16 = HEAP32[$15 >> 2] | 0; //@line 28000
 $sext2021 = $16 & $14; //@line 28001
 $17 = $sext2021 << 24 >> 24; //@line 28003
 $19 = ($17 | 0) == 0 & 1; //@line 28005
 HEAP32[96441] = 0; //@line 28006
 HEAP32[96442] = 0; //@line 28006
 HEAP32[96443] = 0; //@line 28006
 HEAP32[96444] = 0; //@line 28006
 HEAP32[96442] = $19; //@line 28007
 HEAP32[96443] = $sext2021 >>> 7 & 1; //@line 28010
 HEAP32[$15 >> 2] = $16 & -256 | $17 & 255; //@line 28014
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28017
 return;
}
function __Z12op_8020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $4 = 0, $8 = 0, $sext2021 = 0;
 $1 = $0 & 7; //@line 13659
 $4 = 651040 + ($1 << 2) | 0; //@line 13662
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 13666
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 13672
 HEAP32[$4 >> 2] = $8; //@line 13673
 $15 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13674
 $16 = HEAP32[$15 >> 2] | 0; //@line 13675
 $sext2021 = $16 | $14; //@line 13676
 $17 = $sext2021 << 24 >> 24; //@line 13678
 $19 = ($17 | 0) == 0 & 1; //@line 13680
 HEAP32[96441] = 0; //@line 13681
 HEAP32[96442] = 0; //@line 13681
 HEAP32[96443] = 0; //@line 13681
 HEAP32[96444] = 0; //@line 13681
 HEAP32[96442] = $19; //@line 13682
 HEAP32[96443] = $sext2021 >>> 7 & 1; //@line 13685
 HEAP32[$15 >> 2] = $16 & -256 | $17 & 255; //@line 13689
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13692
 return;
}
function __Z11op_a68_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 16002
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 16010
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 16023
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 16025
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0) ^ $10; //@line 16030
 $29 = $sext1718 << 16 >> 16; //@line 16032
 $31 = ($29 | 0) == 0 & 1; //@line 16034
 HEAP32[96441] = 0; //@line 16035
 HEAP32[96442] = 0; //@line 16035
 HEAP32[96443] = 0; //@line 16035
 HEAP32[96444] = 0; //@line 16035
 HEAP32[96442] = $31; //@line 16036
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 16039
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 16043
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16046
 return;
}
function __Z12op_30ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36102
 $$cast = $4; //@line 36104
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 36118
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 36124
 $26 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36126
 $27 = $24 << 16 >> 16; //@line 36128
 $29 = ($27 | 0) == 0 & 1; //@line 36130
 HEAP32[96441] = 0; //@line 36131
 HEAP32[96442] = 0; //@line 36131
 HEAP32[96443] = 0; //@line 36131
 HEAP32[96444] = 0; //@line 36131
 HEAP32[96442] = $29; //@line 36132
 HEAP32[96443] = $24 >>> 15 & 1; //@line 36135
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 36141
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36144
 return;
}
function __Z12op_c070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0, $sext2122 = 0;
 $6 = HEAP32[162769] | 0; //@line 35976
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35985
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 35991
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 35992
 $23 = HEAP32[$22 >> 2] | 0; //@line 35993
 $sext2122 = $23 & $21; //@line 35994
 $24 = $sext2122 << 16 >> 16; //@line 35996
 $26 = ($24 | 0) == 0 & 1; //@line 35998
 HEAP32[96441] = 0; //@line 35999
 HEAP32[96442] = 0; //@line 35999
 HEAP32[96443] = 0; //@line 35999
 HEAP32[96444] = 0; //@line 35999
 HEAP32[96442] = $26; //@line 36000
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 36003
 HEAP32[$22 >> 2] = $23 & -65536 | $24 & 65535; //@line 36007
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36010
 return;
}
function __Z12op_9098_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $$lobit39 = 0, $10 = 0, $13 = 0, $14 = 0, $15 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 19072
 $5 = HEAP32[$4 >> 2] | 0; //@line 19073
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 19078
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 19081
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19082
 $14 = HEAP32[$13 >> 2] | 0; //@line 19083
 $15 = $14 - $10 | 0; //@line 19084
 $$lobit38 = $14 >>> 31; //@line 19086
 $$lobit39 = $15 >>> 31; //@line 19087
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 19090
 HEAP32[96444] = ($$lobit39 ^ $$lobit38) & ($$lobit38 ^ $10 >>> 31); //@line 19094
 $22 = $14 >>> 0 < $10 >>> 0 & 1; //@line 19096
 HEAP32[96441] = $22; //@line 19097
 HEAP32[96445] = $22; //@line 19098
 HEAP32[96443] = $$lobit39; //@line 19099
 HEAP32[$13 >> 2] = $15; //@line 19100
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19103
 return;
}
function __Z12op_8070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0, $sext2122 = 0;
 $6 = HEAP32[162769] | 0; //@line 23108
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23117
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 23123
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23124
 $23 = HEAP32[$22 >> 2] | 0; //@line 23125
 $sext2122 = $23 | $21; //@line 23126
 $24 = $sext2122 << 16 >> 16; //@line 23128
 $26 = ($24 | 0) == 0 & 1; //@line 23130
 HEAP32[96441] = 0; //@line 23131
 HEAP32[96442] = 0; //@line 23131
 HEAP32[96443] = 0; //@line 23131
 HEAP32[96444] = 0; //@line 23131
 HEAP32[96442] = $26; //@line 23132
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 23135
 HEAP32[$22 >> 2] = $23 & -65536 | $24 & 65535; //@line 23139
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23142
 return;
}
function __Z12op_10ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 24186
 $$cast = $4; //@line 24188
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 24202
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 24208
 $26 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24210
 $27 = $24 << 24 >> 24; //@line 24212
 $29 = ($27 | 0) == 0 & 1; //@line 24214
 HEAP32[96441] = 0; //@line 24215
 HEAP32[96442] = 0; //@line 24215
 HEAP32[96443] = 0; //@line 24215
 HEAP32[96444] = 0; //@line 24215
 HEAP32[96442] = $29; //@line 24216
 HEAP32[96443] = $24 >>> 7 & 1; //@line 24219
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $27); //@line 24225
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24228
 return;
}
function __Z12op_23f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $15 = 0, $16 = 0, $25 = 0, $34 = 0, $36 = 0;
 $1 = HEAP32[162769] | 0; //@line 34547
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 34557
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10) | 0; //@line 34562
 $16 = HEAP32[162769] | 0; //@line 34563
 $25 = (HEAPU8[$16 + 5 >> 0] | 0) << 16 | (HEAPU8[$16 + 4 >> 0] | 0) << 24; //@line 34572
 $34 = $25 | (HEAPU8[$16 + 6 >> 0] | 0) << 8 | (HEAPU8[$16 + 7 >> 0] | 0); //@line 34581
 $36 = ($15 | 0) == 0 & 1; //@line 34583
 HEAP32[96441] = 0; //@line 34584
 HEAP32[96442] = 0; //@line 34584
 HEAP32[96443] = 0; //@line 34584
 HEAP32[96444] = 0; //@line 34584
 HEAP32[96442] = $36; //@line 34585
 HEAP32[96443] = $15 >>> 31; //@line 34587
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $15); //@line 34593
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 34596
 return;
}
function __Z12op_b068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $24 = 0, $25 = 0, $6 = 0, $sext35$lobit = 0, $sext37$lobit = 0;
 $6 = HEAP32[162769] | 0; //@line 24681
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 24692
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 24698
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24700
 $25 = $24 - $22 | 0; //@line 24701
 $sext35$lobit = $24 >>> 15 & 1; //@line 24705
 $sext37$lobit = $25 >>> 15 & 1; //@line 24707
 HEAP32[96442] = ($25 & 65535 | 0) == 0 & 1; //@line 24711
 HEAP32[96444] = ($22 >>> 15 & 1 | 0) != ($sext35$lobit | 0) & ($sext37$lobit | 0) != ($sext35$lobit | 0) & 1; //@line 24716
 HEAP32[96441] = ($22 & 65535) >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 24721
 HEAP32[96443] = $sext37$lobit; //@line 24722
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24725
 return;
}
function __Z11op_c28_0_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $2 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $sext27$lobit = 0, $sext28$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 18952
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 18954
 $5 = $4 & 255; //@line 18955
 $17 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 18968
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 18974
 $24 = $23 - $5 | 0; //@line 18975
 $sext27$lobit = $23 >>> 7 & 1; //@line 18979
 $sext28$lobit = $24 >>> 7 & 1; //@line 18981
 HEAP32[96442] = ($24 & 255 | 0) == 0 & 1; //@line 18985
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext27$lobit | 0) & ($sext28$lobit | 0) != ($sext27$lobit | 0) & 1; //@line 18990
 HEAP32[96441] = $5 >>> 0 > ($23 & 255) >>> 0 & 1; //@line 18994
 HEAP32[96443] = $sext28$lobit; //@line 18995
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 18998
 return;
}
function __Z12op_c079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $sext1718 = 0;
 $3 = HEAP32[162769] | 0; //@line 28644
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 28653
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 28668
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28669
 $29 = HEAP32[$28 >> 2] | 0; //@line 28670
 $sext1718 = $29 & $27; //@line 28671
 $30 = $sext1718 << 16 >> 16; //@line 28673
 $32 = ($30 | 0) == 0 & 1; //@line 28675
 HEAP32[96441] = 0; //@line 28676
 HEAP32[96442] = 0; //@line 28676
 HEAP32[96443] = 0; //@line 28676
 HEAP32[96444] = 0; //@line 28676
 HEAP32[96442] = $32; //@line 28677
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 28680
 HEAP32[$28 >> 2] = $29 & -65536 | $30 & 65535; //@line 28684
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28687
 return;
}
function __Z12op_8079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $sext1718 = 0;
 $3 = HEAP32[162769] | 0; //@line 14320
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 14329
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 14344
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14345
 $29 = HEAP32[$28 >> 2] | 0; //@line 14346
 $sext1718 = $29 | $27; //@line 14347
 $30 = $sext1718 << 16 >> 16; //@line 14349
 $32 = ($30 | 0) == 0 & 1; //@line 14351
 HEAP32[96441] = 0; //@line 14352
 HEAP32[96442] = 0; //@line 14352
 HEAP32[96443] = 0; //@line 14352
 HEAP32[96444] = 0; //@line 14352
 HEAP32[96442] = $32; //@line 14353
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 14356
 HEAP32[$28 >> 2] = $29 & -65536 | $30 & 65535; //@line 14360
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14363
 return;
}
function __Z12op_5150_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $28 = 0, $4 = 0, $7 = 0, $9 = 0, $sext38$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5541
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5544
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 5546
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 5550
 $16 = ($13 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5555
 $18 = $13 >>> 15; //@line 5557
 $sext38$lobit = $16 >>> 15 & 1; //@line 5560
 HEAP32[96442] = ($16 & 65535 | 0) == 0 & 1; //@line 5564
 HEAP32[96444] = ($sext38$lobit ^ $18 & 1) & ($18 ^ $4 >>> 15); //@line 5568
 $28 = ($4 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 5572
 HEAP32[96441] = $28; //@line 5573
 HEAP32[96445] = $28; //@line 5574
 HEAP32[96443] = $sext38$lobit; //@line 5575
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 5579
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5582
 return;
}
function __Z12op_44b0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $19 = 0, $2 = 0, $22 = 0, $27 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 47747
 $3 = $2 + 2 | 0; //@line 47748
 HEAP32[162769] = $3; //@line 47749
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47751
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 47758
 HEAP32[162769] = $2 + 4; //@line 47760
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 47761
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 47763
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 47766
 $22 = ($19 | 0) > 0 & 1; //@line 47770
 HEAP32[96442] = ($19 | 0) == 0 & 1; //@line 47773
 HEAP32[96444] = $22 & $19 >>> 31; //@line 47775
 $27 = ($19 | 0) != 0 & 1; //@line 47777
 HEAP32[96441] = $27; //@line 47778
 HEAP32[96445] = $27; //@line 47779
 HEAP32[96443] = $22; //@line 47780
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, 0 - $19 | 0); //@line 47784
 return;
}
function __Z10op_18_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 4767
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 4770
 $5 = 651040 + ($1 << 2) | 0; //@line 4771
 $6 = HEAP32[$5 >> 2] | 0; //@line 4772
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 4774
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 4778
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 4783
 $18 = $12 | $4 & 255; //@line 4785
 $19 = $18 << 24 >> 24; //@line 4787
 $21 = ($19 | 0) == 0 & 1; //@line 4789
 HEAP32[96441] = 0; //@line 4790
 HEAP32[96442] = 0; //@line 4790
 HEAP32[96443] = 0; //@line 4790
 HEAP32[96444] = 0; //@line 4790
 HEAP32[96442] = $21; //@line 4791
 HEAP32[96443] = $18 >>> 7 & 1; //@line 4794
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $19); //@line 4798
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4801
 return;
}
function __Z12op_c068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0, $sext2223 = 0;
 $6 = HEAP32[162769] | 0; //@line 28505
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28516
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 28522
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28523
 $24 = HEAP32[$23 >> 2] | 0; //@line 28524
 $sext2223 = $24 & $22; //@line 28525
 $25 = $sext2223 << 16 >> 16; //@line 28527
 $27 = ($25 | 0) == 0 & 1; //@line 28529
 HEAP32[96441] = 0; //@line 28530
 HEAP32[96442] = 0; //@line 28530
 HEAP32[96443] = 0; //@line 28530
 HEAP32[96444] = 0; //@line 28530
 HEAP32[96442] = $27; //@line 28531
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 28534
 HEAP32[$23 >> 2] = $24 & -65536 | $25 & 65535; //@line 28538
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28541
 return;
}
function __Z12op_c030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0, $sext1718 = 0;
 $6 = HEAP32[162769] | 0; //@line 35879
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35888
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 35894
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 35895
 $23 = HEAP32[$22 >> 2] | 0; //@line 35896
 $sext1718 = $23 & $21; //@line 35897
 $24 = $sext1718 << 24 >> 24; //@line 35899
 $26 = ($24 | 0) == 0 & 1; //@line 35901
 HEAP32[96441] = 0; //@line 35902
 HEAP32[96442] = 0; //@line 35902
 HEAP32[96443] = 0; //@line 35902
 HEAP32[96444] = 0; //@line 35902
 HEAP32[96442] = $26; //@line 35903
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 35906
 HEAP32[$22 >> 2] = $23 & -256 | $24 & 255; //@line 35910
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35913
 return;
}
function __Z12op_b070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $23 = 0, $24 = 0, $6 = 0, $sext$lobit = 0, $sext36$lobit = 0;
 $6 = HEAP32[162769] | 0; //@line 35319
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35328
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 35334
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35336
 $24 = $23 - $21 | 0; //@line 35337
 $sext$lobit = $23 >>> 15 & 1; //@line 35341
 $sext36$lobit = $24 >>> 15 & 1; //@line 35343
 HEAP32[96442] = ($24 & 65535 | 0) == 0 & 1; //@line 35347
 HEAP32[96444] = ($21 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext36$lobit | 0) != ($sext$lobit | 0) & 1; //@line 35352
 HEAP32[96441] = ($21 & 65535) >>> 0 > ($23 & 65535) >>> 0 & 1; //@line 35357
 HEAP32[96443] = $sext36$lobit; //@line 35358
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35361
 return;
}
function __Z12op_8068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0, $sext2223 = 0;
 $6 = HEAP32[162769] | 0; //@line 14181
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 14192
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 14198
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14199
 $24 = HEAP32[$23 >> 2] | 0; //@line 14200
 $sext2223 = $24 | $22; //@line 14201
 $25 = $sext2223 << 16 >> 16; //@line 14203
 $27 = ($25 | 0) == 0 & 1; //@line 14205
 HEAP32[96441] = 0; //@line 14206
 HEAP32[96442] = 0; //@line 14206
 HEAP32[96443] = 0; //@line 14206
 HEAP32[96444] = 0; //@line 14206
 HEAP32[96442] = $27; //@line 14207
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 14210
 HEAP32[$23 >> 2] = $24 & -65536 | $25 & 65535; //@line 14214
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14217
 return;
}
function __Z12op_8030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0, $sext1718 = 0;
 $6 = HEAP32[162769] | 0; //@line 23011
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23020
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 23026
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23027
 $23 = HEAP32[$22 >> 2] | 0; //@line 23028
 $sext1718 = $23 | $21; //@line 23029
 $24 = $sext1718 << 24 >> 24; //@line 23031
 $26 = ($24 | 0) == 0 & 1; //@line 23033
 HEAP32[96441] = 0; //@line 23034
 HEAP32[96442] = 0; //@line 23034
 HEAP32[96443] = 0; //@line 23034
 HEAP32[96444] = 0; //@line 23034
 HEAP32[96442] = $26; //@line 23035
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 23038
 HEAP32[$22 >> 2] = $23 & -256 | $24 & 255; //@line 23042
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23045
 return;
}
function __Z12op_23e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $2 = 0, $28 = 0, $30 = 0, $4 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 34372
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 34374
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($4 >>> 16 << 2) >> 2] >> 2] & 127]($4) | 0; //@line 34379
 HEAP32[$2 >> 2] = $4; //@line 34380
 $10 = HEAP32[162769] | 0; //@line 34381
 $19 = (HEAPU8[$10 + 3 >> 0] | 0) << 16 | (HEAPU8[$10 + 2 >> 0] | 0) << 24; //@line 34390
 $28 = $19 | (HEAPU8[$10 + 4 >> 0] | 0) << 8 | (HEAPU8[$10 + 5 >> 0] | 0); //@line 34399
 $30 = ($9 | 0) == 0 & 1; //@line 34401
 HEAP32[96441] = 0; //@line 34402
 HEAP32[96442] = 0; //@line 34402
 HEAP32[96443] = 0; //@line 34402
 HEAP32[96444] = 0; //@line 34402
 HEAP32[96442] = $30; //@line 34403
 HEAP32[96443] = $9 >>> 31; //@line 34405
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $9); //@line 34411
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34414
 return;
}
function __Z11op_c30_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $2 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $sext$lobit = 0, $sext27$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 30300
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 30302
 $5 = $4 & 255; //@line 30303
 $16 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 30314
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 30320
 $23 = $22 - $5 | 0; //@line 30321
 $sext$lobit = $22 >>> 7 & 1; //@line 30325
 $sext27$lobit = $23 >>> 7 & 1; //@line 30327
 HEAP32[96442] = ($23 & 255 | 0) == 0 & 1; //@line 30331
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext27$lobit | 0) != ($sext$lobit | 0) & 1; //@line 30336
 HEAP32[96441] = $5 >>> 0 > ($22 & 255) >>> 0 & 1; //@line 30340
 HEAP32[96443] = $sext27$lobit; //@line 30341
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30344
 return;
}
function __Z11op_218_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 8514
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 8517
 $5 = 651040 + ($1 << 2) | 0; //@line 8518
 $6 = HEAP32[$5 >> 2] | 0; //@line 8519
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 8521
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 8525
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 8530
 $18 = $12 & ($4 & 255); //@line 8532
 $19 = $18 << 24 >> 24; //@line 8534
 $21 = ($19 | 0) == 0 & 1; //@line 8536
 HEAP32[96441] = 0; //@line 8537
 HEAP32[96442] = 0; //@line 8537
 HEAP32[96443] = 0; //@line 8537
 HEAP32[96444] = 0; //@line 8537
 HEAP32[96442] = $21; //@line 8538
 HEAP32[96443] = $18 >>> 7; //@line 8540
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $19); //@line 8544
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8547
 return;
}
function __Z12op_c170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36291
 $8 = HEAP32[162769] | 0; //@line 36294
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 36303
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 36305
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0) & $5; //@line 36310
 $24 = $sext2021 << 16 >> 16; //@line 36312
 $26 = ($24 | 0) == 0 & 1; //@line 36314
 HEAP32[96441] = 0; //@line 36315
 HEAP32[96442] = 0; //@line 36315
 HEAP32[96443] = 0; //@line 36315
 HEAP32[96444] = 0; //@line 36315
 HEAP32[96442] = $26; //@line 36316
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 36319
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $24); //@line 36323
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36326
 return;
}
function __Z12op_b170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35688
 $8 = HEAP32[162769] | 0; //@line 35691
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 35700
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 35702
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0) ^ $5; //@line 35707
 $24 = $sext2021 << 16 >> 16; //@line 35709
 $26 = ($24 | 0) == 0 & 1; //@line 35711
 HEAP32[96441] = 0; //@line 35712
 HEAP32[96442] = 0; //@line 35712
 HEAP32[96443] = 0; //@line 35712
 HEAP32[96444] = 0; //@line 35712
 HEAP32[96442] = $26; //@line 35713
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 35716
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $24); //@line 35720
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35723
 return;
}
function __Z12op_3118_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 36898
 $5 = HEAP32[$4 >> 2] | 0; //@line 36899
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 36905
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 36908
 $14 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36909
 $16 = (HEAP32[$14 >> 2] | 0) + -2 | 0; //@line 36911
 HEAP32[$14 >> 2] = $16; //@line 36912
 $17 = $11 << 16 >> 16; //@line 36914
 $19 = ($17 | 0) == 0 & 1; //@line 36916
 HEAP32[96441] = 0; //@line 36917
 HEAP32[96442] = 0; //@line 36917
 HEAP32[96443] = 0; //@line 36917
 HEAP32[96444] = 0; //@line 36917
 HEAP32[96442] = $19; //@line 36918
 HEAP32[96443] = $11 >>> 15 & 1; //@line 36921
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($16, $17); //@line 36927
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36930
 return;
}
function __Z12op_c130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36244
 $8 = HEAP32[162769] | 0; //@line 36247
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 36256
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 36258
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) & $5; //@line 36263
 $24 = $sext1617 << 24 >> 24; //@line 36265
 $26 = ($24 | 0) == 0 & 1; //@line 36267
 HEAP32[96441] = 0; //@line 36268
 HEAP32[96442] = 0; //@line 36268
 HEAP32[96443] = 0; //@line 36268
 HEAP32[96444] = 0; //@line 36268
 HEAP32[96442] = $26; //@line 36269
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 36272
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $24); //@line 36276
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36279
 return;
}
function __Z12op_b130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35641
 $8 = HEAP32[162769] | 0; //@line 35644
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 35653
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 35655
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) ^ $5; //@line 35660
 $24 = $sext1617 << 24 >> 24; //@line 35662
 $26 = ($24 | 0) == 0 & 1; //@line 35664
 HEAP32[96441] = 0; //@line 35665
 HEAP32[96442] = 0; //@line 35665
 HEAP32[96443] = 0; //@line 35665
 HEAP32[96444] = 0; //@line 35665
 HEAP32[96442] = $26; //@line 35666
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 35669
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $24); //@line 35673
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35676
 return;
}
function __Z12op_b020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $16 = 0, $17 = 0, $4 = 0, $8 = 0, $sext$lobit = 0, $sext35$lobit = 0;
 $1 = $0 & 7; //@line 21930
 $4 = 651040 + ($1 << 2) | 0; //@line 21933
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 21937
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 21943
 HEAP32[$4 >> 2] = $8; //@line 21944
 $16 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21946
 $17 = $16 - $14 | 0; //@line 21947
 $sext$lobit = $16 >>> 7 & 1; //@line 21951
 $sext35$lobit = $17 >>> 7 & 1; //@line 21953
 HEAP32[96442] = ($17 & 255 | 0) == 0 & 1; //@line 21957
 HEAP32[96444] = ($14 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext35$lobit | 0) != ($sext$lobit | 0) & 1; //@line 21962
 HEAP32[96441] = ($14 & 255) >>> 0 > ($16 & 255) >>> 0 & 1; //@line 21967
 HEAP32[96443] = $sext35$lobit; //@line 21968
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21971
 return;
}
function __Z12op_413b_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $19 = 0, $24 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 $3 = HEAP32[162768] | 0; //@line 41903
 $4 = HEAP32[162769] | 0; //@line 41904
 $5 = HEAP32[162770] | 0; //@line 41905
 $7 = $4 + $3 - $5 | 0; //@line 41907
 $$cast = $4; //@line 41908
 $8 = $$cast + 2 | 0; //@line 41909
 HEAP32[162769] = $8; //@line 41910
 $17 = (HEAPU8[$8 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 41920
 HEAP32[162769] = $$cast + 4; //@line 41922
 $19 = __Z15get_disp_ea_020jj($8 + $3 - $5 | 0, $17) | 0; //@line 41923
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19) | 0; //@line 41928
 $26 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41930
 if (($26 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41933
  __Z9Exceptionij(6, $7); //@line 41934
  return;
 }
 if (($26 | 0) <= ($24 | 0)) {
  return;
 }
 HEAP32[96443] = 0; //@line 41941
 __Z9Exceptionij(6, $7); //@line 41942
 return;
}
function __Z12op_4130_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $11 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $9 = 0;
 $5 = HEAP32[162769] | 0; //@line 41702
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41705
 $$cast = $5; //@line 41706
 $9 = $$cast + 2 | 0; //@line 41707
 HEAP32[162769] = $9; //@line 41708
 $11 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41710
 $18 = (HEAPU8[$9 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0); //@line 41717
 HEAP32[162769] = $$cast + 4; //@line 41719
 $20 = __Z15get_disp_ea_020jj($11, $18) | 0; //@line 41720
 $25 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 41725
 $27 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41727
 if (($27 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41730
  __Z9Exceptionij(6, $8); //@line 41731
  return;
 }
 if (($27 | 0) <= ($25 | 0)) {
  return;
 }
 HEAP32[96443] = 0; //@line 41738
 __Z9Exceptionij(6, $8); //@line 41739
 return;
}
function __Z11op_ea0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $17 = 0, $27 = 0, $31 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22399
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 22406
 $9 = $7 << 24 >> 16; //@line 22408
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 22411
 $14 = (HEAP32[$12 >> 2] | 0) + -4 | 0; //@line 22413
 if (!($9 & 2048)) {
  $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 22419
  HEAP32[$12 >> 2] = $14; //@line 22420
  $31 = $7 >>> 4 & 7; //@line 22424
  HEAP32[($9 & 32768 | 0 ? 651040 + ($31 << 2) | 0 : 651008 + ($31 << 2) | 0) >> 2] = $27; //@line 22428
 } else {
  $17 = HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0; //@line 22432
  HEAP32[$12 >> 2] = $14; //@line 22433
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, $17); //@line 22439
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22443
 return;
}
function __Z12op_d0b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $15 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $31 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36733
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36742
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 36747
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36748
 $22 = HEAP32[$21 >> 2] | 0; //@line 36749
 $23 = $22 + $20 | 0; //@line 36750
 $$lobit38 = $23 >>> 31; //@line 36753
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 36756
 HEAP32[96444] = ($$lobit38 ^ $20 >>> 31) & ($$lobit38 ^ $22 >>> 31); //@line 36760
 $31 = $20 >>> 0 > ~$22 >>> 0 & 1; //@line 36763
 HEAP32[96441] = $31; //@line 36764
 HEAP32[96445] = $31; //@line 36765
 HEAP32[96443] = $$lobit38; //@line 36766
 HEAP32[$21 >> 2] = $23; //@line 36767
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36770
 return;
}
function __Z12op_c039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $sext1314 = 0;
 $3 = HEAP32[162769] | 0; //@line 28169
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 28178
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 28193
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28194
 $29 = HEAP32[$28 >> 2] | 0; //@line 28195
 $sext1314 = $29 & $27; //@line 28196
 $30 = $sext1314 << 24 >> 24; //@line 28198
 $32 = ($30 | 0) == 0 & 1; //@line 28200
 HEAP32[96441] = 0; //@line 28201
 HEAP32[96442] = 0; //@line 28201
 HEAP32[96443] = 0; //@line 28201
 HEAP32[96444] = 0; //@line 28201
 HEAP32[96442] = $32; //@line 28202
 HEAP32[96443] = $sext1314 >>> 7 & 1; //@line 28205
 HEAP32[$28 >> 2] = $29 & -256 | $30 & 255; //@line 28209
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28212
 return;
}
function __Z12op_b079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 24846
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 24855
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 24870
 $29 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24872
 $30 = $29 - $27 | 0; //@line 24873
 $sext$lobit = $29 >>> 15 & 1; //@line 24877
 $sext32$lobit = $30 >>> 15 & 1; //@line 24879
 HEAP32[96442] = ($30 & 65535 | 0) == 0 & 1; //@line 24883
 HEAP32[96444] = ($27 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24888
 HEAP32[96441] = ($27 & 65535) >>> 0 > ($29 & 65535) >>> 0 & 1; //@line 24893
 HEAP32[96443] = $sext32$lobit; //@line 24894
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 24897
 return;
}
function __Z12op_8170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23466
 $8 = HEAP32[162769] | 0; //@line 23469
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 23478
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 23480
 $sext2021 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 4 >> 2] & 127]($17) | 0 | $5; //@line 23485
 $24 = $sext2021 << 16 >> 16; //@line 23487
 $26 = ($24 | 0) == 0 & 1; //@line 23489
 HEAP32[96441] = 0; //@line 23490
 HEAP32[96442] = 0; //@line 23490
 HEAP32[96443] = 0; //@line 23490
 HEAP32[96444] = 0; //@line 23490
 HEAP32[96442] = $26; //@line 23491
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 23494
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 16 >> 2] & 31]($17, $24); //@line 23498
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23501
 return;
}
function __Z12op_8039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0, $sext1314 = 0;
 $3 = HEAP32[162769] | 0; //@line 13844
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 13853
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 13868
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13869
 $29 = HEAP32[$28 >> 2] | 0; //@line 13870
 $sext1314 = $29 | $27; //@line 13871
 $30 = $sext1314 << 24 >> 24; //@line 13873
 $32 = ($30 | 0) == 0 & 1; //@line 13875
 HEAP32[96441] = 0; //@line 13876
 HEAP32[96442] = 0; //@line 13876
 HEAP32[96443] = 0; //@line 13876
 HEAP32[96444] = 0; //@line 13876
 HEAP32[96442] = $32; //@line 13877
 HEAP32[96443] = $sext1314 >>> 7 & 1; //@line 13880
 HEAP32[$28 >> 2] = $29 & -256 | $30 & 255; //@line 13884
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13887
 return;
}
function __Z11op_c39_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $sext$lobit = 0, $sext23$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19113
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 19115
 $4 = $3 & 255; //@line 19116
 $13 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 19125
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 19140
 $29 = $28 - $4 | 0; //@line 19141
 $sext$lobit = $28 >>> 7 & 1; //@line 19145
 $sext23$lobit = $29 >>> 7 & 1; //@line 19147
 HEAP32[96442] = ($29 & 255 | 0) == 0 & 1; //@line 19151
 HEAP32[96444] = (($3 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext23$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19156
 HEAP32[96441] = $4 >>> 0 > ($28 & 255) >>> 0 & 1; //@line 19160
 HEAP32[96443] = $sext23$lobit; //@line 19161
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 19164
 return;
}
function __Z12op_d198_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $12 = 0, $15 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34772
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 34773
 $7 = HEAP32[$6 >> 2] | 0; //@line 34774
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 34776
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 34779
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 34782
 $15 = $12 + $5 | 0; //@line 34783
 $$lobit39 = $15 >>> 31; //@line 34786
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 34789
 HEAP32[96444] = ($$lobit39 ^ $5 >>> 31) & ($$lobit39 ^ $12 >>> 31); //@line 34793
 $23 = $5 >>> 0 > ~$12 >>> 0 & 1; //@line 34796
 HEAP32[96441] = $23; //@line 34797
 HEAP32[96445] = $23; //@line 34798
 HEAP32[96443] = $$lobit39; //@line 34799
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 34803
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34806
 return;
}
function __Z12op_8130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23419
 $8 = HEAP32[162769] | 0; //@line 23422
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 23431
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 23433
 $sext1617 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0 | $5; //@line 23438
 $24 = $sext1617 << 24 >> 24; //@line 23440
 $26 = ($24 | 0) == 0 & 1; //@line 23442
 HEAP32[96441] = 0; //@line 23443
 HEAP32[96442] = 0; //@line 23443
 HEAP32[96443] = 0; //@line 23443
 HEAP32[96444] = 0; //@line 23443
 HEAP32[96442] = $26; //@line 23444
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 23447
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $24); //@line 23451
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23454
 return;
}
function __Z12op_4418_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $2 = 0, $23 = 0, $3 = 0, $5 = 0, $9 = 0, $sext28$lobit = 0;
 $1 = $0 & 7; //@line 46881
 $2 = 651040 + ($1 << 2) | 0; //@line 46882
 $3 = HEAP32[$2 >> 2] | 0; //@line 46883
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 46885
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 46889
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 46894
 $15 = 0 - ($9 << 24 >> 24) | 0; //@line 46897
 $sext28$lobit = $15 >>> 7 & 1; //@line 46900
 HEAP32[96442] = ($15 & 255 | 0) == 0 & 1; //@line 46904
 HEAP32[96444] = $sext28$lobit & $9 >>> 7; //@line 46906
 $23 = ($9 & 255 | 0) != 0 & 1; //@line 46909
 HEAP32[96441] = $23; //@line 46910
 HEAP32[96445] = $23; //@line 46911
 HEAP32[96443] = $sext28$lobit; //@line 46912
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $15); //@line 46916
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46919
 return;
}
function __Z12op_c028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0, $sext1819 = 0;
 $6 = HEAP32[162769] | 0; //@line 28030
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28041
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 28047
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28048
 $24 = HEAP32[$23 >> 2] | 0; //@line 28049
 $sext1819 = $24 & $22; //@line 28050
 $25 = $sext1819 << 24 >> 24; //@line 28052
 $27 = ($25 | 0) == 0 & 1; //@line 28054
 HEAP32[96441] = 0; //@line 28055
 HEAP32[96442] = 0; //@line 28055
 HEAP32[96443] = 0; //@line 28055
 HEAP32[96444] = 0; //@line 28055
 HEAP32[96442] = $27; //@line 28056
 HEAP32[96443] = $sext1819 >>> 7 & 1; //@line 28059
 HEAP32[$23 >> 2] = $24 & -256 | $25 & 255; //@line 28063
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28066
 return;
}
function __Z12op_8028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0, $sext1819 = 0;
 $6 = HEAP32[162769] | 0; //@line 13705
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 13716
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 13722
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13723
 $24 = HEAP32[$23 >> 2] | 0; //@line 13724
 $sext1819 = $24 | $22; //@line 13725
 $25 = $sext1819 << 24 >> 24; //@line 13727
 $27 = ($25 | 0) == 0 & 1; //@line 13729
 HEAP32[96441] = 0; //@line 13730
 HEAP32[96442] = 0; //@line 13730
 HEAP32[96443] = 0; //@line 13730
 HEAP32[96444] = 0; //@line 13730
 HEAP32[96442] = $27; //@line 13731
 HEAP32[96443] = $sext1819 >>> 7 & 1; //@line 13734
 HEAP32[$23 >> 2] = $24 & -256 | $25 & 255; //@line 13738
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13741
 return;
}
function __Z12op_31bc_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 38615
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 38618
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 38623
 $12 = $3 + 4 | 0; //@line 38624
 HEAP32[162769] = $12; //@line 38625
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38627
 $21 = (HEAPU8[$12 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 38634
 HEAP32[162769] = $3 + 6; //@line 38636
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 38637
 $24 = $11 << 16 >> 16; //@line 38639
 $26 = ($24 | 0) == 0 & 1; //@line 38641
 HEAP32[96441] = 0; //@line 38642
 HEAP32[96442] = 0; //@line 38642
 HEAP32[96443] = 0; //@line 38642
 HEAP32[96444] = 0; //@line 38642
 HEAP32[96442] = $26; //@line 38643
 HEAP32[96443] = $6 >>> 7; //@line 38645
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($23, $24); //@line 38651
 return;
}
function __Z11op_ab0_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $31 = 0, $33 = 0, $37 = 0, $39 = 0;
 $2 = HEAP32[162769] | 0; //@line 30242
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 30260
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 30271
 $33 = 123608 + ($31 >>> 16 << 2) | 0; //@line 30273
 $37 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$33 >> 2] >> 2] & 127]($31) | 0) ^ $20; //@line 30277
 $39 = ($37 | 0) == 0 & 1; //@line 30279
 HEAP32[96441] = 0; //@line 30280
 HEAP32[96442] = 0; //@line 30280
 HEAP32[96443] = 0; //@line 30280
 HEAP32[96444] = 0; //@line 30280
 HEAP32[96442] = $39; //@line 30281
 HEAP32[96443] = $37 >>> 31; //@line 30283
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$33 >> 2] | 0) + 12 >> 2] & 31]($31, $37); //@line 30287
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 30290
 return;
}
function __Z11op_2b0_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $31 = 0, $33 = 0, $37 = 0, $39 = 0;
 $2 = HEAP32[162769] | 0; //@line 16844
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 16862
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 16873
 $33 = 123608 + ($31 >>> 16 << 2) | 0; //@line 16875
 $37 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$33 >> 2] >> 2] & 127]($31) | 0) & $20; //@line 16879
 $39 = ($37 | 0) == 0 & 1; //@line 16881
 HEAP32[96441] = 0; //@line 16882
 HEAP32[96442] = 0; //@line 16882
 HEAP32[96443] = 0; //@line 16882
 HEAP32[96444] = 0; //@line 16882
 HEAP32[96442] = $39; //@line 16883
 HEAP32[96443] = $37 >>> 31; //@line 16885
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$33 >> 2] | 0) + 12 >> 2] & 31]($31, $37); //@line 16889
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 16892
 return;
}
function __Z12op_e4f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 41151
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 41160
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 41169
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41171
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 41175
 $26 = $25 & 1; //@line 41176
 $27 = $25 >>> 1; //@line 41177
 $$ = (HEAP32[96445] | 0) == 0 ? $27 & 32767 : $27 | 32768; //@line 41182
 HEAP32[96444] = 0; //@line 41186
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41187
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41190
 HEAP32[96441] = $26; //@line 41191
 HEAP32[96445] = $26; //@line 41192
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $$ & 65535); //@line 41197
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41200
 return;
}
function __Z12op_e1f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 40219
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 40228
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 40237
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40239
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 40243
 $26 = $25 & 32768; //@line 40244
 $27 = $25 << 1; //@line 40245
 HEAP32[96442] = ($25 & 32767 | 0) == 0 & 1; //@line 40250
 HEAP32[96443] = $25 >>> 14 & 1; //@line 40253
 $$lobit = $26 >>> 15; //@line 40255
 HEAP32[96441] = $$lobit; //@line 40256
 HEAP32[96445] = $$lobit; //@line 40257
 HEAP32[96444] = ($27 & 32768 ^ $26) >>> 15; //@line 40260
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $27 & 131070); //@line 40264
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 40267
 return;
}
function __Z12op_d0b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $12 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $37 = 0;
 $3 = HEAP32[162769] | 0; //@line 32920
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 32929
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 32943
 $27 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32944
 $28 = HEAP32[$27 >> 2] | 0; //@line 32945
 $29 = $28 + $26 | 0; //@line 32946
 $$lobit34 = $29 >>> 31; //@line 32949
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 32952
 HEAP32[96444] = ($$lobit34 ^ $26 >>> 31) & ($$lobit34 ^ $28 >>> 31); //@line 32956
 $37 = $26 >>> 0 > ~$28 >>> 0 & 1; //@line 32959
 HEAP32[96441] = $37; //@line 32960
 HEAP32[96445] = $37; //@line 32961
 HEAP32[96443] = $$lobit34; //@line 32962
 HEAP32[$27 >> 2] = $29; //@line 32963
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 32966
 return;
}
function __Z12op_c168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30277
 $8 = HEAP32[162769] | 0; //@line 30280
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 30291
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 30293
 $sext2122 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) & $5; //@line 30298
 $25 = $sext2122 << 16 >> 16; //@line 30300
 $27 = ($25 | 0) == 0 & 1; //@line 30302
 HEAP32[96441] = 0; //@line 30303
 HEAP32[96442] = 0; //@line 30303
 HEAP32[96443] = 0; //@line 30303
 HEAP32[96444] = 0; //@line 30303
 HEAP32[96442] = $27; //@line 30304
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 30307
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 30311
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30314
 return;
}
function __Z12op_b168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26792
 $8 = HEAP32[162769] | 0; //@line 26795
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 26806
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 26808
 $sext2122 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) ^ $5; //@line 26813
 $25 = $sext2122 << 16 >> 16; //@line 26815
 $27 = ($25 | 0) == 0 & 1; //@line 26817
 HEAP32[96441] = 0; //@line 26818
 HEAP32[96442] = 0; //@line 26818
 HEAP32[96443] = 0; //@line 26818
 HEAP32[96444] = 0; //@line 26818
 HEAP32[96442] = $27; //@line 26819
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 26822
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 26826
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26829
 return;
}
function __Z12op_b028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $24 = 0, $25 = 0, $6 = 0, $sext31$lobit = 0, $sext33$lobit = 0;
 $6 = HEAP32[162769] | 0; //@line 21985
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 21996
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 22002
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22004
 $25 = $24 - $22 | 0; //@line 22005
 $sext31$lobit = $24 >>> 7 & 1; //@line 22009
 $sext33$lobit = $25 >>> 7 & 1; //@line 22011
 HEAP32[96442] = ($25 & 255 | 0) == 0 & 1; //@line 22015
 HEAP32[96444] = ($22 >>> 7 & 1 | 0) != ($sext31$lobit | 0) & ($sext33$lobit | 0) != ($sext31$lobit | 0) & 1; //@line 22020
 HEAP32[96441] = ($22 & 255) >>> 0 > ($24 & 255) >>> 0 & 1; //@line 22025
 HEAP32[96443] = $sext33$lobit; //@line 22026
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22029
 return;
}
function __Z12op_4618_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $17 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0, $sext = 0;
 $1 = $0 & 7; //@line 48317
 $2 = 651040 + ($1 << 2) | 0; //@line 48318
 $3 = HEAP32[$2 >> 2] | 0; //@line 48319
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48321
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 48325
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 48330
 $sext = $9 << 24; //@line 48331
 $14 = $sext >> 24; //@line 48332
 $15 = ~$14; //@line 48333
 $17 = ($14 | 0) == -1 & 1; //@line 48335
 HEAP32[96441] = 0; //@line 48336
 HEAP32[96442] = 0; //@line 48336
 HEAP32[96443] = 0; //@line 48336
 HEAP32[96444] = 0; //@line 48336
 HEAP32[96442] = $17; //@line 48337
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48340
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $15); //@line 48344
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48347
 return;
}
function __Z12op_303b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 44229
 $4 = HEAP32[162769] | 0; //@line 44231
 $$cast = $4; //@line 44236
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44245
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 44251
 $24 = $23 << 16 >> 16; //@line 44253
 $26 = ($24 | 0) == 0 & 1; //@line 44255
 HEAP32[96441] = 0; //@line 44256
 HEAP32[96442] = 0; //@line 44256
 HEAP32[96443] = 0; //@line 44256
 HEAP32[96444] = 0; //@line 44256
 HEAP32[96442] = $26; //@line 44257
 HEAP32[96443] = $23 >>> 15 & 1; //@line 44260
 $28 = 651008 + ($2 << 2) | 0; //@line 44261
 HEAP32[$28 >> 2] = HEAP32[$28 >> 2] & -65536 | $24 & 65535; //@line 44266
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44269
 return;
}
function __Z10op_b0_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $31 = 0, $33 = 0, $37 = 0, $39 = 0;
 $2 = HEAP32[162769] | 0; //@line 16312
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 16330
 $31 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) | 0; //@line 16341
 $33 = 123608 + ($31 >>> 16 << 2) | 0; //@line 16343
 $37 = $20 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$33 >> 2] >> 2] & 127]($31) | 0); //@line 16347
 $39 = ($37 | 0) == 0 & 1; //@line 16349
 HEAP32[96441] = 0; //@line 16350
 HEAP32[96442] = 0; //@line 16350
 HEAP32[96443] = 0; //@line 16350
 HEAP32[96444] = 0; //@line 16350
 HEAP32[96442] = $39; //@line 16351
 HEAP32[96443] = $37 >>> 31; //@line 16353
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$33 >> 2] | 0) + 12 >> 2] & 31]($31, $37); //@line 16357
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 16360
 return;
}
function __Z12op_c128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext1718 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29930
 $8 = HEAP32[162769] | 0; //@line 29933
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 29944
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 29946
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) & $5; //@line 29951
 $25 = $sext1718 << 24 >> 24; //@line 29953
 $27 = ($25 | 0) == 0 & 1; //@line 29955
 HEAP32[96441] = 0; //@line 29956
 HEAP32[96442] = 0; //@line 29956
 HEAP32[96443] = 0; //@line 29956
 HEAP32[96444] = 0; //@line 29956
 HEAP32[96442] = $27; //@line 29957
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 29960
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 29964
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29967
 return;
}
function __Z12op_b128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext1718 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26392
 $8 = HEAP32[162769] | 0; //@line 26395
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 26406
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 26408
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) ^ $5; //@line 26413
 $25 = $sext1718 << 24 >> 24; //@line 26415
 $27 = ($25 | 0) == 0 & 1; //@line 26417
 HEAP32[96441] = 0; //@line 26418
 HEAP32[96442] = 0; //@line 26418
 HEAP32[96443] = 0; //@line 26418
 HEAP32[96444] = 0; //@line 26418
 HEAP32[96442] = $27; //@line 26419
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 26422
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 26426
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26429
 return;
}
function __Z12op_90a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $$lobit40 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $21 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 19114
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 19116
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 19121
 HEAP32[$4 >> 2] = $6; //@line 19122
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19123
 $13 = HEAP32[$12 >> 2] | 0; //@line 19124
 $14 = $13 - $11 | 0; //@line 19125
 $$lobit39 = $13 >>> 31; //@line 19127
 $$lobit40 = $14 >>> 31; //@line 19128
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 19131
 HEAP32[96444] = ($$lobit40 ^ $$lobit39) & ($$lobit39 ^ $11 >>> 31); //@line 19135
 $21 = $13 >>> 0 < $11 >>> 0 & 1; //@line 19137
 HEAP32[96441] = $21; //@line 19138
 HEAP32[96445] = $21; //@line 19139
 HEAP32[96443] = $$lobit40; //@line 19140
 HEAP32[$12 >> 2] = $14; //@line 19141
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19144
 return;
}
function __Z12op_d0a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $32 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32772
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 32783
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 32788
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32789
 $23 = HEAP32[$22 >> 2] | 0; //@line 32790
 $24 = $23 + $21 | 0; //@line 32791
 $$lobit38 = $24 >>> 31; //@line 32794
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 32797
 HEAP32[96444] = ($$lobit38 ^ $21 >>> 31) & ($$lobit38 ^ $23 >>> 31); //@line 32801
 $32 = $21 >>> 0 > ~$23 >>> 0 & 1; //@line 32804
 HEAP32[96441] = $32; //@line 32805
 HEAP32[96445] = $32; //@line 32806
 HEAP32[96443] = $$lobit38; //@line 32807
 HEAP32[$22 >> 2] = $24; //@line 32808
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32811
 return;
}
function __Z12op_90b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit33 = 0, $$lobit34 = 0, $12 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $27 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 19254
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 19264
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 19269
 $18 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19270
 $19 = HEAP32[$18 >> 2] | 0; //@line 19271
 $20 = $19 - $17 | 0; //@line 19272
 $$lobit33 = $19 >>> 31; //@line 19274
 $$lobit34 = $20 >>> 31; //@line 19275
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 19278
 HEAP32[96444] = ($$lobit34 ^ $$lobit33) & ($$lobit33 ^ $17 >>> 31); //@line 19282
 $27 = $19 >>> 0 < $17 >>> 0 & 1; //@line 19284
 HEAP32[96441] = $27; //@line 19285
 HEAP32[96445] = $27; //@line 19286
 HEAP32[96443] = $$lobit34; //@line 19287
 HEAP32[$18 >> 2] = $20; //@line 19288
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19291
 return;
}
function __Z12op_8168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16289
 $8 = HEAP32[162769] | 0; //@line 16292
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 16303
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16305
 $sext2122 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0 | $5; //@line 16310
 $25 = $sext2122 << 16 >> 16; //@line 16312
 $27 = ($25 | 0) == 0 & 1; //@line 16314
 HEAP32[96441] = 0; //@line 16315
 HEAP32[96442] = 0; //@line 16315
 HEAP32[96443] = 0; //@line 16315
 HEAP32[96444] = 0; //@line 16315
 HEAP32[96442] = $27; //@line 16316
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 16319
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 16323
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16326
 return;
}
function __Z12op_5110_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $28 = 0, $4 = 0, $7 = 0, $9 = 0, $sext36$lobit = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5053
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5056
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 5058
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 5062
 $16 = ($13 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5067
 $18 = $13 >>> 7; //@line 5069
 $sext36$lobit = $16 >>> 7 & 1; //@line 5072
 HEAP32[96442] = ($16 & 255 | 0) == 0 & 1; //@line 5076
 HEAP32[96444] = ($sext36$lobit ^ $18 & 1) & ($18 ^ $4 >>> 7); //@line 5080
 $28 = ($4 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 5084
 HEAP32[96441] = $28; //@line 5085
 HEAP32[96445] = $28; //@line 5086
 HEAP32[96443] = $sext36$lobit; //@line 5087
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $16); //@line 5091
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5094
 return;
}
function __Z12op_4810_0_ffj($0) {
 $0 = $0 | 0;
 var $$027$in = 0, $10 = 0, $14 = 0, $16 = 0, $19 = 0, $21 = 0, $22 = 0, $3 = 0, $5 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49635
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 49637
 $10 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0) << 24 >> 24; //@line 49643
 $14 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($10 & 15) | 0; //@line 49648
 $16 = $14 & 65535; //@line 49650
 $19 = ($16 >>> 0 > 9 ? $16 + -6 | 0 : $14) - ($10 & 240) | 0; //@line 49654
 $21 = ($19 & 496) >>> 0 > 144; //@line 49656
 $22 = $21 & 1; //@line 49657
 $$027$in = $21 ? ($19 & 65535) + -96 | 0 : $19; //@line 49660
 HEAP32[96441] = $22; //@line 49661
 HEAP32[96445] = $22; //@line 49662
 HEAP32[96442] = ($$027$in & 255 | 0) == 0 & HEAP32[96442]; //@line 49668
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $$027$in & 65535); //@line 49673
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49676
 return;
}
function __Z12op_46b0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $19 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 49036
 $3 = $2 + 2 | 0; //@line 49037
 HEAP32[162769] = $3; //@line 49038
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49040
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 49047
 HEAP32[162769] = $2 + 4; //@line 49049
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 49050
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 49052
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 49055
 $20 = ~$19; //@line 49056
 $22 = ($19 | 0) == -1 & 1; //@line 49058
 HEAP32[96441] = 0; //@line 49059
 HEAP32[96442] = 0; //@line 49059
 HEAP32[96443] = 0; //@line 49059
 HEAP32[96444] = 0; //@line 49059
 HEAP32[96442] = $22; //@line 49060
 HEAP32[96443] = $19 >>> 31 ^ 1; //@line 49063
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 49067
 return;
}
function __Z12op_30d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 36350
 $5 = HEAP32[$4 >> 2] | 0; //@line 36351
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 36357
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 36360
 $14 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36361
 $15 = HEAP32[$14 >> 2] | 0; //@line 36362
 HEAP32[$14 >> 2] = $15 + 2; //@line 36364
 $17 = $11 << 16 >> 16; //@line 36366
 $19 = ($17 | 0) == 0 & 1; //@line 36368
 HEAP32[96441] = 0; //@line 36369
 HEAP32[96442] = 0; //@line 36369
 HEAP32[96443] = 0; //@line 36369
 HEAP32[96444] = 0; //@line 36369
 HEAP32[96442] = $19; //@line 36370
 HEAP32[96443] = $11 >>> 15 & 1; //@line 36373
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($15, $17); //@line 36379
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36382
 return;
}
function __Z10op_20_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 4809
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 4812
 $5 = 651040 + ($1 << 2) | 0; //@line 4813
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 4817
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 4819
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 4823
 HEAP32[$5 >> 2] = $9; //@line 4824
 $17 = $15 | $4 & 255; //@line 4826
 $18 = $17 << 24 >> 24; //@line 4828
 $20 = ($18 | 0) == 0 & 1; //@line 4830
 HEAP32[96441] = 0; //@line 4831
 HEAP32[96442] = 0; //@line 4831
 HEAP32[96443] = 0; //@line 4831
 HEAP32[96444] = 0; //@line 4831
 HEAP32[96442] = $20; //@line 4832
 HEAP32[96443] = $17 >>> 7 & 1; //@line 4835
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, $18); //@line 4839
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4842
 return;
}
function __Z12op_b030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $23 = 0, $24 = 0, $6 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $6 = HEAP32[162769] | 0; //@line 24387
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 24396
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 24402
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24404
 $24 = $23 - $21 | 0; //@line 24405
 $sext$lobit = $23 >>> 7 & 1; //@line 24409
 $sext32$lobit = $24 >>> 7 & 1; //@line 24411
 HEAP32[96442] = ($24 & 255 | 0) == 0 & 1; //@line 24415
 HEAP32[96444] = ($21 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24420
 HEAP32[96441] = ($21 & 255) >>> 0 > ($23 & 255) >>> 0 & 1; //@line 24425
 HEAP32[96443] = $sext32$lobit; //@line 24426
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24429
 return;
}
function __Z12op_8128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0, $sext1718 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15880
 $8 = HEAP32[162769] | 0; //@line 15883
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 15894
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 15896
 $sext1718 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0 | $5; //@line 15901
 $25 = $sext1718 << 24 >> 24; //@line 15903
 $27 = ($25 | 0) == 0 & 1; //@line 15905
 HEAP32[96441] = 0; //@line 15906
 HEAP32[96442] = 0; //@line 15906
 HEAP32[96443] = 0; //@line 15906
 HEAP32[96444] = 0; //@line 15906
 HEAP32[96442] = $27; //@line 15907
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 15910
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $25); //@line 15914
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15917
 return;
}
function __Z11op_220_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 8555
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 8558
 $5 = 651040 + ($1 << 2) | 0; //@line 8559
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 8563
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 8565
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 8569
 HEAP32[$5 >> 2] = $9; //@line 8570
 $17 = $15 & ($4 & 255); //@line 8572
 $18 = $17 << 24 >> 24; //@line 8574
 $20 = ($18 | 0) == 0 & 1; //@line 8576
 HEAP32[96441] = 0; //@line 8577
 HEAP32[96442] = 0; //@line 8577
 HEAP32[96443] = 0; //@line 8577
 HEAP32[96444] = 0; //@line 8577
 HEAP32[96442] = $20; //@line 8578
 HEAP32[96443] = $17 >>> 7; //@line 8580
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, $18); //@line 8584
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8587
 return;
}
function __Z10op_68_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 5230
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 5238
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 5251
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 5253
 $sext1718 = $10 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0); //@line 5258
 $29 = $sext1718 << 16 >> 16; //@line 5260
 $31 = ($29 | 0) == 0 & 1; //@line 5262
 HEAP32[96441] = 0; //@line 5263
 HEAP32[96442] = 0; //@line 5263
 HEAP32[96443] = 0; //@line 5263
 HEAP32[96444] = 0; //@line 5263
 HEAP32[96442] = $31; //@line 5264
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 5267
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 5271
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5274
 return;
}
function __Z12op_c0bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 29164
 $4 = $3 + 2 | 0; //@line 29165
 HEAP32[162769] = $4; //@line 29166
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 29171
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 29178
 HEAP32[162769] = $3 + 4; //@line 29180
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 29181
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 29186
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29187
 $25 = HEAP32[$23 >> 2] & $22; //@line 29189
 $27 = ($25 | 0) == 0 & 1; //@line 29191
 HEAP32[96441] = 0; //@line 29192
 HEAP32[96442] = 0; //@line 29192
 HEAP32[96443] = 0; //@line 29192
 HEAP32[96444] = 0; //@line 29192
 HEAP32[96442] = $27; //@line 29193
 HEAP32[96443] = $25 >>> 31; //@line 29195
 HEAP32[$23 >> 2] = $25; //@line 29196
 return;
}
function __Z12op_80bb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 14841
 $4 = $3 + 2 | 0; //@line 14842
 HEAP32[162769] = $4; //@line 14843
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 14848
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 14855
 HEAP32[162769] = $3 + 4; //@line 14857
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 14858
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 14863
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14864
 $25 = HEAP32[$23 >> 2] | $22; //@line 14866
 $27 = ($25 | 0) == 0 & 1; //@line 14868
 HEAP32[96441] = 0; //@line 14869
 HEAP32[96442] = 0; //@line 14869
 HEAP32[96443] = 0; //@line 14869
 HEAP32[96444] = 0; //@line 14869
 HEAP32[96442] = $27; //@line 14870
 HEAP32[96443] = $25 >>> 31; //@line 14872
 HEAP32[$23 >> 2] = $25; //@line 14873
 return;
}
function __Z11op_aa8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 17982
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 18000
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 18013
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 18015
 $38 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0) ^ $20; //@line 18019
 $40 = ($38 | 0) == 0 & 1; //@line 18021
 HEAP32[96441] = 0; //@line 18022
 HEAP32[96442] = 0; //@line 18022
 HEAP32[96443] = 0; //@line 18022
 HEAP32[96444] = 0; //@line 18022
 HEAP32[96442] = $40; //@line 18023
 HEAP32[96443] = $38 >>> 31; //@line 18025
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 18029
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 18032
 return;
}
function __Z12op_b1fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit34 = 0, $$lobit35 = 0, $17 = 0, $22 = 0, $24 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 35826
 $$cast = $4; //@line 35831
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 35840
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 35845
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35847
 $25 = $24 - $22 | 0; //@line 35848
 $$lobit34 = $24 >>> 31; //@line 35850
 $$lobit35 = $25 >>> 31; //@line 35851
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 35854
 HEAP32[96444] = ($22 >>> 31 | 0) != ($$lobit34 | 0) & ($$lobit35 | 0) != ($$lobit34 | 0) & 1; //@line 35859
 HEAP32[96441] = $24 >>> 0 < $22 >>> 0 & 1; //@line 35862
 HEAP32[96443] = $$lobit35; //@line 35863
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35866
 return;
}
function __Z12op_b0bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit34 = 0, $$lobit35 = 0, $17 = 0, $22 = 0, $24 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 35480
 $$cast = $4; //@line 35485
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 35494
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 35499
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35501
 $25 = $24 - $22 | 0; //@line 35502
 $$lobit34 = $24 >>> 31; //@line 35504
 $$lobit35 = $25 >>> 31; //@line 35505
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 35508
 HEAP32[96444] = ($22 >>> 31 | 0) != ($$lobit34 | 0) & ($$lobit35 | 0) != ($$lobit34 | 0) & 1; //@line 35513
 HEAP32[96441] = $24 >>> 0 < $22 >>> 0 & 1; //@line 35516
 HEAP32[96443] = $$lobit35; //@line 35517
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35520
 return;
}
function __Z12op_4098_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit33 = 0, $13 = 0, $17 = 0, $2 = 0, $3 = 0, $5 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40914
 $3 = HEAP32[$2 >> 2] | 0; //@line 40915
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40917
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 40920
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 40923
 $13 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $8 | 0; //@line 40927
 $$lobit = $8 >>> 31; //@line 40928
 $$lobit33 = $13 >>> 31; //@line 40929
 HEAP32[96444] = $$lobit33 & $$lobit; //@line 40931
 $17 = $$lobit33 & ~$$lobit ^ $$lobit; //@line 40934
 HEAP32[96441] = $17; //@line 40935
 HEAP32[96445] = $17; //@line 40936
 HEAP32[96442] = ($13 | 0) == 0 & HEAP32[96442]; //@line 40941
 HEAP32[96443] = $$lobit33; //@line 40942
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, $13); //@line 40946
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40949
 return;
}
function __Z12op_2198_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $15 = 0, $24 = 0, $26 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 43463
 $5 = HEAP32[$4 >> 2] | 0; //@line 43464
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 43469
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 43472
 $15 = HEAP32[162769] | 0; //@line 43475
 $24 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$15 + 2 >> 0] | 0) << 8 | (HEAPU8[$15 + 3 >> 0] | 0)) | 0; //@line 43484
 $26 = ($10 | 0) == 0 & 1; //@line 43486
 HEAP32[96441] = 0; //@line 43487
 HEAP32[96442] = 0; //@line 43487
 HEAP32[96443] = 0; //@line 43487
 HEAP32[96444] = 0; //@line 43487
 HEAP32[96442] = $26; //@line 43488
 HEAP32[96443] = $10 >>> 31; //@line 43490
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $10); //@line 43496
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43499
 return;
}
function __Z12op_103b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 30704
 $4 = HEAP32[162769] | 0; //@line 30706
 $$cast = $4; //@line 30711
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 30720
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0; //@line 30726
 $24 = $23 << 24 >> 24; //@line 30728
 $26 = ($24 | 0) == 0 & 1; //@line 30730
 HEAP32[96441] = 0; //@line 30731
 HEAP32[96442] = 0; //@line 30731
 HEAP32[96443] = 0; //@line 30731
 HEAP32[96444] = 0; //@line 30731
 HEAP32[96442] = $26; //@line 30732
 HEAP32[96443] = $23 >>> 7 & 1; //@line 30735
 $28 = 651008 + ($2 << 2) | 0; //@line 30736
 HEAP32[$28 >> 2] = HEAP32[$28 >> 2] & -256 | $24 & 255; //@line 30741
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30744
 return;
}
function __Z12op_e188_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $12 = 0, $14 = 0, $15 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39646
 $7 = HEAP32[$6 >> 2] | 0; //@line 39647
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39648
 $9 = $8 >>> 0 > 31; //@line 39649
 HEAP32[96441] = 0; //@line 39650
 HEAP32[96442] = 0; //@line 39650
 HEAP32[96443] = 0; //@line 39650
 HEAP32[96444] = 0; //@line 39650
 if ($9) {
  $12 = ($8 | 0) == 32 ? $7 & 1 : 0; //@line 39654
  HEAP32[96441] = $12; //@line 39655
  HEAP32[96445] = $12; //@line 39656
  $$0 = 0; //@line 39657
 } else {
  $14 = $7 << $8 + -1; //@line 39660
  $15 = $14 >>> 31; //@line 39661
  HEAP32[96441] = $15; //@line 39662
  HEAP32[96445] = $15; //@line 39663
  $$0 = $14 << 1; //@line 39665
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39669
 HEAP32[96443] = $$0 >>> 31; //@line 39671
 HEAP32[$6 >> 2] = $$0; //@line 39672
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39675
 return;
}
function __Z12op_d1b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $14 = 0, $16 = 0, $19 = 0, $20 = 0, $28 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34971
 $5 = HEAP32[162769] | 0; //@line 34972
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 34982
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 34984
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 34987
 $20 = $19 + $4 | 0; //@line 34988
 $$lobit34 = $20 >>> 31; //@line 34991
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 34994
 HEAP32[96444] = ($$lobit34 ^ $4 >>> 31) & ($$lobit34 ^ $19 >>> 31); //@line 34998
 $28 = $4 >>> 0 > ~$19 >>> 0 & 1; //@line 35001
 HEAP32[96441] = $28; //@line 35002
 HEAP32[96445] = $28; //@line 35003
 HEAP32[96443] = $$lobit34; //@line 35004
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 35008
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35011
 return;
}
function __Z12op_d1a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit40 = 0, $10 = 0, $13 = 0, $14 = 0, $22 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34818
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 34819
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 34821
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 34823
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 34826
 HEAP32[$6 >> 2] = $8; //@line 34827
 $14 = $13 + $5 | 0; //@line 34828
 $$lobit40 = $14 >>> 31; //@line 34831
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 34834
 HEAP32[96444] = ($$lobit40 ^ $5 >>> 31) & ($$lobit40 ^ $13 >>> 31); //@line 34838
 $22 = $5 >>> 0 > ~$13 >>> 0 & 1; //@line 34841
 HEAP32[96441] = $22; //@line 34842
 HEAP32[96445] = $22; //@line 34843
 HEAP32[96443] = $$lobit40; //@line 34844
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 34848
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34851
 return;
}
function __Z12op_b039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $sext$lobit = 0, $sext28$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 22150
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 22159
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 22174
 $29 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22176
 $30 = $29 - $27 | 0; //@line 22177
 $sext$lobit = $29 >>> 7 & 1; //@line 22181
 $sext28$lobit = $30 >>> 7 & 1; //@line 22183
 HEAP32[96442] = ($30 & 255 | 0) == 0 & 1; //@line 22187
 HEAP32[96444] = ($27 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext28$lobit | 0) != ($sext$lobit | 0) & 1; //@line 22192
 HEAP32[96441] = ($27 & 255) >>> 0 > ($29 & 255) >>> 0 & 1; //@line 22197
 HEAP32[96443] = $sext28$lobit; //@line 22198
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 22201
 return;
}
function __Z12op_4420_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $2 = 0, $22 = 0, $6 = 0, $8 = 0, $sext29$lobit = 0;
 $1 = $0 & 7; //@line 46927
 $2 = 651040 + ($1 << 2) | 0; //@line 46928
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 46932
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 46934
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 46938
 HEAP32[$2 >> 2] = $6; //@line 46939
 $14 = 0 - ($12 << 24 >> 24) | 0; //@line 46942
 $sext29$lobit = $14 >>> 7 & 1; //@line 46945
 HEAP32[96442] = ($14 & 255 | 0) == 0 & 1; //@line 46949
 HEAP32[96444] = $sext29$lobit & $12 >>> 7; //@line 46951
 $22 = ($12 & 255 | 0) != 0 & 1; //@line 46954
 HEAP32[96441] = $22; //@line 46955
 HEAP32[96445] = $22; //@line 46956
 HEAP32[96443] = $sext29$lobit; //@line 46957
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $14); //@line 46961
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46964
 return;
}
function __Z11op_268_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $22 = 0, $24 = 0, $29 = 0, $31 = 0, $sext1718 = 0;
 $2 = HEAP32[162769] | 0; //@line 8968
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8976
 $22 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8989
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 8991
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$24 >> 2] | 0) + 4 >> 2] & 127]($22) | 0) & $10; //@line 8996
 $29 = $sext1718 << 16 >> 16; //@line 8998
 $31 = ($29 | 0) == 0 & 1; //@line 9000
 HEAP32[96441] = 0; //@line 9001
 HEAP32[96442] = 0; //@line 9001
 HEAP32[96443] = 0; //@line 9001
 HEAP32[96444] = 0; //@line 9001
 HEAP32[96442] = $31; //@line 9002
 HEAP32[96443] = $sext1718 >>> 15; //@line 9004
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 16 >> 2] & 31]($22, $29); //@line 9008
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9011
 return;
}
function __Z12op_4468_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $30 = 0, $4 = 0, $sext29$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 47350
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 47361
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 47363
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 47367
 $22 = 0 - ($20 << 16 >> 16) | 0; //@line 47370
 $sext29$lobit = $22 >>> 15 & 1; //@line 47373
 HEAP32[96442] = ($22 & 65535 | 0) == 0 & 1; //@line 47377
 HEAP32[96444] = $sext29$lobit & $20 >>> 15; //@line 47379
 $30 = ($20 & 65535 | 0) != 0 & 1; //@line 47382
 HEAP32[96441] = $30; //@line 47383
 HEAP32[96445] = $30; //@line 47384
 HEAP32[96443] = $sext29$lobit; //@line 47385
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22); //@line 47389
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47392
 return;
}
function __Z12op_3120_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $15 = 0, $16 = 0, $18 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 36941
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 36943
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 36949
 HEAP32[$4 >> 2] = $6; //@line 36950
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36951
 $15 = (HEAP32[$13 >> 2] | 0) + -2 | 0; //@line 36953
 HEAP32[$13 >> 2] = $15; //@line 36954
 $16 = $12 << 16 >> 16; //@line 36956
 $18 = ($16 | 0) == 0 & 1; //@line 36958
 HEAP32[96441] = 0; //@line 36959
 HEAP32[96442] = 0; //@line 36959
 HEAP32[96443] = 0; //@line 36959
 HEAP32[96444] = 0; //@line 36959
 HEAP32[96442] = $18; //@line 36960
 HEAP32[96443] = $12 >>> 15 & 1; //@line 36963
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($15, $16); //@line 36969
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36972
 return;
}
function ___fflush_unlocked($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $3 = 0, label = 0;
 $1 = $0 + 20 | 0; //@line 388
 $3 = $0 + 28 | 0; //@line 390
 if ((HEAP32[$1 >> 2] | 0) >>> 0 > (HEAP32[$3 >> 2] | 0) >>> 0) {
  FUNCTION_TABLE_iiii[HEAP32[$0 + 36 >> 2] & 15]($0, 0, 0) | 0; //@line 396
  if (!(HEAP32[$1 >> 2] | 0)) {
   $$0 = -1; //@line 400
  } else {
   label = 3; //@line 402
  }
 } else {
  label = 3; //@line 405
 }
 if ((label | 0) == 3) {
  $10 = $0 + 4 | 0; //@line 408
  $11 = HEAP32[$10 >> 2] | 0; //@line 409
  $12 = $0 + 8 | 0; //@line 410
  $13 = HEAP32[$12 >> 2] | 0; //@line 411
  if ($11 >>> 0 < $13 >>> 0) {
   FUNCTION_TABLE_iiii[HEAP32[$0 + 40 >> 2] & 15]($0, $11 - $13 | 0, 1) | 0; //@line 419
  }
  HEAP32[$0 + 16 >> 2] = 0; //@line 422
  HEAP32[$3 >> 2] = 0; //@line 423
  HEAP32[$1 >> 2] = 0; //@line 424
  HEAP32[$12 >> 2] = 0; //@line 425
  HEAP32[$10 >> 2] = 0; //@line 426
  $$0 = 0; //@line 427
 }
 return $$0 | 0; //@line 429
}
function __Z12op_3138_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 37085
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 37095
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 37101
 $19 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37102
 $21 = (HEAP32[$19 >> 2] | 0) + -2 | 0; //@line 37104
 HEAP32[$19 >> 2] = $21; //@line 37105
 $22 = $18 << 16 >> 16; //@line 37107
 $24 = ($22 | 0) == 0 & 1; //@line 37109
 HEAP32[96441] = 0; //@line 37110
 HEAP32[96442] = 0; //@line 37110
 HEAP32[96443] = 0; //@line 37110
 HEAP32[96444] = 0; //@line 37110
 HEAP32[96442] = $24; //@line 37111
 HEAP32[96443] = $18 >>> 15 & 1; //@line 37114
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($21, $22); //@line 37120
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37123
 return;
}
function __Z11op_a39_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $1 = HEAP32[162769] | 0; //@line 15761
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15763
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 15772
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 15781
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15783
 $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0) ^ $3 & 255; //@line 15789
 $30 = $29 << 24 >> 24; //@line 15791
 $32 = ($30 | 0) == 0 & 1; //@line 15793
 HEAP32[96441] = 0; //@line 15794
 HEAP32[96442] = 0; //@line 15794
 HEAP32[96443] = 0; //@line 15794
 HEAP32[96444] = 0; //@line 15794
 HEAP32[96442] = $32; //@line 15795
 HEAP32[96443] = $29 >>> 7 & 1; //@line 15798
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, $30); //@line 15802
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 15805
 return;
}
function __Z12op_40b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit28 = 0, $1 = 0, $10 = 0, $12 = 0, $15 = 0, $18 = 0, $22 = 0;
 $1 = HEAP32[162769] | 0; //@line 41105
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 41115
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41117
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$12 >> 2] >> 2] & 127]($10) | 0; //@line 41120
 $18 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $15 | 0; //@line 41124
 $$lobit = $15 >>> 31; //@line 41125
 $$lobit28 = $18 >>> 31; //@line 41126
 HEAP32[96444] = $$lobit28 & $$lobit; //@line 41128
 $22 = $$lobit28 & ~$$lobit ^ $$lobit; //@line 41131
 HEAP32[96441] = $22; //@line 41132
 HEAP32[96445] = $22; //@line 41133
 HEAP32[96442] = ($18 | 0) == 0 & HEAP32[96442]; //@line 41138
 HEAP32[96443] = $$lobit28; //@line 41139
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 12 >> 2] & 31]($10, $18); //@line 41143
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41146
 return;
}
function __Z12op_4620_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $2 = 0, $6 = 0, $8 = 0, $sext = 0;
 $1 = $0 & 7; //@line 48355
 $2 = 651040 + ($1 << 2) | 0; //@line 48356
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 48360
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 48362
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 48366
 HEAP32[$2 >> 2] = $6; //@line 48367
 $sext = $12 << 24; //@line 48368
 $13 = $sext >> 24; //@line 48369
 $14 = ~$13; //@line 48370
 $16 = ($13 | 0) == -1 & 1; //@line 48372
 HEAP32[96441] = 0; //@line 48373
 HEAP32[96442] = 0; //@line 48373
 HEAP32[96443] = 0; //@line 48373
 HEAP32[96444] = 0; //@line 48373
 HEAP32[96442] = $16; //@line 48374
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48377
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $14); //@line 48381
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48384
 return;
}
function __Z12op_2158_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $15 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32476
 $5 = HEAP32[$4 >> 2] | 0; //@line 32477
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 32482
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 32485
 $15 = HEAP32[162769] | 0; //@line 32488
 $25 = (((HEAPU8[$15 + 2 >> 0] | 0) << 8 | (HEAPU8[$15 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32499
 $27 = ($10 | 0) == 0 & 1; //@line 32501
 HEAP32[96441] = 0; //@line 32502
 HEAP32[96442] = 0; //@line 32502
 HEAP32[96443] = 0; //@line 32502
 HEAP32[96444] = 0; //@line 32502
 HEAP32[96442] = $27; //@line 32503
 HEAP32[96443] = $10 >>> 31; //@line 32505
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $10); //@line 32511
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32514
 return;
}
function __Z12op_e088_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $13 = 0, $15 = 0, $16 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38191
 $7 = HEAP32[$6 >> 2] | 0; //@line 38192
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38193
 $9 = $8 >>> 0 > 31; //@line 38194
 HEAP32[96441] = 0; //@line 38195
 HEAP32[96442] = 0; //@line 38195
 HEAP32[96443] = 0; //@line 38195
 HEAP32[96444] = 0; //@line 38195
 if ($9) {
  $13 = ($8 | 0) == 32 & $7 >>> 31; //@line 38200
  HEAP32[96441] = $13; //@line 38201
  HEAP32[96445] = $13; //@line 38202
  $$0 = 0; //@line 38203
 } else {
  $15 = $7 >>> ($8 + -1 | 0); //@line 38206
  $16 = $15 & 1; //@line 38207
  HEAP32[96441] = $16; //@line 38208
  HEAP32[96445] = $16; //@line 38209
  $$0 = $15 >>> 1; //@line 38211
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38215
 HEAP32[96443] = 0; //@line 38216
 HEAP32[$6 >> 2] = $$0; //@line 38217
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38220
 return;
}
function __Z12op_c158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30198
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30199
 $7 = HEAP32[$6 >> 2] | 0; //@line 30200
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 30202
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 30206
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 30209
 $sext2122 = $13 & $5; //@line 30210
 $16 = $sext2122 << 16 >> 16; //@line 30212
 $18 = ($16 | 0) == 0 & 1; //@line 30214
 HEAP32[96441] = 0; //@line 30215
 HEAP32[96442] = 0; //@line 30215
 HEAP32[96443] = 0; //@line 30215
 HEAP32[96444] = 0; //@line 30215
 HEAP32[96442] = $18; //@line 30216
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 30219
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 30223
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30226
 return;
}
function __Z12op_b158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26713
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 26714
 $7 = HEAP32[$6 >> 2] | 0; //@line 26715
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 26717
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 26721
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 26724
 $sext2122 = $13 ^ $5; //@line 26725
 $16 = $sext2122 << 16 >> 16; //@line 26727
 $18 = ($16 | 0) == 0 & 1; //@line 26729
 HEAP32[96441] = 0; //@line 26730
 HEAP32[96442] = 0; //@line 26730
 HEAP32[96443] = 0; //@line 26730
 HEAP32[96444] = 0; //@line 26730
 HEAP32[96442] = $18; //@line 26731
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 26734
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 26738
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26741
 return;
}
function __Z12op_8158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $16 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $sext2122 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16210
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 16211
 $7 = HEAP32[$6 >> 2] | 0; //@line 16212
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 16214
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0; //@line 16218
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 16221
 $sext2122 = $13 | $5; //@line 16222
 $16 = $sext2122 << 16 >> 16; //@line 16224
 $18 = ($16 | 0) == 0 & 1; //@line 16226
 HEAP32[96441] = 0; //@line 16227
 HEAP32[96442] = 0; //@line 16227
 HEAP32[96443] = 0; //@line 16227
 HEAP32[96444] = 0; //@line 16227
 HEAP32[96442] = $18; //@line 16228
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 16231
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $16); //@line 16235
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16238
 return;
}
function __Z12op_31d8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 38783
 $3 = HEAP32[$2 >> 2] | 0; //@line 38784
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 38790
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 38793
 $12 = HEAP32[162769] | 0; //@line 38794
 $21 = ((HEAPU8[$12 + 2 >> 0] | 0) << 8 | (HEAPU8[$12 + 3 >> 0] | 0)) << 16 >> 16; //@line 38804
 $22 = $9 << 16 >> 16; //@line 38806
 $24 = ($22 | 0) == 0 & 1; //@line 38808
 HEAP32[96441] = 0; //@line 38809
 HEAP32[96442] = 0; //@line 38809
 HEAP32[96443] = 0; //@line 38809
 HEAP32[96444] = 0; //@line 38809
 HEAP32[96442] = $24; //@line 38810
 HEAP32[96443] = $9 >>> 15 & 1; //@line 38813
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($21, $22); //@line 38819
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38822
 return;
}
function __Z12op_303a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 35223
 $4 = HEAP32[162769] | 0; //@line 35225
 $$cast = $4; //@line 35227
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 35241
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 35247
 $25 = $24 << 16 >> 16; //@line 35249
 $27 = ($25 | 0) == 0 & 1; //@line 35251
 HEAP32[96441] = 0; //@line 35252
 HEAP32[96442] = 0; //@line 35252
 HEAP32[96443] = 0; //@line 35252
 HEAP32[96444] = 0; //@line 35252
 HEAP32[96442] = $27; //@line 35253
 HEAP32[96443] = $24 >>> 15 & 1; //@line 35256
 $29 = 651008 + ($2 << 2) | 0; //@line 35257
 HEAP32[$29 >> 2] = HEAP32[$29 >> 2] & -65536 | $25 & 65535; //@line 35262
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35265
 return;
}
function __Z12op_2130_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32383
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 32392
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 32397
 $21 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 32398
 $23 = (HEAP32[$21 >> 2] | 0) + -4 | 0; //@line 32400
 HEAP32[$21 >> 2] = $23; //@line 32401
 $25 = ($20 | 0) == 0 & 1; //@line 32403
 HEAP32[96441] = 0; //@line 32404
 HEAP32[96442] = 0; //@line 32404
 HEAP32[96443] = 0; //@line 32404
 HEAP32[96444] = 0; //@line 32404
 HEAP32[96442] = $25; //@line 32405
 HEAP32[96443] = $20 >>> 31; //@line 32407
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $20); //@line 32413
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32416
 return;
}
function __Z12op_4639_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $29 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 48521
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 48530
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 48539
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 48541
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24; //@line 48546
 $26 = $sext >> 24; //@line 48547
 $27 = ~$26; //@line 48548
 $29 = ($26 | 0) == -1 & 1; //@line 48550
 HEAP32[96441] = 0; //@line 48551
 HEAP32[96442] = 0; //@line 48551
 HEAP32[96443] = 0; //@line 48551
 HEAP32[96444] = 0; //@line 48551
 HEAP32[96442] = $29; //@line 48552
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48555
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $27); //@line 48559
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 48562
 return;
}
function __Z12op_4428_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $30 = 0, $4 = 0, $sext27$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 46976
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 46987
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 46989
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 46993
 $22 = 0 - ($20 << 24 >> 24) | 0; //@line 46996
 $sext27$lobit = $22 >>> 7 & 1; //@line 46999
 HEAP32[96442] = ($22 & 255 | 0) == 0 & 1; //@line 47003
 HEAP32[96444] = $sext27$lobit & $20 >>> 7; //@line 47005
 $30 = ($20 & 255 | 0) != 0 & 1; //@line 47008
 HEAP32[96441] = $30; //@line 47009
 HEAP32[96445] = $30; //@line 47010
 HEAP32[96443] = $sext27$lobit; //@line 47011
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $22); //@line 47015
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47018
 return;
}
function __Z12op_e7f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $23 = 0, $24 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 42039
 $3 = $2 + 2 | 0; //@line 42040
 HEAP32[162769] = $3; //@line 42041
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42043
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 42050
 HEAP32[162769] = $2 + 4; //@line 42052
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 42053
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 42055
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 42059
 $23 = $20 >>> 15 & 1; //@line 42062
 $24 = $23 | $20 << 1; //@line 42063
 HEAP32[96444] = 0; //@line 42067
 HEAP32[96442] = ($24 & 65535) << 16 >> 16 == 0 & 1; //@line 42068
 HEAP32[96443] = $20 >>> 14 & 1; //@line 42071
 HEAP32[96441] = $23; //@line 42072
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $24 & 65535); //@line 42077
 return;
}
function __Z12op_30e0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 36393
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 36395
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 36401
 HEAP32[$4 >> 2] = $6; //@line 36402
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36403
 $14 = HEAP32[$13 >> 2] | 0; //@line 36404
 HEAP32[$13 >> 2] = $14 + 2; //@line 36406
 $16 = $12 << 16 >> 16; //@line 36408
 $18 = ($16 | 0) == 0 & 1; //@line 36410
 HEAP32[96441] = 0; //@line 36411
 HEAP32[96442] = 0; //@line 36411
 HEAP32[96443] = 0; //@line 36411
 HEAP32[96444] = 0; //@line 36411
 HEAP32[96442] = $18; //@line 36412
 HEAP32[96443] = $12 >>> 15 & 1; //@line 36415
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, $16); //@line 36421
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36424
 return;
}
function __ZN13driver_windowD0Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $6 = 0, $9 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 43881
 STACKTOP = STACKTOP + 16 | 0; //@line 43882
 $vararg_buffer = sp; //@line 43883
 HEAP32[$0 >> 2] = 4248; //@line 43884
 $2 = HEAP32[$0 + 16 >> 2] | 0; //@line 43886
 if ($2 | 0) {
  _SDL_FreeSurface($2 | 0); //@line 43889
 }
 $4 = HEAP32[30852] | 0; //@line 43891
 if ($4 | 0) {
  $6 = HEAP32[30853] | 0; //@line 43894
  HEAP32[$vararg_buffer >> 2] = $4; //@line 43895
  HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 43897
  _printf(102326, $vararg_buffer) | 0; //@line 43898
  __Z10vm_releasePvj(HEAP32[30852] | 0, HEAP32[30853] | 0) | 0; //@line 43901
  HEAP32[30852] = 0; //@line 43902
 }
 $9 = HEAP32[30854] | 0; //@line 43904
 if (!$9) {
  __ZdlPv($0); //@line 43907
  STACKTOP = sp; //@line 43908
  return;
 }
 _free($9); //@line 43910
 HEAP32[30854] = 0; //@line 43911
 __ZdlPv($0); //@line 43912
 STACKTOP = sp; //@line 43913
 return;
}
function __Z12op_c0b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 28996
 $5 = $4 + 2 | 0; //@line 28997
 HEAP32[162769] = $5; //@line 28998
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29000
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 29007
 HEAP32[162769] = $4 + 4; //@line 29009
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 29010
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 29015
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29016
 $24 = HEAP32[$22 >> 2] & $21; //@line 29018
 $26 = ($24 | 0) == 0 & 1; //@line 29020
 HEAP32[96441] = 0; //@line 29021
 HEAP32[96442] = 0; //@line 29021
 HEAP32[96443] = 0; //@line 29021
 HEAP32[96444] = 0; //@line 29021
 HEAP32[96442] = $26; //@line 29022
 HEAP32[96443] = $24 >>> 31; //@line 29024
 HEAP32[$22 >> 2] = $24; //@line 29025
 return;
}
function __Z12op_b0f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit35 = 0, $15 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 35534
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35543
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 35549
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35551
 $24 = $21 << 16 >> 16; //@line 35553
 $25 = $23 - $24 | 0; //@line 35554
 $$lobit = $23 >>> 31; //@line 35557
 $$lobit35 = $25 >>> 31; //@line 35558
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 35561
 HEAP32[96444] = ($21 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit35 | 0) != ($$lobit | 0) & 1; //@line 35566
 HEAP32[96441] = $23 >>> 0 < $24 >>> 0 & 1; //@line 35569
 HEAP32[96443] = $$lobit35; //@line 35570
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35573
 return;
}
function __Z12op_80b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 14673
 $5 = $4 + 2 | 0; //@line 14674
 HEAP32[162769] = $5; //@line 14675
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14677
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 14684
 HEAP32[162769] = $4 + 4; //@line 14686
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 14687
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 14692
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14693
 $24 = HEAP32[$22 >> 2] | $21; //@line 14695
 $26 = ($24 | 0) == 0 & 1; //@line 14697
 HEAP32[96441] = 0; //@line 14698
 HEAP32[96442] = 0; //@line 14698
 HEAP32[96443] = 0; //@line 14698
 HEAP32[96444] = 0; //@line 14698
 HEAP32[96442] = $26; //@line 14699
 HEAP32[96443] = $24 >>> 31; //@line 14701
 HEAP32[$22 >> 2] = $24; //@line 14702
 return;
}
function __Z12op_30f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 36537
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 36547
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 36553
 $19 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36554
 $20 = HEAP32[$19 >> 2] | 0; //@line 36555
 HEAP32[$19 >> 2] = $20 + 2; //@line 36557
 $22 = $18 << 16 >> 16; //@line 36559
 $24 = ($22 | 0) == 0 & 1; //@line 36561
 HEAP32[96441] = 0; //@line 36562
 HEAP32[96442] = 0; //@line 36562
 HEAP32[96443] = 0; //@line 36562
 HEAP32[96444] = 0; //@line 36562
 HEAP32[96442] = $24; //@line 36563
 HEAP32[96443] = $18 >>> 15 & 1; //@line 36566
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($20, $22); //@line 36572
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36575
 return;
}
function __Z12op_2139_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 29916
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 29925
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 29939
 $27 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29940
 $29 = (HEAP32[$27 >> 2] | 0) + -4 | 0; //@line 29942
 HEAP32[$27 >> 2] = $29; //@line 29943
 $31 = ($26 | 0) == 0 & 1; //@line 29945
 HEAP32[96441] = 0; //@line 29946
 HEAP32[96442] = 0; //@line 29946
 HEAP32[96443] = 0; //@line 29946
 HEAP32[96444] = 0; //@line 29946
 HEAP32[96442] = $31; //@line 29947
 HEAP32[96443] = $26 >>> 31; //@line 29949
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($29, $26); //@line 29955
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29958
 return;
}
function __Z12op_b1fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit32 = 0, $$lobit33 = 0, $18 = 0, $23 = 0, $25 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 27726
 $$cast = $4; //@line 27728
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 27742
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 27747
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27749
 $26 = $25 - $23 | 0; //@line 27750
 $$lobit32 = $25 >>> 31; //@line 27752
 $$lobit33 = $26 >>> 31; //@line 27753
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 27756
 HEAP32[96444] = ($23 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 27761
 HEAP32[96441] = $25 >>> 0 < $23 >>> 0 & 1; //@line 27764
 HEAP32[96443] = $$lobit33; //@line 27765
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27768
 return;
}
function __Z12op_b0ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $$lobit32 = 0, $$lobit33 = 0, $18 = 0, $23 = 0, $25 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 25454
 $$cast = $4; //@line 25456
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 25470
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 25475
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25477
 $26 = $25 - $23 | 0; //@line 25478
 $$lobit32 = $25 >>> 31; //@line 25480
 $$lobit33 = $26 >>> 31; //@line 25481
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 25484
 HEAP32[96444] = ($23 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 25489
 HEAP32[96441] = $25 >>> 0 < $23 >>> 0 & 1; //@line 25492
 HEAP32[96443] = $$lobit33; //@line 25493
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25496
 return;
}
function __Z12op_5098_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $12 = 0, $15 = 0, $23 = 0, $4 = 0, $6 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4455
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 4457
 $7 = HEAP32[$6 >> 2] | 0; //@line 4458
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 4460
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 4463
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 4466
 $15 = $12 + $4 | 0; //@line 4467
 $$lobit39 = $15 >>> 31; //@line 4470
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 4473
 HEAP32[96444] = ($$lobit39 ^ $4 >>> 31) & ($$lobit39 ^ $12 >>> 31); //@line 4477
 $23 = $4 >>> 0 > ~$12 >>> 0 & 1; //@line 4480
 HEAP32[96441] = $23; //@line 4481
 HEAP32[96445] = $23; //@line 4482
 HEAP32[96443] = $$lobit39; //@line 4483
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 4487
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4490
 return;
}
function __Z12op_4679_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $29 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 48829
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 48838
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 48847
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 48849
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0) << 16; //@line 48854
 $26 = $sext >> 16; //@line 48855
 $27 = ~$26; //@line 48856
 $29 = ($26 | 0) == -1 & 1; //@line 48858
 HEAP32[96441] = 0; //@line 48859
 HEAP32[96442] = 0; //@line 48859
 HEAP32[96443] = 0; //@line 48859
 HEAP32[96444] = 0; //@line 48859
 HEAP32[96442] = $29; //@line 48860
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48863
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $27); //@line 48867
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 48870
 return;
}
function __Z12op_4470_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $21 = 0, $29 = 0, $4 = 0, $sext28$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 2276
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2285
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2287
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 2291
 $21 = 0 - ($19 << 16 >> 16) | 0; //@line 2294
 $sext28$lobit = $21 >>> 15 & 1; //@line 2297
 HEAP32[96442] = ($21 & 65535 | 0) == 0 & 1; //@line 2301
 HEAP32[96444] = $sext28$lobit & $19 >>> 15; //@line 2303
 $29 = ($19 & 65535 | 0) != 0 & 1; //@line 2306
 HEAP32[96441] = $29; //@line 2307
 HEAP32[96445] = $29; //@line 2308
 HEAP32[96443] = $sext28$lobit; //@line 2309
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $21); //@line 2313
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2316
 return;
}
function __Z12op_33d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 39370
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 39376
 $10 = HEAP32[162769] | 0; //@line 39377
 $19 = (HEAPU8[$10 + 3 >> 0] | 0) << 16 | (HEAPU8[$10 + 2 >> 0] | 0) << 24; //@line 39386
 $28 = $19 | (HEAPU8[$10 + 4 >> 0] | 0) << 8 | (HEAPU8[$10 + 5 >> 0] | 0); //@line 39395
 $29 = $9 << 16 >> 16; //@line 39397
 $31 = ($29 | 0) == 0 & 1; //@line 39399
 HEAP32[96441] = 0; //@line 39400
 HEAP32[96442] = 0; //@line 39400
 HEAP32[96443] = 0; //@line 39400
 HEAP32[96444] = 0; //@line 39400
 HEAP32[96442] = $31; //@line 39401
 HEAP32[96443] = $9 >>> 15 & 1; //@line 39404
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($28, $29); //@line 39410
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39413
 return;
}
function __Z12op_103a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 23703
 $4 = HEAP32[162769] | 0; //@line 23705
 $$cast = $4; //@line 23707
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 23721
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0; //@line 23727
 $25 = $24 << 24 >> 24; //@line 23729
 $27 = ($25 | 0) == 0 & 1; //@line 23731
 HEAP32[96441] = 0; //@line 23732
 HEAP32[96442] = 0; //@line 23732
 HEAP32[96443] = 0; //@line 23732
 HEAP32[96444] = 0; //@line 23732
 HEAP32[96442] = $27; //@line 23733
 HEAP32[96443] = $24 >>> 7 & 1; //@line 23736
 $29 = 651008 + ($2 << 2) | 0; //@line 23737
 HEAP32[$29 >> 2] = HEAP32[$29 >> 2] & -256 | $25 & 255; //@line 23742
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23745
 return;
}
function __Z11op_1c8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $25 = 0, $32 = 0, $39 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7966
 $8 = HEAP32[162769] | 0; //@line 7969
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7980
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($18, $5 >> 24); //@line 7987
 $25 = $18 + 2 | 0; //@line 7988
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($25, $5 >> 16); //@line 7995
 $32 = $18 + 4 | 0; //@line 7996
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($32, $5 >> 8); //@line 8003
 $39 = $18 + 6 | 0; //@line 8004
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($39 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($39, $5); //@line 8010
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8013
 return;
}
function __ZN11driver_baseD0Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $6 = 0, $9 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 43799
 STACKTOP = STACKTOP + 16 | 0; //@line 43800
 $vararg_buffer = sp; //@line 43801
 HEAP32[$0 >> 2] = 4248; //@line 43802
 $2 = HEAP32[$0 + 16 >> 2] | 0; //@line 43804
 if ($2 | 0) {
  _SDL_FreeSurface($2 | 0); //@line 43807
 }
 $4 = HEAP32[30852] | 0; //@line 43809
 if ($4 | 0) {
  $6 = HEAP32[30853] | 0; //@line 43812
  HEAP32[$vararg_buffer >> 2] = $4; //@line 43813
  HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 43815
  _printf(102326, $vararg_buffer) | 0; //@line 43816
  __Z10vm_releasePvj(HEAP32[30852] | 0, HEAP32[30853] | 0) | 0; //@line 43819
  HEAP32[30852] = 0; //@line 43820
 }
 $9 = HEAP32[30854] | 0; //@line 43822
 if (!$9) {
  __ZdlPv($0); //@line 43825
  STACKTOP = sp; //@line 43826
  return;
 }
 _free($9); //@line 43828
 HEAP32[30854] = 0; //@line 43829
 __ZdlPv($0); //@line 43830
 STACKTOP = sp; //@line 43831
 return;
}
function __Z12op_40a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit34 = 0, $12 = 0, $16 = 0, $2 = 0, $4 = 0, $6 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40958
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 40960
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40962
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$6 >> 2] >> 2] & 127]($4) | 0; //@line 40965
 HEAP32[$2 >> 2] = $4; //@line 40966
 $12 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $9 | 0; //@line 40970
 $$lobit = $9 >>> 31; //@line 40971
 $$lobit34 = $12 >>> 31; //@line 40972
 HEAP32[96444] = $$lobit34 & $$lobit; //@line 40974
 $16 = $$lobit34 & ~$$lobit ^ $$lobit; //@line 40977
 HEAP32[96441] = $16; //@line 40978
 HEAP32[96445] = $16; //@line 40979
 HEAP32[96442] = ($12 | 0) == 0 & HEAP32[96442]; //@line 40984
 HEAP32[96443] = $$lobit34; //@line 40985
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 12 >> 2] & 31]($4, $12); //@line 40989
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40992
 return;
}
function __Z12op_21a0_3_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $23 = 0, $25 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 43510
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 43512
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 43517
 HEAP32[$4 >> 2] = $6; //@line 43518
 $14 = HEAP32[162769] | 0; //@line 43521
 $23 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) | 0; //@line 43530
 $25 = ($11 | 0) == 0 & 1; //@line 43532
 HEAP32[96441] = 0; //@line 43533
 HEAP32[96442] = 0; //@line 43533
 HEAP32[96443] = 0; //@line 43533
 HEAP32[96444] = 0; //@line 43533
 HEAP32[96442] = $25; //@line 43534
 HEAP32[96443] = $11 >>> 31; //@line 43536
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $11); //@line 43542
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43545
 return;
}
function __Z12op_2128_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 29780
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 29791
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 29796
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29797
 $24 = (HEAP32[$22 >> 2] | 0) + -4 | 0; //@line 29799
 HEAP32[$22 >> 2] = $24; //@line 29800
 $26 = ($21 | 0) == 0 & 1; //@line 29802
 HEAP32[96441] = 0; //@line 29803
 HEAP32[96442] = 0; //@line 29803
 HEAP32[96443] = 0; //@line 29803
 HEAP32[96444] = 0; //@line 29803
 HEAP32[96442] = $26; //@line 29804
 HEAP32[96443] = $21 >>> 31; //@line 29806
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $21); //@line 29812
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29815
 return;
}
function __Z12op_13d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $28 = 0, $29 = 0, $3 = 0, $31 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27245
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 27251
 $10 = HEAP32[162769] | 0; //@line 27252
 $19 = (HEAPU8[$10 + 3 >> 0] | 0) << 16 | (HEAPU8[$10 + 2 >> 0] | 0) << 24; //@line 27261
 $28 = $19 | (HEAPU8[$10 + 4 >> 0] | 0) << 8 | (HEAPU8[$10 + 5 >> 0] | 0); //@line 27270
 $29 = $9 << 24 >> 24; //@line 27272
 $31 = ($29 | 0) == 0 & 1; //@line 27274
 HEAP32[96441] = 0; //@line 27275
 HEAP32[96442] = 0; //@line 27275
 HEAP32[96443] = 0; //@line 27275
 HEAP32[96444] = 0; //@line 27275
 HEAP32[96442] = $31; //@line 27276
 HEAP32[96443] = $9 >>> 7 & 1; //@line 27279
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($28, $29); //@line 27285
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27288
 return;
}
function __Z12op_b0f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit31 = 0, $12 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 25966
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 25975
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 25990
 $29 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25992
 $30 = $27 << 16 >> 16; //@line 25994
 $31 = $29 - $30 | 0; //@line 25995
 $$lobit = $29 >>> 31; //@line 25998
 $$lobit31 = $31 >>> 31; //@line 25999
 HEAP32[96442] = ($31 | 0) == 0 & 1; //@line 26002
 HEAP32[96444] = ($27 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit31 | 0) != ($$lobit | 0) & 1; //@line 26007
 HEAP32[96441] = $29 >>> 0 < $30 >>> 0 & 1; //@line 26010
 HEAP32[96443] = $$lobit31; //@line 26011
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26014
 return;
}
function __Z12op_5fc8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $12 = 0, $2 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 11061
 $3 = HEAP32[$2 >> 2] | 0; //@line 11062
 $4 = HEAP32[162769] | 0; //@line 11063
 $12 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 11071
 if (HEAP32[96442] | 0) {
  $$sink18 = 4; //@line 11075
  $27 = $4; //@line 11075
  $26 = $27 + $$sink18 | 0; //@line 11076
  HEAP32[162769] = $26; //@line 11077
  return;
 }
 if ((HEAP32[96443] | 0) != (HEAP32[96444] | 0)) {
  $$sink18 = 4; //@line 11084
  $27 = $4; //@line 11084
  $26 = $27 + $$sink18 | 0; //@line 11085
  HEAP32[162769] = $26; //@line 11086
  return;
 }
 HEAP32[$2 >> 2] = $3 & -65536 | $3 + 65535 & 65535; //@line 11094
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($12 << 16 >> 16) + 2 | 0; //@line 11101
 $27 = HEAP32[162769] | 0; //@line 11101
 $26 = $27 + $$sink18 | 0; //@line 11102
 HEAP32[162769] = $26; //@line 11103
 return;
}
function __Z12op_21b8_3_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $20 = 0, $29 = 0, $3 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 43668
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 43678
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 43683
 $20 = HEAP32[162769] | 0; //@line 43686
 $29 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$20 + 4 >> 0] | 0) << 8 | (HEAPU8[$20 + 5 >> 0] | 0)) | 0; //@line 43695
 $31 = ($17 | 0) == 0 & 1; //@line 43697
 HEAP32[96441] = 0; //@line 43698
 HEAP32[96442] = 0; //@line 43698
 HEAP32[96443] = 0; //@line 43698
 HEAP32[96444] = 0; //@line 43698
 HEAP32[96442] = $31; //@line 43699
 HEAP32[96443] = $17 >>> 31; //@line 43701
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($29, $17); //@line 43707
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43710
 return;
}
function __Z11op_2a8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 9397
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9415
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 9428
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 9430
 $38 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0) & $20; //@line 9434
 $40 = ($38 | 0) == 0 & 1; //@line 9436
 HEAP32[96441] = 0; //@line 9437
 HEAP32[96442] = 0; //@line 9437
 HEAP32[96443] = 0; //@line 9437
 HEAP32[96444] = 0; //@line 9437
 HEAP32[96442] = $40; //@line 9438
 HEAP32[96443] = $38 >>> 31; //@line 9440
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 9444
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 9447
 return;
}
function __Z12op_e2f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 40425
 $3 = $2 + 2 | 0; //@line 40426
 HEAP32[162769] = $3; //@line 40427
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40429
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 40436
 HEAP32[162769] = $2 + 4; //@line 40438
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 40439
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40441
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40445
 $21 = $20 & 1; //@line 40446
 $23 = $20 >>> 1 & 32767; //@line 40448
 HEAP32[96444] = 0; //@line 40451
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 40452
 HEAP32[96443] = 0; //@line 40453
 HEAP32[96441] = $21; //@line 40454
 HEAP32[96445] = $21; //@line 40455
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 40459
 return;
}
function __Z12op_c160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $8 = 0, $sext2223 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30238
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30239
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 30241
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 30243
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 30247
 HEAP32[$6 >> 2] = $8; //@line 30248
 $sext2223 = $14 & $5; //@line 30249
 $15 = $sext2223 << 16 >> 16; //@line 30251
 $17 = ($15 | 0) == 0 & 1; //@line 30253
 HEAP32[96441] = 0; //@line 30254
 HEAP32[96442] = 0; //@line 30254
 HEAP32[96443] = 0; //@line 30254
 HEAP32[96444] = 0; //@line 30254
 HEAP32[96442] = $17; //@line 30255
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 30258
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $15); //@line 30262
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30265
 return;
}
function __Z12op_b160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $8 = 0, $sext2223 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26753
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 26754
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 26756
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 26758
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 26762
 HEAP32[$6 >> 2] = $8; //@line 26763
 $sext2223 = $14 ^ $5; //@line 26764
 $15 = $sext2223 << 16 >> 16; //@line 26766
 $17 = ($15 | 0) == 0 & 1; //@line 26768
 HEAP32[96441] = 0; //@line 26769
 HEAP32[96442] = 0; //@line 26769
 HEAP32[96443] = 0; //@line 26769
 HEAP32[96444] = 0; //@line 26769
 HEAP32[96442] = $17; //@line 26770
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 26773
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $15); //@line 26777
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26780
 return;
}
function __Z12op_8160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $8 = 0, $sext2223 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16250
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 16251
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 16253
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 16255
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$10 >> 2] | 0) + 4 >> 2] & 127]($8) | 0; //@line 16259
 HEAP32[$6 >> 2] = $8; //@line 16260
 $sext2223 = $14 | $5; //@line 16261
 $15 = $sext2223 << 16 >> 16; //@line 16263
 $17 = ($15 | 0) == 0 & 1; //@line 16265
 HEAP32[96441] = 0; //@line 16266
 HEAP32[96442] = 0; //@line 16266
 HEAP32[96443] = 0; //@line 16266
 HEAP32[96444] = 0; //@line 16266
 HEAP32[96442] = $17; //@line 16267
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 16270
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 16 >> 2] & 31]($8, $15); //@line 16274
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16277
 return;
}
function __Z12op_31e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $2 = 0, $20 = 0, $21 = 0, $23 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 38831
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 38833
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 38839
 HEAP32[$2 >> 2] = $4; //@line 38840
 $11 = HEAP32[162769] | 0; //@line 38841
 $20 = ((HEAPU8[$11 + 2 >> 0] | 0) << 8 | (HEAPU8[$11 + 3 >> 0] | 0)) << 16 >> 16; //@line 38851
 $21 = $10 << 16 >> 16; //@line 38853
 $23 = ($21 | 0) == 0 & 1; //@line 38855
 HEAP32[96441] = 0; //@line 38856
 HEAP32[96442] = 0; //@line 38856
 HEAP32[96443] = 0; //@line 38856
 HEAP32[96444] = 0; //@line 38856
 HEAP32[96442] = $23; //@line 38857
 HEAP32[96443] = $10 >>> 15 & 1; //@line 38860
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($20, $21); //@line 38866
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38869
 return;
}
function __Z12op_20f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32288
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 32297
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 32302
 $21 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 32303
 $22 = HEAP32[$21 >> 2] | 0; //@line 32304
 HEAP32[$21 >> 2] = $22 + 4; //@line 32306
 $25 = ($20 | 0) == 0 & 1; //@line 32308
 HEAP32[96441] = 0; //@line 32309
 HEAP32[96442] = 0; //@line 32309
 HEAP32[96443] = 0; //@line 32309
 HEAP32[96444] = 0; //@line 32309
 HEAP32[96442] = $25; //@line 32310
 HEAP32[96443] = $20 >>> 31; //@line 32312
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $20); //@line 32318
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32321
 return;
}
function __Z11op_eb8_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0, $36 = 0, $41 = 0, $45 = 0, $6 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22604
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 22607
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 22610
 $8 = $6 << 24 >> 16; //@line 22612
 if (!($8 & 2048)) {
  $36 = (HEAPU8[$3 + 6 >> 0] << 8 | HEAPU8[$3 + 7 >> 0]) << 16 >> 16; //@line 22625
  $41 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($36 >>> 16 << 2) >> 2] >> 2] & 127]($36) | 0; //@line 22630
  $45 = $6 >>> 4 & 7; //@line 22634
  HEAP32[($8 & 32768 | 0 ? 651040 + ($45 << 2) | 0 : 651008 + ($45 << 2) | 0) >> 2] = $41; //@line 22638
 } else {
  $22 = (HEAPU8[$3 + 4 >> 0] << 8 | HEAPU8[$3 + 5 >> 0]) << 16 >> 16; //@line 22652
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, HEAP32[651008 + ($6 >>> 4 << 2) >> 2] | 0); //@line 22658
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 22662
 return;
}
function __Z11op_cb8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit27 = 0, $$lobit28 = 0, $1 = 0, $19 = 0, $28 = 0, $33 = 0, $34 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 20181
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 20184
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 20199
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 20209
 $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($28 >>> 16 << 2) >> 2] >> 2] & 127]($28) | 0; //@line 20214
 $34 = $33 - $19 | 0; //@line 20215
 $$lobit27 = $33 >>> 31; //@line 20217
 $$lobit28 = $34 >>> 31; //@line 20218
 HEAP32[96442] = ($34 | 0) == 0 & 1; //@line 20221
 HEAP32[96444] = ($4 >>> 7 | 0) != ($$lobit27 | 0) & ($$lobit28 | 0) != ($$lobit27 | 0) & 1; //@line 20226
 HEAP32[96441] = $33 >>> 0 < $19 >>> 0 & 1; //@line 20229
 HEAP32[96443] = $$lobit28; //@line 20230
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 20233
 return;
}
function __Z10op_a8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $32 = 0, $34 = 0, $38 = 0, $40 = 0;
 $2 = HEAP32[162769] | 0; //@line 5663
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5681
 $32 = (((HEAPU8[$2 + 6 >> 0] | 0) << 8 | (HEAPU8[$2 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 5694
 $34 = 123608 + ($32 >>> 16 << 2) | 0; //@line 5696
 $38 = $20 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$34 >> 2] >> 2] & 127]($32) | 0); //@line 5700
 $40 = ($38 | 0) == 0 & 1; //@line 5702
 HEAP32[96441] = 0; //@line 5703
 HEAP32[96442] = 0; //@line 5703
 HEAP32[96443] = 0; //@line 5703
 HEAP32[96444] = 0; //@line 5703
 HEAP32[96442] = $40; //@line 5704
 HEAP32[96443] = $38 >>> 31; //@line 5706
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$34 >> 2] | 0) + 12 >> 2] & 31]($32, $38); //@line 5710
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 5713
 return;
}
function __Z12op_b0e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit36 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 25811
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 25822
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 25828
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25830
 $25 = $22 << 16 >> 16; //@line 25832
 $26 = $24 - $25 | 0; //@line 25833
 $$lobit = $24 >>> 31; //@line 25836
 $$lobit36 = $26 >>> 31; //@line 25837
 HEAP32[96442] = ($26 | 0) == 0 & 1; //@line 25840
 HEAP32[96444] = ($22 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit36 | 0) != ($$lobit | 0) & 1; //@line 25845
 HEAP32[96441] = $24 >>> 0 < $25 >>> 0 & 1; //@line 25848
 HEAP32[96443] = $$lobit36; //@line 25849
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25852
 return;
}
function __Z12op_31f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $17 = 0, $26 = 0, $27 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 38994
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 39004
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 39010
 $17 = HEAP32[162769] | 0; //@line 39011
 $26 = ((HEAPU8[$17 + 4 >> 0] | 0) << 8 | (HEAPU8[$17 + 5 >> 0] | 0)) << 16 >> 16; //@line 39021
 $27 = $16 << 16 >> 16; //@line 39023
 $29 = ($27 | 0) == 0 & 1; //@line 39025
 HEAP32[96441] = 0; //@line 39026
 HEAP32[96442] = 0; //@line 39026
 HEAP32[96443] = 0; //@line 39026
 HEAP32[96444] = 0; //@line 39026
 HEAP32[96442] = $29; //@line 39027
 HEAP32[96443] = $16 >>> 15 & 1; //@line 39030
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($26, $27); //@line 39036
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39039
 return;
}
function _tanh($0) {
 $0 = +$0;
 var $$0 = 0.0, $16 = 0.0, $2 = 0, $21 = 0.0, $3 = 0, $4 = 0.0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 62548
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62549
 $3 = $2 & 2147483647; //@line 62550
 HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2]; //@line 62551
 HEAP32[tempDoublePtr + 4 >> 2] = $3; //@line 62551
 $4 = +HEAPF64[tempDoublePtr >> 3]; //@line 62551
 do {
  if ($3 >>> 0 > 1071748074) {
   if ($3 >>> 0 > 1077149696) {
    $$0 = 1.0 - 0.0 / $4; //@line 62559
    break;
   } else {
    $$0 = 1.0 - 2.0 / (+_expm1($4 * 2.0) + 2.0); //@line 62567
    break;
   }
  } else {
   if ($3 >>> 0 > 1070618798) {
    $16 = +_expm1($4 * 2.0); //@line 62574
    $$0 = $16 / ($16 + 2.0); //@line 62577
    break;
   }
   if ($3 >>> 0 > 1048575) {
    $21 = +_expm1($4 * -2.0); //@line 62583
    $$0 = -$21 / ($21 + 2.0); //@line 62587
   } else {
    $$0 = $4; //@line 62589
   }
  }
 } while (0);
 return +(($2 | 0) < 0 ? -$$0 : $$0);
}
function __Z12op_4ebb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $20 = 0, $22 = 0, $33 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 934
 $2 = $1 + 2 | 0; //@line 935
 HEAP32[162769] = $2; //@line 936
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 941
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 948
 HEAP32[162769] = $1 + 4; //@line 950
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 951
 $20 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 956
 $22 = (HEAP32[162767] | 0) + -4 | 0; //@line 958
 HEAP32[162767] = $22; //@line 959
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $20); //@line 965
 $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($15) | 0; //@line 971
 HEAP32[162770] = $33; //@line 972
 HEAP32[162769] = $33; //@line 973
 HEAP32[162768] = $15; //@line 974
 return;
}
function __Z12op_11f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $17 = 0, $26 = 0, $27 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 26922
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 26932
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 26938
 $17 = HEAP32[162769] | 0; //@line 26939
 $26 = ((HEAPU8[$17 + 4 >> 0] | 0) << 8 | (HEAPU8[$17 + 5 >> 0] | 0)) << 16 >> 16; //@line 26949
 $27 = $16 << 24 >> 24; //@line 26951
 $29 = ($27 | 0) == 0 & 1; //@line 26953
 HEAP32[96441] = 0; //@line 26954
 HEAP32[96442] = 0; //@line 26954
 HEAP32[96443] = 0; //@line 26954
 HEAP32[96444] = 0; //@line 26954
 HEAP32[96442] = $29; //@line 26955
 HEAP32[96443] = $16 >>> 7 & 1; //@line 26958
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $27); //@line 26964
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26967
 return;
}
function __Z12op_1098_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 23898
 $4 = 651040 + ($1 << 2) | 0; //@line 23901
 $5 = HEAP32[$4 >> 2] | 0; //@line 23902
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 23908
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 23913
 $17 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23915
 $18 = $11 << 24 >> 24; //@line 23917
 $20 = ($18 | 0) == 0 & 1; //@line 23919
 HEAP32[96441] = 0; //@line 23920
 HEAP32[96442] = 0; //@line 23920
 HEAP32[96443] = 0; //@line 23920
 HEAP32[96444] = 0; //@line 23920
 HEAP32[96442] = $20; //@line 23921
 HEAP32[96443] = $11 >>> 7 & 1; //@line 23924
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, $18); //@line 23930
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23933
 return;
}
function __Z12op_4430_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $21 = 0, $29 = 0, $4 = 0, $sext26$lobit = 0;
 $4 = HEAP32[162769] | 0; //@line 2225
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2234
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2236
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 2240
 $21 = 0 - ($19 << 24 >> 24) | 0; //@line 2243
 $sext26$lobit = $21 >>> 7 & 1; //@line 2246
 HEAP32[96442] = ($21 & 255 | 0) == 0 & 1; //@line 2250
 HEAP32[96444] = $sext26$lobit & $19 >>> 7; //@line 2252
 $29 = ($19 & 255 | 0) != 0 & 1; //@line 2255
 HEAP32[96441] = $29; //@line 2256
 HEAP32[96445] = $29; //@line 2257
 HEAP32[96443] = $sext26$lobit; //@line 2258
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $21); //@line 2262
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2265
 return;
}
function __Z12op_2160_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $24 = 0, $26 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32525
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 32527
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 32532
 HEAP32[$4 >> 2] = $6; //@line 32533
 $14 = HEAP32[162769] | 0; //@line 32536
 $24 = (((HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32547
 $26 = ($11 | 0) == 0 & 1; //@line 32549
 HEAP32[96441] = 0; //@line 32550
 HEAP32[96442] = 0; //@line 32550
 HEAP32[96443] = 0; //@line 32550
 HEAP32[96444] = 0; //@line 32550
 HEAP32[96442] = $26; //@line 32551
 HEAP32[96443] = $11 >>> 31; //@line 32553
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $11); //@line 32559
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32562
 return;
}
function __Z12op_20f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 29406
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 29415
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 29429
 $27 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29430
 $28 = HEAP32[$27 >> 2] | 0; //@line 29431
 HEAP32[$27 >> 2] = $28 + 4; //@line 29433
 $31 = ($26 | 0) == 0 & 1; //@line 29435
 HEAP32[96441] = 0; //@line 29436
 HEAP32[96442] = 0; //@line 29436
 HEAP32[96443] = 0; //@line 29436
 HEAP32[96444] = 0; //@line 29436
 HEAP32[96442] = $31; //@line 29437
 HEAP32[96443] = $26 >>> 31; //@line 29439
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $26); //@line 29445
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29448
 return;
}
function __Z12op_50b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $14 = 0, $16 = 0, $19 = 0, $20 = 0, $28 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4655
 $5 = HEAP32[162769] | 0; //@line 4656
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 4666
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 4668
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 4671
 $20 = $19 + $4 | 0; //@line 4672
 $$lobit34 = $20 >>> 31; //@line 4675
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 4678
 HEAP32[96444] = ($$lobit34 ^ $4 >>> 31) & ($$lobit34 ^ $19 >>> 31); //@line 4682
 $28 = $4 >>> 0 > ~$19 >>> 0 & 1; //@line 4685
 HEAP32[96441] = $28; //@line 4686
 HEAP32[96445] = $28; //@line 4687
 HEAP32[96443] = $$lobit34; //@line 4688
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 4692
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4695
 return;
}
function __Z12op_2178_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $20 = 0, $3 = 0, $30 = 0, $32 = 0;
 $3 = HEAP32[162769] | 0; //@line 32691
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 32701
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 32706
 $20 = HEAP32[162769] | 0; //@line 32709
 $30 = (((HEAPU8[$20 + 4 >> 0] | 0) << 8 | (HEAPU8[$20 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32720
 $32 = ($17 | 0) == 0 & 1; //@line 32722
 HEAP32[96441] = 0; //@line 32723
 HEAP32[96442] = 0; //@line 32723
 HEAP32[96443] = 0; //@line 32723
 HEAP32[96444] = 0; //@line 32723
 HEAP32[96442] = $32; //@line 32724
 HEAP32[96443] = $17 >>> 31; //@line 32726
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($30 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($30, $17); //@line 32732
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 32735
 return;
}
function __Z11op_c78_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $24 = 0, $25 = 0, $4 = 0, $9 = 0, $sext27$lobit = 0, $sext29$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19596
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 19599
 $9 = $4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 19604
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 19614
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 19620
 $25 = $24 - $9 | 0; //@line 19621
 $sext27$lobit = $24 >>> 15 & 1; //@line 19624
 $sext29$lobit = $25 >>> 15 & 1; //@line 19626
 HEAP32[96442] = ($25 & 65535 | 0) == 0 & 1; //@line 19630
 HEAP32[96444] = ($4 >>> 7 | 0) != ($sext27$lobit | 0) & ($sext29$lobit | 0) != ($sext27$lobit | 0) & 1; //@line 19635
 HEAP32[96441] = $9 >>> 0 > ($24 & 65535) >>> 0 & 1; //@line 19639
 HEAP32[96443] = $sext29$lobit; //@line 19640
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19643
 return;
}
function __Z12op_50a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit40 = 0, $10 = 0, $13 = 0, $14 = 0, $22 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4501
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 4503
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 4505
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 4507
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 4510
 HEAP32[$6 >> 2] = $8; //@line 4511
 $14 = $13 + $4 | 0; //@line 4512
 $$lobit40 = $14 >>> 31; //@line 4515
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 4518
 HEAP32[96444] = ($$lobit40 ^ $4 >>> 31) & ($$lobit40 ^ $13 >>> 31); //@line 4522
 $22 = $4 >>> 0 > ~$13 >>> 0 & 1; //@line 4525
 HEAP32[96441] = $22; //@line 4526
 HEAP32[96445] = $22; //@line 4527
 HEAP32[96443] = $$lobit40; //@line 4528
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 4532
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4535
 return;
}
function __Z12op_21f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $19 = 0, $28 = 0, $30 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 43956
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 43965
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 43970
 $19 = HEAP32[162769] | 0; //@line 43971
 $28 = ((HEAPU8[$19 + 4 >> 0] | 0) << 8 | (HEAPU8[$19 + 5 >> 0] | 0)) << 16 >> 16; //@line 43981
 $30 = ($18 | 0) == 0 & 1; //@line 43983
 HEAP32[96441] = 0; //@line 43984
 HEAP32[96442] = 0; //@line 43984
 HEAP32[96443] = 0; //@line 43984
 HEAP32[96444] = 0; //@line 43984
 HEAP32[96442] = $30; //@line 43985
 HEAP32[96443] = $18 >>> 31; //@line 43987
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $18); //@line 43993
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43996
 return;
}
function __Z12op_20e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 29270
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 29281
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 29286
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29287
 $23 = HEAP32[$22 >> 2] | 0; //@line 29288
 HEAP32[$22 >> 2] = $23 + 4; //@line 29290
 $26 = ($21 | 0) == 0 & 1; //@line 29292
 HEAP32[96441] = 0; //@line 29293
 HEAP32[96442] = 0; //@line 29293
 HEAP32[96443] = 0; //@line 29293
 HEAP32[96444] = 0; //@line 29293
 HEAP32[96442] = $26; //@line 29294
 HEAP32[96443] = $21 >>> 31; //@line 29296
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 29302
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29305
 return;
}
function __Z12op_c1fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $28 = 0, $30 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36425
 $$cast = $4; //@line 36430
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36439
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36445
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36446
 $28 = Math_imul(HEAP32[$24 >> 2] << 16 >> 16, $23 << 16 >> 16) | 0; //@line 36452
 $30 = ($28 | 0) == 0 & 1; //@line 36454
 HEAP32[96441] = 0; //@line 36455
 HEAP32[96442] = 0; //@line 36455
 HEAP32[96443] = 0; //@line 36455
 HEAP32[96444] = 0; //@line 36455
 HEAP32[96442] = $30; //@line 36456
 HEAP32[96443] = $28 >>> 31; //@line 36458
 HEAP32[$24 >> 2] = $28; //@line 36459
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36462
 return;
}
function __Z11op_239_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $1 = HEAP32[162769] | 0; //@line 8731
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 8733
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 8742
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 8751
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 8753
 $29 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0) & ($3 & 255); //@line 8759
 $30 = $29 << 24 >> 24; //@line 8761
 $32 = ($30 | 0) == 0 & 1; //@line 8763
 HEAP32[96441] = 0; //@line 8764
 HEAP32[96442] = 0; //@line 8764
 HEAP32[96443] = 0; //@line 8764
 HEAP32[96444] = 0; //@line 8764
 HEAP32[96442] = $32; //@line 8765
 HEAP32[96443] = $29 >>> 7; //@line 8767
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, $30); //@line 8771
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 8774
 return;
}
function __Z12op_e3f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $20 = 0, $26 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 40723
 $3 = $2 + 2 | 0; //@line 40724
 HEAP32[162769] = $3; //@line 40725
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40727
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 40734
 HEAP32[162769] = $2 + 4; //@line 40736
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 40737
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40739
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40743
 HEAP32[96444] = 0; //@line 40748
 HEAP32[96442] = ($20 & 32767 | 0) == 0 & 1; //@line 40749
 HEAP32[96443] = $20 >>> 14 & 1; //@line 40752
 $26 = $20 >>> 15 & 1; //@line 40754
 HEAP32[96441] = $26; //@line 40755
 HEAP32[96445] = $26; //@line 40756
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $20 << 1 & 65534); //@line 40761
 return;
}
function __Z12op_21f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $24 = 0, $25 = 0, $34 = 0, $36 = 0;
 $1 = HEAP32[162769] | 0; //@line 33959
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 33968
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 33982
 $25 = HEAP32[162769] | 0; //@line 33983
 $34 = ((HEAPU8[$25 + 6 >> 0] | 0) << 8 | (HEAPU8[$25 + 7 >> 0] | 0)) << 16 >> 16; //@line 33993
 $36 = ($24 | 0) == 0 & 1; //@line 33995
 HEAP32[96441] = 0; //@line 33996
 HEAP32[96442] = 0; //@line 33996
 HEAP32[96443] = 0; //@line 33996
 HEAP32[96444] = 0; //@line 33996
 HEAP32[96442] = $36; //@line 33997
 HEAP32[96443] = $24 >>> 31; //@line 33999
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($34 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($34, $24); //@line 34005
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 34008
 return;
}
function __Z10op_39_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $1 = HEAP32[162769] | 0; //@line 4989
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 4991
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 5000
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 5009
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 5011
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0 | $3 & 255; //@line 5017
 $30 = $29 << 24 >> 24; //@line 5019
 $32 = ($30 | 0) == 0 & 1; //@line 5021
 HEAP32[96441] = 0; //@line 5022
 HEAP32[96442] = 0; //@line 5022
 HEAP32[96443] = 0; //@line 5022
 HEAP32[96444] = 0; //@line 5022
 HEAP32[96442] = $32; //@line 5023
 HEAP32[96443] = $29 >>> 7 & 1; //@line 5026
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, $30); //@line 5030
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 5033
 return;
}
function __Z12op_21e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $19 = 0, $20 = 0, $29 = 0, $31 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 33805
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 33816
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 33821
 $20 = HEAP32[162769] | 0; //@line 33822
 $29 = ((HEAPU8[$20 + 4 >> 0] | 0) << 8 | (HEAPU8[$20 + 5 >> 0] | 0)) << 16 >> 16; //@line 33832
 $31 = ($19 | 0) == 0 & 1; //@line 33834
 HEAP32[96441] = 0; //@line 33835
 HEAP32[96442] = 0; //@line 33835
 HEAP32[96443] = 0; //@line 33835
 HEAP32[96444] = 0; //@line 33835
 HEAP32[96442] = $31; //@line 33836
 HEAP32[96443] = $19 >>> 31; //@line 33838
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($29, $19); //@line 33844
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 33847
 return;
}
function __Z12op_1110_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 24890
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24892
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 24898
 $12 = 651040 + ($3 << 2) | 0; //@line 24899
 $16 = (HEAP32[$12 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 24903
 HEAP32[$12 >> 2] = $16; //@line 24904
 $17 = $11 << 24 >> 24; //@line 24906
 $19 = ($17 | 0) == 0 & 1; //@line 24908
 HEAP32[96441] = 0; //@line 24909
 HEAP32[96442] = 0; //@line 24909
 HEAP32[96443] = 0; //@line 24909
 HEAP32[96444] = 0; //@line 24909
 HEAP32[96442] = $19; //@line 24910
 HEAP32[96443] = $11 >>> 7 & 1; //@line 24913
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, $17); //@line 24919
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24922
 return;
}
function __Z12op_e4f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $13 = 0, $15 = 0, $19 = 0, $20 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 50011
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 50020
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 50022
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 50026
 $20 = $19 & 1; //@line 50027
 $21 = $19 >>> 1; //@line 50028
 $$ = (HEAP32[96445] | 0) == 0 ? $21 & 32767 : $21 | 32768; //@line 50033
 HEAP32[96444] = 0; //@line 50037
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 50038
 HEAP32[96443] = $$ >>> 15 & 1; //@line 50041
 HEAP32[96441] = $20; //@line 50042
 HEAP32[96445] = $20; //@line 50043
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $$ & 65535); //@line 50048
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50051
 return;
}
function __Z12op_e1f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $13 = 0, $15 = 0, $19 = 0, $20 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49871
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 49880
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49882
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 49886
 $20 = $19 & 32768; //@line 49887
 $21 = $19 << 1; //@line 49888
 HEAP32[96442] = ($19 & 32767 | 0) == 0 & 1; //@line 49893
 HEAP32[96443] = $19 >>> 14 & 1; //@line 49896
 $$lobit = $20 >>> 15; //@line 49898
 HEAP32[96441] = $$lobit; //@line 49899
 HEAP32[96445] = $$lobit; //@line 49900
 HEAP32[96444] = ($21 & 32768 ^ $20) >>> 15; //@line 49903
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $21 & 131070); //@line 49907
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49910
 return;
}
function __Z12op_4eb0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $19 = 0, $2 = 0, $21 = 0, $3 = 0, $32 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 753
 $3 = $2 + 2 | 0; //@line 754
 HEAP32[162769] = $3; //@line 755
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 757
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 764
 HEAP32[162769] = $2 + 4; //@line 766
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 767
 $19 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 772
 $21 = (HEAP32[162767] | 0) + -4 | 0; //@line 774
 HEAP32[162767] = $21; //@line 775
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($21, $19); //@line 781
 $32 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 787
 HEAP32[162770] = $32; //@line 788
 HEAP32[162769] = $32; //@line 789
 HEAP32[162768] = $14; //@line 790
 return;
}
function __Z12op_c0fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $28 = 0, $30 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36197
 $$cast = $4; //@line 36202
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36211
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36217
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36218
 $28 = Math_imul(HEAP32[$24 >> 2] & 65535, $23 & 65535) | 0; //@line 36222
 $30 = ($28 | 0) == 0 & 1; //@line 36224
 HEAP32[96441] = 0; //@line 36225
 HEAP32[96442] = 0; //@line 36225
 HEAP32[96443] = 0; //@line 36225
 HEAP32[96444] = 0; //@line 36225
 HEAP32[96442] = $30; //@line 36226
 HEAP32[96443] = $28 >>> 31; //@line 36228
 HEAP32[$24 >> 2] = $28; //@line 36229
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36232
 return;
}
function __Z12op_c058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $4 = 0, $5 = 0, $sext2223 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28424
 $5 = HEAP32[$4 >> 2] | 0; //@line 28425
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 28431
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 28434
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28435
 $15 = HEAP32[$14 >> 2] | 0; //@line 28436
 $sext2223 = $15 & $11; //@line 28437
 $16 = $sext2223 << 16 >> 16; //@line 28439
 $18 = ($16 | 0) == 0 & 1; //@line 28441
 HEAP32[96441] = 0; //@line 28442
 HEAP32[96442] = 0; //@line 28442
 HEAP32[96443] = 0; //@line 28442
 HEAP32[96444] = 0; //@line 28442
 HEAP32[96442] = $18; //@line 28443
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 28446
 HEAP32[$14 >> 2] = $15 & -65536 | $16 & 65535; //@line 28450
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28453
 return;
}
function __Z12op_8058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $15 = 0, $16 = 0, $18 = 0, $4 = 0, $5 = 0, $sext2223 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 14100
 $5 = HEAP32[$4 >> 2] | 0; //@line 14101
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 14107
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 14110
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14111
 $15 = HEAP32[$14 >> 2] | 0; //@line 14112
 $sext2223 = $15 | $11; //@line 14113
 $16 = $sext2223 << 16 >> 16; //@line 14115
 $18 = ($16 | 0) == 0 & 1; //@line 14117
 HEAP32[96441] = 0; //@line 14118
 HEAP32[96442] = 0; //@line 14118
 HEAP32[96443] = 0; //@line 14118
 HEAP32[96444] = 0; //@line 14118
 HEAP32[96442] = $18; //@line 14119
 HEAP32[96443] = $sext2223 >>> 15 & 1; //@line 14122
 HEAP32[$14 >> 2] = $15 & -65536 | $16 & 65535; //@line 14126
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14129
 return;
}
function __Z12op_d048_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 31925
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31926
 $7 = HEAP32[$6 >> 2] | 0; //@line 31927
 $8 = $7 << 16 >> 16; //@line 31929
 $10 = $8 + ($5 << 16 >> 16) | 0; //@line 31932
 $13 = $10 >>> 15; //@line 31936
 $sext36$lobit = $13 & 1; //@line 31937
 $sext36$mask = $10 & 65535; //@line 31938
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 31941
 HEAP32[96444] = ($sext36$lobit ^ $7 >>> 15 & 1) & ($13 ^ $5 >>> 15); //@line 31945
 $23 = ($8 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 31950
 HEAP32[96441] = $23; //@line 31951
 HEAP32[96445] = $23; //@line 31952
 HEAP32[96443] = $sext36$lobit; //@line 31953
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 31956
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31959
 return;
}
function __Z12op_d040_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 31879
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31880
 $7 = HEAP32[$6 >> 2] | 0; //@line 31881
 $8 = $7 << 16 >> 16; //@line 31883
 $10 = $8 + ($5 << 16 >> 16) | 0; //@line 31886
 $13 = $10 >>> 15; //@line 31890
 $sext36$lobit = $13 & 1; //@line 31891
 $sext36$mask = $10 & 65535; //@line 31892
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 31895
 HEAP32[96444] = ($sext36$lobit ^ $7 >>> 15 & 1) & ($13 ^ $5 >>> 15); //@line 31899
 $23 = ($8 & 65535 ^ 65535) >>> 0 < ($5 & 65535) >>> 0 & 1; //@line 31904
 HEAP32[96441] = $23; //@line 31905
 HEAP32[96445] = $23; //@line 31906
 HEAP32[96443] = $sext36$lobit; //@line 31907
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 31910
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31913
 return;
}
function __Z12op_d03c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $23 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $sext27$lobit = 0, $sext27$mask = 0;
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 31833
 $7 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31835
 $8 = HEAP32[$7 >> 2] | 0; //@line 31836
 $9 = $8 << 24 >> 24; //@line 31838
 $11 = $9 + ($5 << 24 >> 24) | 0; //@line 31840
 $14 = $11 >>> 7; //@line 31845
 $sext27$lobit = $14 & 1; //@line 31846
 $sext27$mask = $11 & 255; //@line 31847
 HEAP32[96442] = ($sext27$mask | 0) == 0 & 1; //@line 31850
 HEAP32[96444] = ($sext27$lobit ^ $8 >>> 7 & 1) & ($14 ^ ($5 & 255) >>> 7 & 255); //@line 31854
 $23 = ($9 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 31858
 HEAP32[96441] = $23; //@line 31859
 HEAP32[96445] = $23; //@line 31860
 HEAP32[96443] = $sext27$lobit; //@line 31861
 HEAP32[$7 >> 2] = $sext27$mask | $8 & -256; //@line 31864
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31867
 return;
}
function __Z12op_10a0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $16 = 0, $17 = 0, $19 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 23941
 $4 = 651040 + ($1 << 2) | 0; //@line 23944
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 23948
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 23954
 HEAP32[$4 >> 2] = $8; //@line 23955
 $16 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23957
 $17 = $14 << 24 >> 24; //@line 23959
 $19 = ($17 | 0) == 0 & 1; //@line 23961
 HEAP32[96441] = 0; //@line 23962
 HEAP32[96442] = 0; //@line 23962
 HEAP32[96443] = 0; //@line 23962
 HEAP32[96444] = 0; //@line 23962
 HEAP32[96442] = $19; //@line 23963
 HEAP32[96443] = $14 >>> 7 & 1; //@line 23966
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, $17); //@line 23972
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23975
 return;
}
function __Z12op_10d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 24355
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24357
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 24363
 $12 = 651040 + ($3 << 2) | 0; //@line 24364
 $13 = HEAP32[$12 >> 2] | 0; //@line 24365
 HEAP32[$12 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $13; //@line 24369
 $17 = $11 << 24 >> 24; //@line 24371
 $19 = ($17 | 0) == 0 & 1; //@line 24373
 HEAP32[96441] = 0; //@line 24374
 HEAP32[96442] = 0; //@line 24374
 HEAP32[96443] = 0; //@line 24374
 HEAP32[96444] = 0; //@line 24374
 HEAP32[96442] = $19; //@line 24375
 HEAP32[96443] = $11 >>> 7 & 1; //@line 24378
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $17); //@line 24384
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24387
 return;
}
function __Z12op_c1fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 31096
 $$cast = $4; //@line 31098
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 31112
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 31118
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31119
 $29 = Math_imul(HEAP32[$25 >> 2] << 16 >> 16, $24 << 16 >> 16) | 0; //@line 31125
 $31 = ($29 | 0) == 0 & 1; //@line 31127
 HEAP32[96441] = 0; //@line 31128
 HEAP32[96442] = 0; //@line 31128
 HEAP32[96443] = 0; //@line 31128
 HEAP32[96444] = 0; //@line 31128
 HEAP32[96442] = $31; //@line 31129
 HEAP32[96443] = $29 >>> 31; //@line 31131
 HEAP32[$25 >> 2] = $29; //@line 31132
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31135
 return;
}
function __Z12op_e4e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $14 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 41000
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41011
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41013
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41017
 $21 = $20 & 1; //@line 41018
 $22 = $20 >>> 1; //@line 41019
 $$ = (HEAP32[96445] | 0) == 0 ? $22 & 32767 : $22 | 32768; //@line 41024
 HEAP32[96444] = 0; //@line 41028
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41029
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41032
 HEAP32[96441] = $21; //@line 41033
 HEAP32[96445] = $21; //@line 41034
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41039
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41042
 return;
}
function __Z12op_e1e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $14 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 40071
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 40082
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40084
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40088
 $21 = $20 & 32768; //@line 40089
 $22 = $20 << 1; //@line 40090
 HEAP32[96442] = ($20 & 32767 | 0) == 0 & 1; //@line 40095
 HEAP32[96443] = $20 >>> 14 & 1; //@line 40098
 $$lobit = $21 >>> 15; //@line 40100
 HEAP32[96441] = $$lobit; //@line 40101
 HEAP32[96445] = $$lobit; //@line 40102
 HEAP32[96444] = ($22 & 32768 ^ $21) >>> 15; //@line 40105
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22 & 131070); //@line 40109
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40112
 return;
}
function __Z12op_b058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $15 = 0, $16 = 0, $4 = 0, $5 = 0, $sext$lobit = 0, $sext37$lobit = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 24583
 $5 = HEAP32[$4 >> 2] | 0; //@line 24584
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 24590
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 24593
 $15 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24595
 $16 = $15 - $11 | 0; //@line 24596
 $sext$lobit = $15 >>> 15 & 1; //@line 24600
 $sext37$lobit = $16 >>> 15 & 1; //@line 24602
 HEAP32[96442] = ($16 & 65535 | 0) == 0 & 1; //@line 24606
 HEAP32[96444] = ($11 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext37$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24611
 HEAP32[96441] = ($11 & 65535) >>> 0 > ($15 & 65535) >>> 0 & 1; //@line 24616
 HEAP32[96443] = $sext37$lobit; //@line 24617
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24620
 return;
}
function __Z12op_90bc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit30 = 0, $$lobit31 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $31 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 19463
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 19466
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 19481
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19482
 $23 = HEAP32[$22 >> 2] | 0; //@line 19483
 $24 = $23 - $21 | 0; //@line 19484
 $$lobit30 = $23 >>> 31; //@line 19486
 $$lobit31 = $24 >>> 31; //@line 19487
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 19490
 HEAP32[96444] = ($$lobit31 ^ $$lobit30) & ($$lobit30 ^ $6 >>> 7); //@line 19494
 $31 = $23 >>> 0 < $21 >>> 0 & 1; //@line 19496
 HEAP32[96441] = $31; //@line 19497
 HEAP32[96445] = $31; //@line 19498
 HEAP32[96443] = $$lobit31; //@line 19499
 HEAP32[$22 >> 2] = $24; //@line 19500
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19503
 return;
}
function __Z12op_20bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $24 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32239
 $$cast = $4; //@line 32244
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 32253
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32258
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 32260
 $26 = ($22 | 0) == 0 & 1; //@line 32262
 HEAP32[96441] = 0; //@line 32263
 HEAP32[96442] = 0; //@line 32263
 HEAP32[96443] = 0; //@line 32263
 HEAP32[96444] = 0; //@line 32263
 HEAP32[96442] = $26; //@line 32264
 HEAP32[96443] = $22 >>> 31; //@line 32266
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $22); //@line 32272
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32275
 return;
}
function __Z12op_3190_3_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $23 = 0, $24 = 0, $26 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 44871
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 44877
 $14 = HEAP32[162769] | 0; //@line 44880
 $23 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) | 0; //@line 44889
 $24 = $11 << 16 >> 16; //@line 44891
 $26 = ($24 | 0) == 0 & 1; //@line 44893
 HEAP32[96441] = 0; //@line 44894
 HEAP32[96442] = 0; //@line 44894
 HEAP32[96443] = 0; //@line 44894
 HEAP32[96444] = 0; //@line 44894
 HEAP32[96442] = $26; //@line 44895
 HEAP32[96443] = $11 >>> 15 & 1; //@line 44898
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($23, $24); //@line 44904
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44907
 return;
}
function __Z12op_30b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 44355
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44364
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 44370
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 44372
 $24 = $21 << 16 >> 16; //@line 44374
 $26 = ($24 | 0) == 0 & 1; //@line 44376
 HEAP32[96441] = 0; //@line 44377
 HEAP32[96442] = 0; //@line 44377
 HEAP32[96443] = 0; //@line 44377
 HEAP32[96444] = 0; //@line 44377
 HEAP32[96442] = $26; //@line 44378
 HEAP32[96443] = $21 >>> 15 & 1; //@line 44381
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($23, $24); //@line 44387
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44390
 return;
}
function __Z11op_a30_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 17662
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17664
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17675
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 17677
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0) ^ $4 & 255; //@line 17683
 $24 = $23 << 24 >> 24; //@line 17685
 $26 = ($24 | 0) == 0 & 1; //@line 17687
 HEAP32[96441] = 0; //@line 17688
 HEAP32[96442] = 0; //@line 17688
 HEAP32[96443] = 0; //@line 17688
 HEAP32[96444] = 0; //@line 17688
 HEAP32[96442] = $26; //@line 17689
 HEAP32[96443] = $23 >>> 7 & 1; //@line 17692
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, $24); //@line 17696
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17699
 return;
}
function __Z12op_d098_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit39 = 0, $10 = 0, $13 = 0, $14 = 0, $15 = 0, $23 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32685
 $5 = HEAP32[$4 >> 2] | 0; //@line 32686
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 32691
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 32694
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32695
 $14 = HEAP32[$13 >> 2] | 0; //@line 32696
 $15 = $14 + $10 | 0; //@line 32697
 $$lobit39 = $15 >>> 31; //@line 32700
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 32703
 HEAP32[96444] = ($$lobit39 ^ $10 >>> 31) & ($$lobit39 ^ $14 >>> 31); //@line 32707
 $23 = $10 >>> 0 > ~$14 >>> 0 & 1; //@line 32710
 HEAP32[96441] = $23; //@line 32711
 HEAP32[96445] = $23; //@line 32712
 HEAP32[96443] = $$lobit39; //@line 32713
 HEAP32[$13 >> 2] = $15; //@line 32714
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32717
 return;
}
function __Z12op_1190_3_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $23 = 0, $24 = 0, $26 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 31241
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 31247
 $14 = HEAP32[162769] | 0; //@line 31250
 $23 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) | 0; //@line 31259
 $24 = $11 << 24 >> 24; //@line 31261
 $26 = ($24 | 0) == 0 & 1; //@line 31263
 HEAP32[96441] = 0; //@line 31264
 HEAP32[96442] = 0; //@line 31264
 HEAP32[96443] = 0; //@line 31264
 HEAP32[96444] = 0; //@line 31264
 HEAP32[96442] = $26; //@line 31265
 HEAP32[96443] = $11 >>> 7 & 1; //@line 31268
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, $24); //@line 31274
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31277
 return;
}
function __Z12op_10b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $23 = 0, $24 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 30757
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 30766
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 30772
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30774
 $24 = $21 << 24 >> 24; //@line 30776
 $26 = ($24 | 0) == 0 & 1; //@line 30778
 HEAP32[96441] = 0; //@line 30779
 HEAP32[96442] = 0; //@line 30779
 HEAP32[96443] = 0; //@line 30779
 HEAP32[96444] = 0; //@line 30779
 HEAP32[96442] = $26; //@line 30780
 HEAP32[96443] = $21 >>> 7 & 1; //@line 30783
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($23, $24); //@line 30789
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30792
 return;
}
function __Z11op_600_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $22 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $sext27$lobit = 0, $sext27$mask = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 12201
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 12203
 $7 = HEAP32[$6 >> 2] | 0; //@line 12204
 $8 = $7 << 24 >> 24; //@line 12206
 $10 = $8 + ($4 << 24 >> 24) | 0; //@line 12208
 $13 = $10 >>> 7; //@line 12213
 $sext27$lobit = $13 & 1; //@line 12214
 $sext27$mask = $10 & 255; //@line 12215
 HEAP32[96442] = ($sext27$mask | 0) == 0 & 1; //@line 12218
 HEAP32[96444] = ($sext27$lobit ^ $7 >>> 7 & 1) & ($13 ^ ($4 & 255) >>> 7 & 255); //@line 12222
 $22 = ($8 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 12226
 HEAP32[96441] = $22; //@line 12227
 HEAP32[96445] = $22; //@line 12228
 HEAP32[96443] = $sext27$lobit; //@line 12229
 HEAP32[$6 >> 2] = $sext27$mask | $7 & -256; //@line 12232
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12235
 return;
}
function __Z12op_9190_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $12 = 0, $13 = 0, $20 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21091
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21093
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 21095
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 21098
 $13 = $12 - $5 | 0; //@line 21099
 $$lobit37 = $12 >>> 31; //@line 21101
 $$lobit38 = $13 >>> 31; //@line 21102
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 21105
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $5 >>> 31); //@line 21109
 $20 = $12 >>> 0 < $5 >>> 0 & 1; //@line 21111
 HEAP32[96441] = $20; //@line 21112
 HEAP32[96445] = $20; //@line 21113
 HEAP32[96443] = $$lobit38; //@line 21114
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 21118
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21121
 return;
}
function __Z12op_4628_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $4 = 0, $sext13 = 0;
 $4 = HEAP32[162769] | 0; //@line 48395
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 48406
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 48408
 $sext13 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24; //@line 48413
 $21 = $sext13 >> 24; //@line 48414
 $22 = ~$21; //@line 48415
 $24 = ($21 | 0) == -1 & 1; //@line 48417
 HEAP32[96441] = 0; //@line 48418
 HEAP32[96442] = 0; //@line 48418
 HEAP32[96443] = 0; //@line 48418
 HEAP32[96444] = 0; //@line 48418
 HEAP32[96442] = $24; //@line 48419
 HEAP32[96443] = ($sext13 | 0) > -16777216 & 1; //@line 48422
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $22); //@line 48426
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48429
 return;
}
function __Z11op_a78_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $9 = 0, $sext1314 = 0;
 $1 = HEAP32[162769] | 0; //@line 16105
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 16113
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 16123
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16125
 $sext1314 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) ^ $9; //@line 16130
 $25 = $sext1314 << 16 >> 16; //@line 16132
 $27 = ($25 | 0) == 0 & 1; //@line 16134
 HEAP32[96441] = 0; //@line 16135
 HEAP32[96442] = 0; //@line 16135
 HEAP32[96443] = 0; //@line 16135
 HEAP32[96444] = 0; //@line 16135
 HEAP32[96442] = $27; //@line 16136
 HEAP32[96443] = $sext1314 >>> 15 & 1; //@line 16139
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 16143
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16146
 return;
}
function __Z11op_230_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 16748
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 16750
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16761
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 16763
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0) & ($4 & 255); //@line 16769
 $24 = $23 << 24 >> 24; //@line 16771
 $26 = ($24 | 0) == 0 & 1; //@line 16773
 HEAP32[96441] = 0; //@line 16774
 HEAP32[96442] = 0; //@line 16774
 HEAP32[96443] = 0; //@line 16774
 HEAP32[96444] = 0; //@line 16774
 HEAP32[96442] = $26; //@line 16775
 HEAP32[96443] = $23 >>> 7; //@line 16777
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, $24); //@line 16781
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16784
 return;
}
function __Z12op_b078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $20 = 0, $21 = 0, $3 = 0, $sext31$lobit = 0, $sext33$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 24792
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 24802
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 24808
 $20 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24810
 $21 = $20 - $18 | 0; //@line 24811
 $sext31$lobit = $20 >>> 15 & 1; //@line 24815
 $sext33$lobit = $21 >>> 15 & 1; //@line 24817
 HEAP32[96442] = ($21 & 65535 | 0) == 0 & 1; //@line 24821
 HEAP32[96444] = ($18 >>> 15 & 1 | 0) != ($sext31$lobit | 0) & ($sext33$lobit | 0) != ($sext31$lobit | 0) & 1; //@line 24826
 HEAP32[96441] = ($18 & 65535) >>> 0 > ($20 & 65535) >>> 0 & 1; //@line 24831
 HEAP32[96443] = $sext33$lobit; //@line 24832
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24835
 return;
}
function __Z12op_30b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $3 = HEAP32[162769] | 0; //@line 36046
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 36055
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 36070
 $29 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36072
 $30 = $27 << 16 >> 16; //@line 36074
 $32 = ($30 | 0) == 0 & 1; //@line 36076
 HEAP32[96441] = 0; //@line 36077
 HEAP32[96442] = 0; //@line 36077
 HEAP32[96443] = 0; //@line 36077
 HEAP32[96444] = 0; //@line 36077
 HEAP32[96442] = $32; //@line 36078
 HEAP32[96443] = $27 >>> 15 & 1; //@line 36081
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($29, $30); //@line 36087
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 36090
 return;
}
function __Z11op_c38_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $19 = 0, $20 = 0, $3 = 0, $4 = 0, $sext23$lobit = 0, $sext24$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 19061
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 19063
 $4 = $3 & 255; //@line 19064
 $13 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 19074
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 19080
 $20 = $19 - $4 | 0; //@line 19081
 $sext23$lobit = $19 >>> 7 & 1; //@line 19085
 $sext24$lobit = $20 >>> 7 & 1; //@line 19087
 HEAP32[96442] = ($20 & 255 | 0) == 0 & 1; //@line 19091
 HEAP32[96444] = (($3 & 255) >>> 7 & 255 | 0) != ($sext23$lobit | 0) & ($sext24$lobit | 0) != ($sext23$lobit | 0) & 1; //@line 19096
 HEAP32[96441] = $4 >>> 0 > ($19 & 255) >>> 0 & 1; //@line 19100
 HEAP32[96443] = $sext24$lobit; //@line 19101
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19104
 return;
}
function __Z10op_30_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 16213
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 16215
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 16226
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 16228
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0 | $4 & 255; //@line 16234
 $24 = $23 << 24 >> 24; //@line 16236
 $26 = ($24 | 0) == 0 & 1; //@line 16238
 HEAP32[96441] = 0; //@line 16239
 HEAP32[96442] = 0; //@line 16239
 HEAP32[96443] = 0; //@line 16239
 HEAP32[96444] = 0; //@line 16239
 HEAP32[96442] = $26; //@line 16240
 HEAP32[96443] = $23 >>> 7 & 1; //@line 16243
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, $24); //@line 16247
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16250
 return;
}
function __Z12op_c0fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 29556
 $$cast = $4; //@line 29558
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 29572
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 29578
 $25 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29579
 $29 = Math_imul(HEAP32[$25 >> 2] & 65535, $24 & 65535) | 0; //@line 29583
 $31 = ($29 | 0) == 0 & 1; //@line 29585
 HEAP32[96441] = 0; //@line 29586
 HEAP32[96442] = 0; //@line 29586
 HEAP32[96443] = 0; //@line 29586
 HEAP32[96444] = 0; //@line 29586
 HEAP32[96442] = $31; //@line 29587
 HEAP32[96443] = $29 >>> 31; //@line 29589
 HEAP32[$25 >> 2] = $29; //@line 29590
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29593
 return;
}
function __Z12op_10b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $3 = HEAP32[162769] | 0; //@line 24130
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 24139
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 24154
 $29 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24156
 $30 = $27 << 24 >> 24; //@line 24158
 $32 = ($30 | 0) == 0 & 1; //@line 24160
 HEAP32[96441] = 0; //@line 24161
 HEAP32[96442] = 0; //@line 24161
 HEAP32[96443] = 0; //@line 24161
 HEAP32[96444] = 0; //@line 24161
 HEAP32[96442] = $32; //@line 24162
 HEAP32[96443] = $27 >>> 7 & 1; //@line 24165
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($29 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($29, $30); //@line 24171
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 24174
 return;
}
function __Z12op_c060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $sext2324 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28464
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 28466
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 28472
 HEAP32[$4 >> 2] = $6; //@line 28473
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28474
 $14 = HEAP32[$13 >> 2] | 0; //@line 28475
 $sext2324 = $14 & $12; //@line 28476
 $15 = $sext2324 << 16 >> 16; //@line 28478
 $17 = ($15 | 0) == 0 & 1; //@line 28480
 HEAP32[96441] = 0; //@line 28481
 HEAP32[96442] = 0; //@line 28481
 HEAP32[96443] = 0; //@line 28481
 HEAP32[96444] = 0; //@line 28481
 HEAP32[96442] = $17; //@line 28482
 HEAP32[96443] = $sext2324 >>> 15 & 1; //@line 28485
 HEAP32[$13 >> 2] = $14 & -65536 | $15 & 65535; //@line 28489
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28492
 return;
}
function __Z12op_8060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $sext2324 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 14140
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 14142
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 14148
 HEAP32[$4 >> 2] = $6; //@line 14149
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14150
 $14 = HEAP32[$13 >> 2] | 0; //@line 14151
 $sext2324 = $14 | $12; //@line 14152
 $15 = $sext2324 << 16 >> 16; //@line 14154
 $17 = ($15 | 0) == 0 & 1; //@line 14156
 HEAP32[96441] = 0; //@line 14157
 HEAP32[96442] = 0; //@line 14157
 HEAP32[96443] = 0; //@line 14157
 HEAP32[96444] = 0; //@line 14157
 HEAP32[96442] = $17; //@line 14158
 HEAP32[96443] = $sext2324 >>> 15 & 1; //@line 14161
 HEAP32[$13 >> 2] = $14 & -65536 | $15 & 65535; //@line 14165
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14168
 return;
}
function __Z12op_4668_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $4 = 0, $sext15 = 0;
 $4 = HEAP32[162769] | 0; //@line 48703
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 48714
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 48716
 $sext15 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0) << 16; //@line 48721
 $21 = $sext15 >> 16; //@line 48722
 $22 = ~$21; //@line 48723
 $24 = ($21 | 0) == -1 & 1; //@line 48725
 HEAP32[96441] = 0; //@line 48726
 HEAP32[96442] = 0; //@line 48726
 HEAP32[96443] = 0; //@line 48726
 HEAP32[96444] = 0; //@line 48726
 HEAP32[96442] = $24; //@line 48727
 HEAP32[96443] = ($sext15 | 0) > -65536 & 1; //@line 48730
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $22); //@line 48734
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48737
 return;
}
function __Z12op_3150_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $24 = 0, $25 = 0, $27 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 37427
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 37433
 $14 = HEAP32[162769] | 0; //@line 37436
 $24 = (((HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37447
 $25 = $11 << 16 >> 16; //@line 37449
 $27 = ($25 | 0) == 0 & 1; //@line 37451
 HEAP32[96441] = 0; //@line 37452
 HEAP32[96442] = 0; //@line 37452
 HEAP32[96443] = 0; //@line 37452
 HEAP32[96444] = 0; //@line 37452
 HEAP32[96442] = $27; //@line 37453
 HEAP32[96443] = $11 >>> 15 & 1; //@line 37456
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 37462
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37465
 return;
}
function __Z12op_30a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 35904
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 35915
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 35921
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35923
 $25 = $22 << 16 >> 16; //@line 35925
 $27 = ($25 | 0) == 0 & 1; //@line 35927
 HEAP32[96441] = 0; //@line 35928
 HEAP32[96442] = 0; //@line 35928
 HEAP32[96443] = 0; //@line 35928
 HEAP32[96444] = 0; //@line 35928
 HEAP32[96442] = $27; //@line 35929
 HEAP32[96443] = $22 >>> 15 & 1; //@line 35932
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($24, $25); //@line 35938
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35941
 return;
}
function __Z11op_a28_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 15623
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 15625
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 15638
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 15640
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) ^ $4 & 255; //@line 15646
 $25 = $24 << 24 >> 24; //@line 15648
 $27 = ($25 | 0) == 0 & 1; //@line 15650
 HEAP32[96441] = 0; //@line 15651
 HEAP32[96442] = 0; //@line 15651
 HEAP32[96443] = 0; //@line 15651
 HEAP32[96444] = 0; //@line 15651
 HEAP32[96442] = $27; //@line 15652
 HEAP32[96443] = $24 >>> 7 & 1; //@line 15655
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 15659
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15662
 return;
}
function __Z11op_480_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit30 = 0, $$lobit31 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $30 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11190
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 11193
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 11208
 $21 = 651008 + (($0 & 7) << 2) | 0; //@line 11209
 $22 = HEAP32[$21 >> 2] | 0; //@line 11210
 $23 = $22 - $20 | 0; //@line 11211
 $$lobit30 = $22 >>> 31; //@line 11213
 $$lobit31 = $23 >>> 31; //@line 11214
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 11217
 HEAP32[96444] = ($$lobit31 ^ $$lobit30) & ($$lobit30 ^ $5 >>> 7); //@line 11221
 $30 = $22 >>> 0 < $20 >>> 0 & 1; //@line 11223
 HEAP32[96441] = $30; //@line 11224
 HEAP32[96445] = $30; //@line 11225
 HEAP32[96443] = $$lobit31; //@line 11226
 HEAP32[$21 >> 2] = $23; //@line 11227
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11230
 return;
}
function __Z12op_e6f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 41818
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 41827
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 41836
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41838
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 41842
 $26 = $25 & 1; //@line 41843
 $27 = $25 >>> 1; //@line 41844
 $$ = ($26 | 0) == 0 ? $27 & 32767 : $27 | 32768; //@line 41848
 HEAP32[96444] = 0; //@line 41852
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41853
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41856
 HEAP32[96441] = $26; //@line 41857
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $$ & 65535); //@line 41862
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41865
 return;
}
function __Z12op_c078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $sext1819 = 0;
 $3 = HEAP32[162769] | 0; //@line 28598
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 28608
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 28614
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28615
 $20 = HEAP32[$19 >> 2] | 0; //@line 28616
 $sext1819 = $20 & $18; //@line 28617
 $21 = $sext1819 << 16 >> 16; //@line 28619
 $23 = ($21 | 0) == 0 & 1; //@line 28621
 HEAP32[96441] = 0; //@line 28622
 HEAP32[96442] = 0; //@line 28622
 HEAP32[96443] = 0; //@line 28622
 HEAP32[96444] = 0; //@line 28622
 HEAP32[96442] = $23; //@line 28623
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 28626
 HEAP32[$19 >> 2] = $20 & -65536 | $21 & 65535; //@line 28630
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28633
 return;
}
function __Z12op_8078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $sext1819 = 0;
 $3 = HEAP32[162769] | 0; //@line 14274
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 14284
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 14290
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14291
 $20 = HEAP32[$19 >> 2] | 0; //@line 14292
 $sext1819 = $20 | $18; //@line 14293
 $21 = $sext1819 << 16 >> 16; //@line 14295
 $23 = ($21 | 0) == 0 & 1; //@line 14297
 HEAP32[96441] = 0; //@line 14298
 HEAP32[96442] = 0; //@line 14298
 HEAP32[96443] = 0; //@line 14298
 HEAP32[96444] = 0; //@line 14298
 HEAP32[96442] = $23; //@line 14299
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 14302
 HEAP32[$19 >> 2] = $20 & -65536 | $21 & 65535; //@line 14306
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14309
 return;
}
function __Z12op_1150_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $24 = 0, $25 = 0, $27 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25435
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 25441
 $14 = HEAP32[162769] | 0; //@line 25444
 $24 = (((HEAPU8[$14 + 2 >> 0] | 0) << 8 | (HEAPU8[$14 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25455
 $25 = $11 << 24 >> 24; //@line 25457
 $27 = ($25 | 0) == 0 & 1; //@line 25459
 HEAP32[96441] = 0; //@line 25460
 HEAP32[96442] = 0; //@line 25460
 HEAP32[96443] = 0; //@line 25460
 HEAP32[96444] = 0; //@line 25460
 HEAP32[96442] = $27; //@line 25461
 HEAP32[96443] = $11 >>> 7 & 1; //@line 25464
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $25); //@line 25470
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25473
 return;
}
function __Z12op_10a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 23988
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 23999
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 24005
 $24 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24007
 $25 = $22 << 24 >> 24; //@line 24009
 $27 = ($25 | 0) == 0 & 1; //@line 24011
 HEAP32[96441] = 0; //@line 24012
 HEAP32[96442] = 0; //@line 24012
 HEAP32[96443] = 0; //@line 24012
 HEAP32[96444] = 0; //@line 24012
 HEAP32[96442] = $27; //@line 24013
 HEAP32[96443] = $22 >>> 7 & 1; //@line 24016
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($24, $25); //@line 24022
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24025
 return;
}
function __Z12op_d000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 31229
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31230
 $7 = HEAP32[$6 >> 2] | 0; //@line 31231
 $8 = $7 << 24 >> 24; //@line 31233
 $10 = $8 + ($5 << 24 >> 24) | 0; //@line 31236
 $13 = $10 >>> 7; //@line 31240
 $sext32$lobit = $13 & 1; //@line 31241
 $sext32$mask = $10 & 255; //@line 31242
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 31245
 HEAP32[96444] = ($sext32$lobit ^ $7 >>> 7 & 1) & ($13 ^ $5 >>> 7); //@line 31249
 $23 = ($8 & 255 ^ 255) >>> 0 < ($5 & 255) >>> 0 & 1; //@line 31254
 HEAP32[96441] = $23; //@line 31255
 HEAP32[96445] = $23; //@line 31256
 HEAP32[96443] = $sext32$lobit; //@line 31257
 HEAP32[$6 >> 2] = $sext32$mask | $7 & -256; //@line 31260
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 31263
 return;
}
function __Z12op_c1b9_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30722
 $5 = HEAP32[162769] | 0; //@line 30723
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 30732
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 30741
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30743
 $29 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0) & $4; //@line 30747
 $31 = ($29 | 0) == 0 & 1; //@line 30749
 HEAP32[96441] = 0; //@line 30750
 HEAP32[96442] = 0; //@line 30750
 HEAP32[96443] = 0; //@line 30750
 HEAP32[96444] = 0; //@line 30750
 HEAP32[96442] = $31; //@line 30751
 HEAP32[96443] = $29 >>> 31; //@line 30753
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 30757
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30760
 return;
}
function __Z12op_b1b9_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27292
 $5 = HEAP32[162769] | 0; //@line 27293
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 27302
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 27311
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 27313
 $29 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0) ^ $4; //@line 27317
 $31 = ($29 | 0) == 0 & 1; //@line 27319
 HEAP32[96441] = 0; //@line 27320
 HEAP32[96442] = 0; //@line 27320
 HEAP32[96443] = 0; //@line 27320
 HEAP32[96444] = 0; //@line 27320
 HEAP32[96442] = $31; //@line 27321
 HEAP32[96443] = $29 >>> 31; //@line 27323
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 27327
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27330
 return;
}
function __Z12op_4af9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $27 = 0, $sext = 0;
 $1 = HEAP32[162769] | 0; //@line 52829
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 52838
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 52847
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 52849
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0; //@line 52853
 $sext = $25 << 24; //@line 52854
 $27 = ($sext | 0) == 0 & 1; //@line 52856
 HEAP32[96441] = 0; //@line 52857
 HEAP32[96442] = 0; //@line 52857
 HEAP32[96443] = 0; //@line 52857
 HEAP32[96444] = 0; //@line 52857
 HEAP32[96442] = $27; //@line 52858
 HEAP32[96443] = $25 >>> 7 & 1; //@line 52861
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, ($sext | -2147483648) >> 24); //@line 52867
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 52870
 return;
}
function __Z12op_1018_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $18 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 $1 = $0 & 7; //@line 23429
 $3 = $0 >>> 9 & 7; //@line 23431
 $4 = 651040 + ($1 << 2) | 0; //@line 23432
 $5 = HEAP32[$4 >> 2] | 0; //@line 23433
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 23439
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 23444
 $16 = $11 << 24 >> 24; //@line 23446
 $18 = ($16 | 0) == 0 & 1; //@line 23448
 HEAP32[96441] = 0; //@line 23449
 HEAP32[96442] = 0; //@line 23449
 HEAP32[96443] = 0; //@line 23449
 HEAP32[96444] = 0; //@line 23449
 HEAP32[96442] = $18; //@line 23450
 HEAP32[96443] = $11 >>> 7 & 1; //@line 23453
 $20 = 651008 + ($3 << 2) | 0; //@line 23454
 HEAP32[$20 >> 2] = HEAP32[$20 >> 2] & -256 | $16 & 255; //@line 23459
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23462
 return;
}
function __Z12op_20ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 28955
 $$cast = $4; //@line 28957
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 28971
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 28976
 $25 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28978
 $27 = ($23 | 0) == 0 & 1; //@line 28980
 HEAP32[96441] = 0; //@line 28981
 HEAP32[96442] = 0; //@line 28981
 HEAP32[96443] = 0; //@line 28981
 HEAP32[96444] = 0; //@line 28981
 HEAP32[96442] = $27; //@line 28982
 HEAP32[96443] = $23 >>> 31; //@line 28984
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $23); //@line 28990
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28993
 return;
}
function __Z12op_e5f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $34 = 0;
 $1 = HEAP32[162769] | 0; //@line 41491
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 41500
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 41509
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41511
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 41515
 $$ = (HEAP32[96445] | 0) != 0 | $25 << 1; //@line 41520
 HEAP32[96444] = 0; //@line 41524
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41525
 HEAP32[96443] = $25 >>> 14 & 1; //@line 41528
 $34 = $25 >>> 15 & 1; //@line 41530
 HEAP32[96441] = $34; //@line 41531
 HEAP32[96445] = $34; //@line 41532
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $$ & 65535); //@line 41537
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41540
 return;
}
function __Z12op_e0f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $27 = 0, $30 = 0;
 $1 = HEAP32[162769] | 0; //@line 38732
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 38741
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 38750
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 38752
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 38756
 $26 = $25 & 32768; //@line 38757
 $27 = $25 & 1; //@line 38758
 $30 = $25 >>> 1 & 32767 | $26; //@line 38761
 HEAP32[96444] = 0; //@line 38764
 HEAP32[96442] = ($30 | 0) == 0 & 1; //@line 38765
 HEAP32[96443] = $26 >>> 15; //@line 38767
 HEAP32[96441] = $27; //@line 38768
 HEAP32[96445] = $27; //@line 38769
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $30); //@line 38773
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 38776
 return;
}
function __Z12op_b060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $15 = 0, $4 = 0, $6 = 0, $sext$lobit = 0, $sext38$lobit = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 24631
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 24633
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 24639
 HEAP32[$4 >> 2] = $6; //@line 24640
 $14 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24642
 $15 = $14 - $12 | 0; //@line 24643
 $sext$lobit = $14 >>> 15 & 1; //@line 24647
 $sext38$lobit = $15 >>> 15 & 1; //@line 24649
 HEAP32[96442] = ($15 & 65535 | 0) == 0 & 1; //@line 24653
 HEAP32[96444] = ($12 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext38$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24658
 HEAP32[96441] = ($12 & 65535) >>> 0 > ($14 & 65535) >>> 0 & 1; //@line 24663
 HEAP32[96443] = $sext38$lobit; //@line 24664
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24667
 return;
}
function __Z12op_81b9_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $29 = 0, $31 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16815
 $5 = HEAP32[162769] | 0; //@line 16816
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 16825
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 16834
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 16836
 $29 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$25 >> 2] >> 2] & 127]($23) | 0 | $4; //@line 16840
 $31 = ($29 | 0) == 0 & 1; //@line 16842
 HEAP32[96441] = 0; //@line 16843
 HEAP32[96442] = 0; //@line 16843
 HEAP32[96443] = 0; //@line 16843
 HEAP32[96444] = 0; //@line 16843
 HEAP32[96442] = $31; //@line 16844
 HEAP32[96443] = $29 >>> 31; //@line 16846
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 12 >> 2] & 31]($23, $29); //@line 16850
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 16853
 return;
}
function __Z11op_c90_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $2 = 0, $20 = 0, $22 = 0, $27 = 0, $28 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 19887
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19890
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 19905
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19907
 $27 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($22 >>> 16 << 2) >> 2] >> 2] & 127]($22) | 0; //@line 19912
 $28 = $27 - $20 | 0; //@line 19913
 $$lobit31 = $27 >>> 31; //@line 19915
 $$lobit32 = $28 >>> 31; //@line 19916
 HEAP32[96442] = ($28 | 0) == 0 & 1; //@line 19919
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 19924
 HEAP32[96441] = $27 >>> 0 < $20 >>> 0 & 1; //@line 19927
 HEAP32[96443] = $$lobit32; //@line 19928
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19931
 return;
}
function __Z12op_c038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $sext1415 = 0;
 $3 = HEAP32[162769] | 0; //@line 28123
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 28133
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 28139
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28140
 $20 = HEAP32[$19 >> 2] | 0; //@line 28141
 $sext1415 = $20 & $18; //@line 28142
 $21 = $sext1415 << 24 >> 24; //@line 28144
 $23 = ($21 | 0) == 0 & 1; //@line 28146
 HEAP32[96441] = 0; //@line 28147
 HEAP32[96442] = 0; //@line 28147
 HEAP32[96443] = 0; //@line 28147
 HEAP32[96444] = 0; //@line 28147
 HEAP32[96442] = $23; //@line 28148
 HEAP32[96443] = $sext1415 >>> 7 & 1; //@line 28151
 HEAP32[$19 >> 2] = $20 & -256 | $21 & 255; //@line 28155
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28158
 return;
}
function __Z12op_8038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0, $sext1415 = 0;
 $3 = HEAP32[162769] | 0; //@line 13798
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 13808
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 13814
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13815
 $20 = HEAP32[$19 >> 2] | 0; //@line 13816
 $sext1415 = $20 | $18; //@line 13817
 $21 = $sext1415 << 24 >> 24; //@line 13819
 $23 = ($21 | 0) == 0 & 1; //@line 13821
 HEAP32[96441] = 0; //@line 13822
 HEAP32[96442] = 0; //@line 13822
 HEAP32[96443] = 0; //@line 13822
 HEAP32[96444] = 0; //@line 13822
 HEAP32[96442] = $23; //@line 13823
 HEAP32[96443] = $sext1415 >>> 7 & 1; //@line 13826
 HEAP32[$19 >> 2] = $20 & -256 | $21 & 255; //@line 13830
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13833
 return;
}
function __Z12op_4800_1_ffj($0) {
 $0 = $0 | 0;
 var $$026$in = 0, $10 = 0, $13 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $8 = 0, $sext27$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 1672
 $3 = HEAP32[$2 >> 2] | 0; //@line 1673
 $4 = $3 << 24 >> 24; //@line 1675
 $8 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($4 & 15) | 0; //@line 1680
 $10 = $8 & 65535; //@line 1682
 $13 = ($10 >>> 0 > 9 ? $10 + -6 | 0 : $8) - ($4 & 240) | 0; //@line 1686
 $15 = ($13 & 496) >>> 0 > 144; //@line 1688
 $16 = $15 & 1; //@line 1689
 $$026$in = $15 ? ($13 & 65535) + -96 | 0 : $13; //@line 1692
 HEAP32[96441] = $16; //@line 1693
 HEAP32[96445] = $16; //@line 1694
 $sext27$mask = $$026$in & 255; //@line 1696
 HEAP32[96442] = ($sext27$mask | 0) == 0 & HEAP32[96442]; //@line 1700
 HEAP32[96443] = $$026$in >>> 7 & 1; //@line 1703
 HEAP32[$2 >> 2] = $sext27$mask | $3 & -256; //@line 1706
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1709
 return;
}
function __Z12op_3188_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $19 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38057
 $6 = HEAP32[162769] | 0; //@line 38058
 $7 = $6 + 2 | 0; //@line 38059
 HEAP32[162769] = $7; //@line 38060
 $9 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38062
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 38069
 HEAP32[162769] = $6 + 4; //@line 38071
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 38072
 $19 = $5 << 16 >> 16; //@line 38074
 $21 = ($19 | 0) == 0 & 1; //@line 38076
 HEAP32[96441] = 0; //@line 38077
 HEAP32[96442] = 0; //@line 38077
 HEAP32[96443] = 0; //@line 38077
 HEAP32[96444] = 0; //@line 38077
 HEAP32[96442] = $21; //@line 38078
 HEAP32[96443] = $5 >>> 15 & 1; //@line 38081
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($18, $19); //@line 38087
 return;
}
function __Z12op_3180_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $19 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 38015
 $6 = HEAP32[162769] | 0; //@line 38016
 $7 = $6 + 2 | 0; //@line 38017
 HEAP32[162769] = $7; //@line 38018
 $9 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38020
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 38027
 HEAP32[162769] = $6 + 4; //@line 38029
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 38030
 $19 = $5 << 16 >> 16; //@line 38032
 $21 = ($19 | 0) == 0 & 1; //@line 38034
 HEAP32[96441] = 0; //@line 38035
 HEAP32[96442] = 0; //@line 38035
 HEAP32[96443] = 0; //@line 38035
 HEAP32[96444] = 0; //@line 38035
 HEAP32[96442] = $21; //@line 38036
 HEAP32[96443] = $5 >>> 15 & 1; //@line 38039
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($18, $19); //@line 38045
 return;
}
function __Z12op_c178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1718 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30372
 $5 = HEAP32[162769] | 0; //@line 30373
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 30383
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30385
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0) & $4; //@line 30390
 $21 = $sext1718 << 16 >> 16; //@line 30392
 $23 = ($21 | 0) == 0 & 1; //@line 30394
 HEAP32[96441] = 0; //@line 30395
 HEAP32[96442] = 0; //@line 30395
 HEAP32[96443] = 0; //@line 30395
 HEAP32[96444] = 0; //@line 30395
 HEAP32[96442] = $23; //@line 30396
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 30399
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $21); //@line 30403
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30406
 return;
}
function __Z12op_b178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1718 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26887
 $5 = HEAP32[162769] | 0; //@line 26888
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 26898
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 26900
 $sext1718 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0) ^ $4; //@line 26905
 $21 = $sext1718 << 16 >> 16; //@line 26907
 $23 = ($21 | 0) == 0 & 1; //@line 26909
 HEAP32[96441] = 0; //@line 26910
 HEAP32[96442] = 0; //@line 26910
 HEAP32[96443] = 0; //@line 26910
 HEAP32[96444] = 0; //@line 26910
 HEAP32[96442] = $23; //@line 26911
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 26914
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $21); //@line 26918
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26921
 return;
}
function __Z12op_b038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $20 = 0, $21 = 0, $3 = 0, $sext27$lobit = 0, $sext29$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 22096
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 22106
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 22112
 $20 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22114
 $21 = $20 - $18 | 0; //@line 22115
 $sext27$lobit = $20 >>> 7 & 1; //@line 22119
 $sext29$lobit = $21 >>> 7 & 1; //@line 22121
 HEAP32[96442] = ($21 & 255 | 0) == 0 & 1; //@line 22125
 HEAP32[96444] = ($18 >>> 7 & 1 | 0) != ($sext27$lobit | 0) & ($sext29$lobit | 0) != ($sext27$lobit | 0) & 1; //@line 22130
 HEAP32[96441] = ($18 & 255) >>> 0 > ($20 & 255) >>> 0 & 1; //@line 22135
 HEAP32[96443] = $sext29$lobit; //@line 22136
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22139
 return;
}
function __Z12op_5040_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 3866
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 3868
 $7 = HEAP32[$6 >> 2] | 0; //@line 3869
 $8 = $7 << 16 >> 16; //@line 3871
 $10 = $8 + ($4 << 16 >> 16) | 0; //@line 3874
 $13 = $10 >>> 15; //@line 3878
 $sext36$lobit = $13 & 1; //@line 3879
 $sext36$mask = $10 & 65535; //@line 3880
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 3883
 HEAP32[96444] = ($sext36$lobit ^ $7 >>> 15 & 1) & ($13 ^ $4 >>> 15); //@line 3887
 $23 = ($8 & 65535 ^ 65535) >>> 0 < ($4 & 65535) >>> 0 & 1; //@line 3892
 HEAP32[96441] = $23; //@line 3893
 HEAP32[96445] = $23; //@line 3894
 HEAP32[96443] = $sext36$lobit; //@line 3895
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 3898
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 3901
 return;
}
function __Z12op_1180_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $19 = 0, $21 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 26021
 $6 = HEAP32[162769] | 0; //@line 26022
 $7 = $6 + 2 | 0; //@line 26023
 HEAP32[162769] = $7; //@line 26024
 $9 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26026
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 26033
 HEAP32[162769] = $6 + 4; //@line 26035
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 26036
 $19 = $5 << 24 >> 24; //@line 26038
 $21 = ($19 | 0) == 0 & 1; //@line 26040
 HEAP32[96441] = 0; //@line 26041
 HEAP32[96442] = 0; //@line 26041
 HEAP32[96443] = 0; //@line 26041
 HEAP32[96444] = 0; //@line 26041
 HEAP32[96442] = $21; //@line 26042
 HEAP32[96443] = $5 >>> 7 & 1; //@line 26045
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($18, $19); //@line 26051
 return;
}
function __Z12op_d0a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit40 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $22 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 32728
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 32730
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 32735
 HEAP32[$4 >> 2] = $6; //@line 32736
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32737
 $13 = HEAP32[$12 >> 2] | 0; //@line 32738
 $14 = $13 + $11 | 0; //@line 32739
 $$lobit40 = $14 >>> 31; //@line 32742
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 32745
 HEAP32[96444] = ($$lobit40 ^ $11 >>> 31) & ($$lobit40 ^ $13 >>> 31); //@line 32749
 $22 = $11 >>> 0 > ~$13 >>> 0 & 1; //@line 32752
 HEAP32[96441] = $22; //@line 32753
 HEAP32[96445] = $22; //@line 32754
 HEAP32[96443] = $$lobit40; //@line 32755
 HEAP32[$12 >> 2] = $14; //@line 32756
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32759
 return;
}
function __Z12op_c138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1314 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30025
 $5 = HEAP32[162769] | 0; //@line 30026
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 30036
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30038
 $sext1314 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) & $4; //@line 30043
 $21 = $sext1314 << 24 >> 24; //@line 30045
 $23 = ($21 | 0) == 0 & 1; //@line 30047
 HEAP32[96441] = 0; //@line 30048
 HEAP32[96442] = 0; //@line 30048
 HEAP32[96443] = 0; //@line 30048
 HEAP32[96444] = 0; //@line 30048
 HEAP32[96442] = $23; //@line 30049
 HEAP32[96443] = $sext1314 >>> 7 & 1; //@line 30052
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $21); //@line 30056
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30059
 return;
}
function __Z12op_b138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1314 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26487
 $5 = HEAP32[162769] | 0; //@line 26488
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 26498
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 26500
 $sext1314 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) ^ $4; //@line 26505
 $21 = $sext1314 << 24 >> 24; //@line 26507
 $23 = ($21 | 0) == 0 & 1; //@line 26509
 HEAP32[96441] = 0; //@line 26510
 HEAP32[96442] = 0; //@line 26510
 HEAP32[96443] = 0; //@line 26510
 HEAP32[96444] = 0; //@line 26510
 HEAP32[96442] = $23; //@line 26511
 HEAP32[96443] = $sext1314 >>> 7 & 1; //@line 26514
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $21); //@line 26518
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26521
 return;
}
function __Z12op_d0b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $12 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $28 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 32871
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 32881
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 32886
 $18 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32887
 $19 = HEAP32[$18 >> 2] | 0; //@line 32888
 $20 = $19 + $17 | 0; //@line 32889
 $$lobit34 = $20 >>> 31; //@line 32892
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 32895
 HEAP32[96444] = ($$lobit34 ^ $17 >>> 31) & ($$lobit34 ^ $19 >>> 31); //@line 32899
 $28 = $17 >>> 0 > ~$19 >>> 0 & 1; //@line 32902
 HEAP32[96441] = $28; //@line 32903
 HEAP32[96445] = $28; //@line 32904
 HEAP32[96443] = $$lobit34; //@line 32905
 HEAP32[$18 >> 2] = $20; //@line 32906
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32909
 return;
}
function __Z12op_8178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1718 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16384
 $5 = HEAP32[162769] | 0; //@line 16385
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 16395
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 16397
 $sext1718 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0 | $4; //@line 16402
 $21 = $sext1718 << 16 >> 16; //@line 16404
 $23 = ($21 | 0) == 0 & 1; //@line 16406
 HEAP32[96441] = 0; //@line 16407
 HEAP32[96442] = 0; //@line 16407
 HEAP32[96443] = 0; //@line 16407
 HEAP32[96444] = 0; //@line 16407
 HEAP32[96442] = $23; //@line 16408
 HEAP32[96443] = $sext1718 >>> 15 & 1; //@line 16411
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $21); //@line 16415
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16418
 return;
}
function __Z12op_8138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $5 = 0, $sext1314 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15975
 $5 = HEAP32[162769] | 0; //@line 15976
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 15986
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 15988
 $sext1314 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0 | $4; //@line 15993
 $21 = $sext1314 << 24 >> 24; //@line 15995
 $23 = ($21 | 0) == 0 & 1; //@line 15997
 HEAP32[96441] = 0; //@line 15998
 HEAP32[96442] = 0; //@line 15998
 HEAP32[96443] = 0; //@line 15998
 HEAP32[96444] = 0; //@line 15998
 HEAP32[96442] = $23; //@line 15999
 HEAP32[96443] = $sext1314 >>> 7 & 1; //@line 16002
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $21); //@line 16006
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16009
 return;
}
function __Z12op_4040_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $3 = 0, $7 = 0, $8 = 0, $9 = 0, $sext$lobit = 0, $sext30$lobit = 0, $sext30$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 40416
 $3 = HEAP32[$2 >> 2] | 0; //@line 40417
 $7 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($3 << 16 >> 16) | 0; //@line 40423
 $8 = $3 >>> 15; //@line 40424
 $sext$lobit = $8 & 1; //@line 40425
 $9 = $7 >>> 15; //@line 40426
 $sext30$lobit = $9 & 1; //@line 40427
 HEAP32[96444] = $sext30$lobit & $8; //@line 40429
 $13 = ($sext30$lobit ^ $sext$lobit) & $9 ^ $sext$lobit; //@line 40432
 HEAP32[96441] = $13; //@line 40433
 HEAP32[96445] = $13; //@line 40434
 $sext30$mask = $7 & 65535; //@line 40436
 HEAP32[96442] = ($sext30$mask | 0) == 0 & HEAP32[96442]; //@line 40440
 HEAP32[96443] = $sext30$lobit; //@line 40441
 HEAP32[$2 >> 2] = $sext30$mask | $3 & -65536; //@line 40444
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40447
 return;
}
function _atanh($0) {
 $0 = +$0;
 var $$0 = 0.0, $$sink19 = 0.0, $1 = 0, $10 = 0.0, $2 = 0, $3 = 0, $5 = 0, $7 = 0.0, label = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 62395
 $1 = HEAP32[tempDoublePtr >> 2] | 0; //@line 62395
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 62396
 $3 = _bitshift64Lshr($1 | 0, $2 | 0, 52) | 0; //@line 62397
 $5 = $3 & 2047; //@line 62399
 HEAP32[tempDoublePtr >> 2] = $1; //@line 62401
 HEAP32[tempDoublePtr + 4 >> 2] = $2 & 2147483647; //@line 62401
 $7 = +HEAPF64[tempDoublePtr >> 3]; //@line 62401
 if ($5 >>> 0 < 1022) {
  if ($5 >>> 0 < 991) {
   $$0 = $7; //@line 62406
  } else {
   $10 = $7 * 2.0; //@line 62408
   $$sink19 = $10 + $7 * $10 / (1.0 - $7); //@line 62413
   label = 5; //@line 62414
  }
 } else {
  $$sink19 = $7 / (1.0 - $7) * 2.0; //@line 62420
  label = 5; //@line 62421
 }
 if ((label | 0) == 5) {
  $$0 = +_log1p($$sink19) * .5; //@line 62426
 }
 return +(($2 | 0) < 0 ? -$$0 : $$0);
}
function __Z12op_4458_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $21 = 0, $3 = 0, $5 = 0, $9 = 0, $sext29$lobit = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47260
 $3 = HEAP32[$2 >> 2] | 0; //@line 47261
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 47263
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 47267
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 47270
 $13 = 0 - ($9 << 16 >> 16) | 0; //@line 47273
 $sext29$lobit = $13 >>> 15 & 1; //@line 47276
 HEAP32[96442] = ($13 & 65535 | 0) == 0 & 1; //@line 47280
 HEAP32[96444] = $sext29$lobit & $9 >>> 15; //@line 47282
 $21 = ($9 & 65535 | 0) != 0 & 1; //@line 47285
 HEAP32[96441] = $21; //@line 47286
 HEAP32[96445] = $21; //@line 47287
 HEAP32[96443] = $sext29$lobit; //@line 47288
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $13); //@line 47292
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47295
 return;
}
function __Z12op_2118_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $15 = 0, $17 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29701
 $5 = HEAP32[$4 >> 2] | 0; //@line 29702
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 29707
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 29710
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29711
 $15 = (HEAP32[$13 >> 2] | 0) + -4 | 0; //@line 29713
 HEAP32[$13 >> 2] = $15; //@line 29714
 $17 = ($10 | 0) == 0 & 1; //@line 29716
 HEAP32[96441] = 0; //@line 29717
 HEAP32[96442] = 0; //@line 29717
 HEAP32[96443] = 0; //@line 29717
 HEAP32[96444] = 0; //@line 29717
 HEAP32[96442] = $17; //@line 29718
 HEAP32[96443] = $10 >>> 31; //@line 29720
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($15, $10); //@line 29726
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29729
 return;
}
function __Z12op_11bc_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 26584
 $5 = HEAP8[$3 + 3 >> 0] | 0; //@line 26586
 $6 = $3 + 4 | 0; //@line 26587
 HEAP32[162769] = $6; //@line 26588
 $8 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26590
 $15 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 26597
 HEAP32[162769] = $3 + 6; //@line 26599
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 26600
 $18 = $5 << 24 >> 24; //@line 26601
 $20 = $5 << 24 >> 24 == 0 & 1; //@line 26603
 HEAP32[96441] = 0; //@line 26604
 HEAP32[96442] = 0; //@line 26604
 HEAP32[96443] = 0; //@line 26604
 HEAP32[96444] = 0; //@line 26604
 HEAP32[96442] = $20; //@line 26605
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 26608
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, $18); //@line 26614
 return;
}
function __Z11op_ab8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0;
 $1 = HEAP32[162769] | 0; //@line 18099
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 18117
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 18127
 $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 18129
 $34 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0) ^ $19; //@line 18133
 $36 = ($34 | 0) == 0 & 1; //@line 18135
 HEAP32[96441] = 0; //@line 18136
 HEAP32[96442] = 0; //@line 18136
 HEAP32[96443] = 0; //@line 18136
 HEAP32[96444] = 0; //@line 18136
 HEAP32[96442] = $36; //@line 18137
 HEAP32[96443] = $34 >>> 31; //@line 18139
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, $34); //@line 18143
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 18146
 return;
}
function __Z11op_c50_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $18 = 0, $19 = 0, $2 = 0, $5 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19329
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19332
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19337
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19339
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 19345
 $19 = $18 - $10 | 0; //@line 19346
 $sext$lobit = $18 >>> 15 & 1; //@line 19349
 $sext32$lobit = $19 >>> 15 & 1; //@line 19351
 HEAP32[96442] = ($19 & 65535 | 0) == 0 & 1; //@line 19355
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19360
 HEAP32[96441] = $10 >>> 0 > ($18 & 65535) >>> 0 & 1; //@line 19364
 HEAP32[96443] = $sext32$lobit; //@line 19365
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19368
 return;
}
function __Z10op_78_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $9 = 0, $sext1314 = 0;
 $1 = HEAP32[162769] | 0; //@line 5333
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 5341
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 5351
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 5353
 $sext1314 = $9 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0); //@line 5358
 $25 = $sext1314 << 16 >> 16; //@line 5360
 $27 = ($25 | 0) == 0 & 1; //@line 5362
 HEAP32[96441] = 0; //@line 5363
 HEAP32[96442] = 0; //@line 5363
 HEAP32[96443] = 0; //@line 5363
 HEAP32[96444] = 0; //@line 5363
 HEAP32[96442] = $27; //@line 5364
 HEAP32[96443] = $sext1314 >>> 15 & 1; //@line 5367
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 5371
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5374
 return;
}
function __Z12op_b0d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit36 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 25719
 $5 = HEAP32[$4 >> 2] | 0; //@line 25720
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 25726
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 25729
 $15 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25731
 $16 = $11 << 16 >> 16; //@line 25733
 $17 = $15 - $16 | 0; //@line 25734
 $$lobit = $15 >>> 31; //@line 25737
 $$lobit36 = $17 >>> 31; //@line 25738
 HEAP32[96442] = ($17 | 0) == 0 & 1; //@line 25741
 HEAP32[96444] = ($11 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit36 | 0) != ($$lobit | 0) & 1; //@line 25746
 HEAP32[96441] = $15 >>> 0 < $16 >>> 0 & 1; //@line 25749
 HEAP32[96443] = $$lobit36; //@line 25750
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25753
 return;
}
function __Z12op_5190_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $12 = 0, $13 = 0, $20 = 0, $4 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6014
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6017
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 6019
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 6022
 $13 = $12 - $4 | 0; //@line 6023
 $$lobit37 = $12 >>> 31; //@line 6025
 $$lobit38 = $13 >>> 31; //@line 6026
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 6029
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $4 >>> 31); //@line 6033
 $20 = $12 >>> 0 < $4 >>> 0 & 1; //@line 6035
 HEAP32[96441] = $20; //@line 6036
 HEAP32[96445] = $20; //@line 6037
 HEAP32[96443] = $$lobit38; //@line 6038
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 6042
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6045
 return;
}
function __Z12op_4478_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, $26 = 0, $sext25$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 47451
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 47461
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47463
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 47467
 $18 = 0 - ($16 << 16 >> 16) | 0; //@line 47470
 $sext25$lobit = $18 >>> 15 & 1; //@line 47473
 HEAP32[96442] = ($18 & 65535 | 0) == 0 & 1; //@line 47477
 HEAP32[96444] = $sext25$lobit & $16 >>> 15; //@line 47479
 $26 = ($16 & 65535 | 0) != 0 & 1; //@line 47482
 HEAP32[96441] = $26; //@line 47483
 HEAP32[96445] = $26; //@line 47484
 HEAP32[96443] = $sext25$lobit; //@line 47485
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $18); //@line 47489
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47492
 return;
}
function __Z12op_4630_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $20 = 0, $21 = 0, $23 = 0, $4 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 2452
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2461
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2463
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0) << 24; //@line 2468
 $20 = $sext >> 24; //@line 2469
 $21 = ~$20; //@line 2470
 $23 = ($20 | 0) == -1 & 1; //@line 2472
 HEAP32[96441] = 0; //@line 2473
 HEAP32[96442] = 0; //@line 2473
 HEAP32[96443] = 0; //@line 2473
 HEAP32[96444] = 0; //@line 2473
 HEAP32[96442] = $23; //@line 2474
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 2477
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, $21); //@line 2481
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2484
 return;
}
function __Z12op_4000_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $3 = 0, $7 = 0, $8 = 0, $9 = 0, $sext$lobit = 0, $sext28$lobit = 0, $sext28$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 39988
 $3 = HEAP32[$2 >> 2] | 0; //@line 39989
 $7 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($3 << 24 >> 24) | 0; //@line 39995
 $8 = $3 >>> 7; //@line 39996
 $sext$lobit = $8 & 1; //@line 39997
 $9 = $7 >>> 7; //@line 39998
 $sext28$lobit = $9 & 1; //@line 39999
 HEAP32[96444] = $sext28$lobit & $8; //@line 40001
 $13 = ($sext28$lobit ^ $sext$lobit) & $9 ^ $sext$lobit; //@line 40004
 HEAP32[96441] = $13; //@line 40005
 HEAP32[96445] = $13; //@line 40006
 $sext28$mask = $7 & 255; //@line 40008
 HEAP32[96442] = ($sext28$mask | 0) == 0 & HEAP32[96442]; //@line 40012
 HEAP32[96443] = $sext28$lobit; //@line 40013
 HEAP32[$2 >> 2] = $sext28$mask | $3 & -256; //@line 40016
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40019
 return;
}
function __Z12op_1020_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = $0 & 7; //@line 23470
 $3 = $0 >>> 9 & 7; //@line 23472
 $4 = 651040 + ($1 << 2) | 0; //@line 23473
 $8 = (HEAP32[$4 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 23477
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($8) | 0; //@line 23483
 HEAP32[$4 >> 2] = $8; //@line 23484
 $15 = $14 << 24 >> 24; //@line 23486
 $17 = ($15 | 0) == 0 & 1; //@line 23488
 HEAP32[96441] = 0; //@line 23489
 HEAP32[96442] = 0; //@line 23489
 HEAP32[96443] = 0; //@line 23489
 HEAP32[96444] = 0; //@line 23489
 HEAP32[96442] = $17; //@line 23490
 HEAP32[96443] = $14 >>> 7 & 1; //@line 23493
 $19 = 651008 + ($3 << 2) | 0; //@line 23494
 HEAP32[$19 >> 2] = HEAP32[$19 >> 2] & -256 | $15 & 255; //@line 23499
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23502
 return;
}
function __Z11op_278_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $25 = 0, $27 = 0, $9 = 0, $sext1314 = 0;
 $1 = HEAP32[162769] | 0; //@line 9069
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 9077
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 9087
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 9089
 $sext1314 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 4 >> 2] & 127]($18) | 0) & $9; //@line 9094
 $25 = $sext1314 << 16 >> 16; //@line 9096
 $27 = ($25 | 0) == 0 & 1; //@line 9098
 HEAP32[96441] = 0; //@line 9099
 HEAP32[96442] = 0; //@line 9099
 HEAP32[96443] = 0; //@line 9099
 HEAP32[96444] = 0; //@line 9099
 HEAP32[96442] = $27; //@line 9100
 HEAP32[96443] = $sext1314 >>> 15; //@line 9102
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 16 >> 2] & 31]($18, $25); //@line 9106
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9109
 return;
}
function __Z12op_9180_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit37 = 0, $$lobit38 = 0, $11 = 0, $13 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 20991
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 20992
 $7 = HEAP32[$6 >> 2] | 0; //@line 20993
 $11 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) + ($7 - $5) | 0; //@line 20998
 $$lobit = $5 >>> 31; //@line 20999
 $$lobit37 = $7 >>> 31; //@line 21000
 $$lobit38 = $11 >>> 31; //@line 21001
 $13 = $$lobit38 ^ $$lobit37; //@line 21003
 HEAP32[96444] = $13 & ($$lobit37 ^ $$lobit); //@line 21005
 $17 = ($$lobit38 ^ $$lobit) & $13 ^ $$lobit; //@line 21008
 HEAP32[96441] = $17; //@line 21009
 HEAP32[96445] = $17; //@line 21010
 HEAP32[96442] = ($11 | 0) == 0 & HEAP32[96442]; //@line 21015
 HEAP32[96443] = $$lobit38; //@line 21016
 HEAP32[$6 >> 2] = $11; //@line 21017
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21020
 return;
}
function __Z11op_228_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 8596
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 8598
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8611
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 8613
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) & ($4 & 255); //@line 8619
 $25 = $24 << 24 >> 24; //@line 8621
 $27 = ($25 | 0) == 0 & 1; //@line 8623
 HEAP32[96441] = 0; //@line 8624
 HEAP32[96442] = 0; //@line 8624
 HEAP32[96443] = 0; //@line 8624
 HEAP32[96444] = 0; //@line 8624
 HEAP32[96442] = $27; //@line 8625
 HEAP32[96443] = $24 >>> 7; //@line 8627
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 8631
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8634
 return;
}
function __Z12op_4670_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $20 = 0, $21 = 0, $23 = 0, $4 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 2495
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2504
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2506
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0) << 16; //@line 2511
 $20 = $sext >> 16; //@line 2512
 $21 = ~$20; //@line 2513
 $23 = ($20 | 0) == -1 & 1; //@line 2515
 HEAP32[96441] = 0; //@line 2516
 HEAP32[96442] = 0; //@line 2516
 HEAP32[96443] = 0; //@line 2516
 HEAP32[96444] = 0; //@line 2516
 HEAP32[96442] = $23; //@line 2517
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 2520
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $21); //@line 2524
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2527
 return;
}
function __Z12op_4460_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $2 = 0, $20 = 0, $4 = 0, $6 = 0, $sext30$lobit = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47304
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 47306
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 47308
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 47312
 HEAP32[$2 >> 2] = $4; //@line 47313
 $12 = 0 - ($10 << 16 >> 16) | 0; //@line 47316
 $sext30$lobit = $12 >>> 15 & 1; //@line 47319
 HEAP32[96442] = ($12 & 65535 | 0) == 0 & 1; //@line 47323
 HEAP32[96444] = $sext30$lobit & $10 >>> 15; //@line 47325
 $20 = ($10 & 65535 | 0) != 0 & 1; //@line 47328
 HEAP32[96441] = $20; //@line 47329
 HEAP32[96445] = $20; //@line 47330
 HEAP32[96443] = $sext30$lobit; //@line 47331
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $12); //@line 47335
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47338
 return;
}
function __Z12op_3030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 44184
 $6 = HEAP32[162769] | 0; //@line 44187
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44196
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 44202
 $22 = $21 << 16 >> 16; //@line 44204
 $24 = ($22 | 0) == 0 & 1; //@line 44206
 HEAP32[96441] = 0; //@line 44207
 HEAP32[96442] = 0; //@line 44207
 HEAP32[96443] = 0; //@line 44207
 HEAP32[96444] = 0; //@line 44207
 HEAP32[96442] = $24; //@line 44208
 HEAP32[96443] = $21 >>> 15 & 1; //@line 44211
 $26 = 651008 + ($3 << 2) | 0; //@line 44212
 HEAP32[$26 >> 2] = HEAP32[$26 >> 2] & -65536 | $22 & 65535; //@line 44217
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44220
 return;
}
function __Z12op_20d8_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $17 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29191
 $5 = HEAP32[$4 >> 2] | 0; //@line 29192
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 29197
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 29200
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29201
 $14 = HEAP32[$13 >> 2] | 0; //@line 29202
 HEAP32[$13 >> 2] = $14 + 4; //@line 29204
 $17 = ($10 | 0) == 0 & 1; //@line 29206
 HEAP32[96441] = 0; //@line 29207
 HEAP32[96442] = 0; //@line 29207
 HEAP32[96443] = 0; //@line 29207
 HEAP32[96444] = 0; //@line 29207
 HEAP32[96442] = $17; //@line 29208
 HEAP32[96443] = $10 >>> 31; //@line 29210
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, $10); //@line 29216
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29219
 return;
}
function __Z10op_28_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 4851
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 4853
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 4866
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 4868
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0 | $4 & 255; //@line 4874
 $25 = $24 << 24 >> 24; //@line 4876
 $27 = ($25 | 0) == 0 & 1; //@line 4878
 HEAP32[96441] = 0; //@line 4879
 HEAP32[96442] = 0; //@line 4879
 HEAP32[96443] = 0; //@line 4879
 HEAP32[96444] = 0; //@line 4879
 HEAP32[96442] = $27; //@line 4880
 HEAP32[96443] = $24 >>> 7 & 1; //@line 4883
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $25); //@line 4887
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 4890
 return;
}
function __Z12op_5000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 1195
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 1197
 $7 = HEAP32[$6 >> 2] | 0; //@line 1198
 $8 = $7 << 24 >> 24; //@line 1200
 $10 = $8 + ($4 << 24 >> 24) | 0; //@line 1203
 $13 = $10 >>> 7; //@line 1207
 $sext34$lobit = $13 & 1; //@line 1208
 $sext34$mask = $10 & 255; //@line 1209
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 1212
 HEAP32[96444] = ($sext34$lobit ^ $7 >>> 7 & 1) & ($13 ^ $4 >>> 7); //@line 1216
 $23 = ($8 & 255 ^ 255) >>> 0 < ($4 & 255) >>> 0 & 1; //@line 1221
 HEAP32[96441] = $23; //@line 1222
 HEAP32[96445] = $23; //@line 1223
 HEAP32[96443] = $sext34$lobit; //@line 1224
 HEAP32[$6 >> 2] = $sext34$mask | $7 & -256; //@line 1227
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 1230
 return;
}
function __Z12op_4438_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, $26 = 0, $sext23$lobit = 0;
 $1 = HEAP32[162769] | 0; //@line 47077
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 47087
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47089
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 47093
 $18 = 0 - ($16 << 24 >> 24) | 0; //@line 47096
 $sext23$lobit = $18 >>> 7 & 1; //@line 47099
 HEAP32[96442] = ($18 & 255 | 0) == 0 & 1; //@line 47103
 HEAP32[96444] = $sext23$lobit & $16 >>> 7; //@line 47105
 $26 = ($16 & 255 | 0) != 0 & 1; //@line 47108
 HEAP32[96441] = $26; //@line 47109
 HEAP32[96445] = $26; //@line 47110
 HEAP32[96443] = $sext23$lobit; //@line 47111
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $18); //@line 47115
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47118
 return;
}
function __Z12op_3039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $32 = 0;
 $2 = $0 >>> 9 & 7; //@line 35170
 $3 = HEAP32[162769] | 0; //@line 35171
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 35180
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 35195
 $28 = $27 << 16 >> 16; //@line 35197
 $30 = ($28 | 0) == 0 & 1; //@line 35199
 HEAP32[96441] = 0; //@line 35200
 HEAP32[96442] = 0; //@line 35200
 HEAP32[96443] = 0; //@line 35200
 HEAP32[96444] = 0; //@line 35200
 HEAP32[96442] = $30; //@line 35201
 HEAP32[96443] = $27 >>> 15 & 1; //@line 35204
 $32 = 651008 + ($2 << 2) | 0; //@line 35205
 HEAP32[$32 >> 2] = HEAP32[$32 >> 2] & -65536 | $28 & 65535; //@line 35210
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 35213
 return;
}
function __Z12op_4658_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $15 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0, $sext = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 48630
 $3 = HEAP32[$2 >> 2] | 0; //@line 48631
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48633
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 48637
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 48640
 $sext = $9 << 16; //@line 48641
 $12 = $sext >> 16; //@line 48642
 $13 = ~$12; //@line 48643
 $15 = ($12 | 0) == -1 & 1; //@line 48645
 HEAP32[96441] = 0; //@line 48646
 HEAP32[96442] = 0; //@line 48646
 HEAP32[96443] = 0; //@line 48646
 HEAP32[96444] = 0; //@line 48646
 HEAP32[96442] = $15; //@line 48647
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48650
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $13); //@line 48654
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48657
 return;
}
function __Z12op_203b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $22 = 0, $24 = 0, $3 = 0, $4 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 28191
 $3 = HEAP32[162769] | 0; //@line 28192
 $4 = $3 + 2 | 0; //@line 28193
 HEAP32[162769] = $4; //@line 28194
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 28199
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 28206
 HEAP32[162769] = $3 + 4; //@line 28208
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 28209
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 28214
 $24 = ($22 | 0) == 0 & 1; //@line 28216
 HEAP32[96441] = 0; //@line 28217
 HEAP32[96442] = 0; //@line 28217
 HEAP32[96443] = 0; //@line 28217
 HEAP32[96444] = 0; //@line 28217
 HEAP32[96442] = $24; //@line 28218
 HEAP32[96443] = $22 >>> 31; //@line 28220
 HEAP32[651008 + ($2 << 2) >> 2] = $22; //@line 28222
 return;
}
function __Z12op_e8c0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $2 = 0, $25 = 0, $26 = 0, $30 = 0, $33 = 0, $sext = 0;
 $2 = HEAP32[162769] | 0; //@line 42186
 $sext = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) << 16; //@line 42195
 $11 = $sext >> 16; //@line 42196
 $14 = $sext >> 22; //@line 42199
 if (!($11 & 2048)) {
  $30 = $14 & 31; //@line 42202
 } else {
  $30 = HEAP32[651008 + (($14 & 7) << 2) >> 2] | 0; //@line 42207
 }
 if (!($11 & 32)) {
  $25 = $11; //@line 42212
 } else {
  $25 = HEAP32[651008 + (($11 & 7) << 2) >> 2] | 0; //@line 42217
 }
 $26 = $25 + 31 & 31; //@line 42220
 $33 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << ($30 & 31) >>> ($26 ^ 31); //@line 42226
 HEAP32[96443] = ($33 & 1 << $26 | 0) != 0 & 1; //@line 42231
 HEAP32[96442] = ($33 | 0) == 0 & 1; //@line 42234
 HEAP32[96444] = 0; //@line 42235
 HEAP32[96441] = 0; //@line 42236
 HEAP32[162769] = $2 + 4; //@line 42238
 return;
}
function __Z12op_b1f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $15 = 0, $20 = 0, $22 = 0, $23 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 35779
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35788
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 35793
 $22 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35795
 $23 = $22 - $20 | 0; //@line 35796
 $$lobit35 = $22 >>> 31; //@line 35798
 $$lobit36 = $23 >>> 31; //@line 35799
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 35802
 HEAP32[96444] = ($20 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 35807
 HEAP32[96441] = $22 >>> 0 < $20 >>> 0 & 1; //@line 35810
 HEAP32[96443] = $$lobit36; //@line 35811
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35814
 return;
}
function __Z12op_b0b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $15 = 0, $20 = 0, $22 = 0, $23 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 35433
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 35442
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 35447
 $22 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35449
 $23 = $22 - $20 | 0; //@line 35450
 $$lobit35 = $22 >>> 31; //@line 35452
 $$lobit36 = $23 >>> 31; //@line 35453
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 35456
 HEAP32[96444] = ($20 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 35461
 HEAP32[96441] = $22 >>> 0 < $20 >>> 0 & 1; //@line 35464
 HEAP32[96443] = $$lobit36; //@line 35465
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35468
 return;
}
function __Z12op_3028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 35032
 $6 = HEAP32[162769] | 0; //@line 35035
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 35046
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 35052
 $23 = $22 << 16 >> 16; //@line 35054
 $25 = ($23 | 0) == 0 & 1; //@line 35056
 HEAP32[96441] = 0; //@line 35057
 HEAP32[96442] = 0; //@line 35057
 HEAP32[96443] = 0; //@line 35057
 HEAP32[96444] = 0; //@line 35057
 HEAP32[96442] = $25; //@line 35058
 HEAP32[96443] = $22 >>> 15 & 1; //@line 35061
 $27 = 651008 + ($3 << 2) | 0; //@line 35062
 HEAP32[$27 >> 2] = HEAP32[$27 >> 2] & -65536 | $23 & 65535; //@line 35067
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35070
 return;
}
function __Z12op_2120_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $16 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29740
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 29742
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 29747
 HEAP32[$4 >> 2] = $6; //@line 29748
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29749
 $14 = (HEAP32[$12 >> 2] | 0) + -4 | 0; //@line 29751
 HEAP32[$12 >> 2] = $14; //@line 29752
 $16 = ($11 | 0) == 0 & 1; //@line 29754
 HEAP32[96441] = 0; //@line 29755
 HEAP32[96442] = 0; //@line 29755
 HEAP32[96443] = 0; //@line 29755
 HEAP32[96444] = 0; //@line 29755
 HEAP32[96442] = $16; //@line 29756
 HEAP32[96443] = $11 >>> 31; //@line 29758
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, $11); //@line 29764
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29767
 return;
}
function __Z12op_1030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 30659
 $6 = HEAP32[162769] | 0; //@line 30662
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 30671
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 30677
 $22 = $21 << 24 >> 24; //@line 30679
 $24 = ($22 | 0) == 0 & 1; //@line 30681
 HEAP32[96441] = 0; //@line 30682
 HEAP32[96442] = 0; //@line 30682
 HEAP32[96443] = 0; //@line 30682
 HEAP32[96444] = 0; //@line 30682
 HEAP32[96442] = $24; //@line 30683
 HEAP32[96443] = $21 >>> 7 & 1; //@line 30686
 $26 = 651008 + ($3 << 2) | 0; //@line 30687
 HEAP32[$26 >> 2] = HEAP32[$26 >> 2] & -256 | $22 & 255; //@line 30692
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30695
 return;
}
function __Z12op_4ad8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0, $sext = 0;
 $1 = $0 & 7; //@line 52625
 $2 = 651040 + ($1 << 2) | 0; //@line 52626
 $3 = HEAP32[$2 >> 2] | 0; //@line 52627
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 52629
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 52633
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 52638
 $sext = $9 << 24; //@line 52639
 $15 = ($sext | 0) == 0 & 1; //@line 52641
 HEAP32[96441] = 0; //@line 52642
 HEAP32[96442] = 0; //@line 52642
 HEAP32[96443] = 0; //@line 52642
 HEAP32[96444] = 0; //@line 52642
 HEAP32[96442] = $15; //@line 52643
 HEAP32[96443] = $9 >>> 7 & 1; //@line 52646
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, ($sext | -2147483648) >> 24); //@line 52652
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52655
 return;
}
function __Z12op_2138_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29871
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 29881
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 29886
 $18 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29887
 $20 = (HEAP32[$18 >> 2] | 0) + -4 | 0; //@line 29889
 HEAP32[$18 >> 2] = $20; //@line 29890
 $22 = ($17 | 0) == 0 & 1; //@line 29892
 HEAP32[96441] = 0; //@line 29893
 HEAP32[96442] = 0; //@line 29893
 HEAP32[96443] = 0; //@line 29893
 HEAP32[96444] = 0; //@line 29893
 HEAP32[96442] = $22; //@line 29894
 HEAP32[96443] = $17 >>> 31; //@line 29896
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($20, $17); //@line 29902
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29905
 return;
}
function __Z12op_903c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $22 = 0, $5 = 0, $7 = 0, $8 = 0, $sext27$lobit = 0, $sext27$mask = 0;
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 18237
 $7 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18239
 $8 = HEAP32[$7 >> 2] | 0; //@line 18240
 $11 = ($8 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 18244
 $13 = $8 >>> 7; //@line 18247
 $sext27$lobit = $11 >>> 7 & 1; //@line 18250
 $sext27$mask = $11 & 255; //@line 18251
 HEAP32[96442] = ($sext27$mask | 0) == 0 & 1; //@line 18254
 HEAP32[96444] = ($sext27$lobit ^ $13 & 1) & (($5 & 255) >>> 7 & 255 ^ $13); //@line 18258
 $22 = ($5 & 255) >>> 0 > ($8 & 255) >>> 0 & 1; //@line 18261
 HEAP32[96441] = $22; //@line 18262
 HEAP32[96445] = $22; //@line 18263
 HEAP32[96443] = $sext27$lobit; //@line 18264
 HEAP32[$7 >> 2] = $sext27$mask | $8 & -256; //@line 18267
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18270
 return;
}
function __Z11op_a50_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $19 = 0, $2 = 0, $21 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 15870
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 15878
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15880
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15882
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0) ^ $10; //@line 15887
 $19 = $sext1617 << 16 >> 16; //@line 15889
 $21 = ($19 | 0) == 0 & 1; //@line 15891
 HEAP32[96441] = 0; //@line 15892
 HEAP32[96442] = 0; //@line 15892
 HEAP32[96443] = 0; //@line 15892
 HEAP32[96444] = 0; //@line 15892
 HEAP32[96442] = $21; //@line 15893
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 15896
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $19); //@line 15900
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15903
 return;
}
function __Z11op_2b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0;
 $1 = HEAP32[162769] | 0; //@line 9514
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 9532
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 9542
 $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 9544
 $34 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0) & $19; //@line 9548
 $36 = ($34 | 0) == 0 & 1; //@line 9550
 HEAP32[96441] = 0; //@line 9551
 HEAP32[96442] = 0; //@line 9551
 HEAP32[96443] = 0; //@line 9551
 HEAP32[96444] = 0; //@line 9551
 HEAP32[96442] = $36; //@line 9552
 HEAP32[96443] = $34 >>> 31; //@line 9554
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, $34); //@line 9558
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 9561
 return;
}
function __Z11op_17b_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $5 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7386
 $5 = HEAP32[162769] | 0; //@line 7387
 $6 = $5 + 2 | 0; //@line 7388
 HEAP32[162769] = $6; //@line 7389
 $10 = $6 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 7394
 $17 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0); //@line 7401
 HEAP32[162769] = $5 + 4; //@line 7403
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 7404
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 7406
 $26 = $4 & 7; //@line 7411
 $27 = 1 << $26; //@line 7412
 $29 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) ^ $27) << 24 >> 24; //@line 7415
 HEAP32[96442] = ($29 & $27) >>> $26; //@line 7418
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $29); //@line 7422
 return;
}
function __Z12op_b1f9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $12 = 0, $26 = 0, $28 = 0, $29 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 27670
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 27679
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 27693
 $28 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27695
 $29 = $28 - $26 | 0; //@line 27696
 $$lobit31 = $28 >>> 31; //@line 27698
 $$lobit32 = $29 >>> 31; //@line 27699
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 27702
 HEAP32[96444] = ($26 >>> 31 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 27707
 HEAP32[96441] = $28 >>> 0 < $26 >>> 0 & 1; //@line 27710
 HEAP32[96443] = $$lobit32; //@line 27711
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27714
 return;
}
function __Z12op_b0e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit37 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 25764
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 25766
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 25772
 HEAP32[$4 >> 2] = $6; //@line 25773
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25775
 $15 = $12 << 16 >> 16; //@line 25777
 $16 = $14 - $15 | 0; //@line 25778
 $$lobit = $14 >>> 31; //@line 25781
 $$lobit37 = $16 >>> 31; //@line 25782
 HEAP32[96442] = ($16 | 0) == 0 & 1; //@line 25785
 HEAP32[96444] = ($12 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit37 | 0) != ($$lobit | 0) & 1; //@line 25790
 HEAP32[96441] = $14 >>> 0 < $15 >>> 0 & 1; //@line 25793
 HEAP32[96443] = $$lobit37; //@line 25794
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25797
 return;
}
function __Z12op_b0b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $12 = 0, $26 = 0, $28 = 0, $29 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 25398
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 25407
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 25421
 $28 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25423
 $29 = $28 - $26 | 0; //@line 25424
 $$lobit31 = $28 >>> 31; //@line 25426
 $$lobit32 = $29 >>> 31; //@line 25427
 HEAP32[96442] = ($29 | 0) == 0 & 1; //@line 25430
 HEAP32[96444] = ($26 >>> 31 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 25435
 HEAP32[96441] = $28 >>> 0 < $26 >>> 0 & 1; //@line 25438
 HEAP32[96443] = $$lobit32; //@line 25439
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 25442
 return;
}
function __Z12op_1039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $27 = 0, $28 = 0, $3 = 0, $30 = 0, $32 = 0;
 $2 = $0 >>> 9 & 7; //@line 23650
 $3 = HEAP32[162769] | 0; //@line 23651
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 23660
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 23675
 $28 = $27 << 24 >> 24; //@line 23677
 $30 = ($28 | 0) == 0 & 1; //@line 23679
 HEAP32[96441] = 0; //@line 23680
 HEAP32[96442] = 0; //@line 23680
 HEAP32[96443] = 0; //@line 23680
 HEAP32[96444] = 0; //@line 23680
 HEAP32[96442] = $30; //@line 23681
 HEAP32[96443] = $27 >>> 7 & 1; //@line 23684
 $32 = 651008 + ($2 << 2) | 0; //@line 23685
 HEAP32[$32 >> 2] = HEAP32[$32 >> 2] & -256 | $28 & 255; //@line 23690
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 23693
 return;
}
function __Z10op_b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $30 = 0, $34 = 0, $36 = 0;
 $1 = HEAP32[162769] | 0; //@line 5780
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 5798
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 5808
 $30 = 123608 + ($28 >>> 16 << 2) | 0; //@line 5810
 $34 = $19 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$30 >> 2] >> 2] & 127]($28) | 0); //@line 5814
 $36 = ($34 | 0) == 0 & 1; //@line 5816
 HEAP32[96441] = 0; //@line 5817
 HEAP32[96442] = 0; //@line 5817
 HEAP32[96443] = 0; //@line 5817
 HEAP32[96444] = 0; //@line 5817
 HEAP32[96442] = $36; //@line 5818
 HEAP32[96443] = $34 >>> 31; //@line 5820
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$30 >> 2] | 0) + 12 >> 2] & 31]($28, $34); //@line 5824
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 5827
 return;
}
function __Z12op_b0f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $12 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 25915
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 25925
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 25931
 $20 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25933
 $21 = $18 << 16 >> 16; //@line 25935
 $22 = $20 - $21 | 0; //@line 25936
 $$lobit = $20 >>> 31; //@line 25939
 $$lobit32 = $22 >>> 31; //@line 25940
 HEAP32[96442] = ($22 | 0) == 0 & 1; //@line 25943
 HEAP32[96444] = ($18 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit32 | 0) != ($$lobit | 0) & 1; //@line 25948
 HEAP32[96441] = $20 >>> 0 < $21 >>> 0 & 1; //@line 25951
 HEAP32[96443] = $$lobit32; //@line 25952
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25955
 return;
}
function __Z12op_9048_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18327
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18328
 $7 = HEAP32[$6 >> 2] | 0; //@line 18329
 $10 = ($7 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 18334
 $12 = $7 >>> 15; //@line 18336
 $sext36$lobit = $10 >>> 15 & 1; //@line 18339
 $sext36$mask = $10 & 65535; //@line 18340
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 18343
 HEAP32[96444] = ($sext36$lobit ^ $12 & 1) & ($12 ^ $5 >>> 15); //@line 18347
 $22 = ($5 & 65535) >>> 0 > ($7 & 65535) >>> 0 & 1; //@line 18351
 HEAP32[96441] = $22; //@line 18352
 HEAP32[96445] = $22; //@line 18353
 HEAP32[96443] = $sext36$lobit; //@line 18354
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 18357
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18360
 return;
}
function __Z12op_9040_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 18282
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18283
 $7 = HEAP32[$6 >> 2] | 0; //@line 18284
 $10 = ($7 << 16 >> 16) - ($5 << 16 >> 16) | 0; //@line 18289
 $12 = $7 >>> 15; //@line 18291
 $sext36$lobit = $10 >>> 15 & 1; //@line 18294
 $sext36$mask = $10 & 65535; //@line 18295
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 18298
 HEAP32[96444] = ($sext36$lobit ^ $12 & 1) & ($12 ^ $5 >>> 15); //@line 18302
 $22 = ($5 & 65535) >>> 0 > ($7 & 65535) >>> 0 & 1; //@line 18306
 HEAP32[96441] = $22; //@line 18307
 HEAP32[96445] = $22; //@line 18308
 HEAP32[96443] = $sext36$lobit; //@line 18309
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 18312
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18315
 return;
}
function __Z12op_c0bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36111
 $$cast = $4; //@line 36116
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36125
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 36130
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36131
 $25 = HEAP32[$23 >> 2] & $22; //@line 36133
 $27 = ($25 | 0) == 0 & 1; //@line 36135
 HEAP32[96441] = 0; //@line 36136
 HEAP32[96442] = 0; //@line 36136
 HEAP32[96443] = 0; //@line 36136
 HEAP32[96444] = 0; //@line 36136
 HEAP32[96442] = $27; //@line 36137
 HEAP32[96443] = $25 >>> 31; //@line 36139
 HEAP32[$23 >> 2] = $25; //@line 36140
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36143
 return;
}
function __Z12op_b1e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $16 = 0, $21 = 0, $23 = 0, $24 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 27528
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 27539
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 27544
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27546
 $24 = $23 - $21 | 0; //@line 27547
 $$lobit35 = $23 >>> 31; //@line 27549
 $$lobit36 = $24 >>> 31; //@line 27550
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 27553
 HEAP32[96444] = ($21 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 27558
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 27561
 HEAP32[96443] = $$lobit36; //@line 27562
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27565
 return;
}
function __Z12op_b0a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $16 = 0, $21 = 0, $23 = 0, $24 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 25256
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 25267
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 25272
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25274
 $24 = $23 - $21 | 0; //@line 25275
 $$lobit35 = $23 >>> 31; //@line 25277
 $$lobit36 = $24 >>> 31; //@line 25278
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 25281
 HEAP32[96444] = ($21 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 25286
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 25289
 HEAP32[96443] = $$lobit36; //@line 25290
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25293
 return;
}
function __Z12op_80bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 23243
 $$cast = $4; //@line 23248
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 23257
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 23262
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23263
 $25 = HEAP32[$23 >> 2] | $22; //@line 23265
 $27 = ($25 | 0) == 0 & 1; //@line 23267
 HEAP32[96441] = 0; //@line 23268
 HEAP32[96442] = 0; //@line 23268
 HEAP32[96443] = 0; //@line 23268
 HEAP32[96444] = 0; //@line 23268
 HEAP32[96442] = $27; //@line 23269
 HEAP32[96443] = $25 >>> 31; //@line 23271
 HEAP32[$23 >> 2] = $25; //@line 23272
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23275
 return;
}
function __Z12op_21d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 33715
 $3 = HEAP32[$2 >> 2] | 0; //@line 33716
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 33721
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 33724
 $11 = HEAP32[162769] | 0; //@line 33725
 $20 = ((HEAPU8[$11 + 2 >> 0] | 0) << 8 | (HEAPU8[$11 + 3 >> 0] | 0)) << 16 >> 16; //@line 33735
 $22 = ($8 | 0) == 0 & 1; //@line 33737
 HEAP32[96441] = 0; //@line 33738
 HEAP32[96442] = 0; //@line 33738
 HEAP32[96443] = 0; //@line 33738
 HEAP32[96444] = 0; //@line 33738
 HEAP32[96442] = $22; //@line 33739
 HEAP32[96443] = $8 >>> 31; //@line 33741
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($20, $8); //@line 33747
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33750
 return;
}
function __Z12op_1028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 23512
 $6 = HEAP32[162769] | 0; //@line 23515
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 23526
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 23532
 $23 = $22 << 24 >> 24; //@line 23534
 $25 = ($23 | 0) == 0 & 1; //@line 23536
 HEAP32[96441] = 0; //@line 23537
 HEAP32[96442] = 0; //@line 23537
 HEAP32[96443] = 0; //@line 23537
 HEAP32[96444] = 0; //@line 23537
 HEAP32[96442] = $25; //@line 23538
 HEAP32[96443] = $22 >>> 7 & 1; //@line 23541
 $27 = 651008 + ($3 << 2) | 0; //@line 23542
 HEAP32[$27 >> 2] = HEAP32[$27 >> 2] & -256 | $23 & 255; //@line 23547
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23550
 return;
}
function __ZN11driver_baseD2Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $6 = 0, $9 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 43764
 STACKTOP = STACKTOP + 16 | 0; //@line 43765
 $vararg_buffer = sp; //@line 43766
 HEAP32[$0 >> 2] = 4248; //@line 43767
 $2 = HEAP32[$0 + 16 >> 2] | 0; //@line 43769
 if ($2 | 0) {
  _SDL_FreeSurface($2 | 0); //@line 43772
 }
 $4 = HEAP32[30852] | 0; //@line 43774
 if ($4 | 0) {
  $6 = HEAP32[30853] | 0; //@line 43777
  HEAP32[$vararg_buffer >> 2] = $4; //@line 43778
  HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 43780
  _printf(102326, $vararg_buffer) | 0; //@line 43781
  __Z10vm_releasePvj(HEAP32[30852] | 0, HEAP32[30853] | 0) | 0; //@line 43784
  HEAP32[30852] = 0; //@line 43785
 }
 $9 = HEAP32[30854] | 0; //@line 43787
 if (!$9) {
  STACKTOP = sp; //@line 43790
  return;
 }
 _free($9); //@line 43792
 HEAP32[30854] = 0; //@line 43793
 STACKTOP = sp; //@line 43794
 return;
}
function __Z12op_d180_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit37 = 0, $$lobit38 = 0, $12 = 0, $14 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 34629
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 34630
 $7 = HEAP32[$6 >> 2] | 0; //@line 34631
 $12 = $7 + $5 + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 34636
 $$lobit = $5 >>> 31; //@line 34637
 $$lobit37 = $7 >>> 31; //@line 34638
 $$lobit38 = $12 >>> 31; //@line 34639
 $14 = $$lobit38 ^ $$lobit37; //@line 34641
 HEAP32[96444] = ($$lobit38 ^ $$lobit) & $14; //@line 34643
 $18 = $14 & ($$lobit37 ^ $$lobit) ^ $$lobit; //@line 34646
 HEAP32[96441] = $18; //@line 34647
 HEAP32[96445] = $18; //@line 34648
 HEAP32[96442] = ($12 | 0) == 0 & HEAP32[96442]; //@line 34653
 HEAP32[96443] = $$lobit38; //@line 34654
 HEAP32[$6 >> 2] = $12; //@line 34655
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34658
 return;
}
function __Z10EnqueueMacjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $14 = 0, $25 = 0, $7 = 0, $9 = 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($0 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($0, 0); //@line 12735
 $7 = $1 + 6 | 0; //@line 12736
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 12738
 if (!(FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0)) {
  $14 = $1 + 2 | 0; //@line 12744
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, $0); //@line 12750
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $0); //@line 12754
  return;
 } else {
  $25 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 12759
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $0); //@line 12765
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $0); //@line 12769
  return;
 }
}
function ___toread($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $15 = 0, $23 = 0, $3 = 0, $7 = 0, $9 = 0;
 $1 = $0 + 74 | 0; //@line 55636
 $3 = HEAP8[$1 >> 0] | 0; //@line 55638
 HEAP8[$1 >> 0] = $3 + 255 | $3; //@line 55642
 $7 = $0 + 20 | 0; //@line 55643
 $9 = $0 + 28 | 0; //@line 55645
 if ((HEAP32[$7 >> 2] | 0) >>> 0 > (HEAP32[$9 >> 2] | 0) >>> 0) {
  FUNCTION_TABLE_iiii[HEAP32[$0 + 36 >> 2] & 15]($0, 0, 0) | 0; //@line 55651
 }
 HEAP32[$0 + 16 >> 2] = 0; //@line 55654
 HEAP32[$9 >> 2] = 0; //@line 55655
 HEAP32[$7 >> 2] = 0; //@line 55656
 $15 = HEAP32[$0 >> 2] | 0; //@line 55657
 if (!($15 & 4)) {
  $23 = (HEAP32[$0 + 44 >> 2] | 0) + (HEAP32[$0 + 48 >> 2] | 0) | 0; //@line 55665
  HEAP32[$0 + 8 >> 2] = $23; //@line 55667
  HEAP32[$0 + 4 >> 2] = $23; //@line 55669
  $$0 = $15 << 27 >> 31; //@line 55672
 } else {
  HEAP32[$0 >> 2] = $15 | 32; //@line 55675
  $$0 = -1; //@line 55676
 }
 return $$0 | 0; //@line 55678
}
function __Z12op_20e0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $16 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29230
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 29232
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 29237
 HEAP32[$4 >> 2] = $6; //@line 29238
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29239
 $13 = HEAP32[$12 >> 2] | 0; //@line 29240
 HEAP32[$12 >> 2] = $13 + 4; //@line 29242
 $16 = ($11 | 0) == 0 & 1; //@line 29244
 HEAP32[96441] = 0; //@line 29245
 HEAP32[96442] = 0; //@line 29245
 HEAP32[96443] = 0; //@line 29245
 HEAP32[96444] = 0; //@line 29245
 HEAP32[96442] = $16; //@line 29246
 HEAP32[96443] = $11 >>> 31; //@line 29248
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $11); //@line 29254
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29257
 return;
}
function __Z12SCSICompletejjj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $15 = 0, $3 = 0, sp = 0;
 sp = STACKTOP; //@line 23102
 STACKTOP = STACKTOP + 16 | 0; //@line 23103
 $3 = sp; //@line 23104
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($1, 0); //@line 23110
 if ((HEAP32[28496] | 0) != 3) {
  $$0 = 5; //@line 23114
  STACKTOP = sp; //@line 23115
  return $$0 | 0; //@line 23115
 }
 HEAP16[$3 >> 1] = 0; //@line 23117
 $15 = __Z13scsi_send_cmdjbiPPhPjPtj(HEAP32[28499] | 0, (HEAP8[657355] | 0) != 0, HEAP32[28497] | 0, 114e3, 118096, $3, $0) | 0; //@line 23122
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($2, HEAPU16[$3 >> 1] | 0); //@line 23130
 HEAP32[28496] = 0; //@line 23131
 HEAP16[325962] = 0; //@line 23132
 $$0 = $15 ? 0 : 2; //@line 23134
 STACKTOP = sp; //@line 23135
 return $$0 | 0; //@line 23135
}
function __Z12op_4660_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $14 = 0, $2 = 0, $4 = 0, $6 = 0, $sext = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 48666
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 48668
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 48670
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 48674
 HEAP32[$2 >> 2] = $4; //@line 48675
 $sext = $10 << 16; //@line 48676
 $11 = $sext >> 16; //@line 48677
 $12 = ~$11; //@line 48678
 $14 = ($11 | 0) == -1 & 1; //@line 48680
 HEAP32[96441] = 0; //@line 48681
 HEAP32[96442] = 0; //@line 48681
 HEAP32[96443] = 0; //@line 48681
 HEAP32[96444] = 0; //@line 48681
 HEAP32[96442] = $14; //@line 48682
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48685
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $12); //@line 48689
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48692
 return;
}
function __Z12op_20f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29361
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 29371
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 29376
 $18 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29377
 $19 = HEAP32[$18 >> 2] | 0; //@line 29378
 HEAP32[$18 >> 2] = $19 + 4; //@line 29380
 $22 = ($17 | 0) == 0 & 1; //@line 29382
 HEAP32[96441] = 0; //@line 29383
 HEAP32[96442] = 0; //@line 29383
 HEAP32[96443] = 0; //@line 29383
 HEAP32[96444] = 0; //@line 29383
 HEAP32[96442] = $22; //@line 29384
 HEAP32[96443] = $17 >>> 31; //@line 29386
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, $17); //@line 29392
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29395
 return;
}
function __Z12op_4ae8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $4 = 0, $sext11 = 0;
 $4 = HEAP32[162769] | 0; //@line 52703
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 52714
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 52716
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 52720
 $sext11 = $20 << 24; //@line 52721
 $22 = ($sext11 | 0) == 0 & 1; //@line 52723
 HEAP32[96441] = 0; //@line 52724
 HEAP32[96442] = 0; //@line 52724
 HEAP32[96443] = 0; //@line 52724
 HEAP32[96444] = 0; //@line 52724
 HEAP32[96442] = $22; //@line 52725
 HEAP32[96443] = $20 >>> 7 & 1; //@line 52728
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, ($sext11 | -2147483648) >> 24); //@line 52734
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52737
 return;
}
function __Z11op_400_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $21 = 0, $4 = 0, $6 = 0, $7 = 0, $sext27$lobit = 0, $sext27$mask = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 10239
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 10241
 $7 = HEAP32[$6 >> 2] | 0; //@line 10242
 $10 = ($7 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 10246
 $12 = $7 >>> 7; //@line 10249
 $sext27$lobit = $10 >>> 7 & 1; //@line 10252
 $sext27$mask = $10 & 255; //@line 10253
 HEAP32[96442] = ($sext27$mask | 0) == 0 & 1; //@line 10256
 HEAP32[96444] = ($sext27$lobit ^ $12 & 1) & (($4 & 255) >>> 7 & 255 ^ $12); //@line 10260
 $21 = ($4 & 255) >>> 0 > ($7 & 255) >>> 0 & 1; //@line 10263
 HEAP32[96441] = $21; //@line 10264
 HEAP32[96445] = $21; //@line 10265
 HEAP32[96443] = $sext27$lobit; //@line 10266
 HEAP32[$6 >> 2] = $sext27$mask | $7 & -256; //@line 10269
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10272
 return;
}
function __Z12op_e6f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $13 = 0, $15 = 0, $19 = 0, $20 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 50113
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 50122
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 50124
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 50128
 $20 = $19 & 1; //@line 50129
 $21 = $19 >>> 1; //@line 50130
 $$ = ($20 | 0) == 0 ? $21 & 32767 : $21 | 32768; //@line 50134
 HEAP32[96444] = 0; //@line 50138
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 50139
 HEAP32[96443] = $$ >>> 15 & 1; //@line 50142
 HEAP32[96441] = $20; //@line 50143
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $$ & 65535); //@line 50148
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50151
 return;
}
function __Z12op_4ae0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $2 = 0, $6 = 0, $8 = 0, $sext = 0;
 $1 = $0 & 7; //@line 52663
 $2 = 651040 + ($1 << 2) | 0; //@line 52664
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 52668
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 52670
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 52674
 HEAP32[$2 >> 2] = $6; //@line 52675
 $sext = $12 << 24; //@line 52676
 $14 = ($sext | 0) == 0 & 1; //@line 52678
 HEAP32[96441] = 0; //@line 52679
 HEAP32[96442] = 0; //@line 52679
 HEAP32[96443] = 0; //@line 52679
 HEAP32[96444] = 0; //@line 52679
 HEAP32[96442] = $14; //@line 52680
 HEAP32[96443] = $12 >>> 7 & 1; //@line 52683
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, ($sext | -2147483648) >> 24); //@line 52689
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52692
 return;
}
function __Z12op_2030_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 28031
 $4 = HEAP32[162769] | 0; //@line 28032
 $5 = $4 + 2 | 0; //@line 28033
 HEAP32[162769] = $5; //@line 28034
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28036
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 28043
 HEAP32[162769] = $4 + 4; //@line 28045
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 28046
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28051
 $23 = ($21 | 0) == 0 & 1; //@line 28053
 HEAP32[96441] = 0; //@line 28054
 HEAP32[96442] = 0; //@line 28054
 HEAP32[96443] = 0; //@line 28054
 HEAP32[96444] = 0; //@line 28054
 HEAP32[96442] = $23; //@line 28055
 HEAP32[96443] = $21 >>> 31; //@line 28057
 HEAP32[651008 + ($3 << 2) >> 2] = $21; //@line 28059
 return;
}
function __Z12op_23fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $37 = 0, $39 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 34800
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 34803
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 34818
 $28 = (HEAPU8[$1 + 7 >> 0] | 0) << 16 | (HEAPU8[$1 + 6 >> 0] | 0) << 24; //@line 34827
 $37 = $28 | (HEAPU8[$1 + 8 >> 0] | 0) << 8 | (HEAPU8[$1 + 9 >> 0] | 0); //@line 34836
 $39 = ($19 | 0) == 0 & 1; //@line 34838
 HEAP32[96441] = 0; //@line 34839
 HEAP32[96442] = 0; //@line 34839
 HEAP32[96443] = 0; //@line 34839
 HEAP32[96444] = 0; //@line 34839
 HEAP32[96442] = $39; //@line 34840
 HEAP32[96443] = $4 >>> 7; //@line 34842
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($37, $19); //@line 34848
 HEAP32[162769] = (HEAP32[162769] | 0) + 10; //@line 34851
 return;
}
function __Z12op_c1b0_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $25 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36338
 $8 = HEAP32[162769] | 0; //@line 36341
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 36350
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 36352
 $23 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0) & $5; //@line 36356
 $25 = ($23 | 0) == 0 & 1; //@line 36358
 HEAP32[96441] = 0; //@line 36359
 HEAP32[96442] = 0; //@line 36359
 HEAP32[96443] = 0; //@line 36359
 HEAP32[96444] = 0; //@line 36359
 HEAP32[96442] = $25; //@line 36360
 HEAP32[96443] = $23 >>> 31; //@line 36362
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 36366
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36369
 return;
}
function __Z12op_b1b0_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $25 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35735
 $8 = HEAP32[162769] | 0; //@line 35738
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 35747
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 35749
 $23 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0) ^ $5; //@line 35753
 $25 = ($23 | 0) == 0 & 1; //@line 35755
 HEAP32[96441] = 0; //@line 35756
 HEAP32[96442] = 0; //@line 35756
 HEAP32[96443] = 0; //@line 35756
 HEAP32[96444] = 0; //@line 35756
 HEAP32[96442] = $25; //@line 35757
 HEAP32[96443] = $23 >>> 31; //@line 35759
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 35763
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35766
 return;
}
function __Z12op_41b9_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $31 = 0, $4 = 0, $7 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 42332
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42335
 $$cast = $4; //@line 42336
 $16 = (HEAPU8[$$cast + 3 >> 0] | 0) << 16 | (HEAPU8[$$cast + 2 >> 0] | 0) << 24; //@line 42345
 $31 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) | 0; //@line 42360
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42363
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42366
  __Z9Exceptionij(6, $7); //@line 42367
  return;
 }
 if (($sext | 0) > ($31 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42373
  __Z9Exceptionij(6, $7); //@line 42374
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42379
  return;
 }
}
function __Z12op_21f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $15 = 0, $16 = 0, $25 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 33909
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 33919
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10) | 0; //@line 33924
 $16 = HEAP32[162769] | 0; //@line 33925
 $25 = ((HEAPU8[$16 + 4 >> 0] | 0) << 8 | (HEAPU8[$16 + 5 >> 0] | 0)) << 16 >> 16; //@line 33935
 $27 = ($15 | 0) == 0 & 1; //@line 33937
 HEAP32[96441] = 0; //@line 33938
 HEAP32[96442] = 0; //@line 33938
 HEAP32[96443] = 0; //@line 33938
 HEAP32[96444] = 0; //@line 33938
 HEAP32[96442] = $27; //@line 33939
 HEAP32[96443] = $15 >>> 31; //@line 33941
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($25 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($25, $15); //@line 33947
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 33950
 return;
}
function __Z12op_e5f0_3_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $13 = 0, $15 = 0, $19 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 50062
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 50071
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 50073
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 50077
 $$ = (HEAP32[96445] | 0) != 0 | $19 << 1; //@line 50082
 HEAP32[96444] = 0; //@line 50086
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 50087
 HEAP32[96443] = $19 >>> 14 & 1; //@line 50090
 $28 = $19 >>> 15 & 1; //@line 50092
 HEAP32[96441] = $28; //@line 50093
 HEAP32[96445] = $28; //@line 50094
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $$ & 65535); //@line 50099
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50102
 return;
}
function __Z12op_e0f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $20 = 0, $21 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49825
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 49834
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49836
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 49840
 $20 = $19 & 32768; //@line 49841
 $21 = $19 & 1; //@line 49842
 $24 = $19 >>> 1 & 32767 | $20; //@line 49845
 HEAP32[96444] = 0; //@line 49848
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 49849
 HEAP32[96443] = $20 >>> 15; //@line 49851
 HEAP32[96441] = $21; //@line 49852
 HEAP32[96445] = $21; //@line 49853
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $24); //@line 49857
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49860
 return;
}
function __Z12op_81b0_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $23 = 0, $25 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23513
 $8 = HEAP32[162769] | 0; //@line 23516
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 23525
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 23527
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$19 >> 2] >> 2] & 127]($17) | 0 | $5; //@line 23531
 $25 = ($23 | 0) == 0 & 1; //@line 23533
 HEAP32[96441] = 0; //@line 23534
 HEAP32[96442] = 0; //@line 23534
 HEAP32[96443] = 0; //@line 23534
 HEAP32[96444] = 0; //@line 23534
 HEAP32[96442] = $25; //@line 23535
 HEAP32[96443] = $23 >>> 31; //@line 23537
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 12 >> 2] & 31]($17, $23); //@line 23541
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23544
 return;
}
function __Z12op_44b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $24 = 0, $27 = 0, $32 = 0;
 $1 = HEAP32[162769] | 0; //@line 47836
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 47845
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 47854
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47856
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$21 >> 2] >> 2] & 127]($19) | 0; //@line 47859
 $27 = ($24 | 0) > 0 & 1; //@line 47863
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 47866
 HEAP32[96444] = $27 & $24 >>> 31; //@line 47868
 $32 = ($24 | 0) != 0 & 1; //@line 47870
 HEAP32[96441] = $32; //@line 47871
 HEAP32[96445] = $32; //@line 47872
 HEAP32[96443] = $27; //@line 47873
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 12 >> 2] & 31]($19, 0 - $24 | 0); //@line 47877
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 47880
 return;
}
function __Z12op_41a8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $26 = 0, $5 = 0, $8 = 0, $sext27 = 0;
 $5 = HEAP32[162769] | 0; //@line 42174
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42177
 $$cast = $5; //@line 42180
 $20 = (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 42191
 $26 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($20) | 0; //@line 42197
 $sext27 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42200
 if (($sext27 | 0) < 0) {
  HEAP32[96443] = 1; //@line 42203
  __Z9Exceptionij(6, $8); //@line 42204
  return;
 }
 if (($sext27 | 0) > ($26 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42210
  __Z9Exceptionij(6, $8); //@line 42211
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42216
  return;
 }
}
function __Z12op_e6e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $14 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 41673
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41684
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41686
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41690
 $21 = $20 & 1; //@line 41691
 $22 = $20 >>> 1; //@line 41692
 $$ = ($21 | 0) == 0 ? $22 & 32767 : $22 | 32768; //@line 41696
 HEAP32[96444] = 0; //@line 41700
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41701
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41704
 HEAP32[96441] = $21; //@line 41705
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41710
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41713
 return;
}
function __Z12op_9000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $22 = 0, $5 = 0, $6 = 0, $7 = 0, $sext32$lobit = 0, $sext32$mask = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 17643
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 17644
 $7 = HEAP32[$6 >> 2] | 0; //@line 17645
 $10 = ($7 << 24 >> 24) - ($5 << 24 >> 24) | 0; //@line 17650
 $12 = $7 >>> 7; //@line 17652
 $sext32$lobit = $10 >>> 7 & 1; //@line 17655
 $sext32$mask = $10 & 255; //@line 17656
 HEAP32[96442] = ($sext32$mask | 0) == 0 & 1; //@line 17659
 HEAP32[96444] = ($sext32$lobit ^ $12 & 1) & ($12 ^ $5 >>> 7); //@line 17663
 $22 = ($5 & 255) >>> 0 > ($7 & 255) >>> 0 & 1; //@line 17667
 HEAP32[96441] = $22; //@line 17668
 HEAP32[96445] = $22; //@line 17669
 HEAP32[96443] = $sext32$lobit; //@line 17670
 HEAP32[$6 >> 2] = $sext32$mask | $7 & -256; //@line 17673
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 17676
 return;
}
function __Z12op_c0ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 29120
 $$cast = $4; //@line 29122
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 29136
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 29141
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29142
 $26 = HEAP32[$24 >> 2] & $23; //@line 29144
 $28 = ($26 | 0) == 0 & 1; //@line 29146
 HEAP32[96441] = 0; //@line 29147
 HEAP32[96442] = 0; //@line 29147
 HEAP32[96443] = 0; //@line 29147
 HEAP32[96444] = 0; //@line 29147
 HEAP32[96442] = $28; //@line 29148
 HEAP32[96443] = $26 >>> 31; //@line 29150
 HEAP32[$24 >> 2] = $26; //@line 29151
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29154
 return;
}
function __Z12op_80ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 14797
 $$cast = $4; //@line 14799
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 14813
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 14818
 $24 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14819
 $26 = HEAP32[$24 >> 2] | $23; //@line 14821
 $28 = ($26 | 0) == 0 & 1; //@line 14823
 HEAP32[96441] = 0; //@line 14824
 HEAP32[96442] = 0; //@line 14824
 HEAP32[96443] = 0; //@line 14824
 HEAP32[96444] = 0; //@line 14824
 HEAP32[96442] = $28; //@line 14825
 HEAP32[96443] = $26 >>> 31; //@line 14827
 HEAP32[$24 >> 2] = $26; //@line 14828
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14831
 return;
}
function __Z12op_3098_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $15 = 0, $16 = 0, $18 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 35821
 $5 = HEAP32[$4 >> 2] | 0; //@line 35822
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 35828
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 35831
 $15 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35833
 $16 = $11 << 16 >> 16; //@line 35835
 $18 = ($16 | 0) == 0 & 1; //@line 35837
 HEAP32[96441] = 0; //@line 35838
 HEAP32[96442] = 0; //@line 35838
 HEAP32[96443] = 0; //@line 35838
 HEAP32[96444] = 0; //@line 35838
 HEAP32[96442] = $18; //@line 35839
 HEAP32[96443] = $11 >>> 15 & 1; //@line 35842
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($15, $16); //@line 35848
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35851
 return;
}
function __Z12op_23d0_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $27 = 0, $29 = 0, $3 = 0, $8 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34271
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 34276
 $9 = HEAP32[162769] | 0; //@line 34277
 $18 = (HEAPU8[$9 + 3 >> 0] | 0) << 16 | (HEAPU8[$9 + 2 >> 0] | 0) << 24; //@line 34286
 $27 = $18 | (HEAPU8[$9 + 4 >> 0] | 0) << 8 | (HEAPU8[$9 + 5 >> 0] | 0); //@line 34295
 $29 = ($8 | 0) == 0 & 1; //@line 34297
 HEAP32[96441] = 0; //@line 34298
 HEAP32[96442] = 0; //@line 34298
 HEAP32[96443] = 0; //@line 34298
 HEAP32[96444] = 0; //@line 34298
 HEAP32[96442] = $29; //@line 34299
 HEAP32[96443] = $8 >>> 31; //@line 34301
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($27, $8); //@line 34307
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34310
 return;
}
function __Z11op_87b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = HEAP32[162769] | 0; //@line 14524
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14526
 $4 = $1 + 4 | 0; //@line 14527
 HEAP32[162769] = $4; //@line 14528
 $8 = (HEAP32[162768] | 0) + $4 - (HEAP32[162770] | 0) | 0; //@line 14533
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 14540
 HEAP32[162769] = $1 + 6; //@line 14542
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 14543
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 14545
 $25 = $3 & 7; //@line 14551
 $26 = 1 << $25; //@line 14552
 $28 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) ^ $26) << 24 >> 24; //@line 14555
 HEAP32[96442] = ($28 & $26) >>> $25; //@line 14558
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $28); //@line 14562
 return;
}
function __Z11op_1bb_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7889
 $5 = HEAP32[162769] | 0; //@line 7890
 $6 = $5 + 2 | 0; //@line 7891
 HEAP32[162769] = $6; //@line 7892
 $10 = $6 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 7897
 $17 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0); //@line 7904
 HEAP32[162769] = $5 + 4; //@line 7906
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 7907
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 7909
 $26 = $4 & 7; //@line 7914
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 7916
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 7920
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, ($27 & (1 << $26 ^ 255)) << 24 >> 24); //@line 7929
 return;
}
function __Z11op_170_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $26 = 0, $28 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7196
 $6 = HEAP32[162769] | 0; //@line 7197
 $7 = $6 + 2 | 0; //@line 7198
 HEAP32[162769] = $7; //@line 7199
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7201
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 7208
 HEAP32[162769] = $6 + 4; //@line 7210
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 7211
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 7213
 $25 = $5 & 7; //@line 7218
 $26 = 1 << $25; //@line 7219
 $28 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) ^ $26) << 24 >> 24; //@line 7222
 HEAP32[96442] = ($28 & $26) >>> $25; //@line 7225
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $28); //@line 7229
 return;
}
function __Z12op_e4d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40910
 $3 = HEAP32[$2 >> 2] | 0; //@line 40911
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40913
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40917
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 40920
 $12 = $9 & 1; //@line 40921
 $13 = $9 >>> 1; //@line 40922
 $$ = (HEAP32[96445] | 0) == 0 ? $13 & 32767 : $13 | 32768; //@line 40927
 HEAP32[96444] = 0; //@line 40931
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 40932
 HEAP32[96443] = $$ >>> 15 & 1; //@line 40935
 HEAP32[96441] = $12; //@line 40936
 HEAP32[96445] = $12; //@line 40937
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 40942
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40945
 return;
}
function __Z12op_c1a8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30594
 $8 = HEAP32[162769] | 0; //@line 30597
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 30608
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 30610
 $24 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0) & $5; //@line 30614
 $26 = ($24 | 0) == 0 & 1; //@line 30616
 HEAP32[96441] = 0; //@line 30617
 HEAP32[96442] = 0; //@line 30617
 HEAP32[96443] = 0; //@line 30617
 HEAP32[96444] = 0; //@line 30617
 HEAP32[96442] = $26; //@line 30618
 HEAP32[96443] = $24 >>> 31; //@line 30620
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 30624
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30627
 return;
}
function __Z12op_b1a8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27164
 $8 = HEAP32[162769] | 0; //@line 27167
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 27178
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 27180
 $24 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0) ^ $5; //@line 27184
 $26 = ($24 | 0) == 0 & 1; //@line 27186
 HEAP32[96441] = 0; //@line 27187
 HEAP32[96442] = 0; //@line 27187
 HEAP32[96443] = 0; //@line 27187
 HEAP32[96444] = 0; //@line 27187
 HEAP32[96442] = $26; //@line 27188
 HEAP32[96443] = $24 >>> 31; //@line 27190
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 27194
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27197
 return;
}
function __Z12op_9090_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $20 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19034
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 19039
 $11 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19040
 $12 = HEAP32[$11 >> 2] | 0; //@line 19041
 $13 = $12 - $10 | 0; //@line 19042
 $$lobit37 = $12 >>> 31; //@line 19044
 $$lobit38 = $13 >>> 31; //@line 19045
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 19048
 HEAP32[96444] = ($$lobit38 ^ $$lobit37) & ($$lobit37 ^ $10 >>> 31); //@line 19052
 $20 = $12 >>> 0 < $10 >>> 0 & 1; //@line 19054
 HEAP32[96441] = $20; //@line 19055
 HEAP32[96445] = $20; //@line 19056
 HEAP32[96443] = $$lobit38; //@line 19057
 HEAP32[$11 >> 2] = $13; //@line 19058
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19061
 return;
}
function __Z12op_4e73_4_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $17 = 0, $25 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 3822
  return;
 } else {
  $3 = HEAP32[162767] | 0; //@line 3825
  $10 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0) & 65535; //@line 3832
  $12 = (HEAP32[162767] | 0) + 2 | 0; //@line 3834
  HEAP32[162767] = $12; //@line 3835
  $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 3840
  HEAP32[162767] = (HEAP32[162767] | 0) + 4; //@line 3843
  HEAP16[325558] = $10; //@line 3844
  $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($17) | 0; //@line 3850
  HEAP32[162770] = $25; //@line 3851
  HEAP32[162769] = $25; //@line 3852
  HEAP32[162768] = $17; //@line 3853
  __Z10MakeFromSRv(); //@line 3854
  return;
 }
}
function __Z12op_41b0_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $25 = 0, $5 = 0, $8 = 0, $sext = 0;
 $5 = HEAP32[162769] | 0; //@line 45984
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 45987
 $$cast = $5; //@line 45990
 $19 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45999
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 46005
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 46008
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 46011
  __Z9Exceptionij(6, $8); //@line 46012
  return;
 }
 if (($sext | 0) > ($25 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 46018
  __Z9Exceptionij(6, $8); //@line 46019
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46024
  return;
 }
}
function __Z12op_21e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $2 = 0, $21 = 0, $4 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 33759
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 33761
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($4 >>> 16 << 2) >> 2] >> 2] & 127]($4) | 0; //@line 33766
 HEAP32[$2 >> 2] = $4; //@line 33767
 $10 = HEAP32[162769] | 0; //@line 33768
 $19 = ((HEAPU8[$10 + 2 >> 0] | 0) << 8 | (HEAPU8[$10 + 3 >> 0] | 0)) << 16 >> 16; //@line 33778
 $21 = ($9 | 0) == 0 & 1; //@line 33780
 HEAP32[96441] = 0; //@line 33781
 HEAP32[96442] = 0; //@line 33781
 HEAP32[96443] = 0; //@line 33781
 HEAP32[96444] = 0; //@line 33781
 HEAP32[96442] = $21; //@line 33782
 HEAP32[96443] = $9 >>> 31; //@line 33784
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, $9); //@line 33790
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33793
 return;
}
function __Z10op_50_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $19 = 0, $2 = 0, $21 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 5098
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 5106
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5108
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 5110
 $sext1617 = $10 | (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0); //@line 5115
 $19 = $sext1617 << 16 >> 16; //@line 5117
 $21 = ($19 | 0) == 0 & 1; //@line 5119
 HEAP32[96441] = 0; //@line 5120
 HEAP32[96442] = 0; //@line 5120
 HEAP32[96443] = 0; //@line 5120
 HEAP32[96444] = 0; //@line 5120
 HEAP32[96442] = $21; //@line 5121
 HEAP32[96443] = $sext1617 >>> 15 & 1; //@line 5124
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $19); //@line 5128
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5131
 return;
}
function __Z10m68k_resetv() {
 var $1 = 0, $7 = 0;
 HEAP32[162767] = 8192; //@line 52027
 $1 = (HEAP32[30896] | 0) + 42 | 0; //@line 52029
 $7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1) | 0; //@line 52035
 HEAP32[162770] = $7; //@line 52036
 HEAP32[162769] = $7; //@line 52037
 HEAP32[162768] = $1; //@line 52038
 HEAP8[651120] = 1; //@line 52039
 HEAP8[651121] = 0; //@line 52040
 HEAP8[651123] = 0; //@line 52041
 HEAP8[651118] = 0; //@line 52042
 HEAP8[651119] = 0; //@line 52043
 HEAP32[96441] = 0; //@line 52044
 HEAP32[96442] = 0; //@line 52044
 HEAP32[96443] = 0; //@line 52044
 HEAP32[96444] = 0; //@line 52044
 HEAP32[96445] = 0; //@line 52044
 HEAP32[162771] = 0; //@line 52045
 HEAP32[162772] = 7; //@line 52046
 HEAP32[162775] = 0; //@line 52047
 HEAP32[162774] = 0; //@line 52048
 HEAP32[162773] = 0; //@line 52049
 __Z9fpu_resetv(); //@line 52050
 return;
}
function __Z12op_e5e8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $14 = 0, $16 = 0, $20 = 0, $29 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 41340
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41351
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 41353
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 41357
 $$ = (HEAP32[96445] | 0) != 0 | $20 << 1; //@line 41362
 HEAP32[96444] = 0; //@line 41366
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41367
 HEAP32[96443] = $20 >>> 14 & 1; //@line 41370
 $29 = $20 >>> 15 & 1; //@line 41372
 HEAP32[96441] = $29; //@line 41373
 HEAP32[96445] = $29; //@line 41374
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $$ & 65535); //@line 41379
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41382
 return;
}
function __Z12op_e1d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 39984
 $3 = HEAP32[$2 >> 2] | 0; //@line 39985
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 39987
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 39991
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 39994
 $12 = $9 & 32768; //@line 39995
 $13 = $9 << 1; //@line 39996
 HEAP32[96442] = ($9 & 32767 | 0) == 0 & 1; //@line 40001
 HEAP32[96443] = $9 >>> 14 & 1; //@line 40004
 $$lobit = $12 >>> 15; //@line 40006
 HEAP32[96441] = $$lobit; //@line 40007
 HEAP32[96445] = $$lobit; //@line 40008
 HEAP32[96444] = ($13 & 32768 ^ $12) >>> 15; //@line 40011
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $13 & 131070); //@line 40015
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40018
 return;
}
function __Z12op_e0e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $22 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 38597
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 38608
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 38610
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 38614
 $21 = $20 & 32768; //@line 38615
 $22 = $20 & 1; //@line 38616
 $25 = $20 >>> 1 & 32767 | $21; //@line 38619
 HEAP32[96444] = 0; //@line 38622
 HEAP32[96442] = ($25 | 0) == 0 & 1; //@line 38623
 HEAP32[96443] = $21 >>> 15; //@line 38625
 HEAP32[96441] = $22; //@line 38626
 HEAP32[96445] = $22; //@line 38627
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $25); //@line 38631
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38634
 return;
}
function __Z12op_81a8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16687
 $8 = HEAP32[162769] | 0; //@line 16690
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 16701
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 16703
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$20 >> 2] >> 2] & 127]($18) | 0 | $5; //@line 16707
 $26 = ($24 | 0) == 0 & 1; //@line 16709
 HEAP32[96441] = 0; //@line 16710
 HEAP32[96442] = 0; //@line 16710
 HEAP32[96443] = 0; //@line 16710
 HEAP32[96444] = 0; //@line 16710
 HEAP32[96442] = $26; //@line 16711
 HEAP32[96443] = $24 >>> 31; //@line 16713
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 12 >> 2] & 31]($18, $24); //@line 16717
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16720
 return;
}
function __Z11op_a90_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $22 = 0, $24 = 0, $28 = 0, $30 = 0;
 $2 = HEAP32[162769] | 0; //@line 17832
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 17850
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 17852
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 17854
 $28 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0) ^ $20; //@line 17858
 $30 = ($28 | 0) == 0 & 1; //@line 17860
 HEAP32[96441] = 0; //@line 17861
 HEAP32[96442] = 0; //@line 17861
 HEAP32[96443] = 0; //@line 17861
 HEAP32[96444] = 0; //@line 17861
 HEAP32[96442] = $30; //@line 17862
 HEAP32[96443] = $28 >>> 31; //@line 17864
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $28); //@line 17868
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17871
 return;
}
function __Z12op_c1f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $26 = 0, $28 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36382
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36391
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 36397
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36398
 $26 = Math_imul(HEAP32[$22 >> 2] << 16 >> 16, $21 << 16 >> 16) | 0; //@line 36404
 $28 = ($26 | 0) == 0 & 1; //@line 36406
 HEAP32[96441] = 0; //@line 36407
 HEAP32[96442] = 0; //@line 36407
 HEAP32[96443] = 0; //@line 36407
 HEAP32[96444] = 0; //@line 36407
 HEAP32[96442] = $28; //@line 36408
 HEAP32[96443] = $26 >>> 31; //@line 36410
 HEAP32[$22 >> 2] = $26; //@line 36411
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36414
 return;
}
function __Z12op_c100_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $16 = 0, $20 = 0, $24 = 0, $25 = 0, $28 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29684
 $7 = HEAP32[$6 >> 2] | 0; //@line 29685
 $8 = HEAP32[651008 + (($0 & 7) << 2) >> 2] << 24 >> 24; //@line 29687
 $10 = $7 << 24 >> 24; //@line 29690
 $16 = ($10 & 15) + ($8 & 15) + ((HEAP32[96445] | 0) != 0 & 1) | 0; //@line 29696
 $20 = ($10 & 240) + ($8 & 240) + $16 | 0; //@line 29700
 $$ = $16 >>> 0 > 9 ? $20 + 6 | 0 : $20; //@line 29703
 $24 = ($$ & 1008) >>> 0 > 144; //@line 29705
 $25 = $24 & 1; //@line 29706
 HEAP32[96441] = $25; //@line 29709
 HEAP32[96445] = $25; //@line 29710
 $28 = ($24 ? $$ + 96 | 0 : $$) & 255; //@line 29712
 HEAP32[96442] = ($28 | 0) == 0 & HEAP32[96442]; //@line 29716
 HEAP32[$6 >> 2] = $28 | $7 & -256; //@line 29719
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29722
 return;
}
function __Z12op_e4f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 41101
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 41111
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41113
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 41117
 $17 = $16 & 1; //@line 41118
 $18 = $16 >>> 1; //@line 41119
 $$ = (HEAP32[96445] | 0) == 0 ? $18 & 32767 : $18 | 32768; //@line 41124
 HEAP32[96444] = 0; //@line 41128
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41129
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41132
 HEAP32[96441] = $17; //@line 41133
 HEAP32[96445] = $17; //@line 41134
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $$ & 65535); //@line 41139
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41142
 return;
}
function __Z12op_e1f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 40170
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 40180
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40182
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 40186
 $17 = $16 & 32768; //@line 40187
 $18 = $16 << 1; //@line 40188
 HEAP32[96442] = ($16 & 32767 | 0) == 0 & 1; //@line 40193
 HEAP32[96443] = $16 >>> 14 & 1; //@line 40196
 $$lobit = $17 >>> 15; //@line 40198
 HEAP32[96441] = $$lobit; //@line 40199
 HEAP32[96445] = $$lobit; //@line 40200
 HEAP32[96444] = ($18 & 32768 ^ $17) >>> 15; //@line 40203
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $18 & 131070); //@line 40207
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40210
 return;
}
function __Z12op_5140_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $22 = 0, $4 = 0, $6 = 0, $7 = 0, $sext36$lobit = 0, $sext36$mask = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5478
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 5480
 $7 = HEAP32[$6 >> 2] | 0; //@line 5481
 $10 = ($7 << 16 >> 16) - ($4 << 16 >> 16) | 0; //@line 5486
 $12 = $7 >>> 15; //@line 5488
 $sext36$lobit = $10 >>> 15 & 1; //@line 5491
 $sext36$mask = $10 & 65535; //@line 5492
 HEAP32[96442] = ($sext36$mask | 0) == 0 & 1; //@line 5495
 HEAP32[96444] = ($sext36$lobit ^ $12 & 1) & ($12 ^ $4 >>> 15); //@line 5499
 $22 = ($4 & 65535) >>> 0 > ($7 & 65535) >>> 0 & 1; //@line 5503
 HEAP32[96441] = $22; //@line 5504
 HEAP32[96445] = $22; //@line 5505
 HEAP32[96443] = $sext36$lobit; //@line 5506
 HEAP32[$6 >> 2] = $sext36$mask | $7 & -65536; //@line 5509
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5512
 return;
}
function __Z11op_250_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $19 = 0, $2 = 0, $21 = 0, $sext1617 = 0;
 $2 = HEAP32[162769] | 0; //@line 8839
 $10 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8847
 $12 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8849
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 8851
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 4 >> 2] & 127]($12) | 0) & $10; //@line 8856
 $19 = $sext1617 << 16 >> 16; //@line 8858
 $21 = ($19 | 0) == 0 & 1; //@line 8860
 HEAP32[96441] = 0; //@line 8861
 HEAP32[96442] = 0; //@line 8861
 HEAP32[96443] = 0; //@line 8861
 HEAP32[96444] = 0; //@line 8861
 HEAP32[96442] = $21; //@line 8862
 HEAP32[96443] = $sext1617 >>> 15; //@line 8864
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 16 >> 2] & 31]($12, $19); //@line 8868
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8871
 return;
}
function __Z12op_d0bc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $32 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 33084
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 33087
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 33102
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 33103
 $23 = HEAP32[$22 >> 2] | 0; //@line 33104
 $24 = $21 + $23 | 0; //@line 33105
 $$lobit31 = $24 >>> 31; //@line 33108
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 33111
 HEAP32[96444] = ($$lobit31 ^ $6 >>> 7) & ($$lobit31 ^ $23 >>> 31); //@line 33115
 $32 = $21 >>> 0 > ~$23 >>> 0 & 1; //@line 33118
 HEAP32[96441] = $32; //@line 33119
 HEAP32[96445] = $32; //@line 33120
 HEAP32[96443] = $$lobit31; //@line 33121
 HEAP32[$22 >> 2] = $24; //@line 33122
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 33125
 return;
}
function __Z12op_e178_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 39550
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39551
 $7 = HEAP32[$6 >> 2] | 0; //@line 39552
 $8 = $7 & 65535; //@line 39553
 $10 = ($5 & 63 | 0) == 0; //@line 39555
 $11 = $5 & 15; //@line 39556
 $15 = $8 << $11 | $8 >>> (16 - $11 | 0); //@line 39560
 HEAP32[96441] = 0; //@line 39561
 HEAP32[96442] = 0; //@line 39561
 HEAP32[96443] = 0; //@line 39561
 HEAP32[96444] = 0; //@line 39561
 if ($10) {
  $$0 = $8; //@line 39563
 } else {
  HEAP32[96441] = $15 & 1; //@line 39567
  $$0 = $15 & 65535; //@line 39568
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39572
 HEAP32[96443] = $$0 >>> 15; //@line 39574
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 39577
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39580
 return;
}
function __Z12op_c1f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $3 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 31044
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 31053
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 31068
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31069
 $32 = Math_imul(HEAP32[$28 >> 2] << 16 >> 16, $27 << 16 >> 16) | 0; //@line 31075
 $34 = ($32 | 0) == 0 & 1; //@line 31077
 HEAP32[96441] = 0; //@line 31078
 HEAP32[96442] = 0; //@line 31078
 HEAP32[96443] = 0; //@line 31078
 HEAP32[96444] = 0; //@line 31078
 HEAP32[96442] = $34; //@line 31079
 HEAP32[96443] = $32 >>> 31; //@line 31081
 HEAP32[$28 >> 2] = $32; //@line 31082
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31085
 return;
}
function __Z12op_46b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $24 = 0, $25 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 49113
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 49122
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 49131
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 49133
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$21 >> 2] >> 2] & 127]($19) | 0; //@line 49136
 $25 = ~$24; //@line 49137
 $27 = ($24 | 0) == -1 & 1; //@line 49139
 HEAP32[96441] = 0; //@line 49140
 HEAP32[96442] = 0; //@line 49140
 HEAP32[96443] = 0; //@line 49140
 HEAP32[96444] = 0; //@line 49140
 HEAP32[96442] = $27; //@line 49141
 HEAP32[96443] = $24 >>> 31 ^ 1; //@line 49144
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 12 >> 2] & 31]($19, $25); //@line 49148
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49151
 return;
}
function __Z12op_3110_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 36859
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 36865
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36866
 $14 = (HEAP32[$12 >> 2] | 0) + -2 | 0; //@line 36868
 HEAP32[$12 >> 2] = $14; //@line 36869
 $15 = $11 << 16 >> 16; //@line 36871
 $17 = ($15 | 0) == 0 & 1; //@line 36873
 HEAP32[96441] = 0; //@line 36874
 HEAP32[96442] = 0; //@line 36874
 HEAP32[96443] = 0; //@line 36874
 HEAP32[96444] = 0; //@line 36874
 HEAP32[96442] = $17; //@line 36875
 HEAP32[96443] = $11 >>> 15 & 1; //@line 36878
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, $15); //@line 36884
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36887
 return;
}
function _realloc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$1 = 0, $11 = 0, $14 = 0, $17 = 0, $22 = 0;
 if (!$0) {
  $$1 = _malloc($1) | 0; //@line 53342
  return $$1 | 0; //@line 53343
 }
 if ($1 >>> 0 > 4294967231) {
  HEAP32[(___errno_location() | 0) >> 2] = 12; //@line 53348
  $$1 = 0; //@line 53349
  return $$1 | 0; //@line 53350
 }
 $11 = _try_realloc_chunk($0 + -8 | 0, $1 >>> 0 < 11 ? 16 : $1 + 11 & -8) | 0; //@line 53357
 if ($11 | 0) {
  $$1 = $11 + 8 | 0; //@line 53361
  return $$1 | 0; //@line 53362
 }
 $14 = _malloc($1) | 0; //@line 53364
 if (!$14) {
  $$1 = 0; //@line 53367
  return $$1 | 0; //@line 53368
 }
 $17 = HEAP32[$0 + -4 >> 2] | 0; //@line 53371
 $22 = ($17 & -8) - (($17 & 3 | 0) == 0 ? 8 : 4) | 0; //@line 53376
 _memcpy($14 | 0, $0 | 0, ($22 >>> 0 < $1 >>> 0 ? $22 : $1) | 0) | 0; //@line 53379
 _free($0); //@line 53380
 $$1 = $14; //@line 53381
 return $$1 | 0; //@line 53382
}
function __Z11op_1fb_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $4 = 0, $5 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8402
 $5 = HEAP32[162769] | 0; //@line 8403
 $6 = $5 + 2 | 0; //@line 8404
 HEAP32[162769] = $6; //@line 8405
 $10 = $6 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 8410
 $17 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0); //@line 8417
 HEAP32[162769] = $5 + 4; //@line 8419
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 8420
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 8422
 $26 = $4 & 7; //@line 8427
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 8429
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 8433
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, ($27 | 1 << $26) << 24 >> 24); //@line 8441
 return;
}
function __Z12op_e4e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40954
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 40956
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40958
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 40962
 HEAP32[$2 >> 2] = $4; //@line 40963
 $11 = $10 & 1; //@line 40964
 $12 = $10 >>> 1; //@line 40965
 $$ = (HEAP32[96445] | 0) == 0 ? $12 & 32767 : $12 | 32768; //@line 40970
 HEAP32[96444] = 0; //@line 40974
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 40975
 HEAP32[96443] = $$ >>> 15 & 1; //@line 40978
 HEAP32[96441] = $11; //@line 40979
 HEAP32[96445] = $11; //@line 40980
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $$ & 65535); //@line 40985
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40988
 return;
}
function __Z12op_e1e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40027
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 40029
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40031
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 40035
 HEAP32[$2 >> 2] = $4; //@line 40036
 $11 = $10 & 32768; //@line 40037
 $12 = $10 << 1; //@line 40038
 HEAP32[96442] = ($10 & 32767 | 0) == 0 & 1; //@line 40043
 HEAP32[96443] = $10 >>> 14 & 1; //@line 40046
 $$lobit = $11 >>> 15; //@line 40048
 HEAP32[96441] = $$lobit; //@line 40049
 HEAP32[96445] = $$lobit; //@line 40050
 HEAP32[96444] = ($12 & 32768 ^ $11) >>> 15; //@line 40053
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $12 & 131070); //@line 40057
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40060
 return;
}
function __Z12op_c1e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $27 = 0, $29 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 30911
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 30922
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 30928
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30929
 $27 = Math_imul(HEAP32[$23 >> 2] << 16 >> 16, $22 << 16 >> 16) | 0; //@line 30935
 $29 = ($27 | 0) == 0 & 1; //@line 30937
 HEAP32[96441] = 0; //@line 30938
 HEAP32[96442] = 0; //@line 30938
 HEAP32[96443] = 0; //@line 30938
 HEAP32[96444] = 0; //@line 30938
 HEAP32[96442] = $29; //@line 30939
 HEAP32[96443] = $27 >>> 31; //@line 30941
 HEAP32[$23 >> 2] = $27; //@line 30942
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30945
 return;
}
function __Z12op_e078_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38103
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38104
 $7 = HEAP32[$6 >> 2] | 0; //@line 38105
 $8 = $7 & 65535; //@line 38106
 $10 = ($5 & 63 | 0) == 0; //@line 38108
 $11 = $5 & 15; //@line 38109
 $15 = $8 << 16 - $11 & 65535 | $8 >>> $11; //@line 38114
 HEAP32[96441] = 0; //@line 38115
 HEAP32[96442] = 0; //@line 38115
 HEAP32[96443] = 0; //@line 38115
 HEAP32[96444] = 0; //@line 38115
 if ($10) {
  $$0 = $8; //@line 38117
 } else {
  HEAP32[96441] = $15 >>> 15; //@line 38120
  $$0 = $15; //@line 38121
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38125
 HEAP32[96443] = $$0 >>> 15; //@line 38127
 HEAP32[$6 >> 2] = $$0 | $7 & -65536; //@line 38130
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38133
 return;
}
function __Z12op_d190_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $12 = 0, $13 = 0, $21 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 34729
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34731
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 34733
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 34736
 $13 = $12 + $5 | 0; //@line 34737
 $$lobit38 = $13 >>> 31; //@line 34740
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 34743
 HEAP32[96444] = ($$lobit38 ^ $5 >>> 31) & ($$lobit38 ^ $12 >>> 31); //@line 34747
 $21 = $5 >>> 0 > ~$12 >>> 0 & 1; //@line 34750
 HEAP32[96441] = $21; //@line 34751
 HEAP32[96445] = $21; //@line 34752
 HEAP32[96443] = $$lobit38; //@line 34753
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 34757
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34760
 return;
}
function __Z12op_4af0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $21 = 0, $4 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 3200
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 3209
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 3211
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 3215
 $sext = $19 << 24; //@line 3216
 $21 = ($sext | 0) == 0 & 1; //@line 3218
 HEAP32[96441] = 0; //@line 3219
 HEAP32[96442] = 0; //@line 3219
 HEAP32[96443] = 0; //@line 3219
 HEAP32[96444] = 0; //@line 3219
 HEAP32[96442] = $21; //@line 3220
 HEAP32[96443] = $19 >>> 7 & 1; //@line 3223
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 20 >> 2] & 31]($13, ($sext | -2147483648) >> 24); //@line 3229
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3232
 return;
}
function __Z13PrefsAddInt32PKci($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$sink$i = 0, $11 = 0, $2 = 0, $4 = 0, $9 = 0;
 $2 = _malloc(4) | 0; //@line 1281
 if (!$2) {
  return;
 }
 HEAP8[$2 >> 0] = $1; //@line 1286
 HEAP8[$2 + 1 >> 0] = $1 >> 8; //@line 1286
 HEAP8[$2 + 2 >> 0] = $1 >> 16; //@line 1286
 HEAP8[$2 + 3 >> 0] = $1 >> 24; //@line 1286
 $4 = __Znwj(16) | 0; //@line 1287
 HEAP32[$4 >> 2] = 0; //@line 1288
 HEAP32[$4 + 4 >> 2] = ___strdup($0) | 0; //@line 1291
 HEAP32[$4 + 8 >> 2] = 2; //@line 1293
 HEAP32[$4 + 12 >> 2] = $2; //@line 1295
 $9 = HEAP32[28198] | 0; //@line 1296
 if (!$9) {
  $$sink$i = 112792; //@line 1299
 } else {
  $$0$i = $9; //@line 1301
  while (1) {
   $11 = HEAP32[$$0$i >> 2] | 0; //@line 1303
   if (!$11) {
    break;
   } else {
    $$0$i = $11; //@line 1308
   }
  }
  $$sink$i = $$0$i; //@line 1311
 }
 HEAP32[$$sink$i >> 2] = $4; //@line 1313
 return;
}
function __Z11op_870_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 14338
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 14340
 $5 = $2 + 4 | 0; //@line 14341
 HEAP32[162769] = $5; //@line 14342
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14344
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 14351
 HEAP32[162769] = $2 + 6; //@line 14353
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 14354
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 14356
 $24 = $4 & 7; //@line 14362
 $25 = 1 << $24; //@line 14363
 $27 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) ^ $25) << 24 >> 24; //@line 14366
 HEAP32[96442] = ($27 & $25) >>> $24; //@line 14369
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $27); //@line 14373
 return;
}
function __Z12op_c198_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30523
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30524
 $7 = HEAP32[$6 >> 2] | 0; //@line 30525
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 30527
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 30530
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 30533
 $15 = $12 & $5; //@line 30534
 $17 = ($15 | 0) == 0 & 1; //@line 30536
 HEAP32[96441] = 0; //@line 30537
 HEAP32[96442] = 0; //@line 30537
 HEAP32[96443] = 0; //@line 30537
 HEAP32[96444] = 0; //@line 30537
 HEAP32[96442] = $17; //@line 30538
 HEAP32[96443] = $15 >>> 31; //@line 30540
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 30544
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30547
 return;
}
function __Z12op_c0f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $26 = 0, $28 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36156
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36165
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 36171
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36172
 $26 = Math_imul(HEAP32[$22 >> 2] & 65535, $21 & 65535) | 0; //@line 36176
 $28 = ($26 | 0) == 0 & 1; //@line 36178
 HEAP32[96441] = 0; //@line 36179
 HEAP32[96442] = 0; //@line 36179
 HEAP32[96443] = 0; //@line 36179
 HEAP32[96444] = 0; //@line 36179
 HEAP32[96442] = $28; //@line 36180
 HEAP32[96443] = $26 >>> 31; //@line 36182
 HEAP32[$22 >> 2] = $26; //@line 36183
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36186
 return;
}
function __Z12op_b198_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27093
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 27094
 $7 = HEAP32[$6 >> 2] | 0; //@line 27095
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 27097
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 27100
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 27103
 $15 = $12 ^ $5; //@line 27104
 $17 = ($15 | 0) == 0 & 1; //@line 27106
 HEAP32[96441] = 0; //@line 27107
 HEAP32[96442] = 0; //@line 27107
 HEAP32[96443] = 0; //@line 27107
 HEAP32[96444] = 0; //@line 27107
 HEAP32[96442] = $17; //@line 27108
 HEAP32[96443] = $15 >>> 31; //@line 27110
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 27114
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27117
 return;
}
function __Z12op_8198_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16616
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 16617
 $7 = HEAP32[$6 >> 2] | 0; //@line 16618
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 16620
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 16623
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 4; //@line 16626
 $15 = $12 | $5; //@line 16627
 $17 = ($15 | 0) == 0 & 1; //@line 16629
 HEAP32[96441] = 0; //@line 16630
 HEAP32[96442] = 0; //@line 16630
 HEAP32[96443] = 0; //@line 16630
 HEAP32[96444] = 0; //@line 16630
 HEAP32[96442] = $17; //@line 16631
 HEAP32[96443] = $15 >>> 31; //@line 16633
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $15); //@line 16637
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16640
 return;
}
function __Z12op_30a0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 35862
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 35864
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 35870
 HEAP32[$4 >> 2] = $6; //@line 35871
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35873
 $15 = $12 << 16 >> 16; //@line 35875
 $17 = ($15 | 0) == 0 & 1; //@line 35877
 HEAP32[96441] = 0; //@line 35878
 HEAP32[96442] = 0; //@line 35878
 HEAP32[96443] = 0; //@line 35878
 HEAP32[96444] = 0; //@line 35878
 HEAP32[96442] = $17; //@line 35879
 HEAP32[96443] = $12 >>> 15 & 1; //@line 35882
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, $15); //@line 35888
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35891
 return;
}
function __Z12op_4678_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $17 = 0, $18 = 0, $20 = 0, $sext11 = 0;
 $1 = HEAP32[162769] | 0; //@line 48788
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 48798
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 48800
 $sext11 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0) << 16; //@line 48805
 $17 = $sext11 >> 16; //@line 48806
 $18 = ~$17; //@line 48807
 $20 = ($17 | 0) == -1 & 1; //@line 48809
 HEAP32[96441] = 0; //@line 48810
 HEAP32[96442] = 0; //@line 48810
 HEAP32[96443] = 0; //@line 48810
 HEAP32[96444] = 0; //@line 48810
 HEAP32[96442] = $20; //@line 48811
 HEAP32[96443] = ($sext11 | 0) > -65536 & 1; //@line 48814
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $18); //@line 48818
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48821
 return;
}
function __Z12op_30b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 35999
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 36009
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 36015
 $20 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36017
 $21 = $18 << 16 >> 16; //@line 36019
 $23 = ($21 | 0) == 0 & 1; //@line 36021
 HEAP32[96441] = 0; //@line 36022
 HEAP32[96442] = 0; //@line 36022
 HEAP32[96443] = 0; //@line 36022
 HEAP32[96444] = 0; //@line 36022
 HEAP32[96442] = $23; //@line 36023
 HEAP32[96443] = $18 >>> 15 & 1; //@line 36026
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($20, $21); //@line 36032
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36035
 return;
}
function __Z11op_a38_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 15716
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15718
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 15728
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15730
 $20 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0) ^ $3 & 255; //@line 15736
 $21 = $20 << 24 >> 24; //@line 15738
 $23 = ($21 | 0) == 0 & 1; //@line 15740
 HEAP32[96441] = 0; //@line 15741
 HEAP32[96442] = 0; //@line 15741
 HEAP32[96443] = 0; //@line 15741
 HEAP32[96444] = 0; //@line 15741
 HEAP32[96442] = $23; //@line 15742
 HEAP32[96443] = $20 >>> 7 & 1; //@line 15745
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, $21); //@line 15749
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15752
 return;
}
function __Z11op_680_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $31 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 13168
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 13171
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13186
 $21 = 651008 + (($0 & 7) << 2) | 0; //@line 13187
 $22 = HEAP32[$21 >> 2] | 0; //@line 13188
 $23 = $20 + $22 | 0; //@line 13189
 $$lobit31 = $23 >>> 31; //@line 13192
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 13195
 HEAP32[96444] = ($$lobit31 ^ $5 >>> 7) & ($$lobit31 ^ $22 >>> 31); //@line 13199
 $31 = $20 >>> 0 > ~$22 >>> 0 & 1; //@line 13202
 HEAP32[96441] = $31; //@line 13203
 HEAP32[96445] = $31; //@line 13204
 HEAP32[96443] = $$lobit31; //@line 13205
 HEAP32[$21 >> 2] = $23; //@line 13206
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13209
 return;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $7$0 = 0, $7$1 = 0;
 $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 4605
 $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 4606
 $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 4607
 $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 4608
 $4$0 = _i64Subtract($1$0 ^ $a$0 | 0, $1$1 ^ $a$1 | 0, $1$0 | 0, $1$1 | 0) | 0; //@line 4609
 $4$1 = tempRet0; //@line 4610
 $7$0 = $2$0 ^ $1$0; //@line 4612
 $7$1 = $2$1 ^ $1$1; //@line 4613
 return _i64Subtract((___udivmoddi4($4$0, $4$1, _i64Subtract($2$0 ^ $b$0 | 0, $2$1 ^ $b$1 | 0, $2$0 | 0, $2$1 | 0) | 0, tempRet0, 0) | 0) ^ $7$0 | 0, tempRet0 ^ $7$1 | 0, $7$0 | 0, $7$1 | 0) | 0; //@line 4616
}
function __Z12op_4638_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $17 = 0, $18 = 0, $20 = 0, $sext9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48480
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 48490
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 48492
 $sext9 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0) << 24; //@line 48497
 $17 = $sext9 >> 24; //@line 48498
 $18 = ~$17; //@line 48499
 $20 = ($17 | 0) == -1 & 1; //@line 48501
 HEAP32[96441] = 0; //@line 48502
 HEAP32[96442] = 0; //@line 48502
 HEAP32[96443] = 0; //@line 48502
 HEAP32[96444] = 0; //@line 48502
 HEAP32[96442] = $20; //@line 48503
 HEAP32[96443] = ($sext9 | 0) > -16777216 & 1; //@line 48506
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $18); //@line 48510
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48513
 return;
}
function __Z12op_30d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 36311
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 36317
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36318
 $13 = HEAP32[$12 >> 2] | 0; //@line 36319
 HEAP32[$12 >> 2] = $13 + 2; //@line 36321
 $15 = $11 << 16 >> 16; //@line 36323
 $17 = ($15 | 0) == 0 & 1; //@line 36325
 HEAP32[96441] = 0; //@line 36326
 HEAP32[96442] = 0; //@line 36326
 HEAP32[96443] = 0; //@line 36326
 HEAP32[96444] = 0; //@line 36326
 HEAP32[96442] = $17; //@line 36327
 HEAP32[96443] = $11 >>> 15 & 1; //@line 36330
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $15); //@line 36336
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36339
 return;
}
function __Z12op_10b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 24083
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 24093
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 24099
 $20 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24101
 $21 = $18 << 24 >> 24; //@line 24103
 $23 = ($21 | 0) == 0 & 1; //@line 24105
 HEAP32[96441] = 0; //@line 24106
 HEAP32[96442] = 0; //@line 24106
 HEAP32[96443] = 0; //@line 24106
 HEAP32[96444] = 0; //@line 24106
 HEAP32[96442] = $23; //@line 24107
 HEAP32[96443] = $18 >>> 7 & 1; //@line 24110
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($20, $21); //@line 24116
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24119
 return;
}
function __Z11op_1b0_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7682
 $6 = HEAP32[162769] | 0; //@line 7683
 $7 = $6 + 2 | 0; //@line 7684
 HEAP32[162769] = $7; //@line 7685
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7687
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 7694
 HEAP32[162769] = $6 + 4; //@line 7696
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 7697
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 7699
 $25 = $5 & 7; //@line 7704
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 7706
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 7710
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($26 & (1 << $25 ^ 255)) << 24 >> 24); //@line 7719
 return;
}
function __Z13SonyInterruptv() {
 var $$sroa$03$09$i = 0, $0 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 18142
 STACKTOP = STACKTOP + 80 | 0; //@line 18143
 $0 = sp; //@line 18144
 if (!(HEAP8[657352] | 0)) {
  STACKTOP = sp; //@line 18148
  return;
 }
 $3 = HEAP32[28486] | 0; //@line 18150
 $4 = HEAP32[28485] | 0; //@line 18151
 if (($4 | 0) == ($3 | 0)) {
  STACKTOP = sp; //@line 18154
  return;
 }
 $6 = $0 + 32 | 0; //@line 18156
 $$sroa$03$09$i = $4; //@line 18157
 do {
  $7 = $$sroa$03$09$i + 8 | 0; //@line 18159
  if (HEAP8[$7 >> 0] | 0) {
   HEAP32[$0 >> 2] = HEAP32[$$sroa$03$09$i >> 2]; //@line 18164
   HEAP32[$6 >> 2] = 7; //@line 18165
   _Execute68kTrap(-24529, $0); //@line 18166
   HEAP8[$7 >> 0] = 0; //@line 18167
  }
  $$sroa$03$09$i = $$sroa$03$09$i + 16 | 0; //@line 18169
 } while (($$sroa$03$09$i | 0) != ($3 | 0));
 STACKTOP = sp; //@line 18177
 return;
}
function __Z12op_c0f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $3 = 0, $32 = 0, $34 = 0;
 $3 = HEAP32[162769] | 0; //@line 29506
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 29515
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 29530
 $28 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29531
 $32 = Math_imul(HEAP32[$28 >> 2] & 65535, $27 & 65535) | 0; //@line 29535
 $34 = ($32 | 0) == 0 & 1; //@line 29537
 HEAP32[96441] = 0; //@line 29538
 HEAP32[96442] = 0; //@line 29538
 HEAP32[96443] = 0; //@line 29538
 HEAP32[96444] = 0; //@line 29538
 HEAP32[96442] = $34; //@line 29539
 HEAP32[96443] = $32 >>> 31; //@line 29541
 HEAP32[$28 >> 2] = $32; //@line 29542
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29545
 return;
}
function __Z11op_8bb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = HEAP32[162769] | 0; //@line 14976
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14978
 $4 = $1 + 4 | 0; //@line 14979
 HEAP32[162769] = $4; //@line 14980
 $8 = (HEAP32[162768] | 0) + $4 - (HEAP32[162770] | 0) | 0; //@line 14985
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 14992
 HEAP32[162769] = $1 + 6; //@line 14994
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 14995
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 14997
 $25 = $3 & 7; //@line 15003
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 15005
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 15009
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($26 & (1 << $25 ^ 255)) << 24 >> 24); //@line 15018
 return;
}
function __Z12op_e138_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 39151
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39152
 $7 = HEAP32[$6 >> 2] | 0; //@line 39153
 $8 = $7 & 255; //@line 39154
 $10 = ($5 & 63 | 0) == 0; //@line 39156
 $11 = $5 & 7; //@line 39157
 $15 = $8 << $11 & 255 | $8 >>> (8 - $11 | 0); //@line 39162
 HEAP32[96441] = 0; //@line 39163
 HEAP32[96442] = 0; //@line 39163
 HEAP32[96443] = 0; //@line 39163
 HEAP32[96444] = 0; //@line 39163
 if ($10) {
  $$0 = $8; //@line 39165
 } else {
  HEAP32[96441] = $15 & 1; //@line 39168
  $$0 = $15; //@line 39169
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39173
 HEAP32[96443] = $$0 >>> 7; //@line 39175
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 39178
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39181
 return;
}
function __Z12op_5100_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $22 = 0, $4 = 0, $6 = 0, $7 = 0, $sext34$lobit = 0, $sext34$mask = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5008
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 5010
 $7 = HEAP32[$6 >> 2] | 0; //@line 5011
 $10 = ($7 << 24 >> 24) - ($4 << 24 >> 24) | 0; //@line 5016
 $12 = $7 >>> 7; //@line 5018
 $sext34$lobit = $10 >>> 7 & 1; //@line 5021
 $sext34$mask = $10 & 255; //@line 5022
 HEAP32[96442] = ($sext34$mask | 0) == 0 & 1; //@line 5025
 HEAP32[96444] = ($sext34$lobit ^ $12 & 1) & ($12 ^ $4 >>> 7); //@line 5029
 $22 = ($4 & 255) >>> 0 > ($7 & 255) >>> 0 & 1; //@line 5033
 HEAP32[96441] = $22; //@line 5034
 HEAP32[96445] = $22; //@line 5035
 HEAP32[96443] = $sext34$lobit; //@line 5036
 HEAP32[$6 >> 2] = $sext34$mask | $7 & -256; //@line 5039
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5042
 return;
}
function __Z12op_c0e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $27 = 0, $29 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 29380
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 29391
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 29397
 $23 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29398
 $27 = Math_imul(HEAP32[$23 >> 2] & 65535, $22 & 65535) | 0; //@line 29402
 $29 = ($27 | 0) == 0 & 1; //@line 29404
 HEAP32[96441] = 0; //@line 29405
 HEAP32[96442] = 0; //@line 29405
 HEAP32[96443] = 0; //@line 29405
 HEAP32[96444] = 0; //@line 29405
 HEAP32[96442] = $29; //@line 29406
 HEAP32[96443] = $27 >>> 31; //@line 29408
 HEAP32[$23 >> 2] = $27; //@line 29409
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29412
 return;
}
function __Z12op_4090_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $11 = 0, $15 = 0, $3 = 0, $5 = 0, $8 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40874
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40876
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 40879
 $11 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $8 | 0; //@line 40883
 $$lobit = $8 >>> 31; //@line 40884
 $$lobit32 = $11 >>> 31; //@line 40885
 HEAP32[96444] = $$lobit32 & $$lobit; //@line 40887
 $15 = $$lobit32 & ~$$lobit ^ $$lobit; //@line 40890
 HEAP32[96441] = $15; //@line 40891
 HEAP32[96445] = $15; //@line 40892
 HEAP32[96442] = ($11 | 0) == 0 & HEAP32[96442]; //@line 40897
 HEAP32[96443] = $$lobit32; //@line 40898
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, $11); //@line 40902
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40905
 return;
}
function __Z12op_2190_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $22 = 0, $24 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 43420
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 43425
 $13 = HEAP32[162769] | 0; //@line 43428
 $22 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$13 + 2 >> 0] | 0) << 8 | (HEAPU8[$13 + 3 >> 0] | 0)) | 0; //@line 43437
 $24 = ($10 | 0) == 0 & 1; //@line 43439
 HEAP32[96441] = 0; //@line 43440
 HEAP32[96442] = 0; //@line 43440
 HEAP32[96443] = 0; //@line 43440
 HEAP32[96444] = 0; //@line 43440
 HEAP32[96442] = $24; //@line 43441
 HEAP32[96443] = $10 >>> 31; //@line 43443
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $10); //@line 43449
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43452
 return;
}
function __Z12op_20b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $22 = 0, $24 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32197
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 32206
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 32211
 $22 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 32213
 $24 = ($20 | 0) == 0 & 1; //@line 32215
 HEAP32[96441] = 0; //@line 32216
 HEAP32[96442] = 0; //@line 32216
 HEAP32[96443] = 0; //@line 32216
 HEAP32[96444] = 0; //@line 32216
 HEAP32[96442] = $24; //@line 32217
 HEAP32[96443] = $20 >>> 31; //@line 32219
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $20); //@line 32225
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32228
 return;
}
function __Z11op_290_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $22 = 0, $24 = 0, $28 = 0, $30 = 0;
 $2 = HEAP32[162769] | 0; //@line 9247
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 9265
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9267
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 9269
 $28 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0) & $20; //@line 9273
 $30 = ($28 | 0) == 0 & 1; //@line 9275
 HEAP32[96441] = 0; //@line 9276
 HEAP32[96442] = 0; //@line 9276
 HEAP32[96443] = 0; //@line 9276
 HEAP32[96444] = 0; //@line 9276
 HEAP32[96442] = $30; //@line 9277
 HEAP32[96443] = $28 >>> 31; //@line 9279
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $28); //@line 9283
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9286
 return;
}
function __Z10op_90_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $20 = 0, $22 = 0, $24 = 0, $28 = 0, $30 = 0;
 $2 = HEAP32[162769] | 0; //@line 5513
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 5531
 $22 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 5533
 $24 = 123608 + ($22 >>> 16 << 2) | 0; //@line 5535
 $28 = $20 | (FUNCTION_TABLE_ii[HEAP32[HEAP32[$24 >> 2] >> 2] & 127]($22) | 0); //@line 5539
 $30 = ($28 | 0) == 0 & 1; //@line 5541
 HEAP32[96441] = 0; //@line 5542
 HEAP32[96442] = 0; //@line 5542
 HEAP32[96443] = 0; //@line 5542
 HEAP32[96444] = 0; //@line 5542
 HEAP32[96442] = $30; //@line 5543
 HEAP32[96443] = $28 >>> 31; //@line 5545
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$24 >> 2] | 0) + 12 >> 2] & 31]($22, $28); //@line 5549
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5552
 return;
}
function __Z12op_e7f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $28 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 42131
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 42140
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 42149
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 42151
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 42155
 $28 = $25 >>> 15 & 1; //@line 42158
 $29 = $28 | $25 << 1; //@line 42159
 HEAP32[96444] = 0; //@line 42163
 HEAP32[96442] = ($29 & 65535) << 16 >> 16 == 0 & 1; //@line 42164
 HEAP32[96443] = $25 >>> 14 & 1; //@line 42167
 HEAP32[96441] = $28; //@line 42168
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $29 & 65535); //@line 42173
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42176
 return;
}
function __Z12op_2188_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33029
 $6 = HEAP32[162769] | 0; //@line 33030
 $7 = $6 + 2 | 0; //@line 33031
 HEAP32[162769] = $7; //@line 33032
 $9 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 33034
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 33041
 HEAP32[162769] = $6 + 4; //@line 33043
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 33044
 $20 = ($5 | 0) == 0 & 1; //@line 33046
 HEAP32[96441] = 0; //@line 33047
 HEAP32[96442] = 0; //@line 33047
 HEAP32[96443] = 0; //@line 33047
 HEAP32[96444] = 0; //@line 33047
 HEAP32[96442] = $20; //@line 33048
 HEAP32[96443] = $5 >>> 31; //@line 33050
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $5); //@line 33056
 return;
}
function __Z12op_2180_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 32990
 $6 = HEAP32[162769] | 0; //@line 32991
 $7 = $6 + 2 | 0; //@line 32992
 HEAP32[162769] = $7; //@line 32993
 $9 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 32995
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 33002
 HEAP32[162769] = $6 + 4; //@line 33004
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 33005
 $20 = ($5 | 0) == 0 & 1; //@line 33007
 HEAP32[96441] = 0; //@line 33008
 HEAP32[96442] = 0; //@line 33008
 HEAP32[96443] = 0; //@line 33008
 HEAP32[96444] = 0; //@line 33008
 HEAP32[96442] = $20; //@line 33009
 HEAP32[96443] = $5 >>> 31; //@line 33011
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $5); //@line 33017
 return;
}
function __Z12op_e038_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $11 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 37720
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37721
 $7 = HEAP32[$6 >> 2] | 0; //@line 37722
 $8 = $7 & 255; //@line 37723
 $10 = ($5 & 63 | 0) == 0; //@line 37725
 $11 = $5 & 7; //@line 37726
 $15 = $8 << 8 - $11 & 255 | $8 >>> $11; //@line 37731
 HEAP32[96441] = 0; //@line 37732
 HEAP32[96442] = 0; //@line 37732
 HEAP32[96443] = 0; //@line 37732
 HEAP32[96444] = 0; //@line 37732
 if ($10) {
  $$0 = $8; //@line 37734
 } else {
  HEAP32[96441] = $15 >>> 7; //@line 37737
  $$0 = $15; //@line 37738
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 37742
 HEAP32[96443] = $$0 >>> 7; //@line 37744
 HEAP32[$6 >> 2] = $$0 | $7 & -256; //@line 37747
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37750
 return;
}
function __Z12op_c1a0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30559
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30560
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 30562
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 30564
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 30567
 HEAP32[$6 >> 2] = $8; //@line 30568
 $14 = $13 & $5; //@line 30569
 $16 = ($14 | 0) == 0 & 1; //@line 30571
 HEAP32[96441] = 0; //@line 30572
 HEAP32[96442] = 0; //@line 30572
 HEAP32[96443] = 0; //@line 30572
 HEAP32[96444] = 0; //@line 30572
 HEAP32[96442] = $16; //@line 30573
 HEAP32[96443] = $14 >>> 31; //@line 30575
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 30579
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30582
 return;
}
function __Z12op_b1a0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27129
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 27130
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 27132
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 27134
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 27137
 HEAP32[$6 >> 2] = $8; //@line 27138
 $14 = $13 ^ $5; //@line 27139
 $16 = ($14 | 0) == 0 & 1; //@line 27141
 HEAP32[96441] = 0; //@line 27142
 HEAP32[96442] = 0; //@line 27142
 HEAP32[96443] = 0; //@line 27142
 HEAP32[96444] = 0; //@line 27142
 HEAP32[96442] = $16; //@line 27143
 HEAP32[96443] = $14 >>> 31; //@line 27145
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 27149
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27152
 return;
}
function __Z12op_81a0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16652
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 16653
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 16655
 $10 = 123608 + ($8 >>> 16 << 2) | 0; //@line 16657
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$10 >> 2] >> 2] & 127]($8) | 0; //@line 16660
 HEAP32[$6 >> 2] = $8; //@line 16661
 $14 = $13 | $5; //@line 16662
 $16 = ($14 | 0) == 0 & 1; //@line 16664
 HEAP32[96441] = 0; //@line 16665
 HEAP32[96442] = 0; //@line 16665
 HEAP32[96443] = 0; //@line 16665
 HEAP32[96444] = 0; //@line 16665
 HEAP32[96442] = $16; //@line 16666
 HEAP32[96443] = $14 >>> 31; //@line 16668
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$10 >> 2] | 0) + 12 >> 2] & 31]($8, $14); //@line 16672
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16675
 return;
}
function __Z12op_20b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $28 = 0, $3 = 0, $30 = 0;
 $3 = HEAP32[162769] | 0; //@line 28904
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 28913
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 28927
 $28 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28929
 $30 = ($26 | 0) == 0 & 1; //@line 28931
 HEAP32[96441] = 0; //@line 28932
 HEAP32[96442] = 0; //@line 28932
 HEAP32[96443] = 0; //@line 28932
 HEAP32[96444] = 0; //@line 28932
 HEAP32[96442] = $30; //@line 28933
 HEAP32[96443] = $26 >>> 31; //@line 28935
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $26); //@line 28941
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28944
 return;
}
function __Z12op_213c_0_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $22 = 0, $24 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 30067
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 30070
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 30085
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 30086
 $24 = (HEAP32[$22 >> 2] | 0) + -4 | 0; //@line 30088
 HEAP32[$22 >> 2] = $24; //@line 30089
 $26 = ($21 | 0) == 0 & 1; //@line 30091
 HEAP32[96441] = 0; //@line 30092
 HEAP32[96442] = 0; //@line 30092
 HEAP32[96443] = 0; //@line 30092
 HEAP32[96444] = 0; //@line 30092
 HEAP32[96442] = $26; //@line 30093
 HEAP32[96443] = $6 >>> 7; //@line 30095
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($24, $21); //@line 30101
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 30104
 return;
}
function __Z12op_4139_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $30 = 0, $32 = 0, $4 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 41798
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41801
 $$cast = $4; //@line 41802
 $16 = (HEAPU8[$$cast + 3 >> 0] | 0) << 16 | (HEAPU8[$$cast + 2 >> 0] | 0) << 24; //@line 41811
 $30 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0)) | 0; //@line 41825
 $32 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41827
 if (($32 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41830
  __Z9Exceptionij(6, $7); //@line 41831
  return;
 }
 if (($32 | 0) > ($30 | 0)) {
  HEAP32[96443] = 0; //@line 41836
  __Z9Exceptionij(6, $7); //@line 41837
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41842
  return;
 }
}
function __Z12op_21bc_3_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $3 = 0, $32 = 0, $34 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 43900
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 43903
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 43918
 $32 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$3 + 6 >> 0] | 0) << 8 | (HEAPU8[$3 + 7 >> 0] | 0)) | 0; //@line 43929
 $34 = ($21 | 0) == 0 & 1; //@line 43931
 HEAP32[96441] = 0; //@line 43932
 HEAP32[96442] = 0; //@line 43932
 HEAP32[96443] = 0; //@line 43932
 HEAP32[96444] = 0; //@line 43932
 HEAP32[96442] = $34; //@line 43933
 HEAP32[96443] = $6 >>> 7; //@line 43935
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($32 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($32, $21); //@line 43941
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 43944
 return;
}
function __Z12op_2150_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $23 = 0, $25 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30198
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 30203
 $13 = HEAP32[162769] | 0; //@line 30206
 $23 = (((HEAPU8[$13 + 2 >> 0] | 0) << 8 | (HEAPU8[$13 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 30217
 $25 = ($10 | 0) == 0 & 1; //@line 30219
 HEAP32[96441] = 0; //@line 30220
 HEAP32[96442] = 0; //@line 30220
 HEAP32[96443] = 0; //@line 30220
 HEAP32[96444] = 0; //@line 30220
 HEAP32[96442] = $25; //@line 30221
 HEAP32[96443] = $10 >>> 31; //@line 30223
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $10); //@line 30229
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30232
 return;
}
function __Z12op_20a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $23 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 28775
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28786
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28791
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28793
 $25 = ($21 | 0) == 0 & 1; //@line 28795
 HEAP32[96441] = 0; //@line 28796
 HEAP32[96442] = 0; //@line 28796
 HEAP32[96443] = 0; //@line 28796
 HEAP32[96444] = 0; //@line 28796
 HEAP32[96442] = $25; //@line 28797
 HEAP32[96443] = $21 >>> 31; //@line 28799
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 28805
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28808
 return;
}
function __Z11op_1f0_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $20 = 0, $25 = 0, $26 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8199
 $6 = HEAP32[162769] | 0; //@line 8200
 $7 = $6 + 2 | 0; //@line 8201
 HEAP32[162769] = $7; //@line 8202
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8204
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 8211
 HEAP32[162769] = $6 + 4; //@line 8213
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 8214
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 8216
 $25 = $5 & 7; //@line 8221
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 8223
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 8227
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($26 | 1 << $25) << 24 >> 24); //@line 8235
 return;
}
function __Z12op_31d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $20 = 0, $22 = 0, $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38739
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 38745
 $10 = HEAP32[162769] | 0; //@line 38746
 $19 = ((HEAPU8[$10 + 2 >> 0] | 0) << 8 | (HEAPU8[$10 + 3 >> 0] | 0)) << 16 >> 16; //@line 38756
 $20 = $9 << 16 >> 16; //@line 38758
 $22 = ($20 | 0) == 0 & 1; //@line 38760
 HEAP32[96441] = 0; //@line 38761
 HEAP32[96442] = 0; //@line 38761
 HEAP32[96443] = 0; //@line 38761
 HEAP32[96444] = 0; //@line 38761
 HEAP32[96442] = $22; //@line 38762
 HEAP32[96443] = $9 >>> 15 & 1; //@line 38765
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($19, $20); //@line 38771
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38774
 return;
}
function __Z12op_3018_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $16 = 0, $18 = 0, $3 = 0, $4 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 34955
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 34956
 $5 = HEAP32[$4 >> 2] | 0; //@line 34957
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 34963
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 34966
 $14 = $11 << 16 >> 16; //@line 34968
 $16 = ($14 | 0) == 0 & 1; //@line 34970
 HEAP32[96441] = 0; //@line 34971
 HEAP32[96442] = 0; //@line 34971
 HEAP32[96443] = 0; //@line 34971
 HEAP32[96444] = 0; //@line 34971
 HEAP32[96442] = $16; //@line 34972
 HEAP32[96443] = $11 >>> 15 & 1; //@line 34975
 $18 = 651008 + ($3 << 2) | 0; //@line 34976
 HEAP32[$18 >> 2] = HEAP32[$18 >> 2] & -65536 | $14 & 65535; //@line 34981
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34984
 return;
}
function __Z11op_8fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = HEAP32[162769] | 0; //@line 15422
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15424
 $4 = $1 + 4 | 0; //@line 15425
 HEAP32[162769] = $4; //@line 15426
 $8 = (HEAP32[162768] | 0) + $4 - (HEAP32[162770] | 0) | 0; //@line 15431
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 15438
 HEAP32[162769] = $1 + 6; //@line 15440
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 15441
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 15443
 $25 = $3 & 7; //@line 15449
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 15451
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 15455
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($26 | 1 << $25) << 24 >> 24); //@line 15463
 return;
}
function __Z11SerialPrimejji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $5 = 0;
 $5 = HEAP32[113900 + ($2 >> 1 << 2) >> 2] | 0; //@line 14752
 if (!(HEAP8[$5 + 4 >> 0] | 0)) {
  $$0 = -28; //@line 14757
  return $$0 | 0; //@line 14758
 }
 if (($2 | 2 | 0) == 2) {
  if (!(HEAP8[$5 + 6 >> 0] | 0)) {
   $$0 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 15]($5, $0, $1) | 0; //@line 14771
   return $$0 | 0; //@line 14772
  } else {
   _puts(93416) | 0; //@line 14774
   $$0 = -19; //@line 14775
   return $$0 | 0; //@line 14776
  }
 } else {
  if (!(HEAP8[$5 + 12 >> 0] | 0)) {
   $$0 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 15]($5, $0, $1) | 0; //@line 14787
   return $$0 | 0; //@line 14788
  } else {
   _puts(93471) | 0; //@line 14790
   $$0 = -19; //@line 14791
   return $$0 | 0; //@line 14792
  }
 }
 return 0; //@line 14795
}
function __Z12op_e2f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $26 = 0, $28 = 0;
 $1 = HEAP32[162769] | 0; //@line 40508
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 40517
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 40526
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40528
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 40532
 $26 = $25 & 1; //@line 40533
 $28 = $25 >>> 1 & 32767; //@line 40535
 HEAP32[96444] = 0; //@line 40538
 HEAP32[96442] = ($28 | 0) == 0 & 1; //@line 40539
 HEAP32[96443] = 0; //@line 40540
 HEAP32[96441] = $26; //@line 40541
 HEAP32[96445] = $26; //@line 40542
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $28); //@line 40546
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 40549
 return;
}
function __Z12op_11d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $19 = 0, $20 = 0, $22 = 0, $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26663
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 26669
 $10 = HEAP32[162769] | 0; //@line 26670
 $19 = ((HEAPU8[$10 + 2 >> 0] | 0) << 8 | (HEAPU8[$10 + 3 >> 0] | 0)) << 16 >> 16; //@line 26680
 $20 = $9 << 24 >> 24; //@line 26682
 $22 = ($20 | 0) == 0 & 1; //@line 26684
 HEAP32[96441] = 0; //@line 26685
 HEAP32[96442] = 0; //@line 26685
 HEAP32[96443] = 0; //@line 26685
 HEAP32[96444] = 0; //@line 26685
 HEAP32[96442] = $22; //@line 26686
 HEAP32[96443] = $9 >>> 7 & 1; //@line 26689
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($19, $20); //@line 26695
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26698
 return;
}
function __Z12op_5090_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $12 = 0, $13 = 0, $21 = 0, $4 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4412
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4415
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 4417
 $12 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0; //@line 4420
 $13 = $12 + $4 | 0; //@line 4421
 $$lobit38 = $13 >>> 31; //@line 4424
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 4427
 HEAP32[96444] = ($$lobit38 ^ $4 >>> 31) & ($$lobit38 ^ $12 >>> 31); //@line 4431
 $21 = $4 >>> 0 > ~$12 >>> 0 & 1; //@line 4434
 HEAP32[96441] = $21; //@line 4435
 HEAP32[96445] = $21; //@line 4436
 HEAP32[96443] = $$lobit38; //@line 4437
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 4441
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4444
 return;
}
function __Z11op_8b0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 14773
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 14775
 $5 = $2 + 4 | 0; //@line 14776
 HEAP32[162769] = $5; //@line 14777
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14779
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 14786
 HEAP32[162769] = $2 + 6; //@line 14788
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 14789
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 14791
 $24 = $4 & 7; //@line 14797
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24; //@line 14799
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 14803
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, ($25 & (1 << $24 ^ 255)) << 24 >> 24); //@line 14812
 return;
}
function __Z12op_4130_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $24 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[162769] | 0; //@line 45886
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 45889
 $$cast = $5; //@line 45892
 $19 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45901
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19) | 0; //@line 45906
 $26 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 45908
 if (($26 | 0) < 0) {
  HEAP32[96443] = 1; //@line 45911
  __Z9Exceptionij(6, $8); //@line 45912
  return;
 }
 if (($26 | 0) > ($24 | 0)) {
  HEAP32[96443] = 0; //@line 45917
  __Z9Exceptionij(6, $8); //@line 45918
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45923
  return;
 }
}
function __Z12op_217c_0_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $3 = 0, $33 = 0, $35 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 32932
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 32935
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 32950
 $33 = (((HEAPU8[$3 + 6 >> 0] | 0) << 8 | (HEAPU8[$3 + 7 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 32963
 $35 = ($21 | 0) == 0 & 1; //@line 32965
 HEAP32[96441] = 0; //@line 32966
 HEAP32[96442] = 0; //@line 32966
 HEAP32[96443] = 0; //@line 32966
 HEAP32[96444] = 0; //@line 32966
 HEAP32[96442] = $35; //@line 32967
 HEAP32[96443] = $6 >>> 7; //@line 32969
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($33 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($33, $21); //@line 32975
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 32978
 return;
}
function __Z12op_b1d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit36 = 0, $$lobit37 = 0, $10 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 27445
 $5 = HEAP32[$4 >> 2] | 0; //@line 27446
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27451
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 27454
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27456
 $15 = $14 - $10 | 0; //@line 27457
 $$lobit36 = $14 >>> 31; //@line 27459
 $$lobit37 = $15 >>> 31; //@line 27460
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 27463
 HEAP32[96444] = ($10 >>> 31 | 0) != ($$lobit36 | 0) & ($$lobit37 | 0) != ($$lobit36 | 0) & 1; //@line 27468
 HEAP32[96441] = $14 >>> 0 < $10 >>> 0 & 1; //@line 27471
 HEAP32[96443] = $$lobit37; //@line 27472
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27475
 return;
}
function __Z12op_b098_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit36 = 0, $$lobit37 = 0, $10 = 0, $14 = 0, $15 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 25173
 $5 = HEAP32[$4 >> 2] | 0; //@line 25174
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 25179
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 25182
 $14 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25184
 $15 = $14 - $10 | 0; //@line 25185
 $$lobit36 = $14 >>> 31; //@line 25187
 $$lobit37 = $15 >>> 31; //@line 25188
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 25191
 HEAP32[96444] = ($10 >>> 31 | 0) != ($$lobit36 | 0) & ($$lobit37 | 0) != ($$lobit36 | 0) & 1; //@line 25196
 HEAP32[96441] = $14 >>> 0 < $10 >>> 0 & 1; //@line 25199
 HEAP32[96443] = $$lobit37; //@line 25200
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25203
 return;
}
function __Z12op_20fc_0_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $22 = 0, $23 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 29557
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 29560
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 29575
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29576
 $23 = HEAP32[$22 >> 2] | 0; //@line 29577
 HEAP32[$22 >> 2] = $23 + 4; //@line 29579
 $26 = ($21 | 0) == 0 & 1; //@line 29581
 HEAP32[96441] = 0; //@line 29582
 HEAP32[96442] = 0; //@line 29582
 HEAP32[96443] = 0; //@line 29582
 HEAP32[96444] = 0; //@line 29582
 HEAP32[96442] = $26; //@line 29583
 HEAP32[96443] = $6 >>> 7; //@line 29585
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 29591
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29594
 return;
}
function __Z15EtherReadPacketRjS_S_S_($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $15 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $4 = HEAP32[$2 >> 2] | 0; //@line 16747
 $5 = HEAP32[$3 >> 2] | 0; //@line 16748
 $7 = $4 >>> 0 > $5 >>> 0 ? $5 : $4; //@line 16750
 $8 = HEAP32[$1 >> 2] | 0; //@line 16751
 $9 = HEAP32[$0 >> 2] | 0; //@line 16752
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($8) | 0; //@line 16758
 _memcpy($15 | 0, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($9) | 0, $7 | 0) | 0; //@line 16765
 HEAP32[$0 >> 2] = (HEAP32[$0 >> 2] | 0) + $7; //@line 16768
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + $7; //@line 16771
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) - $7; //@line 16774
 HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) - $7; //@line 16777
 return;
}
function __Z11op_238_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 8687
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 8689
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 8699
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 8701
 $20 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0) & ($3 & 255); //@line 8707
 $21 = $20 << 24 >> 24; //@line 8709
 $23 = ($21 | 0) == 0 & 1; //@line 8711
 HEAP32[96441] = 0; //@line 8712
 HEAP32[96442] = 0; //@line 8712
 HEAP32[96443] = 0; //@line 8712
 HEAP32[96444] = 0; //@line 8712
 HEAP32[96442] = $23; //@line 8713
 HEAP32[96443] = $20 >>> 7; //@line 8715
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, $21); //@line 8719
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8722
 return;
}
function __Z10op_38_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 4944
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 4946
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 4956
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 4958
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0 | $3 & 255; //@line 4964
 $21 = $20 << 24 >> 24; //@line 4966
 $23 = ($21 | 0) == 0 & 1; //@line 4968
 HEAP32[96441] = 0; //@line 4969
 HEAP32[96442] = 0; //@line 4969
 HEAP32[96443] = 0; //@line 4969
 HEAP32[96444] = 0; //@line 4969
 HEAP32[96442] = $23; //@line 4970
 HEAP32[96443] = $20 >>> 7 & 1; //@line 4973
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, $21); //@line 4977
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 4980
 return;
}
function __Z12op_e3f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $21 = 0, $25 = 0, $31 = 0;
 $1 = HEAP32[162769] | 0; //@line 40815
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 40824
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 40833
 $21 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40835
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 4 >> 2] & 127]($19) | 0; //@line 40839
 HEAP32[96444] = 0; //@line 40844
 HEAP32[96442] = ($25 & 32767 | 0) == 0 & 1; //@line 40845
 HEAP32[96443] = $25 >>> 14 & 1; //@line 40848
 $31 = $25 >>> 15 & 1; //@line 40850
 HEAP32[96441] = $31; //@line 40851
 HEAP32[96445] = $31; //@line 40852
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 16 >> 2] & 31]($19, $25 << 1 & 65534); //@line 40857
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 40860
 return;
}
function __Z12op_41bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $4 = 0, $7 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 46036
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 46039
 $$cast = $4; //@line 46041
 $17 = __Z15get_disp_ea_000jj($7 + 2 | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 46050
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 46056
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 46059
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 46062
  __Z9Exceptionij(6, $7); //@line 46063
  return;
 }
 if (($sext | 0) > ($23 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 46069
  __Z9Exceptionij(6, $7); //@line 46070
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46075
  return;
 }
}
function __Z12op_4128_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[162769] | 0; //@line 41650
 $8 = $5 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41653
 $$cast = $5; //@line 41656
 $20 = (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41667
 $25 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($20 >>> 16 << 2) >> 2] >> 2] & 127]($20) | 0; //@line 41672
 $27 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41674
 if (($27 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41677
  __Z9Exceptionij(6, $8); //@line 41678
  return;
 }
 if (($27 | 0) > ($25 | 0)) {
  HEAP32[96443] = 0; //@line 41683
  __Z9Exceptionij(6, $8); //@line 41684
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41689
  return;
 }
}
function __Z11op_c10_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $4 = 0, $5 = 0, $7 = 0, $sext$lobit = 0, $sext27$lobit = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 18812
 $5 = $4 & 255; //@line 18813
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 18815
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 18821
 $14 = $13 - $5 | 0; //@line 18822
 $sext$lobit = $13 >>> 7 & 1; //@line 18826
 $sext27$lobit = $14 >>> 7 & 1; //@line 18828
 HEAP32[96442] = ($14 & 255 | 0) == 0 & 1; //@line 18832
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext27$lobit | 0) != ($sext$lobit | 0) & 1; //@line 18837
 HEAP32[96441] = $5 >>> 0 > ($13 & 255) >>> 0 & 1; //@line 18841
 HEAP32[96443] = $sext27$lobit; //@line 18842
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 18845
 return;
}
function __Z11SerialClosejji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$1 = 0, $15 = 0, $3 = 0, $8 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 14927
 STACKTOP = STACKTOP + 80 | 0; //@line 14928
 $3 = sp; //@line 14929
 if (($2 | 2 | 0) == 2) {
  $$1 = 0; //@line 14933
  STACKTOP = sp; //@line 14934
  return $$1 | 0; //@line 14934
 }
 $8 = HEAP32[113900 + ($2 >> 1 << 2) >> 2] | 0; //@line 14938
 $9 = $8 + 4 | 0; //@line 14939
 if (!(HEAP8[$9 >> 0] | 0)) {
  $$1 = 0; //@line 14943
  STACKTOP = sp; //@line 14944
  return $$1 | 0; //@line 14944
 }
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 28 >> 2] & 127]($8) | 0; //@line 14949
 HEAP32[$3 + 32 >> 2] = HEAP32[$8 + 8 >> 2]; //@line 14953
 _Execute68kTrap(-24545, $3); //@line 14954
 HEAP8[$9 >> 0] = 0; //@line 14955
 $$1 = $15; //@line 14956
 STACKTOP = sp; //@line 14957
 return $$1 | 0; //@line 14957
}
function __Z11op_8f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 15224
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 15226
 $5 = $2 + 4 | 0; //@line 15227
 HEAP32[162769] = $5; //@line 15228
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15230
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 15237
 HEAP32[162769] = $2 + 6; //@line 15239
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 15240
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 15242
 $24 = $4 & 7; //@line 15248
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24; //@line 15250
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 15254
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, ($25 | 1 << $24) << 24 >> 24); //@line 15262
 return;
}
function __Z12op_44a8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $19 = 0, $22 = 0, $27 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 47701
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 47712
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 47714
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 47717
 $22 = ($19 | 0) > 0 & 1; //@line 47721
 HEAP32[96442] = ($19 | 0) == 0 & 1; //@line 47724
 HEAP32[96444] = $22 & $19 >>> 31; //@line 47726
 $27 = ($19 | 0) != 0 & 1; //@line 47728
 HEAP32[96441] = $27; //@line 47729
 HEAP32[96445] = $27; //@line 47730
 HEAP32[96443] = $22; //@line 47731
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, 0 - $19 | 0); //@line 47735
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47738
 return;
}
function __Z12op_41ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $4 = 0, $7 = 0, $sext24 = 0;
 $4 = HEAP32[162769] | 0; //@line 42391
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42394
 $$cast = $4; //@line 42396
 $18 = $7 + 2 + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 42407
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 42413
 $sext24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42416
 if (($sext24 | 0) < 0) {
  HEAP32[96443] = 1; //@line 42419
  __Z9Exceptionij(6, $7); //@line 42420
  return;
 }
 if (($sext24 | 0) > ($24 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42426
  __Z9Exceptionij(6, $7); //@line 42427
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42432
  return;
 }
}
function __Z12op_3020_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $15 = 0, $17 = 0, $3 = 0, $4 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 34994
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 34995
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 34997
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 35003
 HEAP32[$4 >> 2] = $6; //@line 35004
 $13 = $12 << 16 >> 16; //@line 35006
 $15 = ($13 | 0) == 0 & 1; //@line 35008
 HEAP32[96441] = 0; //@line 35009
 HEAP32[96442] = 0; //@line 35009
 HEAP32[96443] = 0; //@line 35009
 HEAP32[96444] = 0; //@line 35009
 HEAP32[96442] = $15; //@line 35010
 HEAP32[96443] = $12 >>> 15 & 1; //@line 35013
 $17 = 651008 + ($3 << 2) | 0; //@line 35014
 HEAP32[$17 >> 2] = HEAP32[$17 >> 2] & -65536 | $13 & 65535; //@line 35019
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35022
 return;
}
function __Z19Screen_blitter_initRK12VisualFormatbi($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $3 = 0, $8 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 26450
 STACKTOP = STACKTOP + 16 | 0; //@line 26451
 $vararg_buffer = sp; //@line 26452
 _puts(96452) | 0; //@line 26453
 HEAP32[30807] = 4; //@line 26454
 $3 = $0 + 4 | 0; //@line 26455
 HEAP32[$vararg_buffer >> 2] = HEAP32[$3 >> 2]; //@line 26457
 HEAP32[$vararg_buffer + 4 >> 2] = $2; //@line 26459
 _printf(96472, $vararg_buffer) | 0; //@line 26460
 if (($2 | 0) == 8 & (HEAP32[$3 >> 2] | 0) == 32) {
  _puts(96495) | 0; //@line 26466
  HEAP32[30807] = 5; //@line 26467
  $8 = 1; //@line 26468
  STACKTOP = sp; //@line 26469
  return $8 | 0; //@line 26469
 } else {
  $8 = (HEAP32[30807] | 0) != 4; //@line 26473
  STACKTOP = sp; //@line 26474
  return $8 | 0; //@line 26474
 }
 return 0; //@line 26476
}
function __Z12op_3038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $2 = 0, $21 = 0, $23 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 35125
 $3 = HEAP32[162769] | 0; //@line 35126
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 35136
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 35142
 $19 = $18 << 16 >> 16; //@line 35144
 $21 = ($19 | 0) == 0 & 1; //@line 35146
 HEAP32[96441] = 0; //@line 35147
 HEAP32[96442] = 0; //@line 35147
 HEAP32[96443] = 0; //@line 35147
 HEAP32[96444] = 0; //@line 35147
 HEAP32[96442] = $21; //@line 35148
 HEAP32[96443] = $18 >>> 15 & 1; //@line 35151
 $23 = 651008 + ($2 << 2) | 0; //@line 35152
 HEAP32[$23 >> 2] = HEAP32[$23 >> 2] & -65536 | $19 & 65535; //@line 35157
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35160
 return;
}
function _strncat($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$lcssa = 0, $$01013 = 0, $$01112 = 0, $$014 = 0, $10 = 0, $4 = 0, $6 = 0;
 $4 = $0 + (_strlen($0) | 0) | 0; //@line 2960
 L1 : do {
  if (!$2) {
   $$0$lcssa = $4; //@line 2964
  } else {
   $$01013 = $2; //@line 2966
   $$01112 = $1; //@line 2966
   $$014 = $4; //@line 2966
   while (1) {
    $6 = HEAP8[$$01112 >> 0] | 0; //@line 2968
    if (!($6 << 24 >> 24)) {
     $$0$lcssa = $$014; //@line 2971
     break L1;
    }
    $$01013 = $$01013 + -1 | 0; //@line 2974
    $10 = $$014 + 1 | 0; //@line 2976
    HEAP8[$$014 >> 0] = $6; //@line 2977
    if (!$$01013) {
     $$0$lcssa = $10; //@line 2980
     break;
    } else {
     $$01112 = $$01112 + 1 | 0; //@line 2983
     $$014 = $10; //@line 2983
    }
   }
  }
 } while (0);
 HEAP8[$$0$lcssa >> 0] = 0; //@line 2988
 return $0 | 0; //@line 2989
}
function __Z12op_b1e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $11 = 0, $13 = 0, $14 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 27486
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 27488
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 27493
 HEAP32[$4 >> 2] = $6; //@line 27494
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27496
 $14 = $13 - $11 | 0; //@line 27497
 $$lobit37 = $13 >>> 31; //@line 27499
 $$lobit38 = $14 >>> 31; //@line 27500
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 27503
 HEAP32[96444] = ($11 >>> 31 | 0) != ($$lobit37 | 0) & ($$lobit38 | 0) != ($$lobit37 | 0) & 1; //@line 27508
 HEAP32[96441] = $13 >>> 0 < $11 >>> 0 & 1; //@line 27511
 HEAP32[96443] = $$lobit38; //@line 27512
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27515
 return;
}
function __Z12op_b0a0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit37 = 0, $$lobit38 = 0, $11 = 0, $13 = 0, $14 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 25214
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 25216
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 25221
 HEAP32[$4 >> 2] = $6; //@line 25222
 $13 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25224
 $14 = $13 - $11 | 0; //@line 25225
 $$lobit37 = $13 >>> 31; //@line 25227
 $$lobit38 = $14 >>> 31; //@line 25228
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 25231
 HEAP32[96444] = ($11 >>> 31 | 0) != ($$lobit37 | 0) & ($$lobit38 | 0) != ($$lobit37 | 0) & 1; //@line 25236
 HEAP32[96441] = $13 >>> 0 < $11 >>> 0 & 1; //@line 25239
 HEAP32[96443] = $$lobit38; //@line 25240
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25243
 return;
}
function __Z12op_b1f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 27623
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 27633
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 27638
 $19 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27640
 $20 = $19 - $17 | 0; //@line 27641
 $$lobit31 = $19 >>> 31; //@line 27643
 $$lobit32 = $20 >>> 31; //@line 27644
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 27647
 HEAP32[96444] = ($17 >>> 31 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 27652
 HEAP32[96441] = $19 >>> 0 < $17 >>> 0 & 1; //@line 27655
 HEAP32[96443] = $$lobit32; //@line 27656
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27659
 return;
}
function __Z12op_b0b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit31 = 0, $$lobit32 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 25351
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 25361
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 25366
 $19 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25368
 $20 = $19 - $17 | 0; //@line 25369
 $$lobit31 = $19 >>> 31; //@line 25371
 $$lobit32 = $20 >>> 31; //@line 25372
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 25375
 HEAP32[96444] = ($17 >>> 31 | 0) != ($$lobit31 | 0) & ($$lobit32 | 0) != ($$lobit31 | 0) & 1; //@line 25380
 HEAP32[96441] = $19 >>> 0 < $17 >>> 0 & 1; //@line 25383
 HEAP32[96443] = $$lobit32; //@line 25384
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25387
 return;
}
function __Z12op_4ebb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $34 = 0;
 $2 = HEAP32[162769] | 0; //@line 3648
 $$cast = $2; //@line 3653
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 3662
 $21 = (HEAP32[162768] | 0) + 4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 3668
 $23 = (HEAP32[162767] | 0) + -4 | 0; //@line 3670
 HEAP32[162767] = $23; //@line 3671
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 3677
 $34 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($15) | 0; //@line 3683
 HEAP32[162770] = $34; //@line 3684
 HEAP32[162769] = $34; //@line 3685
 HEAP32[162768] = $15; //@line 3686
 return;
}
function __Z12op_1038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $2 = 0, $21 = 0, $23 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 23605
 $3 = HEAP32[162769] | 0; //@line 23606
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 23616
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0; //@line 23622
 $19 = $18 << 24 >> 24; //@line 23624
 $21 = ($19 | 0) == 0 & 1; //@line 23626
 HEAP32[96441] = 0; //@line 23627
 HEAP32[96442] = 0; //@line 23627
 HEAP32[96443] = 0; //@line 23627
 HEAP32[96444] = 0; //@line 23627
 HEAP32[96442] = $21; //@line 23628
 HEAP32[96443] = $18 >>> 7 & 1; //@line 23631
 $23 = 651008 + ($2 << 2) | 0; //@line 23632
 HEAP32[$23 >> 2] = HEAP32[$23 >> 2] & -256 | $19 & 255; //@line 23637
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23640
 return;
}
function __Z12op_313c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 37298
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 37301
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 37306
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37307
 $14 = (HEAP32[$12 >> 2] | 0) + -2 | 0; //@line 37309
 HEAP32[$12 >> 2] = $14; //@line 37310
 $15 = $11 << 16 >> 16; //@line 37312
 $17 = ($15 | 0) == 0 & 1; //@line 37314
 HEAP32[96441] = 0; //@line 37315
 HEAP32[96442] = 0; //@line 37315
 HEAP32[96443] = 0; //@line 37315
 HEAP32[96444] = 0; //@line 37315
 HEAP32[96442] = $17; //@line 37316
 HEAP32[96443] = $6 >>> 7; //@line 37318
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, $15); //@line 37324
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37327
 return;
}
function __Z12op_44b0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $18 = 0, $21 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2327
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2336
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2338
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($13) | 0; //@line 2341
 $21 = ($18 | 0) > 0 & 1; //@line 2345
 HEAP32[96442] = ($18 | 0) == 0 & 1; //@line 2348
 HEAP32[96444] = $21 & $18 >>> 31; //@line 2350
 $26 = ($18 | 0) != 0 & 1; //@line 2352
 HEAP32[96441] = $26; //@line 2353
 HEAP32[96445] = $26; //@line 2354
 HEAP32[96443] = $21; //@line 2355
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 12 >> 2] & 31]($13, 0 - $18 | 0); //@line 2359
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2362
 return;
}
function __Z12op_31bc_3_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $22 = 0, $23 = 0, $25 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 45386
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 45389
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 45394
 $22 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 45405
 $23 = $11 << 16 >> 16; //@line 45407
 $25 = ($23 | 0) == 0 & 1; //@line 45409
 HEAP32[96441] = 0; //@line 45410
 HEAP32[96442] = 0; //@line 45410
 HEAP32[96443] = 0; //@line 45410
 HEAP32[96444] = 0; //@line 45410
 HEAP32[96442] = $25; //@line 45411
 HEAP32[96443] = $6 >>> 7; //@line 45413
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($22, $23); //@line 45419
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 45422
 return;
}
function __Z12op_46a8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $19 = 0, $20 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 48996
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 49007
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 49009
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0; //@line 49012
 $20 = ~$19; //@line 49013
 $22 = ($19 | 0) == -1 & 1; //@line 49015
 HEAP32[96441] = 0; //@line 49016
 HEAP32[96442] = 0; //@line 49016
 HEAP32[96443] = 0; //@line 49016
 HEAP32[96444] = 0; //@line 49016
 HEAP32[96442] = $22; //@line 49017
 HEAP32[96443] = $19 >>> 31 ^ 1; //@line 49020
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 49024
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49027
 return;
}
function __Z11op_17b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $29 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16499
 $6 = HEAP32[162769] | 0; //@line 16501
 $$cast = $6; //@line 16506
 $19 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 16515
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 16517
 $26 = $4 & 7; //@line 16522
 $27 = 1 << $26; //@line 16523
 $29 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) ^ $27) << 24 >> 24; //@line 16526
 HEAP32[96442] = ($29 & $27) >>> $26; //@line 16529
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, $29); //@line 16533
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16536
 return;
}
function __Z12op_c050_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $sext2122 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28388
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 28394
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28395
 $13 = HEAP32[$12 >> 2] | 0; //@line 28396
 $sext2122 = $13 & $11; //@line 28397
 $14 = $sext2122 << 16 >> 16; //@line 28399
 $16 = ($14 | 0) == 0 & 1; //@line 28401
 HEAP32[96441] = 0; //@line 28402
 HEAP32[96442] = 0; //@line 28402
 HEAP32[96443] = 0; //@line 28402
 HEAP32[96444] = 0; //@line 28402
 HEAP32[96442] = $16; //@line 28403
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 28406
 HEAP32[$12 >> 2] = $13 & -65536 | $14 & 65535; //@line 28410
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28413
 return;
}
function __Z12op_8050_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $sext2122 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14064
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 14070
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14071
 $13 = HEAP32[$12 >> 2] | 0; //@line 14072
 $sext2122 = $13 | $11; //@line 14073
 $14 = $sext2122 << 16 >> 16; //@line 14075
 $16 = ($14 | 0) == 0 & 1; //@line 14077
 HEAP32[96441] = 0; //@line 14078
 HEAP32[96442] = 0; //@line 14078
 HEAP32[96443] = 0; //@line 14078
 HEAP32[96444] = 0; //@line 14078
 HEAP32[96442] = $16; //@line 14079
 HEAP32[96443] = $sext2122 >>> 15 & 1; //@line 14082
 HEAP32[$12 >> 2] = $13 & -65536 | $14 & 65535; //@line 14086
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14089
 return;
}
function __Z12op_e6d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41588
 $3 = HEAP32[$2 >> 2] | 0; //@line 41589
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41591
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41595
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 41598
 $12 = $9 & 1; //@line 41599
 $13 = $9 >>> 1; //@line 41600
 $$ = ($12 | 0) == 0 ? $13 & 32767 : $13 | 32768; //@line 41604
 HEAP32[96444] = 0; //@line 41608
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41609
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41612
 HEAP32[96441] = $12; //@line 41613
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 41618
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41621
 return;
}
function __Z12op_c1d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 30834
 $5 = HEAP32[$4 >> 2] | 0; //@line 30835
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 30841
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 30844
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30845
 $18 = Math_imul(HEAP32[$14 >> 2] << 16 >> 16, $11 << 16 >> 16) | 0; //@line 30851
 $20 = ($18 | 0) == 0 & 1; //@line 30853
 HEAP32[96441] = 0; //@line 30854
 HEAP32[96442] = 0; //@line 30854
 HEAP32[96443] = 0; //@line 30854
 HEAP32[96444] = 0; //@line 30854
 HEAP32[96442] = $20; //@line 30855
 HEAP32[96443] = $18 >>> 31; //@line 30857
 HEAP32[$14 >> 2] = $18; //@line 30858
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30861
 return;
}
function __Z12op_4af8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, $sext7 = 0;
 $1 = HEAP32[162769] | 0; //@line 52788
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 52798
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 52800
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 52804
 $sext7 = $16 << 24; //@line 52805
 $18 = ($sext7 | 0) == 0 & 1; //@line 52807
 HEAP32[96441] = 0; //@line 52808
 HEAP32[96442] = 0; //@line 52808
 HEAP32[96443] = 0; //@line 52808
 HEAP32[96444] = 0; //@line 52808
 HEAP32[96442] = $18; //@line 52809
 HEAP32[96443] = $16 >>> 7 & 1; //@line 52812
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, ($sext7 | -2147483648) >> 24); //@line 52818
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52821
 return;
}
function __Z12op_30fc_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 36750
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 36753
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 36758
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36759
 $13 = HEAP32[$12 >> 2] | 0; //@line 36760
 HEAP32[$12 >> 2] = $13 + 2; //@line 36762
 $15 = $11 << 16 >> 16; //@line 36764
 $17 = ($15 | 0) == 0 & 1; //@line 36766
 HEAP32[96441] = 0; //@line 36767
 HEAP32[96442] = 0; //@line 36767
 HEAP32[96443] = 0; //@line 36767
 HEAP32[96444] = 0; //@line 36767
 HEAP32[96442] = $17; //@line 36768
 HEAP32[96443] = $6 >>> 7; //@line 36770
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $15); //@line 36776
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36779
 return;
}
function __Z12op_c010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $sext1718 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27909
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 27915
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 27916
 $13 = HEAP32[$12 >> 2] | 0; //@line 27917
 $sext1718 = $13 & $11; //@line 27918
 $14 = $sext1718 << 24 >> 24; //@line 27920
 $16 = ($14 | 0) == 0 & 1; //@line 27922
 HEAP32[96441] = 0; //@line 27923
 HEAP32[96442] = 0; //@line 27923
 HEAP32[96443] = 0; //@line 27923
 HEAP32[96444] = 0; //@line 27923
 HEAP32[96442] = $16; //@line 27924
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 27927
 HEAP32[$12 >> 2] = $13 & -256 | $14 & 255; //@line 27931
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27934
 return;
}
function __Z12op_b050_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $14 = 0, $5 = 0, $sext$lobit = 0, $sext36$lobit = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24539
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 24545
 $13 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24547
 $14 = $13 - $11 | 0; //@line 24548
 $sext$lobit = $13 >>> 15 & 1; //@line 24552
 $sext36$lobit = $14 >>> 15 & 1; //@line 24554
 HEAP32[96442] = ($14 & 65535 | 0) == 0 & 1; //@line 24558
 HEAP32[96444] = ($11 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext36$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24563
 HEAP32[96441] = ($11 & 65535) >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 24568
 HEAP32[96443] = $sext36$lobit; //@line 24569
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24572
 return;
}
function __Z12op_8010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0, $sext1718 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13584
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 13590
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13591
 $13 = HEAP32[$12 >> 2] | 0; //@line 13592
 $sext1718 = $13 | $11; //@line 13593
 $14 = $sext1718 << 24 >> 24; //@line 13595
 $16 = ($14 | 0) == 0 & 1; //@line 13597
 HEAP32[96441] = 0; //@line 13598
 HEAP32[96442] = 0; //@line 13598
 HEAP32[96443] = 0; //@line 13598
 HEAP32[96444] = 0; //@line 13598
 HEAP32[96442] = $16; //@line 13599
 HEAP32[96443] = $sext1718 >>> 7 & 1; //@line 13602
 HEAP32[$12 >> 2] = $13 & -256 | $14 & 255; //@line 13606
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13609
 return;
}
function __Z12op_41b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $22 = 0, $4 = 0, $7 = 0, $sext23 = 0;
 $4 = HEAP32[162769] | 0; //@line 42280
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42283
 $$cast = $4; //@line 42284
 $16 = ((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16; //@line 42294
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 42300
 $sext23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42303
 if (($sext23 | 0) < 0) {
  HEAP32[96443] = 1; //@line 42306
  __Z9Exceptionij(6, $7); //@line 42307
  return;
 }
 if (($sext23 | 0) > ($22 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42313
  __Z9Exceptionij(6, $7); //@line 42314
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42319
  return;
 }
}
function __Z12op_33fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 39936
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 39939
 $18 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 39953
 $27 = $18 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 39962
 $28 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 39964
 $30 = ($28 | 0) == 0 & 1; //@line 39966
 HEAP32[96441] = 0; //@line 39967
 HEAP32[96442] = 0; //@line 39967
 HEAP32[96443] = 0; //@line 39967
 HEAP32[96444] = 0; //@line 39967
 HEAP32[96442] = $30; //@line 39968
 HEAP32[96443] = $4 >>> 7; //@line 39970
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($27, $28); //@line 39976
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 39979
 return;
}
function __Z12op_e7f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $22 = 0, $23 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 50162
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 50171
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 50173
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 50177
 $22 = $19 >>> 15 & 1; //@line 50180
 $23 = $22 | $19 << 1; //@line 50181
 HEAP32[96444] = 0; //@line 50185
 HEAP32[96442] = ($23 & 65535) << 16 >> 16 == 0 & 1; //@line 50186
 HEAP32[96443] = $19 >>> 14 & 1; //@line 50189
 HEAP32[96441] = $22; //@line 50190
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $23 & 65535); //@line 50195
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50198
 return;
}
function __Z12op_e6f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 41770
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 41780
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41782
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 41786
 $17 = $16 & 1; //@line 41787
 $18 = $16 >>> 1; //@line 41788
 $$ = ($17 | 0) == 0 ? $18 & 32767 : $18 | 32768; //@line 41792
 HEAP32[96444] = 0; //@line 41796
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41797
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41800
 HEAP32[96441] = $17; //@line 41801
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $$ & 65535); //@line 41806
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41809
 return;
}
function __Z12op_e5d8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $2 = 0, $20 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41250
 $3 = HEAP32[$2 >> 2] | 0; //@line 41251
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41253
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41257
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 41260
 $$ = (HEAP32[96445] | 0) != 0 | $9 << 1; //@line 41265
 HEAP32[96444] = 0; //@line 41269
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41270
 HEAP32[96443] = $9 >>> 14 & 1; //@line 41273
 $20 = $9 >>> 15 & 1; //@line 41275
 HEAP32[96441] = $20; //@line 41276
 HEAP32[96445] = $20; //@line 41277
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 41282
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41285
 return;
}
function __Z12op_e0d8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $16 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 38518
 $3 = HEAP32[$2 >> 2] | 0; //@line 38519
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 38521
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 38525
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 38528
 $12 = $9 & 32768; //@line 38529
 $13 = $9 & 1; //@line 38530
 $16 = $9 >>> 1 & 32767 | $12; //@line 38533
 HEAP32[96444] = 0; //@line 38536
 HEAP32[96442] = ($16 | 0) == 0 & 1; //@line 38537
 HEAP32[96443] = $12 >>> 15; //@line 38539
 HEAP32[96441] = $13; //@line 38540
 HEAP32[96445] = $13; //@line 38541
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $16); //@line 38545
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38548
 return;
}
function __Z12op_c0b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36073
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36082
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 36087
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 36088
 $23 = HEAP32[$21 >> 2] & $20; //@line 36090
 $25 = ($23 | 0) == 0 & 1; //@line 36092
 HEAP32[96441] = 0; //@line 36093
 HEAP32[96442] = 0; //@line 36093
 HEAP32[96443] = 0; //@line 36093
 HEAP32[96444] = 0; //@line 36093
 HEAP32[96442] = $25; //@line 36094
 HEAP32[96443] = $23 >>> 31; //@line 36096
 HEAP32[$21 >> 2] = $23; //@line 36097
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36100
 return;
}
function __Z12op_80b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $23 = 0, $25 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 23205
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 23214
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 23219
 $21 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 23220
 $23 = HEAP32[$21 >> 2] | $20; //@line 23222
 $25 = ($23 | 0) == 0 & 1; //@line 23224
 HEAP32[96441] = 0; //@line 23225
 HEAP32[96442] = 0; //@line 23225
 HEAP32[96443] = 0; //@line 23225
 HEAP32[96444] = 0; //@line 23225
 HEAP32[96442] = $25; //@line 23226
 HEAP32[96443] = $23 >>> 31; //@line 23228
 HEAP32[$21 >> 2] = $23; //@line 23229
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23232
 return;
}
function __Z12op_203b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $2 = 0, $22 = 0, $24 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 32085
 $4 = HEAP32[162769] | 0; //@line 32087
 $$cast = $4; //@line 32092
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 32101
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32106
 $24 = ($22 | 0) == 0 & 1; //@line 32108
 HEAP32[96441] = 0; //@line 32109
 HEAP32[96442] = 0; //@line 32109
 HEAP32[96443] = 0; //@line 32109
 HEAP32[96444] = 0; //@line 32109
 HEAP32[96442] = $24; //@line 32110
 HEAP32[96443] = $22 >>> 31; //@line 32112
 HEAP32[651008 + ($2 << 2) >> 2] = $22; //@line 32114
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32117
 return;
}
function __Z12op_d090_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit38 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $21 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 32646
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 32651
 $11 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32652
 $12 = HEAP32[$11 >> 2] | 0; //@line 32653
 $13 = $12 + $10 | 0; //@line 32654
 $$lobit38 = $13 >>> 31; //@line 32657
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 32660
 HEAP32[96444] = ($$lobit38 ^ $10 >>> 31) & ($$lobit38 ^ $12 >>> 31); //@line 32664
 $21 = $10 >>> 0 > ~$12 >>> 0 & 1; //@line 32667
 HEAP32[96441] = $21; //@line 32668
 HEAP32[96445] = $21; //@line 32669
 HEAP32[96443] = $$lobit38; //@line 32670
 HEAP32[$11 >> 2] = $13; //@line 32671
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32674
 return;
}
function __Z12op_c1b8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30681
 $5 = HEAP32[162769] | 0; //@line 30682
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 30692
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 30694
 $20 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0) & $4; //@line 30698
 $22 = ($20 | 0) == 0 & 1; //@line 30700
 HEAP32[96441] = 0; //@line 30701
 HEAP32[96442] = 0; //@line 30701
 HEAP32[96443] = 0; //@line 30701
 HEAP32[96444] = 0; //@line 30701
 HEAP32[96442] = $22; //@line 30702
 HEAP32[96443] = $20 >>> 31; //@line 30704
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 30708
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30711
 return;
}
function __Z12op_b1b8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27251
 $5 = HEAP32[162769] | 0; //@line 27252
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 27262
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 27264
 $20 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0) ^ $4; //@line 27268
 $22 = ($20 | 0) == 0 & 1; //@line 27270
 HEAP32[96441] = 0; //@line 27271
 HEAP32[96442] = 0; //@line 27271
 HEAP32[96443] = 0; //@line 27271
 HEAP32[96444] = 0; //@line 27271
 HEAP32[96442] = $22; //@line 27272
 HEAP32[96443] = $20 >>> 31; //@line 27274
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 27278
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 27281
 return;
}
function __Z12op_46b0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2538
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2547
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 2549
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$15 >> 2] >> 2] & 127]($13) | 0; //@line 2552
 $19 = ~$18; //@line 2553
 $21 = ($18 | 0) == -1 & 1; //@line 2555
 HEAP32[96441] = 0; //@line 2556
 HEAP32[96442] = 0; //@line 2556
 HEAP32[96443] = 0; //@line 2556
 HEAP32[96444] = 0; //@line 2556
 HEAP32[96442] = $21; //@line 2557
 HEAP32[96443] = $18 >>> 31 ^ 1; //@line 2560
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 12 >> 2] & 31]($13, $19); //@line 2564
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2567
 return;
}
function __Z12op_e6e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41630
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 41632
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 41634
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 41638
 HEAP32[$2 >> 2] = $4; //@line 41639
 $11 = $10 & 1; //@line 41640
 $12 = $10 >>> 1; //@line 41641
 $$ = ($11 | 0) == 0 ? $12 & 32767 : $12 | 32768; //@line 41645
 HEAP32[96444] = 0; //@line 41649
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41650
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41653
 HEAP32[96441] = $11; //@line 41654
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $$ & 65535); //@line 41659
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41662
 return;
}
function __Z12op_e5f8_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $1 = 0, $10 = 0, $12 = 0, $16 = 0, $25 = 0;
 $1 = HEAP32[162769] | 0; //@line 41441
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 41451
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 41453
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 41457
 $$ = (HEAP32[96445] | 0) != 0 | $16 << 1; //@line 41462
 HEAP32[96444] = 0; //@line 41466
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41467
 HEAP32[96443] = $16 >>> 14 & 1; //@line 41470
 $25 = $16 >>> 15 & 1; //@line 41472
 HEAP32[96441] = $25; //@line 41473
 HEAP32[96445] = $25; //@line 41474
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $$ & 65535); //@line 41479
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41482
 return;
}
function __Z12op_e0f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0;
 $1 = HEAP32[162769] | 0; //@line 38688
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 38698
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 38700
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 38704
 $17 = $16 & 32768; //@line 38705
 $18 = $16 & 1; //@line 38706
 $21 = $16 >>> 1 & 32767 | $17; //@line 38709
 HEAP32[96444] = 0; //@line 38712
 HEAP32[96442] = ($21 | 0) == 0 & 1; //@line 38713
 HEAP32[96443] = $17 >>> 15; //@line 38715
 HEAP32[96441] = $18; //@line 38716
 HEAP32[96445] = $18; //@line 38717
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $21); //@line 38721
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38724
 return;
}
function __Z12op_c0b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 29073
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 29082
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 29096
 $27 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29097
 $29 = HEAP32[$27 >> 2] & $26; //@line 29099
 $31 = ($29 | 0) == 0 & 1; //@line 29101
 HEAP32[96441] = 0; //@line 29102
 HEAP32[96442] = 0; //@line 29102
 HEAP32[96443] = 0; //@line 29102
 HEAP32[96444] = 0; //@line 29102
 HEAP32[96442] = $31; //@line 29103
 HEAP32[96443] = $29 >>> 31; //@line 29105
 HEAP32[$27 >> 2] = $29; //@line 29106
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29109
 return;
}
function __Z12op_81b8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16774
 $5 = HEAP32[162769] | 0; //@line 16775
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 16785
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 16787
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$16 >> 2] >> 2] & 127]($14) | 0 | $4; //@line 16791
 $22 = ($20 | 0) == 0 & 1; //@line 16793
 HEAP32[96441] = 0; //@line 16794
 HEAP32[96442] = 0; //@line 16794
 HEAP32[96443] = 0; //@line 16794
 HEAP32[96444] = 0; //@line 16794
 HEAP32[96442] = $22; //@line 16795
 HEAP32[96443] = $20 >>> 31; //@line 16797
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 12 >> 2] & 31]($14, $20); //@line 16801
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16804
 return;
}
function __Z12op_80b9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0, $31 = 0;
 $3 = HEAP32[162769] | 0; //@line 14750
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 14759
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 14773
 $27 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14774
 $29 = HEAP32[$27 >> 2] | $26; //@line 14776
 $31 = ($29 | 0) == 0 & 1; //@line 14778
 HEAP32[96441] = 0; //@line 14779
 HEAP32[96442] = 0; //@line 14779
 HEAP32[96443] = 0; //@line 14779
 HEAP32[96444] = 0; //@line 14779
 HEAP32[96442] = $31; //@line 14780
 HEAP32[96443] = $29 >>> 31; //@line 14782
 HEAP32[$27 >> 2] = $29; //@line 14783
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14786
 return;
}
function __Z12op_e7e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $23 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 41992
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 42003
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 42005
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 42009
 $23 = $20 >>> 15 & 1; //@line 42012
 $24 = $23 | $20 << 1; //@line 42013
 HEAP32[96444] = 0; //@line 42017
 HEAP32[96442] = ($24 & 65535) << 16 >> 16 == 0 & 1; //@line 42018
 HEAP32[96443] = $20 >>> 14 & 1; //@line 42021
 HEAP32[96441] = $23; //@line 42022
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $24 & 65535); //@line 42027
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42030
 return;
}
function __Z12op_e2f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $20 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49921
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 49930
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49932
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 49936
 $20 = $19 & 1; //@line 49937
 $22 = $19 >>> 1 & 32767; //@line 49939
 HEAP32[96444] = 0; //@line 49942
 HEAP32[96442] = ($22 | 0) == 0 & 1; //@line 49943
 HEAP32[96443] = 0; //@line 49944
 HEAP32[96441] = $20; //@line 49945
 HEAP32[96445] = $20; //@line 49946
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $22); //@line 49950
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49953
 return;
}
function __Z12op_c150_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30161
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30163
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 30165
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0) & $5; //@line 30170
 $14 = $sext2021 << 16 >> 16; //@line 30172
 $16 = ($14 | 0) == 0 & 1; //@line 30174
 HEAP32[96441] = 0; //@line 30175
 HEAP32[96442] = 0; //@line 30175
 HEAP32[96443] = 0; //@line 30175
 HEAP32[96444] = 0; //@line 30175
 HEAP32[96442] = $16; //@line 30176
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 30179
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $14); //@line 30183
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30186
 return;
}
function __Z12op_c0d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29307
 $5 = HEAP32[$4 >> 2] | 0; //@line 29308
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 29314
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 29317
 $14 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29318
 $18 = Math_imul(HEAP32[$14 >> 2] & 65535, $11 & 65535) | 0; //@line 29322
 $20 = ($18 | 0) == 0 & 1; //@line 29324
 HEAP32[96441] = 0; //@line 29325
 HEAP32[96442] = 0; //@line 29325
 HEAP32[96443] = 0; //@line 29325
 HEAP32[96444] = 0; //@line 29325
 HEAP32[96442] = $20; //@line 29326
 HEAP32[96443] = $18 >>> 31; //@line 29328
 HEAP32[$14 >> 2] = $18; //@line 29329
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29332
 return;
}
function __Z12op_b150_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26676
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26678
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 26680
 $sext2021 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0) ^ $5; //@line 26685
 $14 = $sext2021 << 16 >> 16; //@line 26687
 $16 = ($14 | 0) == 0 & 1; //@line 26689
 HEAP32[96441] = 0; //@line 26690
 HEAP32[96442] = 0; //@line 26690
 HEAP32[96443] = 0; //@line 26690
 HEAP32[96444] = 0; //@line 26690
 HEAP32[96442] = $16; //@line 26691
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 26694
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $14); //@line 26698
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26701
 return;
}
function __Z12op_c110_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29810
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29812
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 29814
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0) & $5; //@line 29819
 $14 = $sext1617 << 24 >> 24; //@line 29821
 $16 = ($14 | 0) == 0 & 1; //@line 29823
 HEAP32[96441] = 0; //@line 29824
 HEAP32[96442] = 0; //@line 29824
 HEAP32[96443] = 0; //@line 29824
 HEAP32[96444] = 0; //@line 29824
 HEAP32[96442] = $16; //@line 29825
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 29828
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $14); //@line 29832
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29835
 return;
}
function __Z12op_c0a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 28956
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28967
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28972
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28973
 $24 = HEAP32[$22 >> 2] & $21; //@line 28975
 $26 = ($24 | 0) == 0 & 1; //@line 28977
 HEAP32[96441] = 0; //@line 28978
 HEAP32[96442] = 0; //@line 28978
 HEAP32[96443] = 0; //@line 28978
 HEAP32[96444] = 0; //@line 28978
 HEAP32[96442] = $26; //@line 28979
 HEAP32[96443] = $24 >>> 31; //@line 28981
 HEAP32[$22 >> 2] = $24; //@line 28982
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28985
 return;
}
function __Z12op_b110_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26272
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 26274
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 26276
 $sext1617 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0) ^ $5; //@line 26281
 $14 = $sext1617 << 24 >> 24; //@line 26283
 $16 = ($14 | 0) == 0 & 1; //@line 26285
 HEAP32[96441] = 0; //@line 26286
 HEAP32[96442] = 0; //@line 26286
 HEAP32[96443] = 0; //@line 26286
 HEAP32[96444] = 0; //@line 26286
 HEAP32[96442] = $16; //@line 26287
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 26290
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $14); //@line 26294
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26297
 return;
}
function __Z12op_80a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 14633
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 14644
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 14649
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14650
 $24 = HEAP32[$22 >> 2] | $21; //@line 14652
 $26 = ($24 | 0) == 0 & 1; //@line 14654
 HEAP32[96441] = 0; //@line 14655
 HEAP32[96442] = 0; //@line 14655
 HEAP32[96443] = 0; //@line 14655
 HEAP32[96444] = 0; //@line 14655
 HEAP32[96442] = $26; //@line 14656
 HEAP32[96443] = $24 >>> 31; //@line 14658
 HEAP32[$22 >> 2] = $24; //@line 14659
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14662
 return;
}
function __Z12op_4a7b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 52147
 $2 = $1 + 2 | 0; //@line 52148
 HEAP32[162769] = $2; //@line 52149
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 52154
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 52161
 HEAP32[162769] = $1 + 4; //@line 52163
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 52164
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 52170
 $23 = ($21 & 65535 | 0) == 0 & 1; //@line 52173
 HEAP32[96441] = 0; //@line 52174
 HEAP32[96442] = 0; //@line 52174
 HEAP32[96443] = 0; //@line 52174
 HEAP32[96444] = 0; //@line 52174
 HEAP32[96442] = $23; //@line 52175
 HEAP32[96443] = $21 >>> 15 & 1; //@line 52178
 return;
}
function __Z12op_8150_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext2021 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16173
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16175
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 16177
 $sext2021 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 4 >> 2] & 127]($7) | 0 | $5; //@line 16182
 $14 = $sext2021 << 16 >> 16; //@line 16184
 $16 = ($14 | 0) == 0 & 1; //@line 16186
 HEAP32[96441] = 0; //@line 16187
 HEAP32[96442] = 0; //@line 16187
 HEAP32[96443] = 0; //@line 16187
 HEAP32[96444] = 0; //@line 16187
 HEAP32[96442] = $16; //@line 16188
 HEAP32[96443] = $sext2021 >>> 15 & 1; //@line 16191
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 16 >> 2] & 31]($7, $14); //@line 16195
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16198
 return;
}
function __Z12op_413b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $24 = 0, $4 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 45935
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 45938
 $$cast = $4; //@line 45940
 $17 = __Z15get_disp_ea_000jj($7 + 2 | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 45949
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 45954
 $24 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 45956
 if (($24 | 0) < 0) {
  HEAP32[96443] = 1; //@line 45959
  __Z9Exceptionij(6, $7); //@line 45960
  return;
 }
 if (($24 | 0) > ($22 | 0)) {
  HEAP32[96443] = 0; //@line 45965
  __Z9Exceptionij(6, $7); //@line 45966
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45971
  return;
 }
}
function __Z12op_e5e0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $19 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41294
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 41296
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 41298
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 41302
 HEAP32[$2 >> 2] = $4; //@line 41303
 $$ = (HEAP32[96445] | 0) != 0 | $10 << 1; //@line 41308
 HEAP32[96444] = 0; //@line 41312
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41313
 HEAP32[96443] = $10 >>> 14 & 1; //@line 41316
 $19 = $10 >>> 15 & 1; //@line 41318
 HEAP32[96441] = $19; //@line 41319
 HEAP32[96445] = $19; //@line 41320
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $$ & 65535); //@line 41325
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41328
 return;
}
function __Z12op_e0e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $15 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 38557
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 38559
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 38561
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 38565
 HEAP32[$2 >> 2] = $4; //@line 38566
 $11 = $10 & 32768; //@line 38567
 $12 = $10 & 1; //@line 38568
 $15 = $10 >>> 1 & 32767 | $11; //@line 38571
 HEAP32[96444] = 0; //@line 38574
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 38575
 HEAP32[96443] = $11 >>> 15; //@line 38577
 HEAP32[96441] = $12; //@line 38578
 HEAP32[96445] = $12; //@line 38579
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $15); //@line 38583
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38586
 return;
}
function __Z12op_b010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $14 = 0, $5 = 0, $sext$lobit = 0, $sext32$lobit = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21839
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 21845
 $13 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21847
 $14 = $13 - $11 | 0; //@line 21848
 $sext$lobit = $13 >>> 7 & 1; //@line 21852
 $sext32$lobit = $14 >>> 7 & 1; //@line 21854
 HEAP32[96442] = ($14 & 255 | 0) == 0 & 1; //@line 21858
 HEAP32[96444] = ($11 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext32$lobit | 0) != ($sext$lobit | 0) & 1; //@line 21863
 HEAP32[96441] = ($11 & 255) >>> 0 > ($13 & 255) >>> 0 & 1; //@line 21868
 HEAP32[96443] = $sext32$lobit; //@line 21869
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21872
 return;
}
function __Z12op_8110_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $5 = 0, $7 = 0, $9 = 0, $sext1617 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 15760
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15762
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 15764
 $sext1617 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0 | $5; //@line 15769
 $14 = $sext1617 << 24 >> 24; //@line 15771
 $16 = ($14 | 0) == 0 & 1; //@line 15773
 HEAP32[96441] = 0; //@line 15774
 HEAP32[96442] = 0; //@line 15774
 HEAP32[96443] = 0; //@line 15774
 HEAP32[96444] = 0; //@line 15774
 HEAP32[96442] = $16; //@line 15775
 HEAP32[96443] = $sext1617 >>> 7 & 1; //@line 15778
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $14); //@line 15782
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 15785
 return;
}
function __Z11op_1bb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16598
 $6 = HEAP32[162769] | 0; //@line 16600
 $$cast = $6; //@line 16605
 $19 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 16614
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 16616
 $26 = $4 & 7; //@line 16621
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 16623
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 16627
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, ($27 & (1 << $26 ^ 255)) << 24 >> 24); //@line 16636
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16639
 return;
}
function __Z12op_c1e0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $17 = 0, $19 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 30872
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 30874
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 30880
 HEAP32[$4 >> 2] = $6; //@line 30881
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30882
 $17 = Math_imul(HEAP32[$13 >> 2] << 16 >> 16, $12 << 16 >> 16) | 0; //@line 30888
 $19 = ($17 | 0) == 0 & 1; //@line 30890
 HEAP32[96441] = 0; //@line 30891
 HEAP32[96442] = 0; //@line 30891
 HEAP32[96443] = 0; //@line 30891
 HEAP32[96444] = 0; //@line 30891
 HEAP32[96442] = $19; //@line 30892
 HEAP32[96443] = $17 >>> 31; //@line 30894
 HEAP32[$13 >> 2] = $17; //@line 30895
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30898
 return;
}
function __Z12op_4a3b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 51771
 $2 = $1 + 2 | 0; //@line 51772
 HEAP32[162769] = $2; //@line 51773
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 51778
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 51785
 HEAP32[162769] = $1 + 4; //@line 51787
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 51788
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 51794
 $23 = ($21 & 255 | 0) == 0 & 1; //@line 51797
 HEAP32[96441] = 0; //@line 51798
 HEAP32[96442] = 0; //@line 51798
 HEAP32[96443] = 0; //@line 51798
 HEAP32[96444] = 0; //@line 51798
 HEAP32[96442] = $23; //@line 51799
 HEAP32[96443] = $21 >>> 7 & 1; //@line 51802
 return;
}
function __Z12op_4800_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $8 = 0, $sext26$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 49546
 $3 = HEAP32[$2 >> 2] | 0; //@line 49547
 $4 = $3 << 24 >> 24; //@line 49549
 $8 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - ($4 & 15) | 0; //@line 49554
 $10 = $8 & 65535; //@line 49556
 $13 = ($10 >>> 0 > 9 ? $10 + -6 | 0 : $8) - ($4 & 240) | 0; //@line 49560
 $15 = ($13 & 496) >>> 0 > 144; //@line 49562
 $16 = $15 & 1; //@line 49563
 HEAP32[96441] = $16; //@line 49566
 HEAP32[96445] = $16; //@line 49567
 $sext26$mask = ($15 ? $13 + 160 | 0 : $13) & 255; //@line 49569
 HEAP32[96442] = ($sext26$mask | 0) == 0 & HEAP32[96442]; //@line 49573
 HEAP32[$2 >> 2] = $sext26$mask | $3 & -256; //@line 49576
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49579
 return;
}
function _sinh($0) {
 $0 = +$0;
 var $$ = 0.0, $$0 = 0.0, $2 = 0, $4 = 0, $5 = 0.0, $7 = 0.0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 55763
 $2 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 55764
 $$ = ($2 | 0) < 0 ? -.5 : .5; //@line 55766
 $4 = $2 & 2147483647; //@line 55767
 HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2]; //@line 55768
 HEAP32[tempDoublePtr + 4 >> 2] = $4; //@line 55768
 $5 = +HEAPF64[tempDoublePtr >> 3]; //@line 55768
 do {
  if ($4 >>> 0 < 1082535490) {
   $7 = +_expm1($5); //@line 55772
   if ($4 >>> 0 >= 1072693248) {
    $$0 = $$ * ($7 + $7 / ($7 + 1.0)); //@line 55779
    break;
   }
   if ($4 >>> 0 < 1045430272) {
    $$0 = $0; //@line 55784
   } else {
    $$0 = $$ * ($7 * 2.0 - $7 * $7 / ($7 + 1.0)); //@line 55792
   }
  } else {
   $$0 = $$ * 2.0 * +___expo2($5); //@line 55798
  }
 } while (0);
 return +$$0;
}
function __Z12op_e2e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $21 = 0, $23 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 40382
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 40393
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40395
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40399
 $21 = $20 & 1; //@line 40400
 $23 = $20 >>> 1 & 32767; //@line 40402
 HEAP32[96444] = 0; //@line 40405
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 40406
 HEAP32[96443] = 0; //@line 40407
 HEAP32[96441] = $21; //@line 40408
 HEAP32[96445] = $21; //@line 40409
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $23); //@line 40413
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40416
 return;
}
function __Z12op_c1f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $23 = 0, $25 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 31000
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 31010
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 31016
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31017
 $23 = Math_imul(HEAP32[$19 >> 2] << 16 >> 16, $18 << 16 >> 16) | 0; //@line 31023
 $25 = ($23 | 0) == 0 & 1; //@line 31025
 HEAP32[96441] = 0; //@line 31026
 HEAP32[96442] = 0; //@line 31026
 HEAP32[96443] = 0; //@line 31026
 HEAP32[96444] = 0; //@line 31026
 HEAP32[96442] = $25; //@line 31027
 HEAP32[96443] = $23 >>> 31; //@line 31029
 HEAP32[$19 >> 2] = $23; //@line 31030
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31033
 return;
}
function __Z12op_2098_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $16 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28700
 $5 = HEAP32[$4 >> 2] | 0; //@line 28701
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28706
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 28709
 $14 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28711
 $16 = ($10 | 0) == 0 & 1; //@line 28713
 HEAP32[96441] = 0; //@line 28714
 HEAP32[96442] = 0; //@line 28714
 HEAP32[96443] = 0; //@line 28714
 HEAP32[96444] = 0; //@line 28714
 HEAP32[96442] = $16; //@line 28715
 HEAP32[96443] = $10 >>> 31; //@line 28717
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, $10); //@line 28723
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28726
 return;
}
function __Z19timer_host2mac_time7timeval($0) {
 $0 = $0 | 0;
 var $$1 = 0, $1 = 0, $11 = 0, $12 = 0, $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 13654
 if (($1 | 0) < 0) {
  $$1 = 0; //@line 13657
  return $$1 | 0; //@line 13658
 }
 $5 = ___muldi3($1 | 0, (($1 | 0) < 0) << 31 >> 31 | 0, 1e6, 0) | 0; //@line 13662
 $8 = HEAP32[$0 + 4 >> 2] | 0; //@line 13665
 $11 = _i64Add($8 | 0, (($8 | 0) < 0) << 31 >> 31 | 0, $5 | 0, tempRet0 | 0) | 0; //@line 13668
 $12 = tempRet0; //@line 13669
 if ($12 >>> 0 > 0 | ($12 | 0) == 0 & $11 >>> 0 > 2147483647) {
  $18 = ___udivdi3($11 | 0, $12 | 0, 1e3, 0) | 0; //@line 13676
  $$1 = $18; //@line 13678
  return $$1 | 0; //@line 13679
 } else {
  $20 = _i64Subtract(0, 0, $11 | 0, $12 | 0) | 0; //@line 13681
  $$1 = $20; //@line 13683
  return $$1 | 0; //@line 13684
 }
 return 0; //@line 13686
}
function __Z12op_33c8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $22 = 0, $23 = 0, $25 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 39322
 $4 = HEAP32[162769] | 0; //@line 39323
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 39332
 $22 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | (HEAPU8[$4 + 5 >> 0] | 0); //@line 39341
 $23 = $3 << 16 >> 16; //@line 39343
 $25 = ($23 | 0) == 0 & 1; //@line 39345
 HEAP32[96441] = 0; //@line 39346
 HEAP32[96442] = 0; //@line 39346
 HEAP32[96443] = 0; //@line 39346
 HEAP32[96444] = 0; //@line 39346
 HEAP32[96442] = $25; //@line 39347
 HEAP32[96443] = $3 >>> 15 & 1; //@line 39350
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($22, $23); //@line 39356
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39359
 return;
}
function __Z12op_33c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $22 = 0, $23 = 0, $25 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 39275
 $4 = HEAP32[162769] | 0; //@line 39276
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 39285
 $22 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | (HEAPU8[$4 + 5 >> 0] | 0); //@line 39294
 $23 = $3 << 16 >> 16; //@line 39296
 $25 = ($23 | 0) == 0 & 1; //@line 39298
 HEAP32[96441] = 0; //@line 39299
 HEAP32[96442] = 0; //@line 39299
 HEAP32[96443] = 0; //@line 39299
 HEAP32[96444] = 0; //@line 39299
 HEAP32[96442] = $25; //@line 39300
 HEAP32[96443] = $3 >>> 15 & 1; //@line 39303
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($22, $23); //@line 39309
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39312
 return;
}
function __Z12op_203a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $2 = 0, $23 = 0, $25 = 0, $4 = 0;
 $2 = $0 >>> 9 & 7; //@line 28148
 $4 = HEAP32[162769] | 0; //@line 28150
 $$cast = $4; //@line 28152
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 28166
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 28171
 $25 = ($23 | 0) == 0 & 1; //@line 28173
 HEAP32[96441] = 0; //@line 28174
 HEAP32[96442] = 0; //@line 28174
 HEAP32[96443] = 0; //@line 28174
 HEAP32[96444] = 0; //@line 28174
 HEAP32[96442] = $25; //@line 28175
 HEAP32[96443] = $23 >>> 31; //@line 28177
 HEAP32[651008 + ($2 << 2) >> 2] = $23; //@line 28179
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28182
 return;
}
function __Z12op_13c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $22 = 0, $23 = 0, $25 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 27197
 $4 = HEAP32[162769] | 0; //@line 27198
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 27207
 $22 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | (HEAPU8[$4 + 5 >> 0] | 0); //@line 27216
 $23 = $3 << 24 >> 24; //@line 27218
 $25 = ($23 | 0) == 0 & 1; //@line 27220
 HEAP32[96441] = 0; //@line 27221
 HEAP32[96442] = 0; //@line 27221
 HEAP32[96443] = 0; //@line 27221
 HEAP32[96444] = 0; //@line 27221
 HEAP32[96442] = $25; //@line 27222
 HEAP32[96443] = $3 >>> 7 & 1; //@line 27225
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($22, $23); //@line 27231
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27234
 return;
}
function __Z12op_113c_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $5 = 0, $6 = 0;
 $2 = $0 >>> 9 & 7; //@line 25353
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 25356
 $6 = 651040 + ($2 << 2) | 0; //@line 25357
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($2 << 2) >> 2] | 0) | 0; //@line 25361
 HEAP32[$6 >> 2] = $10; //@line 25362
 $11 = $5 << 24 >> 24; //@line 25363
 $13 = $5 << 24 >> 24 == 0 & 1; //@line 25365
 HEAP32[96441] = 0; //@line 25366
 HEAP32[96442] = 0; //@line 25366
 HEAP32[96443] = 0; //@line 25366
 HEAP32[96444] = 0; //@line 25366
 HEAP32[96442] = $13; //@line 25367
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 25370
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, $11); //@line 25376
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25379
 return;
}
function __Z12op_e3f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $19 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49964
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 49973
 $15 = 123608 + ($13 >>> 16 << 2) | 0; //@line 49975
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$15 >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 49979
 HEAP32[96444] = 0; //@line 49984
 HEAP32[96442] = ($19 & 32767 | 0) == 0 & 1; //@line 49985
 HEAP32[96443] = $19 >>> 14 & 1; //@line 49988
 $25 = $19 >>> 15 & 1; //@line 49990
 HEAP32[96441] = $25; //@line 49991
 HEAP32[96445] = $25; //@line 49992
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$15 >> 2] | 0) + 16 >> 2] & 31]($13, $19 << 1 & 65534); //@line 49997
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50000
 return;
}
function __Z11op_858_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 14212
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14215
 $5 = 651040 + ($1 << 2) | 0; //@line 14216
 $6 = HEAP32[$5 >> 2] | 0; //@line 14217
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 14219
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 14223
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 14228
 $18 = $4 & 7; //@line 14230
 $19 = 1 << $18; //@line 14231
 $21 = ($12 ^ $19) << 24 >> 24; //@line 14234
 HEAP32[96442] = ($21 & $19) >>> $18; //@line 14237
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $21); //@line 14241
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14244
 return;
}
function __Z11op_17a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $22 = 0, $27 = 0, $28 = 0, $30 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7336
 $6 = HEAP32[162769] | 0; //@line 7338
 $$cast = $6; //@line 7340
 $20 = (HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 7354
 $22 = 123608 + ($20 >>> 16 << 2) | 0; //@line 7356
 $27 = $4 & 7; //@line 7361
 $28 = 1 << $27; //@line 7362
 $30 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$22 >> 2] | 0) + 8 >> 2] & 127]($20) | 0) ^ $28) << 24 >> 24; //@line 7365
 HEAP32[96442] = ($30 & $28) >>> $27; //@line 7368
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$22 >> 2] | 0) + 20 >> 2] & 31]($20, $30); //@line 7372
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7375
 return;
}
function __Z12op_13fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $22 = 0, $24 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 27814
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 27816
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 27825
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 27834
 $22 = $3 << 24 >> 24; //@line 27835
 $24 = $3 << 24 >> 24 == 0 & 1; //@line 27837
 HEAP32[96441] = 0; //@line 27838
 HEAP32[96442] = 0; //@line 27838
 HEAP32[96443] = 0; //@line 27838
 HEAP32[96444] = 0; //@line 27838
 HEAP32[96442] = $24; //@line 27839
 HEAP32[96443] = ($3 & 255) >>> 7 & 255; //@line 27842
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($21, $22); //@line 27848
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 27851
 return;
}
function __Z11op_1fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $21 = 0, $26 = 0, $27 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16699
 $6 = HEAP32[162769] | 0; //@line 16701
 $$cast = $6; //@line 16706
 $19 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 16715
 $21 = 123608 + ($19 >>> 16 << 2) | 0; //@line 16717
 $26 = $4 & 7; //@line 16722
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$21 >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24; //@line 16724
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 16728
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$21 >> 2] | 0) + 20 >> 2] & 31]($19, ($27 | 1 << $26) << 24 >> 24); //@line 16736
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16739
 return;
}
function __Z12op_c0e0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $17 = 0, $19 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 29343
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 29345
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 29351
 HEAP32[$4 >> 2] = $6; //@line 29352
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29353
 $17 = Math_imul(HEAP32[$13 >> 2] & 65535, $12 & 65535) | 0; //@line 29357
 $19 = ($17 | 0) == 0 & 1; //@line 29359
 HEAP32[96441] = 0; //@line 29360
 HEAP32[96442] = 0; //@line 29360
 HEAP32[96443] = 0; //@line 29360
 HEAP32[96444] = 0; //@line 29360
 HEAP32[96442] = $19; //@line 29361
 HEAP32[96443] = $17 >>> 31; //@line 29363
 HEAP32[$13 >> 2] = $17; //@line 29364
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29367
 return;
}
function __Z12op_4e77_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $28 = 0, $7 = 0, $9 = 0;
 __Z6MakeSRv(); //@line 565
 $1 = HEAP32[162767] | 0; //@line 566
 $7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($1) | 0; //@line 572
 $9 = (HEAP32[162767] | 0) + 2 | 0; //@line 574
 HEAP32[162767] = $9; //@line 575
 $14 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($9 >>> 16 << 2) >> 2] >> 2] & 127]($9) | 0; //@line 580
 HEAP32[162767] = (HEAP32[162767] | 0) + 4; //@line 583
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $7 & 255; //@line 590
 $28 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 596
 HEAP32[162770] = $28; //@line 597
 HEAP32[162769] = $28; //@line 598
 HEAP32[162768] = $14; //@line 599
 __Z10MakeFromSRv(); //@line 600
 return;
}
function __Z12op_4a70_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 51991
 $3 = $2 + 2 | 0; //@line 51992
 HEAP32[162769] = $3; //@line 51993
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51995
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 52002
 HEAP32[162769] = $2 + 4; //@line 52004
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 52005
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 52011
 $22 = ($20 & 65535 | 0) == 0 & 1; //@line 52014
 HEAP32[96441] = 0; //@line 52015
 HEAP32[96442] = 0; //@line 52015
 HEAP32[96443] = 0; //@line 52015
 HEAP32[96444] = 0; //@line 52015
 HEAP32[96442] = $22; //@line 52016
 HEAP32[96443] = $20 >>> 15 & 1; //@line 52019
 return;
}
function __Z12op_4450_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $19 = 0, $3 = 0, $5 = 0, $9 = 0, $sext28$lobit = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47220
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 47222
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 47226
 $11 = 0 - ($9 << 16 >> 16) | 0; //@line 47229
 $sext28$lobit = $11 >>> 15 & 1; //@line 47232
 HEAP32[96442] = ($11 & 65535 | 0) == 0 & 1; //@line 47236
 HEAP32[96444] = $sext28$lobit & $9 >>> 15; //@line 47238
 $19 = ($9 & 65535 | 0) != 0 & 1; //@line 47241
 HEAP32[96441] = $19; //@line 47242
 HEAP32[96445] = $19; //@line 47243
 HEAP32[96443] = $sext28$lobit; //@line 47244
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $11); //@line 47248
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47251
 return;
}
function __Z12op_2110_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29666
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 29671
 $11 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29672
 $13 = (HEAP32[$11 >> 2] | 0) + -4 | 0; //@line 29674
 HEAP32[$11 >> 2] = $13; //@line 29675
 $15 = ($10 | 0) == 0 & 1; //@line 29677
 HEAP32[96441] = 0; //@line 29678
 HEAP32[96442] = 0; //@line 29678
 HEAP32[96443] = 0; //@line 29678
 HEAP32[96444] = 0; //@line 29678
 HEAP32[96442] = $15; //@line 29679
 HEAP32[96443] = $10 >>> 31; //@line 29681
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $10); //@line 29687
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29690
 return;
}
function __Z12op_e3e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $20 = 0, $26 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 40676
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 40687
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 40689
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 40693
 HEAP32[96444] = 0; //@line 40698
 HEAP32[96442] = ($20 & 32767 | 0) == 0 & 1; //@line 40699
 HEAP32[96443] = $20 >>> 14 & 1; //@line 40702
 $26 = $20 >>> 15 & 1; //@line 40704
 HEAP32[96441] = $26; //@line 40705
 HEAP32[96445] = $26; //@line 40706
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 16 >> 2] & 31]($14, $20 << 1 & 65534); //@line 40711
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40714
 return;
}
function __Z12op_c0f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $23 = 0, $25 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29465
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 29475
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 29481
 $19 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29482
 $23 = Math_imul(HEAP32[$19 >> 2] & 65535, $18 & 65535) | 0; //@line 29486
 $25 = ($23 | 0) == 0 & 1; //@line 29488
 HEAP32[96441] = 0; //@line 29489
 HEAP32[96442] = 0; //@line 29489
 HEAP32[96443] = 0; //@line 29489
 HEAP32[96444] = 0; //@line 29489
 HEAP32[96442] = $25; //@line 29490
 HEAP32[96443] = $23 >>> 31; //@line 29492
 HEAP32[$19 >> 2] = $23; //@line 29493
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29496
 return;
}
function __Z12op_413a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $25 = 0, $4 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 41854
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41857
 $$cast = $4; //@line 41859
 $18 = $7 + 2 + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 41870
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 41875
 $25 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41877
 if (($25 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41880
  __Z9Exceptionij(6, $7); //@line 41881
  return;
 }
 if (($25 | 0) > ($23 | 0)) {
  HEAP32[96443] = 0; //@line 41886
  __Z9Exceptionij(6, $7); //@line 41887
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41892
  return;
 }
}
function __Z12op_5ec8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $12 = 0, $2 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 10650
 $3 = HEAP32[$2 >> 2] | 0; //@line 10651
 $4 = HEAP32[162769] | 0; //@line 10652
 $12 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 10660
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   $$sink18 = 4; //@line 10668
   $27 = $4; //@line 10668
   $26 = $27 + $$sink18 | 0; //@line 10669
   HEAP32[162769] = $26; //@line 10670
   return;
  }
 }
 HEAP32[$2 >> 2] = $3 & -65536 | $3 + 65535 & 65535; //@line 10679
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($12 << 16 >> 16) + 2 | 0; //@line 10686
 $27 = HEAP32[162769] | 0; //@line 10686
 $26 = $27 + $$sink18 | 0; //@line 10687
 HEAP32[162769] = $26; //@line 10688
 return;
}
function __Z12op_b0d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit35 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25678
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 25684
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25686
 $14 = $11 << 16 >> 16; //@line 25688
 $15 = $13 - $14 | 0; //@line 25689
 $$lobit = $13 >>> 31; //@line 25692
 $$lobit35 = $15 >>> 31; //@line 25693
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 25696
 HEAP32[96444] = ($11 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit35 | 0) != ($$lobit | 0) & 1; //@line 25701
 HEAP32[96441] = $13 >>> 0 < $14 >>> 0 & 1; //@line 25704
 HEAP32[96443] = $$lobit35; //@line 25705
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25708
 return;
}
function __Z12op_4a30_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $22 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 51615
 $3 = $2 + 2 | 0; //@line 51616
 HEAP32[162769] = $3; //@line 51617
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51619
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 51626
 HEAP32[162769] = $2 + 4; //@line 51628
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 51629
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 51635
 $22 = ($20 & 255 | 0) == 0 & 1; //@line 51638
 HEAP32[96441] = 0; //@line 51639
 HEAP32[96442] = 0; //@line 51639
 HEAP32[96443] = 0; //@line 51639
 HEAP32[96444] = 0; //@line 51639
 HEAP32[96442] = $22; //@line 51640
 HEAP32[96443] = $20 >>> 7 & 1; //@line 51643
 return;
}
function __Z12op_4198_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $16 = 0, $8 = 0, $9 = 0, $sext = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42086
 $9 = 651040 + (($0 & 7) << 2) | 0; //@line 42087
 $10 = HEAP32[$9 >> 2] | 0; //@line 42088
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 42094
 HEAP32[$9 >> 2] = (HEAP32[$9 >> 2] | 0) + 2; //@line 42097
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42100
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42103
  __Z9Exceptionij(6, $8); //@line 42104
  return;
 }
 if (($sext | 0) > ($16 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42110
  __Z9Exceptionij(6, $8); //@line 42111
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42116
  return;
 }
}
function __Z12op_e1b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 39909
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39910
 $7 = HEAP32[$6 >> 2] | 0; //@line 39911
 $9 = ($5 & 63 | 0) == 0; //@line 39913
 $10 = $5 & 31; //@line 39914
 $14 = $7 >>> (32 - $10 | 0) | $7 << $10; //@line 39918
 HEAP32[96441] = 0; //@line 39919
 HEAP32[96442] = 0; //@line 39919
 HEAP32[96443] = 0; //@line 39919
 HEAP32[96444] = 0; //@line 39919
 if ($9) {
  $$0 = $7; //@line 39921
 } else {
  HEAP32[96441] = $14 & 1; //@line 39924
  $$0 = $14; //@line 39925
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 39929
 HEAP32[96443] = $$0 >>> 31; //@line 39931
 HEAP32[$6 >> 2] = $$0; //@line 39932
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39935
 return;
}
function __Z11op_158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $19 = 0, $21 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $3 = $0 & 7; //@line 7068
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7070
 $6 = 651040 + ($3 << 2) | 0; //@line 7071
 $7 = HEAP32[$6 >> 2] | 0; //@line 7072
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 7074
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 7078
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 7083
 $18 = $5 & 7; //@line 7084
 $19 = 1 << $18; //@line 7085
 $21 = ($13 ^ $19) << 24 >> 24; //@line 7088
 HEAP32[96442] = ($21 & $19) >>> $18; //@line 7091
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $21); //@line 7095
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7098
 return;
}
function __Z12op_20a0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $15 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28737
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 28739
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 28744
 HEAP32[$4 >> 2] = $6; //@line 28745
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28747
 $15 = ($11 | 0) == 0 & 1; //@line 28749
 HEAP32[96441] = 0; //@line 28750
 HEAP32[96442] = 0; //@line 28750
 HEAP32[96443] = 0; //@line 28750
 HEAP32[96444] = 0; //@line 28750
 HEAP32[96442] = $15; //@line 28751
 HEAP32[96443] = $11 >>> 31; //@line 28753
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $11); //@line 28759
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28762
 return;
}
function __Z12op_4410_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $19 = 0, $3 = 0, $5 = 0, $9 = 0, $sext26$lobit = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46842
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 46844
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 46848
 $11 = 0 - ($9 << 24 >> 24) | 0; //@line 46851
 $sext26$lobit = $11 >>> 7 & 1; //@line 46854
 HEAP32[96442] = ($11 & 255 | 0) == 0 & 1; //@line 46858
 HEAP32[96444] = $sext26$lobit & $9 >>> 7; //@line 46860
 $19 = ($9 & 255 | 0) != 0 & 1; //@line 46863
 HEAP32[96441] = $19; //@line 46864
 HEAP32[96445] = $19; //@line 46865
 HEAP32[96443] = $sext26$lobit; //@line 46866
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $11); //@line 46870
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46873
 return;
}
function __Z12op_20b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $19 = 0, $21 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 28862
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 28872
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 28877
 $19 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28879
 $21 = ($17 | 0) == 0 & 1; //@line 28881
 HEAP32[96441] = 0; //@line 28882
 HEAP32[96442] = 0; //@line 28882
 HEAP32[96443] = 0; //@line 28882
 HEAP32[96444] = 0; //@line 28882
 HEAP32[96442] = $21; //@line 28883
 HEAP32[96443] = $17 >>> 31; //@line 28885
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, $17); //@line 28891
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28894
 return;
}
function __Z12op_10fc_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = $0 >>> 9 & 7; //@line 24818
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 24821
 $6 = 651040 + ($2 << 2) | 0; //@line 24822
 $7 = HEAP32[$6 >> 2] | 0; //@line 24823
 HEAP32[$6 >> 2] = (HEAP32[5656 + ($2 << 2) >> 2] | 0) + $7; //@line 24827
 $11 = $5 << 24 >> 24; //@line 24828
 $13 = $5 << 24 >> 24 == 0 & 1; //@line 24830
 HEAP32[96441] = 0; //@line 24831
 HEAP32[96442] = 0; //@line 24831
 HEAP32[96443] = 0; //@line 24831
 HEAP32[96444] = 0; //@line 24831
 HEAP32[96442] = $13; //@line 24832
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 24835
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($7, $11); //@line 24841
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24844
 return;
}
function __Z12op_e0b8_0_ffj($0) {
 $0 = $0 | 0;
 var $$0 = 0, $10 = 0, $14 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 38447
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38448
 $7 = HEAP32[$6 >> 2] | 0; //@line 38449
 $9 = ($5 & 63 | 0) == 0; //@line 38451
 $10 = $5 & 31; //@line 38452
 $14 = $7 << 32 - $10 | $7 >>> $10; //@line 38456
 HEAP32[96441] = 0; //@line 38457
 HEAP32[96442] = 0; //@line 38457
 HEAP32[96443] = 0; //@line 38457
 HEAP32[96444] = 0; //@line 38457
 if ($9) {
  $$0 = $7; //@line 38459
 } else {
  HEAP32[96441] = $14 >>> 31; //@line 38462
  $$0 = $14; //@line 38463
 }
 HEAP32[96442] = ($$0 | 0) == 0 & 1; //@line 38467
 HEAP32[96443] = $$0 >>> 31; //@line 38469
 HEAP32[$6 >> 2] = $$0; //@line 38470
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38473
 return;
}
function __Z12op_20d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $12 = 0, $15 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29156
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 29161
 $11 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29162
 $12 = HEAP32[$11 >> 2] | 0; //@line 29163
 HEAP32[$11 >> 2] = $12 + 4; //@line 29165
 $15 = ($10 | 0) == 0 & 1; //@line 29167
 HEAP32[96441] = 0; //@line 29168
 HEAP32[96442] = 0; //@line 29168
 HEAP32[96443] = 0; //@line 29168
 HEAP32[96444] = 0; //@line 29168
 HEAP32[96442] = $15; //@line 29169
 HEAP32[96443] = $10 >>> 31; //@line 29171
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($12, $10); //@line 29177
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29180
 return;
}
function __Z11op_860_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $20 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 14252
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14255
 $5 = 651040 + ($1 << 2) | 0; //@line 14256
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 14260
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 14262
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 14266
 HEAP32[$5 >> 2] = $9; //@line 14267
 $17 = $4 & 7; //@line 14269
 $18 = 1 << $17; //@line 14270
 $20 = ($15 ^ $18) << 24 >> 24; //@line 14273
 HEAP32[96442] = ($20 & $18) >>> $17; //@line 14276
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, $20); //@line 14280
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14283
 return;
}
function __Z11op_160_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0, $6 = 0;
 $3 = $0 & 7; //@line 7108
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7110
 $6 = 651040 + ($3 << 2) | 0; //@line 7111
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 7115
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 7117
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 7121
 HEAP32[$6 >> 2] = $10; //@line 7122
 $17 = $5 & 7; //@line 7123
 $18 = 1 << $17; //@line 7124
 $20 = ($16 ^ $18) << 24 >> 24; //@line 7127
 HEAP32[96442] = ($20 & $18) >>> $17; //@line 7130
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, $20); //@line 7134
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7137
 return;
}
function __Z12op_4c70_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $18 = 0, $2 = 0, $25 = 0, $27 = 0, $3 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53457
 $3 = $2 + 2 | 0; //@line 53458
 HEAP32[162769] = $3; //@line 53459
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53464
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53472
 $16 = $2 + 4 | 0; //@line 53473
 HEAP32[162769] = $16; //@line 53474
 $18 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 53476
 $25 = (HEAPU8[$16 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 53483
 HEAP32[162769] = $2 + 6; //@line 53485
 $27 = __Z15get_disp_ea_020jj($18, $25) | 0; //@line 53486
 __Z9m68k_divljjtj($0, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($27 >>> 16 << 2) >> 2] >> 2] & 127]($27) | 0, $15, $7); //@line 53492
 return;
}
function __Z12op_1100_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $3 = 0, $5 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 24854
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 24856
 $6 = 651040 + ($3 << 2) | 0; //@line 24857
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 24861
 HEAP32[$6 >> 2] = $10; //@line 24862
 $11 = $5 << 24 >> 24; //@line 24864
 $13 = ($11 | 0) == 0 & 1; //@line 24866
 HEAP32[96441] = 0; //@line 24867
 HEAP32[96442] = 0; //@line 24867
 HEAP32[96443] = 0; //@line 24867
 HEAP32[96444] = 0; //@line 24867
 HEAP32[96442] = $13; //@line 24868
 HEAP32[96443] = $5 >>> 7 & 1; //@line 24871
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, $11); //@line 24877
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24880
 return;
}
function __Z11op_e90_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $26 = 0, $30 = 0, $7 = 0, $9 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 22290
  return;
 }
 $7 = HEAPU8[(HEAP32[162769] | 0) + 2 >> 0] | 0; //@line 22297
 $9 = $7 << 24 >> 16; //@line 22299
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 22303
 if (!($9 & 2048)) {
  $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 22309
  $30 = $7 >>> 4 & 7; //@line 22313
  HEAP32[($9 & 32768 | 0 ? 651040 + ($30 << 2) | 0 : 651008 + ($30 << 2) | 0) >> 2] = $26; //@line 22317
 } else {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, HEAP32[651008 + ($7 >>> 4 << 2) >> 2] | 0); //@line 22327
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 22331
 return;
}
function __Z12op_4abb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $20 = 0, $22 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 52500
 $2 = $1 + 2 | 0; //@line 52501
 HEAP32[162769] = $2; //@line 52502
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 52507
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 52514
 HEAP32[162769] = $1 + 4; //@line 52516
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 52517
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 52522
 $22 = ($20 | 0) == 0 & 1; //@line 52524
 HEAP32[96441] = 0; //@line 52525
 HEAP32[96442] = 0; //@line 52525
 HEAP32[96443] = 0; //@line 52525
 HEAP32[96444] = 0; //@line 52525
 HEAP32[96442] = $22; //@line 52526
 HEAP32[96443] = $20 >>> 31; //@line 52528
 return;
}
function _strtox_742($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $10 = 0, $12 = 0, $5 = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 54869
 STACKTOP = STACKTOP + 128 | 0; //@line 54870
 $5 = sp; //@line 54871
 HEAP32[$5 >> 2] = 0; //@line 54872
 $6 = $5 + 4 | 0; //@line 54873
 HEAP32[$6 >> 2] = $0; //@line 54874
 HEAP32[$5 + 44 >> 2] = $0; //@line 54876
 $10 = $5 + 8 | 0; //@line 54880
 HEAP32[$10 >> 2] = ($0 | 0) < 0 ? -1 : $0 + 2147483647 | 0; //@line 54881
 HEAP32[$5 + 76 >> 2] = -1; //@line 54883
 ___shlim($5, 0); //@line 54884
 $12 = ___intscan($5, $2, 1, $3, $4) | 0; //@line 54885
 if ($1 | 0) {
  HEAP32[$1 >> 2] = $0 + ((HEAP32[$6 >> 2] | 0) + (HEAP32[$5 + 108 >> 2] | 0) - (HEAP32[$10 >> 2] | 0)); //@line 54896
 }
 STACKTOP = sp; //@line 54899
 return $12 | 0; //@line 54899
}
function __Z11op_1ba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $22 = 0, $27 = 0, $28 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7834
 $6 = HEAP32[162769] | 0; //@line 7836
 $$cast = $6; //@line 7838
 $20 = (HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 7852
 $22 = 123608 + ($20 >>> 16 << 2) | 0; //@line 7854
 $27 = $4 & 7; //@line 7859
 $28 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$22 >> 2] | 0) + 8 >> 2] & 127]($20) | 0) << 24 >> 24; //@line 7861
 HEAP32[96442] = $28 >>> $27 & 1 ^ 1; //@line 7865
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$22 >> 2] | 0) + 20 >> 2] & 31]($20, ($28 & (1 << $27 ^ 255)) << 24 >> 24); //@line 7874
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7877
 return;
}
function __Z12op_317c_0_ffj($0) {
 $0 = $0 | 0;
 var $23 = 0, $24 = 0, $26 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 37965
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 37968
 $23 = (((HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37986
 $24 = ($6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 37988
 $26 = ($24 | 0) == 0 & 1; //@line 37990
 HEAP32[96441] = 0; //@line 37991
 HEAP32[96442] = 0; //@line 37991
 HEAP32[96443] = 0; //@line 37991
 HEAP32[96444] = 0; //@line 37991
 HEAP32[96442] = $26; //@line 37992
 HEAP32[96443] = $6 >>> 7; //@line 37994
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($23, $24); //@line 38000
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 38003
 return;
}
function __Z11op_898_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 14634
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14637
 $5 = 651040 + ($1 << 2) | 0; //@line 14638
 $6 = HEAP32[$5 >> 2] | 0; //@line 14639
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 14641
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 14645
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 14650
 $18 = $4 & 7; //@line 14652
 $19 = $12 << 24 >> 24; //@line 14654
 HEAP32[96442] = $19 >>> $18 & 1 ^ 1; //@line 14658
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, ($19 & (1 << $18 ^ 255)) << 24 >> 24); //@line 14667
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14670
 return;
}
function __Z14PrefsAddStringPKcS0_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$sink$i = 0, $11 = 0, $13 = 0, $3 = 0, $4 = 0, $6 = 0;
 $3 = (_strlen($1) | 0) + 1 | 0; //@line 837
 $4 = _malloc($3) | 0; //@line 838
 if (!$4) {
  return;
 }
 _memcpy($4 | 0, $1 | 0, $3 | 0) | 0; //@line 843
 $6 = __Znwj(16) | 0; //@line 844
 HEAP32[$6 >> 2] = 0; //@line 845
 HEAP32[$6 + 4 >> 2] = ___strdup($0) | 0; //@line 848
 HEAP32[$6 + 8 >> 2] = 0; //@line 850
 HEAP32[$6 + 12 >> 2] = $4; //@line 852
 $11 = HEAP32[28198] | 0; //@line 853
 if (!$11) {
  $$sink$i = 112792; //@line 856
 } else {
  $$0$i = $11; //@line 858
  while (1) {
   $13 = HEAP32[$$0$i >> 2] | 0; //@line 860
   if (!$13) {
    break;
   } else {
    $$0$i = $13; //@line 865
   }
  }
  $$sink$i = $$0$i; //@line 868
 }
 HEAP32[$$sink$i >> 2] = $6; //@line 870
 return;
}
function __Z12op_41a0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $17 = 0, $8 = 0, $9 = 0, $sext = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42132
 $9 = 651040 + (($0 & 7) << 2) | 0; //@line 42133
 $11 = (HEAP32[$9 >> 2] | 0) + -2 | 0; //@line 42135
 $17 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($11) | 0; //@line 42141
 HEAP32[$9 >> 2] = $11; //@line 42142
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42145
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42148
  __Z9Exceptionij(6, $8); //@line 42149
  return;
 }
 if (($sext | 0) > ($17 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42155
  __Z9Exceptionij(6, $8); //@line 42156
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42161
  return;
 }
}
function __ZN8tinyxml212XMLAttributeD2Ev($0) {
 $0 = $0 | 0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $1 = 0, $12 = 0, $5 = 0, $8 = 0;
 HEAP32[$0 >> 2] = 2144; //@line 38935
 $1 = $0 + 16 | 0; //@line 38936
 $$pre$i$i = $0 + 20 | 0; //@line 38940
 if (HEAP32[$1 >> 2] & 512 | 0) {
  $5 = HEAP32[$$pre$i$i >> 2] | 0; //@line 38942
  if ($5 | 0) {
   __ZdaPv($5); //@line 38945
  }
 }
 HEAP32[$1 >> 2] = 0; //@line 38948
 HEAP32[$$pre$i$i >> 2] = 0; //@line 38949
 HEAP32[$0 + 24 >> 2] = 0; //@line 38951
 $8 = $0 + 4 | 0; //@line 38952
 $$pre$i$i1 = $0 + 8 | 0; //@line 38956
 if (HEAP32[$8 >> 2] & 512 | 0) {
  $12 = HEAP32[$$pre$i$i1 >> 2] | 0; //@line 38958
  if ($12 | 0) {
   __ZdaPv($12); //@line 38961
  }
 }
 HEAP32[$8 >> 2] = 0; //@line 38964
 HEAP32[$$pre$i$i1 >> 2] = 0; //@line 38965
 HEAP32[$0 + 12 >> 2] = 0; //@line 38967
 return;
}
function __Z11op_a10_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15505
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15507
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 15509
 $14 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0) ^ $4 & 255; //@line 15515
 $15 = $14 << 24 >> 24; //@line 15517
 $17 = ($15 | 0) == 0 & 1; //@line 15519
 HEAP32[96441] = 0; //@line 15520
 HEAP32[96442] = 0; //@line 15520
 HEAP32[96443] = 0; //@line 15520
 HEAP32[96444] = 0; //@line 15520
 HEAP32[96442] = $17; //@line 15521
 HEAP32[96443] = $14 >>> 7 & 1; //@line 15524
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $15); //@line 15528
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15531
 return;
}
function __Z12op_4138_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $21 = 0, $23 = 0, $4 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 41750
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41753
 $$cast = $4; //@line 41754
 $16 = ((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16; //@line 41764
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 41769
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41771
 if (($23 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41774
  __Z9Exceptionij(6, $7); //@line 41775
  return;
 }
 if (($23 | 0) > ($21 | 0)) {
  HEAP32[96443] = 0; //@line 41780
  __Z9Exceptionij(6, $7); //@line 41781
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41786
  return;
 }
}
function __Z12op_21fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $28 = 0, $30 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 34130
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 34133
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 34148
 $28 = ((HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) << 16 >> 16; //@line 34158
 $30 = ($19 | 0) == 0 & 1; //@line 34160
 HEAP32[96441] = 0; //@line 34161
 HEAP32[96442] = 0; //@line 34161
 HEAP32[96443] = 0; //@line 34161
 HEAP32[96444] = 0; //@line 34161
 HEAP32[96442] = $30; //@line 34162
 HEAP32[96443] = $4 >>> 7; //@line 34164
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $19); //@line 34170
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 34173
 return;
}
function __Z12op_4498_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $2 = 0, $3 = 0, $5 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47622
 $3 = HEAP32[$2 >> 2] | 0; //@line 47623
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 47625
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 47628
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 47631
 $13 = ($8 | 0) > 0 & 1; //@line 47635
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 47638
 HEAP32[96444] = $13 & $8 >>> 31; //@line 47640
 $18 = ($8 | 0) != 0 & 1; //@line 47642
 HEAP32[96441] = $18; //@line 47643
 HEAP32[96445] = $18; //@line 47644
 HEAP32[96443] = $13; //@line 47645
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, 0 - $8 | 0); //@line 47649
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47652
 return;
}
function __Z11op_198_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $19 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $3 = $0 & 7; //@line 7541
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7543
 $6 = 651040 + ($3 << 2) | 0; //@line 7544
 $7 = HEAP32[$6 >> 2] | 0; //@line 7545
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 7547
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 7551
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 7556
 $18 = $5 & 7; //@line 7557
 $19 = $13 << 24 >> 24; //@line 7559
 HEAP32[96442] = $19 >>> $18 & 1 ^ 1; //@line 7563
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, ($19 & (1 << $18 ^ 255)) << 24 >> 24); //@line 7572
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7575
 return;
}
function __Z11op_179_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $31 = 0, $33 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7284
 $5 = HEAP32[162769] | 0; //@line 7285
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 7294
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 7303
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 7305
 $30 = $4 & 7; //@line 7310
 $31 = 1 << $30; //@line 7311
 $33 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0) ^ $31) << 24 >> 24; //@line 7314
 HEAP32[96442] = ($33 & $31) >>> $30; //@line 7317
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, $33); //@line 7321
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7324
 return;
}
function __Z12op_44b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $15 = 0, $18 = 0, $23 = 0;
 $1 = HEAP32[162769] | 0; //@line 47792
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 47802
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 47804
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$12 >> 2] >> 2] & 127]($10) | 0; //@line 47807
 $18 = ($15 | 0) > 0 & 1; //@line 47811
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 47814
 HEAP32[96444] = $18 & $15 >>> 31; //@line 47816
 $23 = ($15 | 0) != 0 & 1; //@line 47818
 HEAP32[96441] = $23; //@line 47819
 HEAP32[96445] = $23; //@line 47820
 HEAP32[96443] = $18; //@line 47821
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 12 >> 2] & 31]($10, 0 - $15 | 0); //@line 47825
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 47828
 return;
}
function __Z12op_3188_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 44829
 $8 = HEAP32[162769] | 0; //@line 44832
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 44841
 $18 = $5 << 16 >> 16; //@line 44843
 $20 = ($18 | 0) == 0 & 1; //@line 44845
 HEAP32[96441] = 0; //@line 44846
 HEAP32[96442] = 0; //@line 44846
 HEAP32[96443] = 0; //@line 44846
 HEAP32[96444] = 0; //@line 44846
 HEAP32[96442] = $20; //@line 44847
 HEAP32[96443] = $5 >>> 15 & 1; //@line 44850
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($17, $18); //@line 44856
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44859
 return;
}
function __Z12op_3180_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 44787
 $8 = HEAP32[162769] | 0; //@line 44790
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 44799
 $18 = $5 << 16 >> 16; //@line 44801
 $20 = ($18 | 0) == 0 & 1; //@line 44803
 HEAP32[96441] = 0; //@line 44804
 HEAP32[96442] = 0; //@line 44804
 HEAP32[96443] = 0; //@line 44804
 HEAP32[96444] = 0; //@line 44804
 HEAP32[96442] = $20; //@line 44805
 HEAP32[96443] = $5 >>> 15 & 1; //@line 44808
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($17, $18); //@line 44814
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44817
 return;
}
function __Z12op_10c0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 24319
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 24321
 $6 = 651040 + ($3 << 2) | 0; //@line 24322
 $7 = HEAP32[$6 >> 2] | 0; //@line 24323
 HEAP32[$6 >> 2] = (HEAP32[5656 + ($3 << 2) >> 2] | 0) + $7; //@line 24327
 $11 = $5 << 24 >> 24; //@line 24329
 $13 = ($11 | 0) == 0 & 1; //@line 24331
 HEAP32[96441] = 0; //@line 24332
 HEAP32[96442] = 0; //@line 24332
 HEAP32[96443] = 0; //@line 24332
 HEAP32[96444] = 0; //@line 24332
 HEAP32[96442] = $13; //@line 24333
 HEAP32[96443] = $5 >>> 7 & 1; //@line 24336
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($7, $11); //@line 24342
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24345
 return;
}
function __Z11op_1fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $22 = 0, $27 = 0, $28 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8348
 $6 = HEAP32[162769] | 0; //@line 8350
 $$cast = $6; //@line 8352
 $20 = (HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 8366
 $22 = 123608 + ($20 >>> 16 << 2) | 0; //@line 8368
 $27 = $4 & 7; //@line 8373
 $28 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$22 >> 2] | 0) + 8 >> 2] & 127]($20) | 0) << 24 >> 24; //@line 8375
 HEAP32[96442] = $28 >>> $27 & 1 ^ 1; //@line 8379
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$22 >> 2] | 0) + 20 >> 2] & 31]($20, ($28 | 1 << $27) << 24 >> 24); //@line 8387
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8390
 return;
}
function __Z12op_21d0_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $3 = 0, $8 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33675
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 33680
 $9 = HEAP32[162769] | 0; //@line 33681
 $18 = ((HEAPU8[$9 + 2 >> 0] | 0) << 8 | (HEAPU8[$9 + 3 >> 0] | 0)) << 16 >> 16; //@line 33691
 $20 = ($8 | 0) == 0 & 1; //@line 33693
 HEAP32[96441] = 0; //@line 33694
 HEAP32[96442] = 0; //@line 33694
 HEAP32[96443] = 0; //@line 33694
 HEAP32[96444] = 0; //@line 33694
 HEAP32[96442] = $20; //@line 33695
 HEAP32[96443] = $8 >>> 31; //@line 33697
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $8); //@line 33703
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33706
 return;
}
function __Z12op_1180_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 31199
 $8 = HEAP32[162769] | 0; //@line 31202
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 31211
 $18 = $5 << 24 >> 24; //@line 31213
 $20 = ($18 | 0) == 0 & 1; //@line 31215
 HEAP32[96441] = 0; //@line 31216
 HEAP32[96442] = 0; //@line 31216
 HEAP32[96443] = 0; //@line 31216
 HEAP32[96444] = 0; //@line 31216
 HEAP32[96442] = $20; //@line 31217
 HEAP32[96443] = $5 >>> 7 & 1; //@line 31220
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, $18); //@line 31226
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31229
 return;
}
function __Z11op_8d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0;
 $1 = $0 & 7; //@line 15088
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15091
 $5 = 651040 + ($1 << 2) | 0; //@line 15092
 $6 = HEAP32[$5 >> 2] | 0; //@line 15093
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 15095
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 15099
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 15104
 $18 = $4 & 7; //@line 15106
 $19 = $12 << 24 >> 24; //@line 15108
 HEAP32[96442] = $19 >>> $18 & 1 ^ 1; //@line 15112
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, ($19 | 1 << $18) << 24 >> 24); //@line 15120
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15123
 return;
}
function __Z11op_1a0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $5 = 0, $6 = 0;
 $3 = $0 & 7; //@line 7585
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7587
 $6 = 651040 + ($3 << 2) | 0; //@line 7588
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 7592
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 7594
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 7598
 HEAP32[$6 >> 2] = $10; //@line 7599
 $17 = $5 & 7; //@line 7600
 $18 = $16 << 24 >> 24; //@line 7602
 HEAP32[96442] = $18 >>> $17 & 1 ^ 1; //@line 7606
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, ($18 & (1 << $17 ^ 255)) << 24 >> 24); //@line 7615
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7618
 return;
}
function __Z12op_4ab0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $19 = 0, $2 = 0, $21 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 52356
 $3 = $2 + 2 | 0; //@line 52357
 HEAP32[162769] = $3; //@line 52358
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52360
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 52367
 HEAP32[162769] = $2 + 4; //@line 52369
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 52370
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 52375
 $21 = ($19 | 0) == 0 & 1; //@line 52377
 HEAP32[96441] = 0; //@line 52378
 HEAP32[96442] = 0; //@line 52378
 HEAP32[96443] = 0; //@line 52378
 HEAP32[96444] = 0; //@line 52378
 HEAP32[96442] = $21; //@line 52379
 HEAP32[96443] = $19 >>> 31; //@line 52381
 return;
}
function __Z11op_8a0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 14678
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14681
 $5 = 651040 + ($1 << 2) | 0; //@line 14682
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 14686
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 14688
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 14692
 HEAP32[$5 >> 2] = $9; //@line 14693
 $17 = $4 & 7; //@line 14695
 $18 = $15 << 24 >> 24; //@line 14697
 HEAP32[96442] = $18 >>> $17 & 1 ^ 1; //@line 14701
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, ($18 & (1 << $17 ^ 255)) << 24 >> 24); //@line 14710
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14713
 return;
}
function __Z12op_4698_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $2 = 0, $3 = 0, $5 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 48929
 $3 = HEAP32[$2 >> 2] | 0; //@line 48930
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48932
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 48935
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 48938
 $11 = ~$8; //@line 48939
 $13 = ($8 | 0) == -1 & 1; //@line 48941
 HEAP32[96441] = 0; //@line 48942
 HEAP32[96442] = 0; //@line 48942
 HEAP32[96443] = 0; //@line 48942
 HEAP32[96444] = 0; //@line 48942
 HEAP32[96442] = $13; //@line 48943
 HEAP32[96443] = $8 >>> 31 ^ 1; //@line 48946
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, $11); //@line 48950
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48953
 return;
}
function __Z12op_3148_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $19 = 0, $21 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 37383
 $8 = HEAP32[162769] | 0; //@line 37386
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37397
 $19 = $5 << 16 >> 16; //@line 37399
 $21 = ($19 | 0) == 0 & 1; //@line 37401
 HEAP32[96441] = 0; //@line 37402
 HEAP32[96442] = 0; //@line 37402
 HEAP32[96443] = 0; //@line 37402
 HEAP32[96444] = 0; //@line 37402
 HEAP32[96442] = $21; //@line 37403
 HEAP32[96443] = $5 >>> 15 & 1; //@line 37406
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($18, $19); //@line 37412
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37415
 return;
}
function __Z12op_3140_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $19 = 0, $21 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 37339
 $8 = HEAP32[162769] | 0; //@line 37342
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 37353
 $19 = $5 << 16 >> 16; //@line 37355
 $21 = ($19 | 0) == 0 & 1; //@line 37357
 HEAP32[96441] = 0; //@line 37358
 HEAP32[96442] = 0; //@line 37358
 HEAP32[96443] = 0; //@line 37358
 HEAP32[96444] = 0; //@line 37358
 HEAP32[96442] = $21; //@line 37359
 HEAP32[96443] = $5 >>> 15 & 1; //@line 37362
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($18, $19); //@line 37368
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37371
 return;
}
function __Z12op_11bc_3_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $17 = 0, $19 = 0, $3 = 0, $5 = 0;
 $3 = HEAP32[162769] | 0; //@line 31762
 $5 = HEAP8[$3 + 3 >> 0] | 0; //@line 31764
 $16 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 31775
 $17 = $5 << 24 >> 24; //@line 31776
 $19 = $5 << 24 >> 24 == 0 & 1; //@line 31778
 HEAP32[96441] = 0; //@line 31779
 HEAP32[96442] = 0; //@line 31779
 HEAP32[96443] = 0; //@line 31779
 HEAP32[96444] = 0; //@line 31779
 HEAP32[96442] = $19; //@line 31780
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 31783
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($16, $17); //@line 31789
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 31792
 return;
}
function __Z9fpuop_bccjjj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $10 = 0, $14 = 0, $20 = 0;
 switch (__ZL8fpp_condi($0 & 63) | 0) {
 case -1:
  {
   $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1) | 0; //@line 55839
   HEAP32[162770] = $10; //@line 55840
   HEAP32[162769] = $10; //@line 55841
   HEAP32[162768] = $1; //@line 55842
   __Z7op_illgj($0); //@line 55843
   return;
  }
 case 0:
  {
   return;
  }
 default:
  {
   $14 = (($0 & 64 | 0) == 0 ? $2 << 16 >> 16 : $2) + $1 | 0; //@line 55857
   $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 55863
   HEAP32[162770] = $20; //@line 55864
   HEAP32[162769] = $20; //@line 55865
   HEAP32[162768] = $14; //@line 55866
   return;
  }
 }
}
function __Z12op_1140_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $19 = 0, $21 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 25391
 $8 = HEAP32[162769] | 0; //@line 25394
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25405
 $19 = $5 << 24 >> 24; //@line 25407
 $21 = ($19 | 0) == 0 & 1; //@line 25409
 HEAP32[96441] = 0; //@line 25410
 HEAP32[96442] = 0; //@line 25410
 HEAP32[96443] = 0; //@line 25410
 HEAP32[96444] = 0; //@line 25410
 HEAP32[96442] = $21; //@line 25411
 HEAP32[96443] = $5 >>> 7 & 1; //@line 25414
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($18, $19); //@line 25420
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 25423
 return;
}
function __Z11op_1d8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $19 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $3 = $0 & 7; //@line 8061
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8063
 $6 = 651040 + ($3 << 2) | 0; //@line 8064
 $7 = HEAP32[$6 >> 2] | 0; //@line 8065
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 8067
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 8071
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 8076
 $18 = $5 & 7; //@line 8077
 $19 = $13 << 24 >> 24; //@line 8079
 HEAP32[96442] = $19 >>> $18 & 1 ^ 1; //@line 8083
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, ($19 | 1 << $18) << 24 >> 24); //@line 8091
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8094
 return;
}
function __ZN8tinyxml210XMLElementD0Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $5 = 0, $8 = 0, $5$looptemp = 0;
 HEAP32[$0 >> 2] = 2064; //@line 38285
 $1 = $0 + 48 | 0; //@line 38286
 $2 = HEAP32[$1 >> 2] | 0; //@line 38287
 if (!$2) {
  __ZN8tinyxml27XMLNodeD2Ev($0); //@line 38290
  __ZdlPv($0); //@line 38291
  return;
 }
 $5 = $2; //@line 38294
 do {
  $5$looptemp = $5;
  $5 = HEAP32[$5 + 28 >> 2] | 0; //@line 38297
  $8 = HEAP32[$5$looptemp + 32 >> 2] | 0; //@line 38299
  FUNCTION_TABLE_vi[HEAP32[HEAP32[$5$looptemp >> 2] >> 2] & 4095]($5$looptemp); //@line 38302
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 16 >> 2] & 31]($8, HEAP32[$1 >> 2] | 0); //@line 38307
  HEAP32[$1 >> 2] = $5; //@line 38308
 } while (($5 | 0) != 0);
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 38317
 __ZdlPv($0); //@line 38318
 return;
}
function __Z12op_b1fc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit28 = 0, $$lobit29 = 0, $21 = 0, $23 = 0, $24 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 27828
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 27831
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 27846
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27848
 $24 = $23 - $21 | 0; //@line 27849
 $$lobit28 = $23 >>> 31; //@line 27851
 $$lobit29 = $24 >>> 31; //@line 27852
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 27855
 HEAP32[96444] = ($6 >>> 7 | 0) != ($$lobit28 | 0) & ($$lobit29 | 0) != ($$lobit28 | 0) & 1; //@line 27860
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 27863
 HEAP32[96443] = $$lobit29; //@line 27864
 HEAP32[162769] = $3 + 6; //@line 27866
 return;
}
function __Z12op_b0bc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit28 = 0, $$lobit29 = 0, $21 = 0, $23 = 0, $24 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 25556
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 25559
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 25574
 $23 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25576
 $24 = $23 - $21 | 0; //@line 25577
 $$lobit28 = $23 >>> 31; //@line 25579
 $$lobit29 = $24 >>> 31; //@line 25580
 HEAP32[96442] = ($24 | 0) == 0 & 1; //@line 25583
 HEAP32[96444] = ($6 >>> 7 | 0) != ($$lobit28 | 0) & ($$lobit29 | 0) != ($$lobit28 | 0) & 1; //@line 25588
 HEAP32[96441] = $23 >>> 0 < $21 >>> 0 & 1; //@line 25591
 HEAP32[96443] = $$lobit29; //@line 25592
 HEAP32[162769] = $3 + 6; //@line 25594
 return;
}
function _cosh($0) {
 $0 = +$0;
 var $$0 = 0.0, $14 = 0.0, $3 = 0, $4 = 0.0, $7 = 0.0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 55721
 $3 = HEAP32[tempDoublePtr + 4 >> 2] & 2147483647; //@line 55723
 HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2]; //@line 55724
 HEAP32[tempDoublePtr + 4 >> 2] = $3; //@line 55724
 $4 = +HEAPF64[tempDoublePtr >> 3]; //@line 55724
 do {
  if ($3 >>> 0 < 1072049730) {
   if ($3 >>> 0 < 1045430272) {
    $$0 = 1.0; //@line 55730
   } else {
    $7 = +_expm1($4); //@line 55732
    $$0 = $7 * $7 / (($7 + 1.0) * 2.0) + 1.0; //@line 55738
   }
  } else {
   if ($3 >>> 0 < 1082535490) {
    $14 = +Math_exp(+$4); //@line 55743
    $$0 = ($14 + 1.0 / $14) * .5; //@line 55747
    break;
   } else {
    $$0 = +___expo2($4); //@line 55751
    break;
   }
  }
 } while (0);
 return +$$0;
}
function __Z12op_c098_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $15 = 0, $17 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28889
 $5 = HEAP32[$4 >> 2] | 0; //@line 28890
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28895
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 28898
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28899
 $15 = HEAP32[$13 >> 2] & $10; //@line 28901
 $17 = ($15 | 0) == 0 & 1; //@line 28903
 HEAP32[96441] = 0; //@line 28904
 HEAP32[96442] = 0; //@line 28904
 HEAP32[96443] = 0; //@line 28904
 HEAP32[96444] = 0; //@line 28904
 HEAP32[96442] = $17; //@line 28905
 HEAP32[96443] = $15 >>> 31; //@line 28907
 HEAP32[$13 >> 2] = $15; //@line 28908
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28911
 return;
}
function __Z12op_8098_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $15 = 0, $17 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 14566
 $5 = HEAP32[$4 >> 2] | 0; //@line 14567
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 14572
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 14575
 $13 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14576
 $15 = HEAP32[$13 >> 2] | $10; //@line 14578
 $17 = ($15 | 0) == 0 & 1; //@line 14580
 HEAP32[96441] = 0; //@line 14581
 HEAP32[96442] = 0; //@line 14581
 HEAP32[96443] = 0; //@line 14581
 HEAP32[96444] = 0; //@line 14581
 HEAP32[96442] = $17; //@line 14582
 HEAP32[96443] = $15 >>> 31; //@line 14584
 HEAP32[$13 >> 2] = $15; //@line 14585
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14588
 return;
}
function __Z12op_46b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $15 = 0, $16 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 49075
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 49085
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 49087
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$12 >> 2] >> 2] & 127]($10) | 0; //@line 49090
 $16 = ~$15; //@line 49091
 $18 = ($15 | 0) == -1 & 1; //@line 49093
 HEAP32[96441] = 0; //@line 49094
 HEAP32[96442] = 0; //@line 49094
 HEAP32[96443] = 0; //@line 49094
 HEAP32[96444] = 0; //@line 49094
 HEAP32[96442] = $18; //@line 49095
 HEAP32[96443] = $15 >>> 31 ^ 1; //@line 49098
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 12 >> 2] & 31]($10, $16); //@line 49102
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49105
 return;
}
function __Z12op_3090_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35784
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 35790
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35792
 $14 = $11 << 16 >> 16; //@line 35794
 $16 = ($14 | 0) == 0 & 1; //@line 35796
 HEAP32[96441] = 0; //@line 35797
 HEAP32[96442] = 0; //@line 35797
 HEAP32[96443] = 0; //@line 35797
 HEAP32[96444] = 0; //@line 35797
 HEAP32[96442] = $16; //@line 35798
 HEAP32[96443] = $11 >>> 15 & 1; //@line 35801
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $14); //@line 35807
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35810
 return;
}
function __Z12op_e4d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $11 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40870
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40872
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40876
 $10 = $9 & 1; //@line 40877
 $11 = $9 >>> 1; //@line 40878
 $$ = (HEAP32[96445] | 0) == 0 ? $11 & 32767 : $11 | 32768; //@line 40883
 HEAP32[96444] = 0; //@line 40887
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 40888
 HEAP32[96443] = $$ >>> 15 & 1; //@line 40891
 HEAP32[96441] = $10; //@line 40892
 HEAP32[96445] = $10; //@line 40893
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 40898
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40901
 return;
}
function __Z12op_4118_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $15 = 0, $19 = 0, $8 = 0, $9 = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41568
 $9 = 651040 + (($0 & 7) << 2) | 0; //@line 41569
 $10 = HEAP32[$9 >> 2] | 0; //@line 41570
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10) | 0; //@line 41575
 HEAP32[$9 >> 2] = (HEAP32[$9 >> 2] | 0) + 4; //@line 41578
 $19 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41580
 if (($19 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41583
  __Z9Exceptionij(6, $8); //@line 41584
  return;
 }
 if (($19 | 0) > ($15 | 0)) {
  HEAP32[96443] = 0; //@line 41589
  __Z9Exceptionij(6, $8); //@line 41590
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41595
  return;
 }
}
function __Z12op_1090_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $14 = 0, $16 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 23864
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 23870
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23872
 $14 = $11 << 24 >> 24; //@line 23874
 $16 = ($14 | 0) == 0 & 1; //@line 23876
 HEAP32[96441] = 0; //@line 23877
 HEAP32[96442] = 0; //@line 23877
 HEAP32[96443] = 0; //@line 23877
 HEAP32[96444] = 0; //@line 23877
 HEAP32[96442] = $16; //@line 23878
 HEAP32[96443] = $11 >>> 7 & 1; //@line 23881
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $14); //@line 23887
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23890
 return;
}
function __Z11op_1e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $16 = 0, $17 = 0, $18 = 0, $3 = 0, $5 = 0, $6 = 0;
 $3 = $0 & 7; //@line 8104
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8106
 $6 = 651040 + ($3 << 2) | 0; //@line 8107
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 8111
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 8113
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 8117
 HEAP32[$6 >> 2] = $10; //@line 8118
 $17 = $5 & 7; //@line 8119
 $18 = $16 << 24 >> 24; //@line 8121
 HEAP32[96442] = $18 >>> $17 & 1 ^ 1; //@line 8125
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 20 >> 2] & 31]($10, ($18 | 1 << $17) << 24 >> 24); //@line 8133
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8136
 return;
}
function __Z12op_44a0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $2 = 0, $4 = 0, $6 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47661
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 47663
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 47665
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$6 >> 2] >> 2] & 127]($4) | 0; //@line 47668
 HEAP32[$2 >> 2] = $4; //@line 47669
 $12 = ($9 | 0) > 0 & 1; //@line 47673
 HEAP32[96442] = ($9 | 0) == 0 & 1; //@line 47676
 HEAP32[96444] = $12 & $9 >>> 31; //@line 47678
 $17 = ($9 | 0) != 0 & 1; //@line 47680
 HEAP32[96441] = $17; //@line 47681
 HEAP32[96445] = $17; //@line 47682
 HEAP32[96443] = $12; //@line 47683
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 12 >> 2] & 31]($4, 0 - $9 | 0); //@line 47687
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47690
 return;
}
function __Z12op_117c_0_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $18 = 0, $20 = 0, $3 = 0, $5 = 0;
 $3 = HEAP32[162769] | 0; //@line 25977
 $5 = HEAP8[$3 + 3 >> 0] | 0; //@line 25979
 $17 = (((HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 25992
 $18 = $5 << 24 >> 24; //@line 25993
 $20 = $5 << 24 >> 24 == 0 & 1; //@line 25995
 HEAP32[96441] = 0; //@line 25996
 HEAP32[96442] = 0; //@line 25996
 HEAP32[96443] = 0; //@line 25996
 HEAP32[96444] = 0; //@line 25996
 HEAP32[96442] = $20; //@line 25997
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 26000
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($17, $18); //@line 26006
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 26009
 return;
}
function __Z11op_8e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $15 = 0, $17 = 0, $18 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 15131
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15134
 $5 = 651040 + ($1 << 2) | 0; //@line 15135
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 15139
 $11 = 123608 + ($9 >>> 16 << 2) | 0; //@line 15141
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$11 >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 15145
 HEAP32[$5 >> 2] = $9; //@line 15146
 $17 = $4 & 7; //@line 15148
 $18 = $15 << 24 >> 24; //@line 15150
 HEAP32[96442] = $18 >>> $17 & 1 ^ 1; //@line 15154
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$11 >> 2] | 0) + 20 >> 2] & 31]($9, ($18 | 1 << $17) << 24 >> 24); //@line 15162
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15165
 return;
}
function __Z12op_e1d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $10 = 0, $11 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 39945
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 39947
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 39951
 $10 = $9 & 32768; //@line 39952
 $11 = $9 << 1; //@line 39953
 HEAP32[96442] = ($9 & 32767 | 0) == 0 & 1; //@line 39958
 HEAP32[96443] = $9 >>> 14 & 1; //@line 39961
 $$lobit = $10 >>> 15; //@line 39963
 HEAP32[96441] = $$lobit; //@line 39964
 HEAP32[96445] = $$lobit; //@line 39965
 HEAP32[96444] = ($11 & 32768 ^ $10) >>> 15; //@line 39968
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $11 & 131070); //@line 39972
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39975
 return;
}
function __Z11op_210_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 8481
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8483
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 8485
 $14 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0) & ($4 & 255); //@line 8491
 $15 = $14 << 24 >> 24; //@line 8493
 $17 = ($15 | 0) == 0 & 1; //@line 8495
 HEAP32[96441] = 0; //@line 8496
 HEAP32[96442] = 0; //@line 8496
 HEAP32[96443] = 0; //@line 8496
 HEAP32[96444] = 0; //@line 8496
 HEAP32[96442] = $17; //@line 8497
 HEAP32[96443] = $14 >>> 7; //@line 8499
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $15); //@line 8503
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8506
 return;
}
function __Z11op_879_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0, $32 = 0;
 $1 = HEAP32[162769] | 0; //@line 14424
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14426
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 14435
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 14444
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 14446
 $29 = $3 & 7; //@line 14452
 $30 = 1 << $29; //@line 14453
 $32 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0) ^ $30) << 24 >> 24; //@line 14456
 HEAP32[96442] = ($32 & $30) >>> $29; //@line 14459
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, $32); //@line 14463
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 14466
 return;
}
function __Z11op_1b9_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7778
 $5 = HEAP32[162769] | 0; //@line 7779
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 7788
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 7797
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 7799
 $30 = $4 & 7; //@line 7804
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0) << 24 >> 24; //@line 7806
 HEAP32[96442] = $31 >>> $30 & 1 ^ 1; //@line 7810
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, ($31 & (1 << $30 ^ 255)) << 24 >> 24); //@line 7819
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7822
 return;
}
function __Z10op_10_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 4733
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4735
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 4737
 $14 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0 | $4 & 255; //@line 4743
 $15 = $14 << 24 >> 24; //@line 4745
 $17 = ($15 | 0) == 0 & 1; //@line 4747
 HEAP32[96441] = 0; //@line 4748
 HEAP32[96442] = 0; //@line 4748
 HEAP32[96443] = 0; //@line 4748
 HEAP32[96444] = 0; //@line 4748
 HEAP32[96442] = $17; //@line 4749
 HEAP32[96443] = $14 >>> 7 & 1; //@line 4752
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $15); //@line 4756
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4759
 return;
}
function __Z12op_4eb9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $25 = 0, $27 = 0, $38 = 0;
 $1 = HEAP32[162769] | 0; //@line 840
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 849
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 858
 $25 = (HEAP32[162768] | 0) + 6 + $1 - (HEAP32[162770] | 0) | 0; //@line 864
 $27 = (HEAP32[162767] | 0) + -4 | 0; //@line 866
 HEAP32[162767] = $27; //@line 867
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($27 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($27, $25); //@line 873
 $38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($19) | 0; //@line 879
 HEAP32[162770] = $38; //@line 880
 HEAP32[162769] = $38; //@line 881
 HEAP32[162768] = $19; //@line 882
 return;
}
function __Z11op_c80_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit28 = 0, $$lobit29 = 0, $2 = 0, $20 = 0, $22 = 0, $23 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 19839
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19842
 $20 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | $5 << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 19857
 $22 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 19859
 $23 = $22 - $20 | 0; //@line 19860
 $$lobit28 = $22 >>> 31; //@line 19862
 $$lobit29 = $23 >>> 31; //@line 19863
 HEAP32[96442] = ($23 | 0) == 0 & 1; //@line 19866
 HEAP32[96444] = ($5 >>> 7 | 0) != ($$lobit28 | 0) & ($$lobit29 | 0) != ($$lobit28 | 0) & 1; //@line 19871
 HEAP32[96441] = $22 >>> 0 < $20 >>> 0 & 1; //@line 19874
 HEAP32[96443] = $$lobit29; //@line 19875
 HEAP32[162769] = $2 + 6; //@line 19877
 return;
}
function __Z12op_4eb0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $21 = 0, $32 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 3606
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 3615
 $19 = (HEAP32[162768] | 0) + 4 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 3621
 $21 = (HEAP32[162767] | 0) + -4 | 0; //@line 3623
 HEAP32[162767] = $21; //@line 3624
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($21, $19); //@line 3630
 $32 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($13) | 0; //@line 3636
 HEAP32[162770] = $32; //@line 3637
 HEAP32[162769] = $32; //@line 3638
 HEAP32[162768] = $13; //@line 3639
 return;
}
function _pad_684($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $$0$lcssa = 0, $$011 = 0, $13 = 0, $5 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 57785
 STACKTOP = STACKTOP + 256 | 0; //@line 57786
 $5 = sp; //@line 57787
 if (($2 | 0) > ($3 | 0) & ($4 & 73728 | 0) == 0) {
  $9 = $2 - $3 | 0; //@line 57793
  _memset($5 | 0, $1 | 0, ($9 >>> 0 < 256 ? $9 : 256) | 0) | 0; //@line 57796
  if ($9 >>> 0 > 255) {
   $13 = $2 - $3 | 0; //@line 57799
   $$011 = $9; //@line 57800
   do {
    _out($0, $5, 256); //@line 57802
    $$011 = $$011 + -256 | 0; //@line 57803
   } while ($$011 >>> 0 > 255);
   $$0$lcssa = $13 & 255; //@line 57812
  } else {
   $$0$lcssa = $9; //@line 57814
  }
  _out($0, $5, $$0$lcssa); //@line 57816
 }
 STACKTOP = sp; //@line 57818
 return;
}
function __Z12op_e7d8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41911
 $3 = HEAP32[$2 >> 2] | 0; //@line 41912
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41914
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41918
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 41921
 $14 = $9 >>> 15 & 1; //@line 41924
 $15 = $14 | $9 << 1; //@line 41925
 HEAP32[96444] = 0; //@line 41929
 HEAP32[96442] = ($15 & 65535) << 16 >> 16 == 0 & 1; //@line 41930
 HEAP32[96443] = $9 >>> 14 & 1; //@line 41933
 HEAP32[96441] = $14; //@line 41934
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $15 & 65535); //@line 41939
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41942
 return;
}
function __Z12op_46a0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $2 = 0, $4 = 0, $6 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 48962
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 48964
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 48966
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$6 >> 2] >> 2] & 127]($4) | 0; //@line 48969
 HEAP32[$2 >> 2] = $4; //@line 48970
 $10 = ~$9; //@line 48971
 $12 = ($9 | 0) == -1 & 1; //@line 48973
 HEAP32[96441] = 0; //@line 48974
 HEAP32[96442] = 0; //@line 48974
 HEAP32[96443] = 0; //@line 48974
 HEAP32[96444] = 0; //@line 48974
 HEAP32[96442] = $12; //@line 48975
 HEAP32[96443] = $9 >>> 31 ^ 1; //@line 48978
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 12 >> 2] & 31]($4, $10); //@line 48982
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48985
 return;
}
function __Z12op_4610_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $3 = 0, $5 = 0, $sext = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48286
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48288
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0) << 24; //@line 48293
 $10 = $sext >> 24; //@line 48294
 $11 = ~$10; //@line 48295
 $13 = ($10 | 0) == -1 & 1; //@line 48297
 HEAP32[96441] = 0; //@line 48298
 HEAP32[96442] = 0; //@line 48298
 HEAP32[96443] = 0; //@line 48298
 HEAP32[96444] = 0; //@line 48298
 HEAP32[96442] = $13; //@line 48299
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48302
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, $11); //@line 48306
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48309
 return;
}
function __Z11op_170_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $25 = 0, $27 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16455
 $8 = HEAP32[162769] | 0; //@line 16458
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 16467
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 16469
 $24 = $5 & 7; //@line 16474
 $25 = 1 << $24; //@line 16475
 $27 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) ^ $25) << 24 >> 24; //@line 16478
 HEAP32[96442] = ($27 & $25) >>> $24; //@line 16481
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $27); //@line 16485
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16488
 return;
}
function __Z12op_e7f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $19 = 0, $20 = 0;
 $1 = HEAP32[162769] | 0; //@line 42085
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 42095
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 42097
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 42101
 $19 = $16 >>> 15 & 1; //@line 42104
 $20 = $19 | $16 << 1; //@line 42105
 HEAP32[96444] = 0; //@line 42109
 HEAP32[96442] = ($20 & 65535) << 16 >> 16 == 0 & 1; //@line 42110
 HEAP32[96443] = $16 >>> 14 & 1; //@line 42113
 HEAP32[96441] = $19; //@line 42114
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $20 & 65535); //@line 42119
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42122
 return;
}
function __Z12op_c0a0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $16 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28922
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 28924
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 28929
 HEAP32[$4 >> 2] = $6; //@line 28930
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28931
 $14 = HEAP32[$12 >> 2] & $11; //@line 28933
 $16 = ($14 | 0) == 0 & 1; //@line 28935
 HEAP32[96441] = 0; //@line 28936
 HEAP32[96442] = 0; //@line 28936
 HEAP32[96443] = 0; //@line 28936
 HEAP32[96444] = 0; //@line 28936
 HEAP32[96442] = $16; //@line 28937
 HEAP32[96443] = $14 >>> 31; //@line 28939
 HEAP32[$12 >> 2] = $14; //@line 28940
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28943
 return;
}
function __Z12op_80a0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $16 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 14599
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 14601
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 14606
 HEAP32[$4 >> 2] = $6; //@line 14607
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14608
 $14 = HEAP32[$12 >> 2] | $11; //@line 14610
 $16 = ($14 | 0) == 0 & 1; //@line 14612
 HEAP32[96441] = 0; //@line 14613
 HEAP32[96442] = 0; //@line 14613
 HEAP32[96443] = 0; //@line 14613
 HEAP32[96444] = 0; //@line 14613
 HEAP32[96442] = $16; //@line 14614
 HEAP32[96443] = $14 >>> 31; //@line 14616
 HEAP32[$12 >> 2] = $14; //@line 14617
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14620
 return;
}
function __Z12op_4c7b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $15 = 0, $2 = 0, $24 = 0, $26 = 0, $3 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 53637
 $2 = $1 + 2 | 0; //@line 53638
 HEAP32[162769] = $2; //@line 53639
 $3 = HEAP32[162768] | 0; //@line 53640
 $4 = HEAP32[162770] | 0; //@line 53642
 $14 = ((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53652
 $15 = $1 + 4 | 0; //@line 53653
 HEAP32[162769] = $15; //@line 53654
 $24 = (HEAPU8[$15 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 53664
 HEAP32[162769] = $1 + 6; //@line 53666
 $26 = __Z15get_disp_ea_020jj($3 + $15 - $4 | 0, $24) | 0; //@line 53667
 __Z9m68k_divljjtj($0, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($26 >>> 16 << 2) >> 2] >> 2] & 127]($26) | 0, $14, $2 + $3 - $4 | 0); //@line 53673
 return;
}
function __Z12op_4120_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $16 = 0, $18 = 0, $8 = 0, $9 = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41611
 $9 = 651040 + (($0 & 7) << 2) | 0; //@line 41612
 $11 = (HEAP32[$9 >> 2] | 0) + -4 | 0; //@line 41614
 $16 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($11 >>> 16 << 2) >> 2] >> 2] & 127]($11) | 0; //@line 41619
 HEAP32[$9 >> 2] = $11; //@line 41620
 $18 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41622
 if (($18 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41625
  __Z9Exceptionij(6, $8); //@line 41626
  return;
 }
 if (($18 | 0) > ($16 | 0)) {
  HEAP32[96443] = 0; //@line 41631
  __Z9Exceptionij(6, $8); //@line 41632
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41637
  return;
 }
}
function __Z11op_1f9_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $23 = 0, $25 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8293
 $5 = HEAP32[162769] | 0; //@line 8294
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 8303
 $23 = $14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0); //@line 8312
 $25 = 123608 + ($14 >>> 16 << 2) | 0; //@line 8314
 $30 = $4 & 7; //@line 8319
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$25 >> 2] | 0) + 8 >> 2] & 127]($23) | 0) << 24 >> 24; //@line 8321
 HEAP32[96442] = $31 >>> $30 & 1 ^ 1; //@line 8325
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$25 >> 2] | 0) + 20 >> 2] & 31]($23, ($31 | 1 << $30) << 24 >> 24); //@line 8333
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8336
 return;
}
function __Z12op_e2d8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40309
 $3 = HEAP32[$2 >> 2] | 0; //@line 40310
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40312
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40316
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 40319
 $12 = $9 & 1; //@line 40320
 $14 = $9 >>> 1 & 32767; //@line 40322
 HEAP32[96444] = 0; //@line 40325
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 40326
 HEAP32[96443] = 0; //@line 40327
 HEAP32[96441] = $12; //@line 40328
 HEAP32[96445] = $12; //@line 40329
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $14); //@line 40333
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40336
 return;
}
function __Z12op_c0b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29035
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 29045
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 29050
 $18 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29051
 $20 = HEAP32[$18 >> 2] & $17; //@line 29053
 $22 = ($20 | 0) == 0 & 1; //@line 29055
 HEAP32[96441] = 0; //@line 29056
 HEAP32[96442] = 0; //@line 29056
 HEAP32[96443] = 0; //@line 29056
 HEAP32[96444] = 0; //@line 29056
 HEAP32[96442] = $22; //@line 29057
 HEAP32[96443] = $20 >>> 31; //@line 29059
 HEAP32[$18 >> 2] = $20; //@line 29060
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29063
 return;
}
function __Z12op_80b8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 14712
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 14722
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 14727
 $18 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14728
 $20 = HEAP32[$18 >> 2] | $17; //@line 14730
 $22 = ($20 | 0) == 0 & 1; //@line 14732
 HEAP32[96441] = 0; //@line 14733
 HEAP32[96442] = 0; //@line 14733
 HEAP32[96443] = 0; //@line 14733
 HEAP32[96444] = 0; //@line 14733
 HEAP32[96442] = $22; //@line 14734
 HEAP32[96443] = $20 >>> 31; //@line 14736
 HEAP32[$18 >> 2] = $20; //@line 14737
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14740
 return;
}
function __Z12op_5dc8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $15 = 0, $2 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 10303
 $3 = HEAP32[$2 >> 2] | 0; //@line 10304
 $4 = HEAP32[162769] | 0; //@line 10305
 if ((HEAP32[96443] | 0) != (HEAP32[96444] | 0)) {
  $$sink18 = 4; //@line 10310
  $25 = $4; //@line 10310
  $24 = $25 + $$sink18 | 0; //@line 10311
  HEAP32[162769] = $24; //@line 10312
  return;
 }
 $15 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 10322
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 10328
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($15 << 16 >> 16) + 2 | 0; //@line 10335
 $25 = HEAP32[162769] | 0; //@line 10335
 $24 = $25 + $$sink18 | 0; //@line 10336
 HEAP32[162769] = $24; //@line 10337
 return;
}
function __Z12op_4650_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $3 = 0, $5 = 0, $sext = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48598
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48600
 $sext = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0) << 16; //@line 48605
 $10 = $sext >> 16; //@line 48606
 $11 = ~$10; //@line 48607
 $13 = ($10 | 0) == -1 & 1; //@line 48609
 HEAP32[96441] = 0; //@line 48610
 HEAP32[96442] = 0; //@line 48610
 HEAP32[96443] = 0; //@line 48610
 HEAP32[96444] = 0; //@line 48610
 HEAP32[96442] = $13; //@line 48611
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48614
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $11); //@line 48618
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48621
 return;
}
function __Z12op_e150_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39300
 $7 = HEAP32[$6 >> 2] | 0; //@line 39301
 $8 = $7 & 65535; //@line 39302
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39303
 $12 = $8 >>> (16 - $9 | 0); //@line 39306
 $13 = $12 & 1; //@line 39307
 HEAP32[96444] = 0; //@line 39309
 $19 = (HEAP32[96445] | $8 << 1) << $9 + -1 | $12 >>> 1; //@line 39314
 HEAP32[96445] = $13; //@line 39315
 $20 = $19 & 65535; //@line 39316
 HEAP32[96441] = $13; //@line 39317
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 39320
 HEAP32[96443] = $19 >>> 15 & 1; //@line 39323
 HEAP32[$6 >> 2] = $20 | $7 & -65536; //@line 39326
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39329
 return;
}
function __Z12op_e050_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $17 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37861
 $7 = HEAP32[$6 >> 2] | 0; //@line 37862
 $8 = $7 & 65535; //@line 37863
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37864
 HEAP32[96444] = 0; //@line 37867
 $16 = $8 >>> ($9 + -1 | 0); //@line 37872
 $17 = $16 & 1; //@line 37873
 $19 = (HEAP32[96445] | $8 << 1) << 16 - $9 | $16 >>> 1; //@line 37875
 HEAP32[96445] = $17; //@line 37876
 $20 = $19 & 65535; //@line 37877
 HEAP32[96441] = $17; //@line 37878
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 37881
 HEAP32[96443] = $19 >>> 15 & 1; //@line 37884
 HEAP32[$6 >> 2] = $20 | $7 & -65536; //@line 37887
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37890
 return;
}
function __Z12op_20bc_0_ffj($0) {
 $0 = $0 | 0;
 var $21 = 0, $23 = 0, $25 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 29049
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 29052
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 29067
 $23 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 29069
 $25 = ($21 | 0) == 0 & 1; //@line 29071
 HEAP32[96441] = 0; //@line 29072
 HEAP32[96442] = 0; //@line 29072
 HEAP32[96443] = 0; //@line 29072
 HEAP32[96444] = 0; //@line 29072
 HEAP32[96442] = $25; //@line 29073
 HEAP32[96443] = $6 >>> 7; //@line 29075
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($23 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($23, $21); //@line 29081
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29084
 return;
}
function ___stdio_seek($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $10 = 0, $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 54690
 STACKTOP = STACKTOP + 32 | 0; //@line 54691
 $vararg_buffer = sp; //@line 54692
 $3 = sp + 20 | 0; //@line 54693
 HEAP32[$vararg_buffer >> 2] = HEAP32[$0 + 60 >> 2]; //@line 54697
 HEAP32[$vararg_buffer + 4 >> 2] = 0; //@line 54699
 HEAP32[$vararg_buffer + 8 >> 2] = $1; //@line 54701
 HEAP32[$vararg_buffer + 12 >> 2] = $3; //@line 54703
 HEAP32[$vararg_buffer + 16 >> 2] = $2; //@line 54705
 if ((___syscall_ret(___syscall140(140, $vararg_buffer | 0) | 0) | 0) < 0) {
  HEAP32[$3 >> 2] = -1; //@line 54710
  $10 = -1; //@line 54711
 } else {
  $10 = HEAP32[$3 >> 2] | 0; //@line 54714
 }
 STACKTOP = sp; //@line 54716
 return $10 | 0; //@line 54716
}
function __Z12op_e7e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $14 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 41951
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 41953
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 41955
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 41959
 HEAP32[$2 >> 2] = $4; //@line 41960
 $13 = $10 >>> 15 & 1; //@line 41963
 $14 = $13 | $10 << 1; //@line 41964
 HEAP32[96444] = 0; //@line 41968
 HEAP32[96442] = ($14 & 65535) << 16 >> 16 == 0 & 1; //@line 41969
 HEAP32[96443] = $10 >>> 14 & 1; //@line 41972
 HEAP32[96441] = $13; //@line 41973
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $14 & 65535); //@line 41978
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41981
 return;
}
function __Z12op_e2f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 40467
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 40477
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40479
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 40483
 $17 = $16 & 1; //@line 40484
 $19 = $16 >>> 1 & 32767; //@line 40486
 HEAP32[96444] = 0; //@line 40489
 HEAP32[96442] = ($19 | 0) == 0 & 1; //@line 40490
 HEAP32[96443] = 0; //@line 40491
 HEAP32[96441] = $17; //@line 40492
 HEAP32[96445] = $17; //@line 40493
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $19); //@line 40497
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40500
 return;
}
function __Z12op_b07c_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $14 = 0, $3 = 0, $6 = 0, $sext$lobit = 0, $sext29$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 25026
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 25029
 $11 = $6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 25034
 $13 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25036
 $14 = $13 - $11 | 0; //@line 25037
 $sext$lobit = $13 >>> 15 & 1; //@line 25040
 $sext29$lobit = $14 >>> 15 & 1; //@line 25042
 HEAP32[96442] = ($14 & 65535 | 0) == 0 & 1; //@line 25046
 HEAP32[96444] = ($6 >>> 7 | 0) != ($sext$lobit | 0) & ($sext29$lobit | 0) != ($sext$lobit | 0) & 1; //@line 25051
 HEAP32[96441] = $11 >>> 0 > ($13 & 65535) >>> 0 & 1; //@line 25055
 HEAP32[96443] = $sext29$lobit; //@line 25056
 HEAP32[162769] = $3 + 4; //@line 25058
 return;
}
function __Z12op_23c8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $22 = 0, $24 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34227
 $4 = HEAP32[162769] | 0; //@line 34228
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 34237
 $22 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | (HEAPU8[$4 + 5 >> 0] | 0); //@line 34246
 $24 = ($3 | 0) == 0 & 1; //@line 34248
 HEAP32[96441] = 0; //@line 34249
 HEAP32[96442] = 0; //@line 34249
 HEAP32[96443] = 0; //@line 34249
 HEAP32[96444] = 0; //@line 34249
 HEAP32[96442] = $24; //@line 34250
 HEAP32[96443] = $3 >>> 31; //@line 34252
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $3); //@line 34258
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34261
 return;
}
function __Z12op_23c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $22 = 0, $24 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 34183
 $4 = HEAP32[162769] | 0; //@line 34184
 $13 = (HEAPU8[$4 + 3 >> 0] | 0) << 16 | (HEAPU8[$4 + 2 >> 0] | 0) << 24; //@line 34193
 $22 = $13 | (HEAPU8[$4 + 4 >> 0] | 0) << 8 | (HEAPU8[$4 + 5 >> 0] | 0); //@line 34202
 $24 = ($3 | 0) == 0 & 1; //@line 34204
 HEAP32[96441] = 0; //@line 34205
 HEAP32[96442] = 0; //@line 34205
 HEAP32[96443] = 0; //@line 34205
 HEAP32[96444] = 0; //@line 34205
 HEAP32[96442] = $24; //@line 34206
 HEAP32[96443] = $3 >>> 31; //@line 34208
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $3); //@line 34214
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 34217
 return;
}
function __Z12op_2030_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $22 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 32048
 $6 = HEAP32[162769] | 0; //@line 32051
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 32060
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 32065
 $22 = ($20 | 0) == 0 & 1; //@line 32067
 HEAP32[96441] = 0; //@line 32068
 HEAP32[96442] = 0; //@line 32068
 HEAP32[96443] = 0; //@line 32068
 HEAP32[96444] = 0; //@line 32068
 HEAP32[96442] = $22; //@line 32069
 HEAP32[96443] = $20 >>> 31; //@line 32071
 HEAP32[651008 + ($3 << 2) >> 2] = $20; //@line 32073
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32076
 return;
}
function __Z11op_8b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0;
 $1 = HEAP32[162769] | 0; //@line 14867
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14869
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 14878
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 14887
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 14889
 $29 = $3 & 7; //@line 14895
 $30 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0) << 24 >> 24; //@line 14897
 HEAP32[96442] = $30 >>> $29 & 1 ^ 1; //@line 14901
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, ($30 & (1 << $29 ^ 255)) << 24 >> 24); //@line 14910
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 14913
 return;
}
function __Z12op_e2e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40345
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 40347
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40349
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 40353
 HEAP32[$2 >> 2] = $4; //@line 40354
 $11 = $10 & 1; //@line 40355
 $13 = $10 >>> 1 & 32767; //@line 40357
 HEAP32[96444] = 0; //@line 40360
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 40361
 HEAP32[96443] = 0; //@line 40362
 HEAP32[96441] = $11; //@line 40363
 HEAP32[96445] = $11; //@line 40364
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $13); //@line 40368
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40371
 return;
}
function __Z11op_87b_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $28 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 17416
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 17418
 $17 = __Z15get_disp_ea_000jj($1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 17433
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 17435
 $25 = $3 & 7; //@line 17441
 $26 = 1 << $25; //@line 17442
 $28 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) ^ $26) << 24 >> 24; //@line 17445
 HEAP32[96442] = ($28 & $26) >>> $25; //@line 17448
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, $28); //@line 17452
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17455
 return;
}
function __Z12op_e110_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38895
 $7 = HEAP32[$6 >> 2] | 0; //@line 38896
 $8 = $7 & 255; //@line 38897
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38898
 $12 = $8 >>> (8 - $9 | 0); //@line 38901
 $13 = $12 & 1; //@line 38902
 HEAP32[96444] = 0; //@line 38904
 $19 = (HEAP32[96445] | $8 << 1) << $9 + -1 | $12 >>> 1; //@line 38909
 HEAP32[96445] = $13; //@line 38910
 $20 = $19 & 255; //@line 38911
 HEAP32[96441] = $13; //@line 38912
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 38915
 HEAP32[96443] = $19 >>> 7 & 1; //@line 38918
 HEAP32[$6 >> 2] = $20 | $7 & -256; //@line 38921
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38924
 return;
}
function __Z12op_e010_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $17 = 0, $19 = 0, $20 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37471
 $7 = HEAP32[$6 >> 2] | 0; //@line 37472
 $8 = $7 & 255; //@line 37473
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 37474
 HEAP32[96444] = 0; //@line 37477
 $16 = $8 >>> ($9 + -1 | 0); //@line 37482
 $17 = $16 & 1; //@line 37483
 $19 = (HEAP32[96445] | $8 << 1) << 8 - $9 | $16 >>> 1; //@line 37485
 HEAP32[96445] = $17; //@line 37486
 $20 = $19 & 255; //@line 37487
 HEAP32[96441] = $17; //@line 37488
 HEAP32[96442] = ($20 | 0) == 0 & 1; //@line 37491
 HEAP32[96443] = $19 >>> 7 & 1; //@line 37494
 HEAP32[$6 >> 2] = $20 | $7 & -256; //@line 37497
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37500
 return;
}
function __Z12op_2039_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $26 = 0, $28 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 28104
 $3 = HEAP32[162769] | 0; //@line 28105
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 28114
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 28128
 $28 = ($26 | 0) == 0 & 1; //@line 28130
 HEAP32[96441] = 0; //@line 28131
 HEAP32[96442] = 0; //@line 28131
 HEAP32[96443] = 0; //@line 28131
 HEAP32[96444] = 0; //@line 28131
 HEAP32[96442] = $28; //@line 28132
 HEAP32[96443] = $26 >>> 31; //@line 28134
 HEAP32[651008 + ($2 << 2) >> 2] = $26; //@line 28136
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28139
 return;
}
function __Z12op_e3d8_0_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $2 = 0, $3 = 0, $5 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40595
 $3 = HEAP32[$2 >> 2] | 0; //@line 40596
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40598
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40602
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 40605
 HEAP32[96444] = 0; //@line 40610
 HEAP32[96442] = ($9 & 32767 | 0) == 0 & 1; //@line 40611
 HEAP32[96443] = $9 >>> 14 & 1; //@line 40614
 $17 = $9 >>> 15 & 1; //@line 40616
 HEAP32[96441] = $17; //@line 40617
 HEAP32[96445] = $17; //@line 40618
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $9 << 1 & 65534); //@line 40623
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40626
 return;
}
function __Z12op_3010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $16 = 0, $3 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 34919
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34921
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 34927
 $12 = $11 << 16 >> 16; //@line 34929
 $14 = ($12 | 0) == 0 & 1; //@line 34931
 HEAP32[96441] = 0; //@line 34932
 HEAP32[96442] = 0; //@line 34932
 HEAP32[96443] = 0; //@line 34932
 HEAP32[96444] = 0; //@line 34932
 HEAP32[96442] = $14; //@line 34933
 HEAP32[96443] = $11 >>> 15 & 1; //@line 34936
 $16 = 651008 + ($3 << 2) | 0; //@line 34937
 HEAP32[$16 >> 2] = HEAP32[$16 >> 2] & -65536 | $12 & 65535; //@line 34942
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34945
 return;
}
function __Z12op_2028_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $23 = 0, $3 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 27991
 $6 = HEAP32[162769] | 0; //@line 27994
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28005
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28010
 $23 = ($21 | 0) == 0 & 1; //@line 28012
 HEAP32[96441] = 0; //@line 28013
 HEAP32[96442] = 0; //@line 28013
 HEAP32[96443] = 0; //@line 28013
 HEAP32[96444] = 0; //@line 28013
 HEAP32[96442] = $23; //@line 28014
 HEAP32[96443] = $21 >>> 31; //@line 28016
 HEAP32[651008 + ($3 << 2) >> 2] = $21; //@line 28018
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28021
 return;
}
function __Z11op_c40_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $13 = 0, $2 = 0, $5 = 0, $sext$lobit = 0, $sext29$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 19288
 $5 = HEAPU8[$2 + 2 >> 0] | 0; //@line 19291
 $10 = $5 << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 19296
 $12 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 19298
 $13 = $12 - $10 | 0; //@line 19299
 $sext$lobit = $12 >>> 15 & 1; //@line 19302
 $sext29$lobit = $13 >>> 15 & 1; //@line 19304
 HEAP32[96442] = ($13 & 65535 | 0) == 0 & 1; //@line 19308
 HEAP32[96444] = ($5 >>> 7 | 0) != ($sext$lobit | 0) & ($sext29$lobit | 0) != ($sext$lobit | 0) & 1; //@line 19313
 HEAP32[96441] = $10 >>> 0 > ($12 & 65535) >>> 0 & 1; //@line 19317
 HEAP32[96443] = $sext29$lobit; //@line 19318
 HEAP32[162769] = $2 + 4; //@line 19320
 return;
}
function __Z12op_e3f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0, $16 = 0, $22 = 0;
 $1 = HEAP32[162769] | 0; //@line 40769
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 40779
 $12 = 123608 + ($10 >>> 16 << 2) | 0; //@line 40781
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$12 >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 40785
 HEAP32[96444] = 0; //@line 40790
 HEAP32[96442] = ($16 & 32767 | 0) == 0 & 1; //@line 40791
 HEAP32[96443] = $16 >>> 14 & 1; //@line 40794
 $22 = $16 >>> 15 & 1; //@line 40796
 HEAP32[96441] = $22; //@line 40797
 HEAP32[96445] = $22; //@line 40798
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$12 >> 2] | 0) + 16 >> 2] & 31]($10, $16 << 1 & 65534); //@line 40803
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 40806
 return;
}
function __Z12op_5cc8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $15 = 0, $2 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 9963
 $3 = HEAP32[$2 >> 2] | 0; //@line 9964
 $4 = HEAP32[162769] | 0; //@line 9965
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  $$sink18 = 4; //@line 9970
  $25 = $4; //@line 9970
  $24 = $25 + $$sink18 | 0; //@line 9971
  HEAP32[162769] = $24; //@line 9972
  return;
 }
 $15 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 9982
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 9988
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($15 << 16 >> 16) + 2 | 0; //@line 9995
 $25 = HEAP32[162769] | 0; //@line 9995
 $24 = $25 + $$sink18 | 0; //@line 9996
 HEAP32[162769] = $24; //@line 9997
 return;
}
function __Z11op_1b0_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $25 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16549
 $8 = HEAP32[162769] | 0; //@line 16552
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 16561
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 16563
 $24 = $5 & 7; //@line 16568
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 16570
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 16574
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($25 & (1 << $24 ^ 255)) << 24 >> 24); //@line 16583
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16586
 return;
}
function __Z11op_168_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $26 = 0, $28 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7149
 $8 = HEAP32[162769] | 0; //@line 7152
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7163
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 7165
 $25 = $5 & 7; //@line 7170
 $26 = 1 << $25; //@line 7171
 $28 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) ^ $26) << 24 >> 24; //@line 7174
 HEAP32[96442] = ($28 & $26) >>> $25; //@line 7177
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $28); //@line 7181
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7184
 return;
}
function _recvfrom($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 var $17 = 0, $6 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2106
 STACKTOP = STACKTOP + 32 | 0; //@line 2107
 $vararg_buffer = sp; //@line 2108
 $6 = sp + 8 | 0; //@line 2109
 HEAP32[$6 >> 2] = $0; //@line 2110
 HEAP32[$6 + 4 >> 2] = $1; //@line 2113
 HEAP32[$6 + 8 >> 2] = $2; //@line 2115
 HEAP32[$6 + 12 >> 2] = $3; //@line 2117
 HEAP32[$6 + 16 >> 2] = $4; //@line 2120
 HEAP32[$6 + 20 >> 2] = $5; //@line 2123
 HEAP32[$vararg_buffer >> 2] = 12; //@line 2125
 HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 2127
 $17 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 2129
 STACKTOP = sp; //@line 2130
 return $17 | 0; //@line 2130
}
function __Z11op_8f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $21 = 0, $23 = 0, $29 = 0, $3 = 0, $30 = 0;
 $1 = HEAP32[162769] | 0; //@line 15316
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15318
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 15327
 $21 = $12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 15336
 $23 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15338
 $29 = $3 & 7; //@line 15344
 $30 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$23 >> 2] | 0) + 8 >> 2] & 127]($21) | 0) << 24 >> 24; //@line 15346
 HEAP32[96442] = $30 >>> $29 & 1 ^ 1; //@line 15350
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$23 >> 2] | 0) + 20 >> 2] & 31]($21, ($30 | 1 << $29) << 24 >> 24); //@line 15358
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 15361
 return;
}
function __Z12op_b1d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $10 = 0, $12 = 0, $13 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27408
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27413
 $12 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27415
 $13 = $12 - $10 | 0; //@line 27416
 $$lobit35 = $12 >>> 31; //@line 27418
 $$lobit36 = $13 >>> 31; //@line 27419
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 27422
 HEAP32[96444] = ($10 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 27427
 HEAP32[96441] = $12 >>> 0 < $10 >>> 0 & 1; //@line 27430
 HEAP32[96443] = $$lobit36; //@line 27431
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27434
 return;
}
function __Z12op_b090_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $$lobit36 = 0, $10 = 0, $12 = 0, $13 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25136
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 25141
 $12 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25143
 $13 = $12 - $10 | 0; //@line 25144
 $$lobit35 = $12 >>> 31; //@line 25146
 $$lobit36 = $13 >>> 31; //@line 25147
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 25150
 HEAP32[96444] = ($10 >>> 31 | 0) != ($$lobit35 | 0) & ($$lobit36 | 0) != ($$lobit35 | 0) & 1; //@line 25155
 HEAP32[96441] = $12 >>> 0 < $10 >>> 0 & 1; //@line 25158
 HEAP32[96443] = $$lobit36; //@line 25159
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25162
 return;
}
function __Z12op_1010_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $16 = 0, $3 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 23395
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 23397
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($5) | 0; //@line 23403
 $12 = $11 << 24 >> 24; //@line 23405
 $14 = ($12 | 0) == 0 & 1; //@line 23407
 HEAP32[96441] = 0; //@line 23408
 HEAP32[96442] = 0; //@line 23408
 HEAP32[96443] = 0; //@line 23408
 HEAP32[96444] = 0; //@line 23408
 HEAP32[96442] = $14; //@line 23409
 HEAP32[96443] = $11 >>> 7 & 1; //@line 23412
 $16 = 651008 + ($3 << 2) | 0; //@line 23413
 HEAP32[$16 >> 2] = HEAP32[$16 >> 2] & -256 | $12 & 255; //@line 23418
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23421
 return;
}
function _strcmp($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$011 = 0, $$0710 = 0, $$lcssa = 0, $$lcssa8 = 0, $2 = 0, $3 = 0, $8 = 0, $9 = 0;
 $2 = HEAP8[$0 >> 0] | 0; //@line 56020
 $3 = HEAP8[$1 >> 0] | 0; //@line 56021
 if ($2 << 24 >> 24 == 0 ? 1 : $2 << 24 >> 24 != $3 << 24 >> 24) {
  $$lcssa = $3; //@line 56026
  $$lcssa8 = $2; //@line 56026
 } else {
  $$011 = $1; //@line 56028
  $$0710 = $0; //@line 56028
  do {
   $$0710 = $$0710 + 1 | 0; //@line 56030
   $$011 = $$011 + 1 | 0; //@line 56031
   $8 = HEAP8[$$0710 >> 0] | 0; //@line 56032
   $9 = HEAP8[$$011 >> 0] | 0; //@line 56033
  } while (!($8 << 24 >> 24 == 0 ? 1 : $8 << 24 >> 24 != $9 << 24 >> 24));
  $$lcssa = $9; //@line 56038
  $$lcssa8 = $8; //@line 56038
 }
 return ($$lcssa8 & 255) - ($$lcssa & 255) | 0; //@line 56048
}
function _sendto($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 var $16 = 0, $6 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 1999
 STACKTOP = STACKTOP + 32 | 0; //@line 2000
 $vararg_buffer = sp; //@line 2001
 $6 = sp + 8 | 0; //@line 2002
 HEAP32[$6 >> 2] = $0; //@line 2003
 HEAP32[$6 + 4 >> 2] = $1; //@line 2006
 HEAP32[$6 + 8 >> 2] = $2; //@line 2008
 HEAP32[$6 + 12 >> 2] = $3; //@line 2010
 HEAP32[$6 + 16 >> 2] = $4; //@line 2013
 HEAP32[$6 + 20 >> 2] = $5; //@line 2015
 HEAP32[$vararg_buffer >> 2] = 11; //@line 2017
 HEAP32[$vararg_buffer + 4 >> 2] = $6; //@line 2019
 $16 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 2021
 STACKTOP = sp; //@line 2022
 return $16 | 0; //@line 2022
}
function _puts($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $12 = 0, $19 = 0, $21 = 0;
 $1 = HEAP32[22131] | 0; //@line 2741
 if ((HEAP32[$1 + 76 >> 2] | 0) > -1) {
  $21 = ___lockfile($1) | 0; //@line 2747
 } else {
  $21 = 0; //@line 2749
 }
 do {
  if ((_fputs($0, $1) | 0) < 0) {
   $19 = 1; //@line 2755
  } else {
   if ((HEAP8[$1 + 75 >> 0] | 0) != 10) {
    $11 = $1 + 20 | 0; //@line 2761
    $12 = HEAP32[$11 >> 2] | 0; //@line 2762
    if ($12 >>> 0 < (HEAP32[$1 + 16 >> 2] | 0) >>> 0) {
     HEAP32[$11 >> 2] = $12 + 1; //@line 2768
     HEAP8[$12 >> 0] = 10; //@line 2769
     $19 = 0; //@line 2770
     break;
    }
   }
   $19 = (___overflow($1, 10) | 0) < 0; //@line 2776
  }
 } while (0);
 if ($21 | 0) {
  ___unlockfile($1); //@line 2782
 }
 return $19 << 31 >> 31 | 0; //@line 2784
}
function __Z12op_e3e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $16 = 0, $2 = 0, $4 = 0, $6 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 40635
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 40637
 $6 = 123608 + ($4 >>> 16 << 2) | 0; //@line 40639
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$6 >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 40643
 HEAP32[$2 >> 2] = $4; //@line 40644
 HEAP32[96444] = 0; //@line 40649
 HEAP32[96442] = ($10 & 32767 | 0) == 0 & 1; //@line 40650
 HEAP32[96443] = $10 >>> 14 & 1; //@line 40653
 $16 = $10 >>> 15 & 1; //@line 40655
 HEAP32[96441] = $16; //@line 40656
 HEAP32[96445] = $16; //@line 40657
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 31]($4, $10 << 1 & 65534); //@line 40662
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40665
 return;
}
function __Z12op_4eba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $19 = 0, $2 = 0, $30 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 891
 $5 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 894
 $$cast = $2; //@line 896
 $16 = $5 + 2 + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 907
 $19 = (HEAP32[162767] | 0) + -4 | 0; //@line 910
 HEAP32[162767] = $19; //@line 911
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, $5 + 4 | 0); //@line 917
 $30 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($16) | 0; //@line 923
 HEAP32[162770] = $30; //@line 924
 HEAP32[162769] = $30; //@line 925
 HEAP32[162768] = $16; //@line 926
 return;
}
function __Z11op_87a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $26 = 0, $27 = 0, $29 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14475
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14477
 $18 = $1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 14494
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 14496
 $26 = $3 & 7; //@line 14502
 $27 = 1 << $26; //@line 14503
 $29 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) ^ $27) << 24 >> 24; //@line 14506
 HEAP32[96442] = ($29 & $27) >>> $26; //@line 14509
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, $29); //@line 14513
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14516
 return;
}
function __Z11op_1f0_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $24 = 0, $25 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16651
 $8 = HEAP32[162769] | 0; //@line 16654
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 16663
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 16665
 $24 = $5 & 7; //@line 16670
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 16672
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 16676
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($25 | 1 << $24) << 24 >> 24); //@line 16684
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16687
 return;
}
function __Z12op_53c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $16 = 0, $2 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 6988
 $3 = HEAP32[$2 >> 2] | 0; //@line 6989
 $4 = HEAP32[162769] | 0; //@line 6990
 if (HEAP32[96442] | HEAP32[96441] | 0) {
  $$sink18 = 4; //@line 6996
  $26 = $4; //@line 6996
  $25 = $26 + $$sink18 | 0; //@line 6997
  HEAP32[162769] = $25; //@line 6998
  return;
 }
 $16 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 7008
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 7014
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($16 << 16 >> 16) + 2 | 0; //@line 7021
 $26 = HEAP32[162769] | 0; //@line 7021
 $25 = $26 + $$sink18 | 0; //@line 7022
 HEAP32[162769] = $25; //@line 7023
 return;
}
function __Z12op_52c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $16 = 0, $2 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 6636
 $3 = HEAP32[$2 >> 2] | 0; //@line 6637
 $4 = HEAP32[162769] | 0; //@line 6638
 if (!(HEAP32[96442] | HEAP32[96441])) {
  $$sink18 = 4; //@line 6644
  $26 = $4; //@line 6644
  $25 = $26 + $$sink18 | 0; //@line 6645
  HEAP32[162769] = $25; //@line 6646
  return;
 }
 $16 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 6656
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 6662
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($16 << 16 >> 16) + 2 | 0; //@line 6669
 $26 = HEAP32[162769] | 0; //@line 6669
 $25 = $26 + $$sink18 | 0; //@line 6670
 HEAP32[162769] = $25; //@line 6671
 return;
}
function __Z11op_8bb_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 17512
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 17514
 $17 = __Z15get_disp_ea_000jj($1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 17529
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 17531
 $25 = $3 & 7; //@line 17537
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 17539
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 17543
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($26 & (1 << $25 ^ 255)) << 24 >> 24); //@line 17552
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17555
 return;
}
function __Z11op_870_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $26 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 17373
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17375
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17386
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 17388
 $23 = $4 & 7; //@line 17394
 $24 = 1 << $23; //@line 17395
 $26 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0) ^ $24) << 24 >> 24; //@line 17398
 HEAP32[96442] = ($26 & $24) >>> $23; //@line 17401
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, $26); //@line 17405
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17408
 return;
}
function __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $4 = 0, $5 = 0, $7 = 0, $8 = 0;
 $4 = $1 + 16 | 0; //@line 3747
 $5 = HEAP32[$4 >> 2] | 0; //@line 3748
 $7 = $1 + 36 | 0; //@line 3750
 $8 = $1 + 24 | 0; //@line 3751
 do {
  if (!$5) {
   HEAP32[$4 >> 2] = $2; //@line 3754
   HEAP32[$8 >> 2] = $3; //@line 3755
   HEAP32[$7 >> 2] = 1; //@line 3756
  } else {
   if (($5 | 0) != ($2 | 0)) {
    HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 1; //@line 3762
    HEAP32[$8 >> 2] = 2; //@line 3763
    HEAP8[$1 + 54 >> 0] = 1; //@line 3765
    break;
   }
   if ((HEAP32[$8 >> 2] | 0) == 2) {
    HEAP32[$8 >> 2] = $3; //@line 3771
   }
  }
 } while (0);
 return;
}
function __Z12op_9088_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19000
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 19001
 $7 = HEAP32[$6 >> 2] | 0; //@line 19002
 $8 = $7 - $5 | 0; //@line 19003
 $$lobit34 = $7 >>> 31; //@line 19005
 $$lobit35 = $8 >>> 31; //@line 19006
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 19009
 HEAP32[96444] = ($$lobit35 ^ $$lobit34) & ($$lobit34 ^ $5 >>> 31); //@line 19013
 $15 = $7 >>> 0 < $5 >>> 0 & 1; //@line 19015
 HEAP32[96441] = $15; //@line 19016
 HEAP32[96445] = $15; //@line 19017
 HEAP32[96443] = $$lobit35; //@line 19018
 HEAP32[$6 >> 2] = $8; //@line 19019
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19022
 return;
}
function __Z12op_9080_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $15 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 18966
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 18967
 $7 = HEAP32[$6 >> 2] | 0; //@line 18968
 $8 = $7 - $5 | 0; //@line 18969
 $$lobit34 = $7 >>> 31; //@line 18971
 $$lobit35 = $8 >>> 31; //@line 18972
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 18975
 HEAP32[96444] = ($$lobit35 ^ $$lobit34) & ($$lobit34 ^ $5 >>> 31); //@line 18979
 $15 = $7 >>> 0 < $5 >>> 0 & 1; //@line 18981
 HEAP32[96441] = $15; //@line 18982
 HEAP32[96445] = $15; //@line 18983
 HEAP32[96443] = $$lobit35; //@line 18984
 HEAP32[$6 >> 2] = $8; //@line 18985
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 18988
 return;
}
function _ioctl($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $12 = 0, $2 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 62640
 STACKTOP = STACKTOP + 32 | 0; //@line 62641
 $vararg_buffer = sp; //@line 62642
 $2 = sp + 16 | 0; //@line 62643
 HEAP32[$2 >> 2] = $varargs; //@line 62644
 $8 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 62656
 $9 = HEAP32[$8 >> 2] | 0; //@line 62657
 HEAP32[$2 >> 2] = $8 + 4; //@line 62659
 HEAP32[$vararg_buffer >> 2] = $0; //@line 62661
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 62663
 HEAP32[$vararg_buffer + 8 >> 2] = $9; //@line 62665
 $12 = ___syscall_ret(___syscall54(54, $vararg_buffer | 0) | 0) | 0; //@line 62667
 STACKTOP = sp; //@line 62668
 return $12 | 0; //@line 62668
}
function __Z12op_4ea8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $22 = 0, $33 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 709
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 720
 $20 = (HEAP32[162768] | 0) + 4 + $4 - (HEAP32[162770] | 0) | 0; //@line 726
 $22 = (HEAP32[162767] | 0) + -4 | 0; //@line 728
 HEAP32[162767] = $22; //@line 729
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($22 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($22, $20); //@line 735
 $33 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 741
 HEAP32[162770] = $33; //@line 742
 HEAP32[162769] = $33; //@line 743
 HEAP32[162768] = $14; //@line 744
 return;
}
function __Z11op_1a8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7631
 $8 = HEAP32[162769] | 0; //@line 7634
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7645
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 7647
 $25 = $5 & 7; //@line 7652
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 7654
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 7658
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($26 & (1 << $25 ^ 255)) << 24 >> 24); //@line 7667
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7670
 return;
}
function __Z12op_4a7a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $24 = 0;
 $2 = HEAP32[162769] | 0; //@line 52106
 $$cast = $2; //@line 52108
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 52122
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 52128
 $24 = ($22 & 65535 | 0) == 0 & 1; //@line 52131
 HEAP32[96441] = 0; //@line 52132
 HEAP32[96442] = 0; //@line 52132
 HEAP32[96443] = 0; //@line 52132
 HEAP32[96444] = 0; //@line 52132
 HEAP32[96442] = $24; //@line 52133
 HEAP32[96443] = $22 >>> 15 & 1; //@line 52136
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52139
 return;
}
function __Z11op_868_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $27 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 14292
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 14294
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 14307
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 14309
 $24 = $4 & 7; //@line 14315
 $25 = 1 << $24; //@line 14316
 $27 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) ^ $25) << 24 >> 24; //@line 14319
 HEAP32[96442] = ($27 & $25) >>> $24; //@line 14322
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, $27); //@line 14326
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14329
 return;
}
function _memcmp($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$01318 = 0, $$01417 = 0, $$019 = 0, $14 = 0, $4 = 0, $5 = 0;
 L1 : do {
  if (!$2) {
   $14 = 0; //@line 56059
  } else {
   $$01318 = $0; //@line 56061
   $$01417 = $2; //@line 56061
   $$019 = $1; //@line 56061
   while (1) {
    $4 = HEAP8[$$01318 >> 0] | 0; //@line 56063
    $5 = HEAP8[$$019 >> 0] | 0; //@line 56064
    if ($4 << 24 >> 24 != $5 << 24 >> 24) {
     break;
    }
    $$01417 = $$01417 + -1 | 0; //@line 56069
    if (!$$01417) {
     $14 = 0; //@line 56074
     break L1;
    } else {
     $$01318 = $$01318 + 1 | 0; //@line 56077
     $$019 = $$019 + 1 | 0; //@line 56077
    }
   }
   $14 = ($4 & 255) - ($5 & 255) | 0; //@line 56083
  }
 } while (0);
 return $14 | 0; //@line 56086
}
function __Z12op_4a7b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0;
 $2 = HEAP32[162769] | 0; //@line 3087
 $$cast = $2; //@line 3092
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 3101
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 3107
 $23 = ($21 & 65535 | 0) == 0 & 1; //@line 3110
 HEAP32[96441] = 0; //@line 3111
 HEAP32[96442] = 0; //@line 3111
 HEAP32[96443] = 0; //@line 3111
 HEAP32[96444] = 0; //@line 3111
 HEAP32[96442] = $23; //@line 3112
 HEAP32[96443] = $21 >>> 15 & 1; //@line 3115
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3118
 return;
}
function __Z12PrefsAddBoolPKcb($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0$i = 0, $$sink$i = 0, $10 = 0, $12 = 0, $2 = 0, $5 = 0;
 $2 = _malloc(1) | 0; //@line 1240
 if (!$2) {
  return;
 }
 HEAP8[$2 >> 0] = $1 & 1; //@line 1246
 $5 = __Znwj(16) | 0; //@line 1247
 HEAP32[$5 >> 2] = 0; //@line 1248
 HEAP32[$5 + 4 >> 2] = ___strdup($0) | 0; //@line 1251
 HEAP32[$5 + 8 >> 2] = 1; //@line 1253
 HEAP32[$5 + 12 >> 2] = $2; //@line 1255
 $10 = HEAP32[28198] | 0; //@line 1256
 if (!$10) {
  $$sink$i = 112792; //@line 1259
 } else {
  $$0$i = $10; //@line 1261
  while (1) {
   $12 = HEAP32[$$0$i >> 2] | 0; //@line 1263
   if (!$12) {
    break;
   } else {
    $$0$i = $12; //@line 1268
   }
  }
  $$sink$i = $$0$i; //@line 1271
 }
 HEAP32[$$sink$i >> 2] = $5; //@line 1273
 return;
}
function __Z12op_807c_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $16 = 0, $3 = 0, $sext1415 = 0;
 $3 = HEAP32[162769] | 0; //@line 14475
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14484
 $13 = HEAP32[$12 >> 2] | 0; //@line 14485
 $sext1415 = (HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0) | $13; //@line 14486
 $14 = $sext1415 << 16 >> 16; //@line 14488
 $16 = ($14 | 0) == 0 & 1; //@line 14490
 HEAP32[96441] = 0; //@line 14491
 HEAP32[96442] = 0; //@line 14491
 HEAP32[96443] = 0; //@line 14491
 HEAP32[96444] = 0; //@line 14491
 HEAP32[96442] = $16; //@line 14492
 HEAP32[96443] = $sext1415 >>> 15 & 1; //@line 14495
 HEAP32[$12 >> 2] = $13 & -65536 | $14 & 65535; //@line 14499
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14502
 return;
}
function __Z12op_31fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $19 = 0, $21 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 39230
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 39233
 $18 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 39248
 $19 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 39250
 $21 = ($19 | 0) == 0 & 1; //@line 39252
 HEAP32[96441] = 0; //@line 39253
 HEAP32[96442] = 0; //@line 39253
 HEAP32[96443] = 0; //@line 39253
 HEAP32[96444] = 0; //@line 39253
 HEAP32[96442] = $21; //@line 39254
 HEAP32[96443] = $4 >>> 7; //@line 39256
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($18, $19); //@line 39262
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 39265
 return;
}
function _setsockopt($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $14 = 0, $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2045
 STACKTOP = STACKTOP + 32 | 0; //@line 2046
 $vararg_buffer = sp; //@line 2047
 $5 = sp + 8 | 0; //@line 2048
 HEAP32[$5 >> 2] = $0; //@line 2049
 HEAP32[$5 + 4 >> 2] = $1; //@line 2051
 HEAP32[$5 + 8 >> 2] = $2; //@line 2053
 HEAP32[$5 + 12 >> 2] = $3; //@line 2056
 HEAP32[$5 + 16 >> 2] = $4; //@line 2058
 HEAP32[$5 + 20 >> 2] = 0; //@line 2060
 HEAP32[$vararg_buffer >> 2] = 14; //@line 2062
 HEAP32[$vararg_buffer + 4 >> 2] = $5; //@line 2064
 $14 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 2066
 STACKTOP = sp; //@line 2067
 return $14 | 0; //@line 2067
}
function __Z12op_4a3a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0, $24 = 0;
 $2 = HEAP32[162769] | 0; //@line 51730
 $$cast = $2; //@line 51732
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 51746
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0; //@line 51752
 $24 = ($22 & 255 | 0) == 0 & 1; //@line 51755
 HEAP32[96441] = 0; //@line 51756
 HEAP32[96442] = 0; //@line 51756
 HEAP32[96443] = 0; //@line 51756
 HEAP32[96444] = 0; //@line 51756
 HEAP32[96442] = $24; //@line 51757
 HEAP32[96443] = $22 >>> 7 & 1; //@line 51760
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 51763
 return;
}
function __Z12op_2188_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 43381
 $8 = HEAP32[162769] | 0; //@line 43384
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 43393
 $19 = ($5 | 0) == 0 & 1; //@line 43395
 HEAP32[96441] = 0; //@line 43396
 HEAP32[96442] = 0; //@line 43396
 HEAP32[96443] = 0; //@line 43396
 HEAP32[96444] = 0; //@line 43396
 HEAP32[96442] = $19; //@line 43397
 HEAP32[96443] = $5 >>> 31; //@line 43399
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($17, $5); //@line 43405
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43408
 return;
}
function __Z12op_2180_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $19 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 43342
 $8 = HEAP32[162769] | 0; //@line 43345
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 43354
 $19 = ($5 | 0) == 0 & 1; //@line 43356
 HEAP32[96441] = 0; //@line 43357
 HEAP32[96442] = 0; //@line 43357
 HEAP32[96443] = 0; //@line 43357
 HEAP32[96444] = 0; //@line 43357
 HEAP32[96442] = $19; //@line 43358
 HEAP32[96443] = $5 >>> 31; //@line 43360
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($17, $5); //@line 43366
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43369
 return;
}
function __Z11op_8fb_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $19 = 0, $25 = 0, $26 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 17611
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 17613
 $17 = __Z15get_disp_ea_000jj($1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 17628
 $19 = 123608 + ($17 >>> 16 << 2) | 0; //@line 17630
 $25 = $3 & 7; //@line 17636
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$19 >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24; //@line 17638
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 17642
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$19 >> 2] | 0) + 20 >> 2] & 31]($17, ($26 | 1 << $25) << 24 >> 24); //@line 17650
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17653
 return;
}
function __Z12op_c190_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 30490
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30492
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 30494
 $13 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0) & $5; //@line 30498
 $15 = ($13 | 0) == 0 & 1; //@line 30500
 HEAP32[96441] = 0; //@line 30501
 HEAP32[96442] = 0; //@line 30501
 HEAP32[96443] = 0; //@line 30501
 HEAP32[96444] = 0; //@line 30501
 HEAP32[96442] = $15; //@line 30502
 HEAP32[96443] = $13 >>> 31; //@line 30504
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 30508
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30511
 return;
}
function __Z12op_c07c_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $14 = 0, $16 = 0, $3 = 0, $sext1415 = 0;
 $3 = HEAP32[162769] | 0; //@line 28799
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28808
 $13 = HEAP32[$12 >> 2] | 0; //@line 28809
 $sext1415 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) & $13; //@line 28810
 $14 = $sext1415 << 16 >> 16; //@line 28812
 $16 = ($14 | 0) == 0 & 1; //@line 28814
 HEAP32[96441] = 0; //@line 28815
 HEAP32[96442] = 0; //@line 28815
 HEAP32[96443] = 0; //@line 28815
 HEAP32[96444] = 0; //@line 28815
 HEAP32[96442] = $16; //@line 28816
 HEAP32[96443] = $sext1415 >>> 15; //@line 28818
 HEAP32[$12 >> 2] = $13 & -65536 | $14 & 65535; //@line 28822
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28825
 return;
}
function __Z12op_b190_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27060
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27062
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 27064
 $13 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0) ^ $5; //@line 27068
 $15 = ($13 | 0) == 0 & 1; //@line 27070
 HEAP32[96441] = 0; //@line 27071
 HEAP32[96442] = 0; //@line 27071
 HEAP32[96443] = 0; //@line 27071
 HEAP32[96444] = 0; //@line 27071
 HEAP32[96442] = $15; //@line 27072
 HEAP32[96443] = $13 >>> 31; //@line 27074
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 27078
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27081
 return;
}
function __Z12op_4a3b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0, $23 = 0;
 $2 = HEAP32[162769] | 0; //@line 3010
 $$cast = $2; //@line 3015
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 3024
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0; //@line 3030
 $23 = ($21 & 255 | 0) == 0 & 1; //@line 3033
 HEAP32[96441] = 0; //@line 3034
 HEAP32[96442] = 0; //@line 3034
 HEAP32[96443] = 0; //@line 3034
 HEAP32[96444] = 0; //@line 3034
 HEAP32[96442] = $23; //@line 3035
 HEAP32[96443] = $21 >>> 7 & 1; //@line 3038
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3041
 return;
}
function __ZN14EthernetPacketC2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $4 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 16971
 STACKTOP = STACKTOP + 80 | 0; //@line 16972
 $1 = sp; //@line 16973
 $2 = HEAP32[28481] | 0; //@line 16974
 HEAP32[28481] = $2 + 1; //@line 16976
 $4 = HEAP32[28482] | 0; //@line 16977
 if (($2 | 0) == 0 & ($4 | 0) != 0) {
  HEAP32[$0 >> 2] = $4; //@line 16982
  STACKTOP = sp; //@line 16983
  return;
 }
 HEAP32[$1 >> 2] = 1516; //@line 16985
 _Execute68kTrap(-22754, $1); //@line 16986
 $8 = HEAP32[$1 + 32 >> 2] | 0; //@line 16988
 if (!$8) {
  ___assert_fail(93592, 93604, 469, 93619); //@line 16991
 }
 HEAP32[$0 >> 2] = $8; //@line 16994
 if (!(HEAP32[28482] | 0)) {
  HEAP32[28482] = $8; //@line 16998
 }
 STACKTOP = sp; //@line 17000
 return;
}
function __Z14FileDiskLayoutiPhRiS0_($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $6 = 0, $storemerge = 0, label = 0;
 if (($0 | 0) < 838484) {
  switch ($0 | 0) {
  case 419284:
   {
    label = 2; //@line 12845
    break;
   }
  default:
   {
    label = 3; //@line 12849
   }
  }
 } else {
  switch ($0 | 0) {
  case 838484:
   {
    label = 2; //@line 12855
    break;
   }
  default:
   {
    label = 3; //@line 12859
   }
  }
 }
 if ((label | 0) == 2) {
  HEAP32[$2 >> 2] = 84; //@line 12864
  $storemerge = $0 + -84 & -512; //@line 12867
 } else if ((label | 0) == 3) {
  $6 = $0 & 511; //@line 12870
  HEAP32[$2 >> 2] = $6; //@line 12871
  $storemerge = $0 - $6 | 0; //@line 12873
 }
 HEAP32[$3 >> 2] = $storemerge; //@line 12875
 return;
}
function __Z12op_e6d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $10 = 0, $11 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41550
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41552
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41556
 $10 = $9 & 1; //@line 41557
 $11 = $9 >>> 1; //@line 41558
 $$ = ($10 | 0) == 0 ? $11 & 32767 : $11 | 32768; //@line 41562
 HEAP32[96444] = 0; //@line 41566
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41567
 HEAP32[96443] = $$ >>> 15 & 1; //@line 41570
 HEAP32[96441] = $10; //@line 41571
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 41576
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41579
 return;
}
function __Z12op_8190_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16583
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 16585
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 16587
 $13 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$9 >> 2] >> 2] & 127]($7) | 0 | $5; //@line 16591
 $15 = ($13 | 0) == 0 & 1; //@line 16593
 HEAP32[96441] = 0; //@line 16594
 HEAP32[96442] = 0; //@line 16594
 HEAP32[96443] = 0; //@line 16594
 HEAP32[96444] = 0; //@line 16594
 HEAP32[96442] = $15; //@line 16595
 HEAP32[96443] = $13 >>> 31; //@line 16597
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 12 >> 2] & 31]($7, $13); //@line 16601
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 16604
 return;
}
function __Z11op_8ba_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $26 = 0, $27 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14922
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14924
 $18 = $1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 14941
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 14943
 $26 = $3 & 7; //@line 14949
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 14951
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 14955
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($27 & (1 << $26 ^ 255)) << 24 >> 24); //@line 14964
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14967
 return;
}
function __Z13PrefsFindBoolPKc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, label = 0;
 $$01416$i = HEAP32[28198] | 0; //@line 1374
 if (!$$01416$i) {
  $$0 = 0; //@line 1377
  return $$0 | 0; //@line 1378
 } else {
  $$01418$i = $$01416$i; //@line 1380
 }
 while (1) {
  if ((HEAP32[$$01418$i + 8 >> 2] | 0) == 1) {
   if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
    break;
   }
  }
  $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 1395
  if (!$$014$i) {
   $$0 = 0; //@line 1398
   label = 6; //@line 1399
   break;
  } else {
   $$01418$i = $$014$i; //@line 1402
  }
 }
 if ((label | 0) == 6) {
  return $$0 | 0; //@line 1406
 }
 $$0 = (HEAP8[HEAP32[$$01418$i + 12 >> 2] >> 0] | 0) != 0; //@line 1412
 return $$0 | 0; //@line 1413
}
function __Z12op_c1d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $16 = 0, $18 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30800
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 30806
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30807
 $16 = Math_imul(HEAP32[$12 >> 2] << 16 >> 16, $11 << 16 >> 16) | 0; //@line 30813
 $18 = ($16 | 0) == 0 & 1; //@line 30815
 HEAP32[96441] = 0; //@line 30816
 HEAP32[96442] = 0; //@line 30816
 HEAP32[96443] = 0; //@line 30816
 HEAP32[96444] = 0; //@line 30816
 HEAP32[96442] = $18; //@line 30817
 HEAP32[96443] = $16 >>> 31; //@line 30819
 HEAP32[$12 >> 2] = $16; //@line 30820
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30823
 return;
}
function __Z12op_5ac8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 9306
 $3 = HEAP32[$2 >> 2] | 0; //@line 9307
 $4 = HEAP32[162769] | 0; //@line 9308
 if (!(HEAP32[96443] | 0)) {
  $$sink18 = 4; //@line 9312
  $24 = $4; //@line 9312
  $23 = $24 + $$sink18 | 0; //@line 9313
  HEAP32[162769] = $23; //@line 9314
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 9324
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 9330
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 9337
 $24 = HEAP32[162769] | 0; //@line 9337
 $23 = $24 + $$sink18 | 0; //@line 9338
 HEAP32[162769] = $23; //@line 9339
 return;
}
function __Z12op_58c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 8650
 $3 = HEAP32[$2 >> 2] | 0; //@line 8651
 $4 = HEAP32[162769] | 0; //@line 8652
 if (!(HEAP32[96444] | 0)) {
  $$sink18 = 4; //@line 8656
  $24 = $4; //@line 8656
  $23 = $24 + $$sink18 | 0; //@line 8657
  HEAP32[162769] = $23; //@line 8658
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 8668
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 8674
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 8681
 $24 = HEAP32[162769] | 0; //@line 8681
 $23 = $24 + $$sink18 | 0; //@line 8682
 HEAP32[162769] = $23; //@line 8683
 return;
}
function __Z12op_56c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 7994
 $3 = HEAP32[$2 >> 2] | 0; //@line 7995
 $4 = HEAP32[162769] | 0; //@line 7996
 if (!(HEAP32[96442] | 0)) {
  $$sink18 = 4; //@line 8000
  $24 = $4; //@line 8000
  $23 = $24 + $$sink18 | 0; //@line 8001
  HEAP32[162769] = $23; //@line 8002
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 8012
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 8018
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 8025
 $24 = HEAP32[162769] | 0; //@line 8025
 $23 = $24 + $$sink18 | 0; //@line 8026
 HEAP32[162769] = $23; //@line 8027
 return;
}
function __Z12op_54c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 7338
 $3 = HEAP32[$2 >> 2] | 0; //@line 7339
 $4 = HEAP32[162769] | 0; //@line 7340
 if (!(HEAP32[96441] | 0)) {
  $$sink18 = 4; //@line 7344
  $24 = $4; //@line 7344
  $23 = $24 + $$sink18 | 0; //@line 7345
  HEAP32[162769] = $23; //@line 7346
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 7356
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 7362
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 7369
 $24 = HEAP32[162769] | 0; //@line 7369
 $23 = $24 + $$sink18 | 0; //@line 7370
 HEAP32[162769] = $23; //@line 7371
 return;
}
function __Z11op_a40_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $2 = 0, $sext1415 = 0;
 $2 = HEAP32[162769] | 0; //@line 15834
 $11 = 651008 + (($0 & 7) << 2) | 0; //@line 15843
 $12 = HEAP32[$11 >> 2] | 0; //@line 15844
 $sext1415 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) ^ $12; //@line 15845
 $13 = $sext1415 << 16 >> 16; //@line 15847
 $15 = ($13 | 0) == 0 & 1; //@line 15849
 HEAP32[96441] = 0; //@line 15850
 HEAP32[96442] = 0; //@line 15850
 HEAP32[96443] = 0; //@line 15850
 HEAP32[96444] = 0; //@line 15850
 HEAP32[96442] = $15; //@line 15851
 HEAP32[96443] = $sext1415 >>> 15 & 1; //@line 15854
 HEAP32[$11 >> 2] = $12 & -65536 | $13 & 65535; //@line 15858
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15861
 return;
}
function __Z11op_1e8_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $25 = 0, $26 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8149
 $8 = HEAP32[162769] | 0; //@line 8152
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8163
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 8165
 $25 = $5 & 7; //@line 8170
 $26 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 8172
 HEAP32[96442] = $26 >>> $25 & 1 ^ 1; //@line 8176
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($26 | 1 << $25) << 24 >> 24); //@line 8184
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8187
 return;
}
function _getint($0) {
 $0 = $0 | 0;
 var $$0$lcssa = 0, $$06 = 0, $1 = 0, $5 = 0, $7 = 0, $isdigittmp4 = 0, $isdigittmp7 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 57197
 $isdigittmp4 = (HEAP8[$1 >> 0] | 0) + -48 | 0; //@line 57200
 if ($isdigittmp4 >>> 0 < 10) {
  $$06 = 0; //@line 57203
  $7 = $1; //@line 57203
  $isdigittmp7 = $isdigittmp4; //@line 57203
  while (1) {
   $5 = $isdigittmp7 + ($$06 * 10 | 0) | 0; //@line 57206
   $7 = $7 + 1 | 0; //@line 57207
   HEAP32[$0 >> 2] = $7; //@line 57208
   $isdigittmp7 = (HEAP8[$7 >> 0] | 0) + -48 | 0; //@line 57211
   if ($isdigittmp7 >>> 0 >= 10) {
    $$0$lcssa = $5; //@line 57216
    break;
   } else {
    $$06 = $5; //@line 57214
   }
  }
 } else {
  $$0$lcssa = 0; //@line 57221
 }
 return $$0$lcssa | 0; //@line 57223
}
function __Z12op_4ad0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $3 = 0, $5 = 0, $9 = 0, $sext = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52594
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 52596
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 52600
 $sext = $9 << 24; //@line 52601
 $11 = ($sext | 0) == 0 & 1; //@line 52603
 HEAP32[96441] = 0; //@line 52604
 HEAP32[96442] = 0; //@line 52604
 HEAP32[96443] = 0; //@line 52604
 HEAP32[96444] = 0; //@line 52604
 HEAP32[96442] = $11; //@line 52605
 HEAP32[96443] = $9 >>> 7 & 1; //@line 52608
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] & 31]($3, ($sext | -2147483648) >> 24); //@line 52614
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52617
 return;
}
function __Z12op_2148_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 30157
 $8 = HEAP32[162769] | 0; //@line 30160
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 30171
 $20 = ($5 | 0) == 0 & 1; //@line 30173
 HEAP32[96441] = 0; //@line 30174
 HEAP32[96442] = 0; //@line 30174
 HEAP32[96443] = 0; //@line 30174
 HEAP32[96444] = 0; //@line 30174
 HEAP32[96442] = $20; //@line 30175
 HEAP32[96443] = $5 >>> 31; //@line 30177
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $5); //@line 30183
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30186
 return;
}
function __Z12op_2140_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $20 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 30116
 $8 = HEAP32[162769] | 0; //@line 30119
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0) | 0; //@line 30130
 $20 = ($5 | 0) == 0 & 1; //@line 30132
 HEAP32[96441] = 0; //@line 30133
 HEAP32[96442] = 0; //@line 30133
 HEAP32[96443] = 0; //@line 30133
 HEAP32[96444] = 0; //@line 30133
 HEAP32[96442] = $20; //@line 30134
 HEAP32[96443] = $5 >>> 31; //@line 30136
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $5); //@line 30142
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 30145
 return;
}
function __Z12op_b03c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $sext$lobit = 0, $sext24$lobit = 0;
 $3 = HEAP32[162769] | 0; //@line 22330
 $5 = HEAP8[$3 + 3 >> 0] | 0; //@line 22332
 $6 = $5 & 255; //@line 22333
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22335
 $9 = $8 - $6 | 0; //@line 22336
 $sext$lobit = $8 >>> 7 & 1; //@line 22340
 $sext24$lobit = $9 >>> 7 & 1; //@line 22342
 HEAP32[96442] = ($9 & 255 | 0) == 0 & 1; //@line 22346
 HEAP32[96444] = (($5 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext24$lobit | 0) != ($sext$lobit | 0) & 1; //@line 22351
 HEAP32[96441] = $6 >>> 0 > ($8 & 255) >>> 0 & 1; //@line 22355
 HEAP32[96443] = $sext24$lobit; //@line 22356
 HEAP32[162769] = $3 + 4; //@line 22358
 return;
}
function __Z12op_5bc8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 9634
 $3 = HEAP32[$2 >> 2] | 0; //@line 9635
 $4 = HEAP32[162769] | 0; //@line 9636
 if (HEAP32[96443] | 0) {
  $$sink18 = 4; //@line 9640
  $24 = $4; //@line 9640
  $23 = $24 + $$sink18 | 0; //@line 9641
  HEAP32[162769] = $23; //@line 9642
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 9652
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 9658
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 9665
 $24 = HEAP32[162769] | 0; //@line 9665
 $23 = $24 + $$sink18 | 0; //@line 9666
 HEAP32[162769] = $23; //@line 9667
 return;
}
function __Z12op_59c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 8978
 $3 = HEAP32[$2 >> 2] | 0; //@line 8979
 $4 = HEAP32[162769] | 0; //@line 8980
 if (HEAP32[96444] | 0) {
  $$sink18 = 4; //@line 8984
  $24 = $4; //@line 8984
  $23 = $24 + $$sink18 | 0; //@line 8985
  HEAP32[162769] = $23; //@line 8986
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 8996
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 9002
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 9009
 $24 = HEAP32[162769] | 0; //@line 9009
 $23 = $24 + $$sink18 | 0; //@line 9010
 HEAP32[162769] = $23; //@line 9011
 return;
}
function __Z12op_57c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 8322
 $3 = HEAP32[$2 >> 2] | 0; //@line 8323
 $4 = HEAP32[162769] | 0; //@line 8324
 if (HEAP32[96442] | 0) {
  $$sink18 = 4; //@line 8328
  $24 = $4; //@line 8328
  $23 = $24 + $$sink18 | 0; //@line 8329
  HEAP32[162769] = $23; //@line 8330
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 8340
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 8346
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 8353
 $24 = HEAP32[162769] | 0; //@line 8353
 $23 = $24 + $$sink18 | 0; //@line 8354
 HEAP32[162769] = $23; //@line 8355
 return;
}
function __Z12op_55c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink18 = 0, $14 = 0, $2 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 7666
 $3 = HEAP32[$2 >> 2] | 0; //@line 7667
 $4 = HEAP32[162769] | 0; //@line 7668
 if (HEAP32[96441] | 0) {
  $$sink18 = 4; //@line 7672
  $24 = $4; //@line 7672
  $23 = $24 + $$sink18 | 0; //@line 7673
  HEAP32[162769] = $23; //@line 7674
  return;
 }
 $14 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 7684
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 7690
 $$sink18 = ($3 & 65535) << 16 >> 16 == 0 ? 4 : ($14 << 16 >> 16) + 2 | 0; //@line 7697
 $24 = HEAP32[162769] | 0; //@line 7697
 $23 = $24 + $$sink18 | 0; //@line 7698
 HEAP32[162769] = $23; //@line 7699
 return;
}
function __Z11op_8b0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 17464
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17466
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17477
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 17479
 $23 = $4 & 7; //@line 17485
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0) << 24 >> 24; //@line 17487
 HEAP32[96442] = $24 >>> $23 & 1 ^ 1; //@line 17491
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, ($24 & (1 << $23 ^ 255)) << 24 >> 24); //@line 17500
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17503
 return;
}
function __Z12op_e5d0_0_ffj($0) {
 $0 = $0 | 0;
 var $$ = 0, $18 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41210
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41212
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41216
 $$ = (HEAP32[96445] | 0) != 0 | $9 << 1; //@line 41221
 HEAP32[96444] = 0; //@line 41225
 HEAP32[96442] = ($$ & 65535) << 16 >> 16 == 0 & 1; //@line 41226
 HEAP32[96443] = $9 >>> 14 & 1; //@line 41229
 $18 = $9 >>> 15 & 1; //@line 41231
 HEAP32[96441] = $18; //@line 41232
 HEAP32[96445] = $18; //@line 41233
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $$ & 65535); //@line 41238
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41241
 return;
}
function __Z12op_e0d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $14 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38483
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 38485
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 38489
 $10 = $9 & 32768; //@line 38490
 $11 = $9 & 1; //@line 38491
 $14 = $9 >>> 1 & 32767 | $10; //@line 38494
 HEAP32[96444] = 0; //@line 38497
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 38498
 HEAP32[96443] = $10 >>> 15; //@line 38500
 HEAP32[96441] = $11; //@line 38501
 HEAP32[96445] = $11; //@line 38502
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $14); //@line 38506
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38509
 return;
}
function __Z12op_3108_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 36825
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36826
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 36828
 HEAP32[$6 >> 2] = $8; //@line 36829
 $9 = $5 << 16 >> 16; //@line 36831
 $11 = ($9 | 0) == 0 & 1; //@line 36833
 HEAP32[96441] = 0; //@line 36834
 HEAP32[96442] = 0; //@line 36834
 HEAP32[96443] = 0; //@line 36834
 HEAP32[96444] = 0; //@line 36834
 HEAP32[96442] = $11; //@line 36835
 HEAP32[96443] = $5 >>> 15 & 1; //@line 36838
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($8, $9); //@line 36844
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36847
 return;
}
function __Z12op_3100_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 36791
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36792
 $8 = (HEAP32[$6 >> 2] | 0) + -2 | 0; //@line 36794
 HEAP32[$6 >> 2] = $8; //@line 36795
 $9 = $5 << 16 >> 16; //@line 36797
 $11 = ($9 | 0) == 0 & 1; //@line 36799
 HEAP32[96441] = 0; //@line 36800
 HEAP32[96442] = 0; //@line 36800
 HEAP32[96443] = 0; //@line 36800
 HEAP32[96444] = 0; //@line 36800
 HEAP32[96442] = $11; //@line 36801
 HEAP32[96443] = $5 >>> 15 & 1; //@line 36804
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($8, $9); //@line 36810
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36813
 return;
}
function __Z14PrefsFindInt32PKc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$014$i = 0, $$01416$i = 0, $$01418$i = 0, label = 0;
 $$01416$i = HEAP32[28198] | 0; //@line 1419
 if (!$$01416$i) {
  $$0 = 0; //@line 1422
  return $$0 | 0; //@line 1423
 } else {
  $$01418$i = $$01416$i; //@line 1425
 }
 while (1) {
  if ((HEAP32[$$01418$i + 8 >> 2] | 0) == 2) {
   if (!(_strcmp(HEAP32[$$01418$i + 4 >> 2] | 0, $0) | 0)) {
    break;
   }
  }
  $$014$i = HEAP32[$$01418$i >> 2] | 0; //@line 1440
  if (!$$014$i) {
   $$0 = 0; //@line 1443
   label = 6; //@line 1444
   break;
  } else {
   $$01418$i = $$014$i; //@line 1447
  }
 }
 if ((label | 0) == 6) {
  return $$0 | 0; //@line 1451
 }
 $$0 = HEAP32[HEAP32[$$01418$i + 12 >> 2] >> 2] | 0; //@line 1456
 return $$0 | 0; //@line 1457
}
function __Z11op_108_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $23 = 0, $24 = 0, $31 = 0, $32 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 6529
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6540
 $23 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 8; //@line 6547
 $24 = $16 + 2 | 0; //@line 6548
 $31 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($24 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($24) | 0) + $23 | 0; //@line 6555
 $32 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 6556
 HEAP32[$32 >> 2] = HEAP32[$32 >> 2] & -65536 | $31 & 65535; //@line 6561
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6564
 return;
}
function __Z12op_5180_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit34 = 0, $$lobit35 = 0, $15 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 5962
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 5964
 $7 = HEAP32[$6 >> 2] | 0; //@line 5965
 $8 = $7 - $4 | 0; //@line 5966
 $$lobit34 = $7 >>> 31; //@line 5968
 $$lobit35 = $8 >>> 31; //@line 5969
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 5972
 HEAP32[96444] = ($$lobit35 ^ $$lobit34) & ($$lobit34 ^ $4 >>> 31); //@line 5976
 $15 = $7 >>> 0 < $4 >>> 0 & 1; //@line 5978
 HEAP32[96441] = $15; //@line 5979
 HEAP32[96445] = $15; //@line 5980
 HEAP32[96443] = $$lobit35; //@line 5981
 HEAP32[$6 >> 2] = $8; //@line 5982
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5985
 return;
}
function __Z12op_31c8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 38700
 $4 = HEAP32[162769] | 0; //@line 38701
 $13 = ((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16; //@line 38711
 $14 = $3 << 16 >> 16; //@line 38713
 $16 = ($14 | 0) == 0 & 1; //@line 38715
 HEAP32[96441] = 0; //@line 38716
 HEAP32[96442] = 0; //@line 38716
 HEAP32[96443] = 0; //@line 38716
 HEAP32[96444] = 0; //@line 38716
 HEAP32[96442] = $16; //@line 38717
 HEAP32[96443] = $3 >>> 15 & 1; //@line 38720
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $14); //@line 38726
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38729
 return;
}
function __Z12op_31c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 38661
 $4 = HEAP32[162769] | 0; //@line 38662
 $13 = ((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16; //@line 38672
 $14 = $3 << 16 >> 16; //@line 38674
 $16 = ($14 | 0) == 0 & 1; //@line 38676
 HEAP32[96441] = 0; //@line 38677
 HEAP32[96442] = 0; //@line 38677
 HEAP32[96443] = 0; //@line 38677
 HEAP32[96444] = 0; //@line 38677
 HEAP32[96442] = $16; //@line 38678
 HEAP32[96443] = $3 >>> 15 & 1; //@line 38681
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $14); //@line 38687
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 38690
 return;
}
function __Z11op_8fa_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $20 = 0, $26 = 0, $27 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 15370
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15372
 $18 = $1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 15389
 $20 = 123608 + ($18 >>> 16 << 2) | 0; //@line 15391
 $26 = $3 & 7; //@line 15397
 $27 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$20 >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24; //@line 15399
 HEAP32[96442] = $27 >>> $26 & 1 ^ 1; //@line 15403
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$20 >> 2] | 0) + 20 >> 2] & 31]($18, ($27 | 1 << $26) << 24 >> 24); //@line 15411
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15414
 return;
}
function __ZN8tinyxml210XMLElementD2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $5 = 0, $8 = 0, $5$looptemp = 0;
 HEAP32[$0 >> 2] = 2064; //@line 38247
 $1 = $0 + 48 | 0; //@line 38248
 $2 = HEAP32[$1 >> 2] | 0; //@line 38249
 if (!$2) {
  __ZN8tinyxml27XMLNodeD2Ev($0); //@line 38252
  return;
 }
 $5 = $2; //@line 38255
 do {
  $5$looptemp = $5;
  $5 = HEAP32[$5 + 28 >> 2] | 0; //@line 38258
  $8 = HEAP32[$5$looptemp + 32 >> 2] | 0; //@line 38260
  FUNCTION_TABLE_vi[HEAP32[HEAP32[$5$looptemp >> 2] >> 2] & 4095]($5$looptemp); //@line 38263
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 16 >> 2] & 31]($8, HEAP32[$1 >> 2] | 0); //@line 38268
  HEAP32[$1 >> 2] = $5; //@line 38269
 } while (($5 | 0) != 0);
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 38278
 return;
}
function __Z16AddPrefsDefaultsv() {
 __Z12PrefsAddBoolPKcb(93527, 0); //@line 1918
 __Z13PrefsAddInt32PKci(93537, 6066); //@line 1919
 __Z13PrefsAddInt32PKci(89980, 0); //@line 1920
 __Z13PrefsAddInt32PKci(89952, 0); //@line 1921
 __Z13PrefsAddInt32PKci(104571, 8388608); //@line 1922
 __Z13PrefsAddInt32PKci(103028, 6); //@line 1923
 __Z13PrefsAddInt32PKci(91749, 5); //@line 1924
 __Z13PrefsAddInt32PKci(90125, 3); //@line 1925
 __Z12PrefsAddBoolPKcb(90166, 0); //@line 1926
 __Z12PrefsAddBoolPKcb(90708, 0); //@line 1927
 __Z12PrefsAddBoolPKcb(104146, 0); //@line 1928
 __Z12PrefsAddBoolPKcb(90245, 0); //@line 1929
 __Z12PrefsAddBoolPKcb(104565, 0); //@line 1930
 __Z12PrefsAddBoolPKcb(90307, 0); //@line 1931
 __Z13PrefsAddInt32PKci(93397, 5); //@line 1932
 return;
}
function __Z12op_c0d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $16 = 0, $18 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29275
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 29281
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29282
 $16 = Math_imul(HEAP32[$12 >> 2] & 65535, $11 & 65535) | 0; //@line 29286
 $18 = ($16 | 0) == 0 & 1; //@line 29288
 HEAP32[96441] = 0; //@line 29289
 HEAP32[96442] = 0; //@line 29289
 HEAP32[96443] = 0; //@line 29289
 HEAP32[96444] = 0; //@line 29289
 HEAP32[96442] = $18; //@line 29290
 HEAP32[96443] = $16 >>> 31; //@line 29292
 HEAP32[$12 >> 2] = $16; //@line 29293
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29296
 return;
}
function __Z12op_11c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 26624
 $4 = HEAP32[162769] | 0; //@line 26625
 $13 = ((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16; //@line 26635
 $14 = $3 << 24 >> 24; //@line 26637
 $16 = ($14 | 0) == 0 & 1; //@line 26639
 HEAP32[96441] = 0; //@line 26640
 HEAP32[96442] = 0; //@line 26640
 HEAP32[96443] = 0; //@line 26640
 HEAP32[96444] = 0; //@line 26640
 HEAP32[96442] = $16; //@line 26641
 HEAP32[96443] = $3 >>> 7 & 1; //@line 26644
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $14); //@line 26650
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 26653
 return;
}
function __Z11op_8a8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 14723
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 14725
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 14738
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 14740
 $24 = $4 & 7; //@line 14746
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24; //@line 14748
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 14752
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, ($25 & (1 << $24 ^ 255)) << 24 >> 24); //@line 14761
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14764
 return;
}
function __Z11op_c00_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $sext$lobit = 0, $sext24$lobit = 0;
 $2 = HEAP32[162769] | 0; //@line 18773
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 18775
 $5 = $4 & 255; //@line 18776
 $7 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 18778
 $8 = $7 - $5 | 0; //@line 18779
 $sext$lobit = $7 >>> 7 & 1; //@line 18783
 $sext24$lobit = $8 >>> 7 & 1; //@line 18785
 HEAP32[96442] = ($8 & 255 | 0) == 0 & 1; //@line 18789
 HEAP32[96444] = (($4 & 255) >>> 7 & 255 | 0) != ($sext$lobit | 0) & ($sext24$lobit | 0) != ($sext$lobit | 0) & 1; //@line 18794
 HEAP32[96441] = $5 >>> 0 > ($7 & 255) >>> 0 & 1; //@line 18798
 HEAP32[96443] = $sext24$lobit; //@line 18799
 HEAP32[162769] = $2 + 4; //@line 18801
 return;
}
function __Z12op_30c8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 36277
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36278
 $7 = HEAP32[$6 >> 2] | 0; //@line 36279
 HEAP32[$6 >> 2] = $7 + 2; //@line 36281
 $9 = $5 << 16 >> 16; //@line 36283
 $11 = ($9 | 0) == 0 & 1; //@line 36285
 HEAP32[96441] = 0; //@line 36286
 HEAP32[96442] = 0; //@line 36286
 HEAP32[96443] = 0; //@line 36286
 HEAP32[96444] = 0; //@line 36286
 HEAP32[96442] = $11; //@line 36287
 HEAP32[96443] = $5 >>> 15 & 1; //@line 36290
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($7, $9); //@line 36296
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36299
 return;
}
function __Z12op_30c0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 36243
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36244
 $7 = HEAP32[$6 >> 2] | 0; //@line 36245
 HEAP32[$6 >> 2] = $7 + 2; //@line 36247
 $9 = $5 << 16 >> 16; //@line 36249
 $11 = ($9 | 0) == 0 & 1; //@line 36251
 HEAP32[96441] = 0; //@line 36252
 HEAP32[96442] = 0; //@line 36252
 HEAP32[96443] = 0; //@line 36252
 HEAP32[96444] = 0; //@line 36252
 HEAP32[96442] = $11; //@line 36253
 HEAP32[96443] = $5 >>> 15 & 1; //@line 36256
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($7, $9); //@line 36262
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 36265
 return;
}
function __Z11op_8f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $23 = 0, $24 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 17564
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17566
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17577
 $17 = 123608 + ($15 >>> 16 << 2) | 0; //@line 17579
 $23 = $4 & 7; //@line 17585
 $24 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$17 >> 2] | 0) + 8 >> 2] & 127]($15) | 0) << 24 >> 24; //@line 17587
 HEAP32[96442] = $24 >>> $23 & 1 ^ 1; //@line 17591
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$17 >> 2] | 0) + 20 >> 2] & 31]($15, ($24 | 1 << $23) << 24 >> 24); //@line 17599
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17602
 return;
}
function __Z12op_42b0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 46481
 $3 = $2 + 2 | 0; //@line 46482
 HEAP32[162769] = $3; //@line 46483
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46485
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 46492
 HEAP32[162769] = $2 + 4; //@line 46494
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 46495
 HEAP32[96441] = 0; //@line 46496
 HEAP32[96442] = 0; //@line 46496
 HEAP32[96443] = 0; //@line 46496
 HEAP32[96444] = 0; //@line 46496
 HEAP32[96442] = 1; //@line 46497
 HEAP32[96443] = 0; //@line 46498
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, 0); //@line 46504
 return;
}
function __Z12op_4270_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 43064
 $3 = $2 + 2 | 0; //@line 43065
 HEAP32[162769] = $3; //@line 43066
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 43068
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 43075
 HEAP32[162769] = $2 + 4; //@line 43077
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 43078
 HEAP32[96441] = 0; //@line 43079
 HEAP32[96442] = 0; //@line 43079
 HEAP32[96443] = 0; //@line 43079
 HEAP32[96444] = 0; //@line 43079
 HEAP32[96442] = 1; //@line 43080
 HEAP32[96443] = 0; //@line 43081
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, 0); //@line 43087
 return;
}
function __Z12op_4230_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 42847
 $3 = $2 + 2 | 0; //@line 42848
 HEAP32[162769] = $3; //@line 42849
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42851
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 42858
 HEAP32[162769] = $2 + 4; //@line 42860
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 42861
 HEAP32[96441] = 0; //@line 42862
 HEAP32[96442] = 0; //@line 42862
 HEAP32[96443] = 0; //@line 42862
 HEAP32[96444] = 0; //@line 42862
 HEAP32[96442] = 1; //@line 42863
 HEAP32[96443] = 0; //@line 42864
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 0); //@line 42870
 return;
}
function __Z12op_11fc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $13 = 0, $15 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 27158
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 27160
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 27170
 $13 = $3 << 24 >> 24; //@line 27171
 $15 = $3 << 24 >> 24 == 0 & 1; //@line 27173
 HEAP32[96441] = 0; //@line 27174
 HEAP32[96442] = 0; //@line 27174
 HEAP32[96443] = 0; //@line 27174
 HEAP32[96444] = 0; //@line 27174
 HEAP32[96442] = $15; //@line 27175
 HEAP32[96443] = ($3 & 255) >>> 7 & 255; //@line 27178
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($12, $13); //@line 27184
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 27187
 return;
}
function _sbrk(increment) {
 increment = increment | 0;
 var oldDynamicTop = 0, newDynamicTop = 0;
 increment = increment + 15 & -16 | 0; //@line 4481
 oldDynamicTop = HEAP32[DYNAMICTOP_PTR >> 2] | 0; //@line 4482
 newDynamicTop = oldDynamicTop + increment | 0; //@line 4483
 if ((increment | 0) > 0 & (newDynamicTop | 0) < (oldDynamicTop | 0) | (newDynamicTop | 0) < 0) {
  abortOnCannotGrowMemory() | 0; //@line 4487
  ___setErrNo(12); //@line 4488
  return -1;
 }
 HEAP32[DYNAMICTOP_PTR >> 2] = newDynamicTop; //@line 4492
 if ((newDynamicTop | 0) > (getTotalMemory() | 0)) {
  if (!(enlargeMemory() | 0)) {
   HEAP32[DYNAMICTOP_PTR >> 2] = oldDynamicTop; //@line 4496
   ___setErrNo(12); //@line 4497
   return -1;
  }
 }
 return oldDynamicTop | 0; //@line 4501
}
function __Z12op_b0fc_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit28 = 0, $13 = 0, $14 = 0, $15 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 26137
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 26140
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 26147
 $14 = ($6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 26149
 $15 = $13 - $14 | 0; //@line 26150
 $$lobit = $13 >>> 31; //@line 26152
 $$lobit28 = $15 >>> 31; //@line 26153
 HEAP32[96442] = ($15 | 0) == 0 & 1; //@line 26156
 HEAP32[96444] = ($6 >>> 7 | 0) != ($$lobit | 0) & ($$lobit28 | 0) != ($$lobit | 0) & 1; //@line 26161
 HEAP32[96441] = $13 >>> 0 < $14 >>> 0 & 1; //@line 26164
 HEAP32[96443] = $$lobit28; //@line 26165
 HEAP32[162769] = $3 + 4; //@line 26167
 return;
}
function __Z12op_4c58_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $17 = 0, $2 = 0, $22 = 0, $3 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53336
 $3 = $2 + 2 | 0; //@line 53337
 HEAP32[162769] = $3; //@line 53338
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53343
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53351
 $16 = 651040 + (($0 & 7) << 2) | 0; //@line 53352
 $17 = HEAP32[$16 >> 2] | 0; //@line 53353
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 53358
 HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 4; //@line 53361
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 53364
 __Z9m68k_divljjtj($0, $22, $15, $7); //@line 53365
 return;
}
function __Z12op_2090_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $14 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28667
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28672
 $12 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28674
 $14 = ($10 | 0) == 0 & 1; //@line 28676
 HEAP32[96441] = 0; //@line 28677
 HEAP32[96442] = 0; //@line 28677
 HEAP32[96443] = 0; //@line 28677
 HEAP32[96444] = 0; //@line 28677
 HEAP32[96442] = $14; //@line 28678
 HEAP32[96443] = $10 >>> 31; //@line 28680
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($12, $10); //@line 28686
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28689
 return;
}
function __Z12op_4aba_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $21 = 0, $23 = 0;
 $2 = HEAP32[162769] | 0; //@line 52462
 $$cast = $2; //@line 52464
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 52478
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 52483
 $23 = ($21 | 0) == 0 & 1; //@line 52485
 HEAP32[96441] = 0; //@line 52486
 HEAP32[96442] = 0; //@line 52486
 HEAP32[96443] = 0; //@line 52486
 HEAP32[96444] = 0; //@line 52486
 HEAP32[96442] = $23; //@line 52487
 HEAP32[96443] = $21 >>> 31; //@line 52489
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52492
 return;
}
function __Z12op_2018_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 27931
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 27932
 $5 = HEAP32[$4 >> 2] | 0; //@line 27933
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27938
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 27941
 $14 = ($10 | 0) == 0 & 1; //@line 27943
 HEAP32[96441] = 0; //@line 27944
 HEAP32[96442] = 0; //@line 27944
 HEAP32[96443] = 0; //@line 27944
 HEAP32[96444] = 0; //@line 27944
 HEAP32[96442] = $14; //@line 27945
 HEAP32[96443] = $10 >>> 31; //@line 27947
 HEAP32[651008 + ($3 << 2) >> 2] = $10; //@line 27949
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27952
 return;
}
function __ZNK12monitor_desc9has_depthE11video_depth($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $$sroa$03$07 = 0, $3 = 0, $5 = 0, label = 0;
 $3 = HEAP32[$0 + 4 >> 2] | 0; //@line 23534
 $5 = HEAP32[$0 + 8 >> 2] | 0; //@line 23536
 if (($3 | 0) == ($5 | 0)) {
  $$0 = 0; //@line 23539
  return $$0 | 0; //@line 23540
 } else {
  $$sroa$03$07 = $3; //@line 23542
 }
 while (1) {
  if ((HEAP32[$$sroa$03$07 + 12 >> 2] | 0) == ($1 | 0)) {
   $$0 = 1; //@line 23550
   label = 4; //@line 23551
   break;
  }
  $$sroa$03$07 = $$sroa$03$07 + 24 | 0; //@line 23548
  if (($$sroa$03$07 | 0) == ($5 | 0)) {
   $$0 = 0; //@line 23556
   label = 4; //@line 23557
   break;
  }
 }
 if ((label | 0) == 4) {
  return $$0 | 0; //@line 23564
 }
 return 0; //@line 23566
}
function __Z12op_4abb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $20 = 0, $22 = 0;
 $2 = HEAP32[162769] | 0; //@line 3161
 $$cast = $2; //@line 3166
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 3175
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 3180
 $22 = ($20 | 0) == 0 & 1; //@line 3182
 HEAP32[96441] = 0; //@line 3183
 HEAP32[96442] = 0; //@line 3183
 HEAP32[96443] = 0; //@line 3183
 HEAP32[96444] = 0; //@line 3183
 HEAP32[96442] = $22; //@line 3184
 HEAP32[96443] = $20 >>> 31; //@line 3186
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3189
 return;
}
function __Z11op_8e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $2 = 0, $24 = 0, $25 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 15175
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 15177
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 15190
 $18 = 123608 + ($16 >>> 16 << 2) | 0; //@line 15192
 $24 = $4 & 7; //@line 15198
 $25 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$18 >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24; //@line 15200
 HEAP32[96442] = $25 >>> $24 & 1 ^ 1; //@line 15204
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$18 >> 2] | 0) + 20 >> 2] & 31]($16, ($25 | 1 << $24) << 24 >> 24); //@line 15212
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15215
 return;
}
function __Z10op_40_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $2 = 0, $sext1415 = 0;
 $2 = HEAP32[162769] | 0; //@line 5062
 $11 = 651008 + (($0 & 7) << 2) | 0; //@line 5071
 $12 = HEAP32[$11 >> 2] | 0; //@line 5072
 $sext1415 = (HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0) | $12; //@line 5073
 $13 = $sext1415 << 16 >> 16; //@line 5075
 $15 = ($13 | 0) == 0 & 1; //@line 5077
 HEAP32[96441] = 0; //@line 5078
 HEAP32[96442] = 0; //@line 5078
 HEAP32[96443] = 0; //@line 5078
 HEAP32[96444] = 0; //@line 5078
 HEAP32[96442] = $15; //@line 5079
 HEAP32[96443] = $sext1415 >>> 15 & 1; //@line 5082
 HEAP32[$11 >> 2] = $12 & -65536 | $13 & 65535; //@line 5086
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5089
 return;
}
function __Z11op_240_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $15 = 0, $2 = 0, $sext1415 = 0;
 $2 = HEAP32[162769] | 0; //@line 8804
 $11 = 651008 + (($0 & 7) << 2) | 0; //@line 8813
 $12 = HEAP32[$11 >> 2] | 0; //@line 8814
 $sext1415 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & $12; //@line 8815
 $13 = $sext1415 << 16 >> 16; //@line 8817
 $15 = ($13 | 0) == 0 & 1; //@line 8819
 HEAP32[96441] = 0; //@line 8820
 HEAP32[96442] = 0; //@line 8820
 HEAP32[96443] = 0; //@line 8820
 HEAP32[96444] = 0; //@line 8820
 HEAP32[96442] = $15; //@line 8821
 HEAP32[96443] = $sext1415 >>> 15; //@line 8823
 HEAP32[$11 >> 2] = $12 & -65536 | $13 & 65535; //@line 8827
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8830
 return;
}
function __Z12op_4440_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $3 = 0, $5 = 0, $sext26$lobit = 0, $sext26$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 47185
 $3 = HEAP32[$2 >> 2] | 0; //@line 47186
 $5 = 0 - ($3 << 16 >> 16) | 0; //@line 47189
 $sext26$lobit = $5 >>> 15 & 1; //@line 47192
 $sext26$mask = $5 & 65535; //@line 47193
 HEAP32[96442] = ($sext26$mask | 0) == 0 & 1; //@line 47196
 HEAP32[96444] = $sext26$lobit & $3 >>> 15; //@line 47198
 $13 = ($3 & 65535 | 0) != 0 & 1; //@line 47201
 HEAP32[96441] = $13; //@line 47202
 HEAP32[96445] = $13; //@line 47203
 HEAP32[96443] = $sext26$lobit; //@line 47204
 HEAP32[$2 >> 2] = $sext26$mask | $3 & -65536; //@line 47207
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47210
 return;
}
function __Z12op_30bc_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $16 = 0, $3 = 0, $6 = 0;
 $3 = HEAP32[162769] | 0; //@line 36204
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 36207
 $13 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 36214
 $14 = ($6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 36216
 $16 = ($14 | 0) == 0 & 1; //@line 36218
 HEAP32[96441] = 0; //@line 36219
 HEAP32[96442] = 0; //@line 36219
 HEAP32[96443] = 0; //@line 36219
 HEAP32[96444] = 0; //@line 36219
 HEAP32[96442] = $16; //@line 36220
 HEAP32[96443] = $6 >>> 7; //@line 36222
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, $14); //@line 36228
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36231
 return;
}
function __Z12op_4190_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $16 = 0, $8 = 0, $sext = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42043
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42045
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 42051
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42054
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42057
  __Z9Exceptionij(6, $8); //@line 42058
  return;
 }
 if (($sext | 0) > ($16 << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42064
  __Z9Exceptionij(6, $8); //@line 42065
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42070
  return;
 }
}
function __Z12op_4c60_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $18 = 0, $2 = 0, $23 = 0, $3 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53374
 $3 = $2 + 2 | 0; //@line 53375
 HEAP32[162769] = $3; //@line 53376
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53381
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53389
 $16 = 651040 + (($0 & 7) << 2) | 0; //@line 53390
 $18 = (HEAP32[$16 >> 2] | 0) + -4 | 0; //@line 53392
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 53397
 HEAP32[$16 >> 2] = $18; //@line 53398
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 53401
 __Z9m68k_divljjtj($0, $23, $15, $7); //@line 53402
 return;
}
function __Z12op_4400_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $3 = 0, $5 = 0, $sext24$lobit = 0, $sext24$mask = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 46807
 $3 = HEAP32[$2 >> 2] | 0; //@line 46808
 $5 = 0 - ($3 << 24 >> 24) | 0; //@line 46811
 $sext24$lobit = $5 >>> 7 & 1; //@line 46814
 $sext24$mask = $5 & 255; //@line 46815
 HEAP32[96442] = ($sext24$mask | 0) == 0 & 1; //@line 46818
 HEAP32[96444] = $sext24$lobit & $3 >>> 7; //@line 46820
 $13 = ($3 & 255 | 0) != 0 & 1; //@line 46823
 HEAP32[96441] = $13; //@line 46824
 HEAP32[96445] = $13; //@line 46825
 HEAP32[96443] = $sext24$lobit; //@line 46826
 HEAP32[$2 >> 2] = $sext24$mask | $3 & -256; //@line 46829
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46832
 return;
}
function __Z12op_2020_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $3 = 0, $4 = 0, $6 = 0;
 $3 = $0 >>> 9 & 7; //@line 27961
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 27962
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 27964
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 27969
 HEAP32[$4 >> 2] = $6; //@line 27970
 $13 = ($11 | 0) == 0 & 1; //@line 27972
 HEAP32[96441] = 0; //@line 27973
 HEAP32[96442] = 0; //@line 27973
 HEAP32[96443] = 0; //@line 27973
 HEAP32[96444] = 0; //@line 27973
 HEAP32[96442] = $13; //@line 27974
 HEAP32[96443] = $11 >>> 31; //@line 27976
 HEAP32[651008 + ($3 << 2) >> 2] = $11; //@line 27978
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27981
 return;
}
function __Z12op_2038_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $19 = 0, $2 = 0, $3 = 0;
 $2 = $0 >>> 9 & 7; //@line 28068
 $3 = HEAP32[162769] | 0; //@line 28069
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 28079
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 28084
 $19 = ($17 | 0) == 0 & 1; //@line 28086
 HEAP32[96441] = 0; //@line 28087
 HEAP32[96442] = 0; //@line 28087
 HEAP32[96443] = 0; //@line 28087
 HEAP32[96444] = 0; //@line 28087
 HEAP32[96442] = $19; //@line 28088
 HEAP32[96443] = $17 >>> 31; //@line 28090
 HEAP32[651008 + ($2 << 2) >> 2] = $17; //@line 28092
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28095
 return;
}
function __Z12op_4c79_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $23 = 0, $37 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 53543
 $2 = $1 + 2 | 0; //@line 53544
 HEAP32[162769] = $2; //@line 53545
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53550
 $14 = ((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53558
 $23 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 53567
 $37 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($23 >>> 16 << 2) >> 2] >> 2] & 127]($23 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 53581
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 53584
 __Z9m68k_divljjtj($0, $37, $14, $6); //@line 53585
 return;
}
function __Z11op_178_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $24 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7240
 $5 = HEAP32[162769] | 0; //@line 7241
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 7251
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 7253
 $21 = $4 & 7; //@line 7258
 $22 = 1 << $21; //@line 7259
 $24 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) ^ $22) << 24 >> 24; //@line 7262
 HEAP32[96442] = ($24 & $22) >>> $21; //@line 7265
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, $24); //@line 7269
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7272
 return;
}
function _store_int($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $7 = 0;
 L1 : do {
  if ($0 | 0) {
   switch ($1 | 0) {
   case -2:
    {
     HEAP8[$0 >> 0] = $2; //@line 1603
     break L1;
     break;
    }
   case -1:
    {
     HEAP16[$0 >> 1] = $2; //@line 1609
     break L1;
     break;
    }
   case 0:
    {
     HEAP32[$0 >> 2] = $2; //@line 1614
     break L1;
     break;
    }
   case 1:
    {
     HEAP32[$0 >> 2] = $2; //@line 1619
     break L1;
     break;
    }
   case 3:
    {
     $7 = $0; //@line 1624
     HEAP32[$7 >> 2] = $2; //@line 1626
     HEAP32[$7 + 4 >> 2] = $3; //@line 1629
     break L1;
     break;
    }
   default:
    {
     break L1;
    }
   }
  }
 } while (0);
 return;
}
function __Z12op_4c68_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $2 = 0, $27 = 0, $3 = 0, $32 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53411
 $3 = $2 + 2 | 0; //@line 53412
 HEAP32[162769] = $3; //@line 53413
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53418
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53426
 $27 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 53439
 $32 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($27 >>> 16 << 2) >> 2] >> 2] & 127]($27) | 0; //@line 53444
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 53447
 __Z9m68k_divljjtj($0, $32, $15, $7); //@line 53448
 return;
}
function __Z12op_e190_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $16 = 0, $18 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39688
 $7 = HEAP32[$6 >> 2] | 0; //@line 39689
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 39690
 $11 = $7 >>> (32 - $8 | 0); //@line 39693
 $12 = $11 & 1; //@line 39694
 HEAP32[96444] = 0; //@line 39696
 $16 = (HEAP32[96445] | $7 << 1) << $8 + -1; //@line 39699
 $18 = $16 | $11 >>> 1; //@line 39701
 HEAP32[96445] = $12; //@line 39702
 HEAP32[96441] = $12; //@line 39703
 HEAP32[96442] = ($18 | 0) == 0 & 1; //@line 39706
 HEAP32[96443] = $16 >>> 31; //@line 39708
 HEAP32[$6 >> 2] = $18; //@line 39709
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39712
 return;
}
function __Z12op_e090_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $16 = 0, $18 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38233
 $7 = HEAP32[$6 >> 2] | 0; //@line 38234
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 63; //@line 38235
 HEAP32[96444] = 0; //@line 38238
 $14 = (HEAP32[96445] | $7 << 1) << 32 - $8; //@line 38242
 $15 = $7 >>> ($8 + -1 | 0); //@line 38243
 $16 = $15 & 1; //@line 38244
 $18 = $14 | $15 >>> 1; //@line 38246
 HEAP32[96445] = $16; //@line 38247
 HEAP32[96441] = $16; //@line 38248
 HEAP32[96442] = ($18 | 0) == 0 & 1; //@line 38251
 HEAP32[96443] = $14 >>> 31; //@line 38253
 HEAP32[$6 >> 2] = $18; //@line 38254
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38257
 return;
}
function __Z12op_4a18_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $2 = 0, $3 = 0, $9 = 0;
 $1 = $0 & 7; //@line 51512
 $2 = 651040 + ($1 << 2) | 0; //@line 51513
 $3 = HEAP32[$2 >> 2] | 0; //@line 51514
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 51520
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 51525
 $15 = ($9 & 255 | 0) == 0 & 1; //@line 51528
 HEAP32[96441] = 0; //@line 51529
 HEAP32[96442] = 0; //@line 51529
 HEAP32[96443] = 0; //@line 51529
 HEAP32[96444] = 0; //@line 51529
 HEAP32[96442] = $15; //@line 51530
 HEAP32[96443] = $9 >>> 7 & 1; //@line 51533
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51536
 return;
}
function _getsockname($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $13 = 0, $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2161
 STACKTOP = STACKTOP + 32 | 0; //@line 2162
 $vararg_buffer = sp; //@line 2163
 $3 = sp + 8 | 0; //@line 2164
 HEAP32[$3 >> 2] = $0; //@line 2165
 HEAP32[$3 + 4 >> 2] = $1; //@line 2168
 HEAP32[$3 + 8 >> 2] = $2; //@line 2171
 HEAP32[$3 + 12 >> 2] = 0; //@line 2173
 HEAP32[$3 + 16 >> 2] = 0; //@line 2175
 HEAP32[$3 + 20 >> 2] = 0; //@line 2177
 HEAP32[$vararg_buffer >> 2] = 6; //@line 2179
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 2181
 $13 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 2183
 STACKTOP = sp; //@line 2184
 return $13 | 0; //@line 2184
}
function __Z14AudioInterruptv() {
 var $0 = 0, $1 = 0, $3 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 47709
 STACKTOP = STACKTOP + 80 | 0; //@line 47710
 $0 = sp; //@line 47711
 $1 = HEAP32[30820] | 0; //@line 47712
 if (!$1) {
  $9 = (HEAP32[30824] | 0) + 200 | 0; //@line 47716
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($9, 0); //@line 47722
  _sem_post(123464) | 0; //@line 47723
  STACKTOP = sp; //@line 47724
  return;
 } else {
  $3 = HEAP32[30824] | 0; //@line 47726
  HEAP32[$0 + 32 >> 2] = $3 + 200; //@line 47729
  HEAP32[$0 + 36 >> 2] = $1; //@line 47731
  _Execute68k($3 + 126 | 0, $0); //@line 47733
  _sem_post(123464) | 0; //@line 47734
  STACKTOP = sp; //@line 47735
  return;
 }
}
function __Z13TimeToMacTimel($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $13 = 0, $2 = 0, $4 = 0, sp = 0;
 sp = STACKTOP; //@line 12910
 STACKTOP = STACKTOP + 16 | 0; //@line 12911
 $1 = sp; //@line 12912
 HEAP32[$1 >> 2] = $0; //@line 12913
 $2 = _localtime($1 | 0) | 0; //@line 12914
 $4 = HEAP32[$2 + 20 >> 2] | 0; //@line 12916
 $10 = ($4 + 1900 >> 2) - (($4 & 3 | 0) == 0 & 1) | 0; //@line 12922
 $13 = (($10 | 0) / 25 | 0) - ((($10 | 0) % 25 | 0) >>> 31) | 0; //@line 12926
 STACKTOP = sp; //@line 12947
 return ((((((($4 * 365 | 0) + -1920 + (HEAP32[$2 + 28 >> 2] | 0) + $10 - $13 + ($13 >> 2) | 0) * 24 | 0) + (HEAP32[$2 + 8 >> 2] | 0) | 0) * 60 | 0) + (HEAP32[$2 + 4 >> 2] | 0) | 0) * 60 | 0) + (HEAP32[$2 >> 2] | 0) | 0; //@line 12947
}
function __Z10SerialInitv() {
 var $0 = 0, $1 = 0, $6 = 0, $7 = 0;
 $0 = __Znwj(24) | 0; //@line 47039
 $1 = __Z15PrefsFindStringPKci(104120, 0) | 0; //@line 47040
 HEAP8[$0 + 4 >> 0] = 0; //@line 47042
 HEAP32[$0 + 16 >> 2] = 0; //@line 47044
 HEAP32[$0 + 8 >> 2] = 0; //@line 47046
 HEAP32[$0 >> 2] = 5208; //@line 47047
 HEAP32[$0 + 20 >> 2] = $1; //@line 47049
 HEAP32[28475] = $0; //@line 47050
 $6 = __Znwj(24) | 0; //@line 47051
 $7 = __Z15PrefsFindStringPKci(104128, 0) | 0; //@line 47052
 HEAP8[$6 + 4 >> 0] = 0; //@line 47054
 HEAP32[$6 + 16 >> 2] = 0; //@line 47056
 HEAP32[$6 + 8 >> 2] = 0; //@line 47058
 HEAP32[$6 >> 2] = 5208; //@line 47059
 HEAP32[$6 + 20 >> 2] = $7; //@line 47061
 HEAP32[28476] = $6; //@line 47062
 return;
}
function _connect($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $12 = 0, $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 1957
 STACKTOP = STACKTOP + 32 | 0; //@line 1958
 $vararg_buffer = sp; //@line 1959
 $3 = sp + 8 | 0; //@line 1960
 HEAP32[$3 >> 2] = $0; //@line 1961
 HEAP32[$3 + 4 >> 2] = $1; //@line 1964
 HEAP32[$3 + 8 >> 2] = $2; //@line 1966
 HEAP32[$3 + 12 >> 2] = 0; //@line 1968
 HEAP32[$3 + 16 >> 2] = 0; //@line 1970
 HEAP32[$3 + 20 >> 2] = 0; //@line 1972
 HEAP32[$vararg_buffer >> 2] = 3; //@line 1974
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 1976
 $12 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 1978
 STACKTOP = sp; //@line 1979
 return $12 | 0; //@line 1979
}
function __Z12op_4490_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $16 = 0, $3 = 0, $5 = 0, $8 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47587
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 47589
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 47592
 $11 = ($8 | 0) > 0 & 1; //@line 47596
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 47599
 HEAP32[96444] = $11 & $8 >>> 31; //@line 47601
 $16 = ($8 | 0) != 0 & 1; //@line 47603
 HEAP32[96441] = $16; //@line 47604
 HEAP32[96445] = $16; //@line 47605
 HEAP32[96443] = $11; //@line 47606
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, 0 - $8 | 0); //@line 47610
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47613
 return;
}
function _bind($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $12 = 0, $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2074
 STACKTOP = STACKTOP + 32 | 0; //@line 2075
 $vararg_buffer = sp; //@line 2076
 $3 = sp + 8 | 0; //@line 2077
 HEAP32[$3 >> 2] = $0; //@line 2078
 HEAP32[$3 + 4 >> 2] = $1; //@line 2081
 HEAP32[$3 + 8 >> 2] = $2; //@line 2083
 HEAP32[$3 + 12 >> 2] = 0; //@line 2085
 HEAP32[$3 + 16 >> 2] = 0; //@line 2087
 HEAP32[$3 + 20 >> 2] = 0; //@line 2089
 HEAP32[$vararg_buffer >> 2] = 2; //@line 2091
 HEAP32[$vararg_buffer + 4 >> 2] = $3; //@line 2093
 $12 = ___syscall_ret(___syscall102(102, $vararg_buffer | 0) | 0) | 0; //@line 2095
 STACKTOP = sp; //@line 2096
 return $12 | 0; //@line 2096
}
function __Z12op_4a20_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 51544
 $2 = 651040 + ($1 << 2) | 0; //@line 51545
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 51549
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 51555
 HEAP32[$2 >> 2] = $6; //@line 51556
 $14 = ($12 & 255 | 0) == 0 & 1; //@line 51559
 HEAP32[96441] = 0; //@line 51560
 HEAP32[96442] = 0; //@line 51560
 HEAP32[96443] = 0; //@line 51560
 HEAP32[96444] = 0; //@line 51560
 HEAP32[96442] = $14; //@line 51561
 HEAP32[96443] = $12 >>> 7 & 1; //@line 51564
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51567
 return;
}
function __Z12op_d088_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $16 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 32611
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32612
 $7 = HEAP32[$6 >> 2] | 0; //@line 32613
 $8 = $7 + $5 | 0; //@line 32614
 $$lobit35 = $8 >>> 31; //@line 32617
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 32620
 HEAP32[96444] = ($$lobit35 ^ $5 >>> 31) & ($$lobit35 ^ $7 >>> 31); //@line 32624
 $16 = $5 >>> 0 > ~$7 >>> 0 & 1; //@line 32627
 HEAP32[96441] = $16; //@line 32628
 HEAP32[96445] = $16; //@line 32629
 HEAP32[96443] = $$lobit35; //@line 32630
 HEAP32[$6 >> 2] = $8; //@line 32631
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32634
 return;
}
function __Z12op_d080_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $16 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 32576
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 32577
 $7 = HEAP32[$6 >> 2] | 0; //@line 32578
 $8 = $7 + $5 | 0; //@line 32579
 $$lobit35 = $8 >>> 31; //@line 32582
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 32585
 HEAP32[96444] = ($$lobit35 ^ $5 >>> 31) & ($$lobit35 ^ $7 >>> 31); //@line 32589
 $16 = $5 >>> 0 > ~$7 >>> 0 & 1; //@line 32592
 HEAP32[96441] = $16; //@line 32593
 HEAP32[96445] = $16; //@line 32594
 HEAP32[96443] = $$lobit35; //@line 32595
 HEAP32[$6 >> 2] = $8; //@line 32596
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 32599
 return;
}
function __Z12op_303c_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $3 = 0, $6 = 0;
 $2 = $0 >>> 9 & 7; //@line 35322
 $3 = HEAP32[162769] | 0; //@line 35323
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 35326
 $12 = ($6 << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 35333
 $14 = ($12 | 0) == 0 & 1; //@line 35335
 HEAP32[96441] = 0; //@line 35336
 HEAP32[96442] = 0; //@line 35336
 HEAP32[96443] = 0; //@line 35336
 HEAP32[96444] = 0; //@line 35336
 HEAP32[96442] = $14; //@line 35337
 HEAP32[96443] = $6 >>> 7; //@line 35339
 $16 = 651008 + ($2 << 2) | 0; //@line 35340
 HEAP32[$16 >> 2] = HEAP32[$16 >> 2] & -65536 | $12 & 65535; //@line 35345
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35348
 return;
}
function __Z12op_b048_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0, $8 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 24500
 $7 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24502
 $8 = $7 - $5 | 0; //@line 24503
 $sext$lobit = $7 >>> 15 & 1; //@line 24507
 $sext33$lobit = $8 >>> 15 & 1; //@line 24509
 HEAP32[96442] = ($8 & 65535 | 0) == 0 & 1; //@line 24513
 HEAP32[96444] = ($5 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext33$lobit | 0) != ($sext$lobit | 0) & 1; //@line 24518
 HEAP32[96441] = ($5 & 65535) >>> 0 > ($7 & 65535) >>> 0 & 1; //@line 24523
 HEAP32[96443] = $sext33$lobit; //@line 24524
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 24527
 return;
}
function __Z12op_b040_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0, $8 = 0, $sext$lobit = 0, $sext33$lobit = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 22370
 $7 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 22372
 $8 = $7 - $5 | 0; //@line 22373
 $sext$lobit = $7 >>> 15 & 1; //@line 22377
 $sext33$lobit = $8 >>> 15 & 1; //@line 22379
 HEAP32[96442] = ($8 & 65535 | 0) == 0 & 1; //@line 22383
 HEAP32[96444] = ($5 >>> 15 & 1 | 0) != ($sext$lobit | 0) & ($sext33$lobit | 0) != ($sext$lobit | 0) & 1; //@line 22388
 HEAP32[96441] = ($5 & 65535) >>> 0 > ($7 & 65535) >>> 0 & 1; //@line 22393
 HEAP32[96443] = $sext33$lobit; //@line 22394
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 22397
 return;
}
function __Z12op_4eb8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $18 = 0, $29 = 0;
 $1 = HEAP32[162769] | 0; //@line 798
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 808
 $16 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) | 0; //@line 814
 $18 = (HEAP32[162767] | 0) + -4 | 0; //@line 816
 HEAP32[162767] = $18; //@line 817
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $16); //@line 823
 $29 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($10) | 0; //@line 829
 HEAP32[162770] = $29; //@line 830
 HEAP32[162769] = $29; //@line 831
 HEAP32[162768] = $10; //@line 832
 return;
}
function __Z12op_4080_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit29 = 0, $10 = 0, $2 = 0, $3 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 40840
 $3 = HEAP32[$2 >> 2] | 0; //@line 40841
 $6 = (((HEAP32[96445] | 0) != 0) << 31 >> 31) - $3 | 0; //@line 40845
 $$lobit = $3 >>> 31; //@line 40846
 $$lobit29 = $6 >>> 31; //@line 40847
 HEAP32[96444] = $$lobit29 & $$lobit; //@line 40849
 $10 = $$lobit29 & ~$$lobit ^ $$lobit; //@line 40852
 HEAP32[96441] = $10; //@line 40853
 HEAP32[96445] = $10; //@line 40854
 HEAP32[96442] = ($6 | 0) == 0 & HEAP32[96442]; //@line 40859
 HEAP32[96443] = $$lobit29; //@line 40860
 HEAP32[$2 >> 2] = $6; //@line 40861
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40864
 return;
}
function __Z11op_1b8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7730
 $5 = HEAP32[162769] | 0; //@line 7731
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 7741
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 7743
 $21 = $4 & 7; //@line 7748
 $22 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 7750
 HEAP32[96442] = $22 >>> $21 & 1 ^ 1; //@line 7754
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, ($22 & (1 << $21 ^ 255)) << 24 >> 24); //@line 7763
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7766
 return;
}
function __Z11op_878_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $23 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14381
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14383
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 14393
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 14395
 $20 = $3 & 7; //@line 14401
 $21 = 1 << $20; //@line 14402
 $23 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0) ^ $21) << 24 >> 24; //@line 14405
 HEAP32[96442] = ($23 & $21) >>> $20; //@line 14408
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, $23); //@line 14412
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14415
 return;
}
function __Z12op_d0fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 33456
 $4 = $3 + 2 | 0; //@line 33457
 HEAP32[162769] = $4; //@line 33458
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 33463
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 33470
 HEAP32[162769] = $3 + 4; //@line 33472
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 33473
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 33479
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33480
 HEAP32[$24 >> 2] = ($23 << 16 >> 16) + (HEAP32[$24 >> 2] | 0); //@line 33485
 return;
}
function __Z12op_90fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 19834
 $4 = $3 + 2 | 0; //@line 19835
 HEAP32[162769] = $4; //@line 19836
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 19841
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 19848
 HEAP32[162769] = $3 + 4; //@line 19850
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 19851
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 19857
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19858
 HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) - ($23 << 16 >> 16); //@line 19863
 return;
}
function __Z12op_c090_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28860
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28865
 $11 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28866
 $13 = HEAP32[$11 >> 2] & $10; //@line 28868
 $15 = ($13 | 0) == 0 & 1; //@line 28870
 HEAP32[96441] = 0; //@line 28871
 HEAP32[96442] = 0; //@line 28871
 HEAP32[96443] = 0; //@line 28871
 HEAP32[96444] = 0; //@line 28871
 HEAP32[96442] = $15; //@line 28872
 HEAP32[96443] = $13 >>> 31; //@line 28874
 HEAP32[$11 >> 2] = $13; //@line 28875
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28878
 return;
}
function __Z12op_8090_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $13 = 0, $15 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14537
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 14542
 $11 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14543
 $13 = HEAP32[$11 >> 2] | $10; //@line 14545
 $15 = ($13 | 0) == 0 & 1; //@line 14547
 HEAP32[96441] = 0; //@line 14548
 HEAP32[96442] = 0; //@line 14548
 HEAP32[96443] = 0; //@line 14548
 HEAP32[96444] = 0; //@line 14548
 HEAP32[96442] = $15; //@line 14549
 HEAP32[96443] = $13 >>> 31; //@line 14551
 HEAP32[$11 >> 2] = $13; //@line 14552
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14555
 return;
}
function __Z12op_4a79_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 52062
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 52071
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 52086
 $27 = ($25 & 65535 | 0) == 0 & 1; //@line 52089
 HEAP32[96441] = 0; //@line 52090
 HEAP32[96442] = 0; //@line 52090
 HEAP32[96443] = 0; //@line 52090
 HEAP32[96444] = 0; //@line 52090
 HEAP32[96442] = $27; //@line 52091
 HEAP32[96443] = $25 >>> 15 & 1; //@line 52094
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 52097
 return;
}
function __Z12op_4690_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48900
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 48902
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[$5 >> 2] >> 2] & 127]($3) | 0; //@line 48905
 $9 = ~$8; //@line 48906
 $11 = ($8 | 0) == -1 & 1; //@line 48908
 HEAP32[96441] = 0; //@line 48909
 HEAP32[96442] = 0; //@line 48909
 HEAP32[96443] = 0; //@line 48909
 HEAP32[96444] = 0; //@line 48909
 HEAP32[96442] = $11; //@line 48910
 HEAP32[96443] = $8 >>> 31 ^ 1; //@line 48913
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 12 >> 2] & 31]($3, $9); //@line 48917
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48920
 return;
}
function __Z12op_413c_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $4 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[162769] | 0; //@line 41953
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41956
 $$cast = $4; //@line 41957
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41959
 if (($9 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41962
  __Z9Exceptionij(6, $7); //@line 41963
  return;
 }
 if (($9 | 0) > ((HEAPU8[$$cast + 2 >> 0] | 0) << 24 | (HEAPU8[$$cast + 3 >> 0] | 0) << 16 | (HEAPU8[$$cast + 4 >> 0] | 0) << 8 | (HEAPU8[$$cast + 5 >> 0] | 0) | 0)) {
  HEAP32[96443] = 0; //@line 41986
  __Z9Exceptionij(6, $7); //@line 41987
  return;
 } else {
  HEAP32[162769] = $$cast + 6; //@line 41991
  return;
 }
}
function __Z12op_4110_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $15 = 0, $17 = 0, $8 = 0;
 $8 = (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41528
 $10 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41530
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10) | 0; //@line 41535
 $17 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41537
 if (($17 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41540
  __Z9Exceptionij(6, $8); //@line 41541
  return;
 }
 if (($17 | 0) > ($15 | 0)) {
  HEAP32[96443] = 0; //@line 41546
  __Z9Exceptionij(6, $8); //@line 41547
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41552
  return;
 }
}
function __Z12op_4a68_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 51954
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 51965
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 51971
 $22 = ($20 & 65535 | 0) == 0 & 1; //@line 51974
 HEAP32[96441] = 0; //@line 51975
 HEAP32[96442] = 0; //@line 51975
 HEAP32[96443] = 0; //@line 51975
 HEAP32[96444] = 0; //@line 51975
 HEAP32[96442] = $22; //@line 51976
 HEAP32[96443] = $20 >>> 15 & 1; //@line 51979
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 51982
 return;
}
function __Z12op_44fb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 48197
 $2 = $1 + 2 | 0; //@line 48198
 HEAP32[162769] = $2; //@line 48199
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 48204
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48211
 HEAP32[162769] = $1 + 4; //@line 48213
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 48214
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 48220
 __Z6MakeSRv(); //@line 48221
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $21 & 255; //@line 48228
 __Z10MakeFromSRv(); //@line 48229
 return;
}
function __ZN8tinyxml212XMLAttributeD0Ev($0) {
 $0 = $0 | 0;
 var $$pre$i$i$i = 0, $1 = 0, $12 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 2144; //@line 38974
 $1 = $0 + 16 | 0; //@line 38975
 $$pre$i$i$i = $0 + 20 | 0; //@line 38979
 if (HEAP32[$1 >> 2] & 512 | 0) {
  $5 = HEAP32[$$pre$i$i$i >> 2] | 0; //@line 38981
  if ($5 | 0) {
   __ZdaPv($5); //@line 38984
  }
 }
 HEAP32[$1 >> 2] = 0; //@line 38987
 HEAP32[$$pre$i$i$i >> 2] = 0; //@line 38988
 HEAP32[$0 + 24 >> 2] = 0; //@line 38990
 if (!(HEAP32[$0 + 4 >> 2] & 512)) {
  __ZdlPv($0); //@line 38996
  return;
 }
 $12 = HEAP32[$0 + 8 >> 2] | 0; //@line 39000
 if (!$12) {
  __ZdlPv($0); //@line 39003
  return;
 }
 __ZdaPv($12); //@line 39006
 __ZdlPv($0); //@line 39007
 return;
}
function __Z12op_4a39_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 51686
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 51695
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 51710
 $27 = ($25 & 255 | 0) == 0 & 1; //@line 51713
 HEAP32[96441] = 0; //@line 51714
 HEAP32[96442] = 0; //@line 51714
 HEAP32[96443] = 0; //@line 51714
 HEAP32[96444] = 0; //@line 51714
 HEAP32[96442] = $27; //@line 51715
 HEAP32[96443] = $25 >>> 7 & 1; //@line 51718
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 51721
 return;
}
function __Z12op_2108_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29635
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29636
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 29638
 HEAP32[$6 >> 2] = $8; //@line 29639
 $10 = ($5 | 0) == 0 & 1; //@line 29641
 HEAP32[96441] = 0; //@line 29642
 HEAP32[96442] = 0; //@line 29642
 HEAP32[96443] = 0; //@line 29642
 HEAP32[96444] = 0; //@line 29642
 HEAP32[96442] = $10; //@line 29643
 HEAP32[96443] = $5 >>> 31; //@line 29645
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($8, $5); //@line 29651
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29654
 return;
}
function __Z12op_2100_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 29605
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29606
 $8 = (HEAP32[$6 >> 2] | 0) + -4 | 0; //@line 29608
 HEAP32[$6 >> 2] = $8; //@line 29609
 $10 = ($5 | 0) == 0 & 1; //@line 29611
 HEAP32[96441] = 0; //@line 29612
 HEAP32[96442] = 0; //@line 29612
 HEAP32[96443] = 0; //@line 29612
 HEAP32[96444] = 0; //@line 29612
 HEAP32[96442] = $10; //@line 29613
 HEAP32[96443] = $5 >>> 31; //@line 29615
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($8 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($8, $5); //@line 29621
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29624
 return;
}
function __Z11op_1f8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8246
 $5 = HEAP32[162769] | 0; //@line 8247
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 8257
 $16 = 123608 + ($14 >>> 16 << 2) | 0; //@line 8259
 $21 = $4 & 7; //@line 8264
 $22 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$16 >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24; //@line 8266
 HEAP32[96442] = $22 >>> $21 & 1 ^ 1; //@line 8270
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$16 >> 2] | 0) + 20 >> 2] & 31]($14, ($22 | 1 << $21) << 24 >> 24); //@line 8278
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8281
 return;
}
function __Z12op_b000_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0, $8 = 0, $sext$lobit = 0, $sext29$lobit = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 21800
 $7 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 21802
 $8 = $7 - $5 | 0; //@line 21803
 $sext$lobit = $7 >>> 7 & 1; //@line 21807
 $sext29$lobit = $8 >>> 7 & 1; //@line 21809
 HEAP32[96442] = ($8 & 255 | 0) == 0 & 1; //@line 21813
 HEAP32[96444] = ($5 >>> 7 & 1 | 0) != ($sext$lobit | 0) & ($sext29$lobit | 0) != ($sext$lobit | 0) & 1; //@line 21818
 HEAP32[96441] = ($5 & 255) >>> 0 > ($7 & 255) >>> 0 & 1; //@line 21823
 HEAP32[96443] = $sext29$lobit; //@line 21824
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21827
 return;
}
function __Z12op_4a28_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $22 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 51578
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 51589
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0; //@line 51595
 $22 = ($20 & 255 | 0) == 0 & 1; //@line 51598
 HEAP32[96441] = 0; //@line 51599
 HEAP32[96442] = 0; //@line 51599
 HEAP32[96443] = 0; //@line 51599
 HEAP32[96444] = 0; //@line 51599
 HEAP32[96442] = $22; //@line 51600
 HEAP32[96443] = $20 >>> 7 & 1; //@line 51603
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 51606
 return;
}
function __Z12op_4a70_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 3052
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 3061
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 3067
 $21 = ($19 & 65535 | 0) == 0 & 1; //@line 3070
 HEAP32[96441] = 0; //@line 3071
 HEAP32[96442] = 0; //@line 3071
 HEAP32[96443] = 0; //@line 3071
 HEAP32[96444] = 0; //@line 3071
 HEAP32[96442] = $21; //@line 3072
 HEAP32[96443] = $19 >>> 15 & 1; //@line 3075
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3078
 return;
}
function _fwrite($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$ = 0, $11 = 0, $13 = 0, $15 = 0, $4 = 0, $phitmp = 0;
 $4 = Math_imul($2, $1) | 0; //@line 62732
 $$ = ($1 | 0) == 0 ? 0 : $2; //@line 62734
 if ((HEAP32[$3 + 76 >> 2] | 0) > -1) {
  $phitmp = (___lockfile($3) | 0) == 0; //@line 62740
  $11 = ___fwritex($0, $4, $3) | 0; //@line 62741
  if ($phitmp) {
   $13 = $11; //@line 62743
  } else {
   ___unlockfile($3); //@line 62745
   $13 = $11; //@line 62746
  }
 } else {
  $13 = ___fwritex($0, $4, $3) | 0; //@line 62750
 }
 if (($13 | 0) == ($4 | 0)) {
  $15 = $$; //@line 62754
 } else {
  $15 = ($13 >>> 0) / ($1 >>> 0) | 0; //@line 62757
 }
 return $15 | 0; //@line 62759
}
function __Z12op_e7d0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41875
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 41877
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 41881
 $12 = $9 >>> 15 & 1; //@line 41884
 $13 = $12 | $9 << 1; //@line 41885
 HEAP32[96444] = 0; //@line 41889
 HEAP32[96442] = ($13 & 65535) << 16 >> 16 == 0 & 1; //@line 41890
 HEAP32[96443] = $9 >>> 14 & 1; //@line 41893
 HEAP32[96441] = $12; //@line 41894
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $13 & 65535); //@line 41899
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41902
 return;
}
function __Z12op_d0f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 33300
 $5 = $4 + 2 | 0; //@line 33301
 HEAP32[162769] = $5; //@line 33302
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33304
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 33311
 HEAP32[162769] = $4 + 4; //@line 33313
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 33314
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 33320
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33321
 HEAP32[$23 >> 2] = ($22 << 16 >> 16) + (HEAP32[$23 >> 2] | 0); //@line 33326
 return;
}
function __Z12op_90f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $22 = 0, $23 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 19678
 $5 = $4 + 2 | 0; //@line 19679
 HEAP32[162769] = $5; //@line 19680
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19682
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 19689
 HEAP32[162769] = $4 + 4; //@line 19691
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 19692
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 19698
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19699
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) - ($22 << 16 >> 16); //@line 19704
 return;
}
function __Z12op_5080_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit35 = 0, $16 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0;
 $4 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 4359
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 4361
 $7 = HEAP32[$6 >> 2] | 0; //@line 4362
 $8 = $7 + $4 | 0; //@line 4363
 $$lobit35 = $8 >>> 31; //@line 4366
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 4369
 HEAP32[96444] = ($$lobit35 ^ $4 >>> 31) & ($$lobit35 ^ $7 >>> 31); //@line 4373
 $16 = $4 >>> 0 > ~$7 >>> 0 & 1; //@line 4376
 HEAP32[96441] = $16; //@line 4377
 HEAP32[96445] = $16; //@line 4378
 HEAP32[96443] = $$lobit35; //@line 4379
 HEAP32[$6 >> 2] = $8; //@line 4380
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4383
 return;
}
function __Z12op_4a30_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2975
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2984
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($13) | 0; //@line 2990
 $21 = ($19 & 255 | 0) == 0 & 1; //@line 2993
 HEAP32[96441] = 0; //@line 2994
 HEAP32[96442] = 0; //@line 2994
 HEAP32[96443] = 0; //@line 2994
 HEAP32[96444] = 0; //@line 2994
 HEAP32[96442] = $21; //@line 2995
 HEAP32[96443] = $19 >>> 7 & 1; //@line 2998
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3001
 return;
}
function __Z12op_21c8_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33639
 $4 = HEAP32[162769] | 0; //@line 33640
 $13 = ((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16; //@line 33650
 $15 = ($3 | 0) == 0 & 1; //@line 33652
 HEAP32[96441] = 0; //@line 33653
 HEAP32[96442] = 0; //@line 33653
 HEAP32[96443] = 0; //@line 33653
 HEAP32[96444] = 0; //@line 33653
 HEAP32[96442] = $15; //@line 33654
 HEAP32[96443] = $3 >>> 31; //@line 33656
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $3); //@line 33662
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33665
 return;
}
function __Z12op_21c0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $3 = 0, $4 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 33603
 $4 = HEAP32[162769] | 0; //@line 33604
 $13 = ((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16; //@line 33614
 $15 = ($3 | 0) == 0 & 1; //@line 33616
 HEAP32[96441] = 0; //@line 33617
 HEAP32[96442] = 0; //@line 33617
 HEAP32[96443] = 0; //@line 33617
 HEAP32[96444] = 0; //@line 33617
 HEAP32[96442] = $15; //@line 33618
 HEAP32[96443] = $3 >>> 31; //@line 33620
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, $3); //@line 33626
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33629
 return;
}
function __Z12op_20c8_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $6 = 0, $7 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 29125
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29126
 $7 = HEAP32[$6 >> 2] | 0; //@line 29127
 HEAP32[$6 >> 2] = $7 + 4; //@line 29129
 $10 = ($5 | 0) == 0 & 1; //@line 29131
 HEAP32[96441] = 0; //@line 29132
 HEAP32[96442] = 0; //@line 29132
 HEAP32[96443] = 0; //@line 29132
 HEAP32[96444] = 0; //@line 29132
 HEAP32[96442] = $10; //@line 29133
 HEAP32[96443] = $5 >>> 31; //@line 29135
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($7, $5); //@line 29141
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29144
 return;
}
function __Z12op_20c0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $6 = 0, $7 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 29095
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 29096
 $7 = HEAP32[$6 >> 2] | 0; //@line 29097
 HEAP32[$6 >> 2] = $7 + 4; //@line 29099
 $10 = ($5 | 0) == 0 & 1; //@line 29101
 HEAP32[96441] = 0; //@line 29102
 HEAP32[96442] = 0; //@line 29102
 HEAP32[96443] = 0; //@line 29102
 HEAP32[96444] = 0; //@line 29102
 HEAP32[96442] = $10; //@line 29103
 HEAP32[96443] = $5 >>> 31; //@line 29105
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($7, $5); //@line 29111
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29114
 return;
}
function __Z12op_5ff0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $25 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 11251
 $3 = $2 + 2 | 0; //@line 11252
 HEAP32[162769] = $3; //@line 11253
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11255
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 11262
 HEAP32[162769] = $2 + 4; //@line 11264
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 11265
 if (!(HEAP32[96442] | 0)) {
  $25 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11273
 } else {
  $25 = 255; //@line 11275
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, $25); //@line 11282
 return;
}
function __Z11op_8b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14820
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14822
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 14832
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 14834
 $20 = $3 & 7; //@line 14840
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0) << 24 >> 24; //@line 14842
 HEAP32[96442] = $21 >>> $20 & 1 ^ 1; //@line 14846
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, ($21 & (1 << $20 ^ 255)) << 24 >> 24); //@line 14855
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14858
 return;
}
function __Z12op_e2d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40277
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40279
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40283
 $10 = $9 & 1; //@line 40284
 $12 = $9 >>> 1 & 32767; //@line 40286
 HEAP32[96444] = 0; //@line 40289
 HEAP32[96442] = ($12 | 0) == 0 & 1; //@line 40290
 HEAP32[96443] = 0; //@line 40291
 HEAP32[96441] = $10; //@line 40292
 HEAP32[96445] = $10; //@line 40293
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $12); //@line 40297
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40300
 return;
}
function __Z12op_44f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 48037
 $3 = $2 + 2 | 0; //@line 48038
 HEAP32[162769] = $3; //@line 48039
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 48041
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 48048
 HEAP32[162769] = $2 + 4; //@line 48050
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 48051
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 48057
 __Z6MakeSRv(); //@line 48058
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $20 & 255; //@line 48065
 __Z10MakeFromSRv(); //@line 48066
 return;
}
function __Z12op_c0bc_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $24 = 0, $26 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29206
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29225
 $24 = ((HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) & HEAP32[$22 >> 2]; //@line 29227
 $26 = ($24 | 0) == 0 & 1; //@line 29229
 HEAP32[96441] = 0; //@line 29230
 HEAP32[96442] = 0; //@line 29230
 HEAP32[96443] = 0; //@line 29230
 HEAP32[96444] = 0; //@line 29230
 HEAP32[96442] = $26; //@line 29231
 HEAP32[96443] = $24 >>> 31; //@line 29233
 HEAP32[$22 >> 2] = $24; //@line 29234
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 29237
 return;
}
function __Z12op_5ef0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $25 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 10836
 $3 = $2 + 2 | 0; //@line 10837
 HEAP32[162769] = $3; //@line 10838
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10840
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10847
 HEAP32[162769] = $2 + 4; //@line 10849
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 10850
 if (!(HEAP32[96442] | 0)) {
  $25 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10858
 } else {
  $25 = 0; //@line 10860
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, $25); //@line 10867
 return;
}
function _fmt_x($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$05$lcssa = 0, $$056 = 0, $14 = 0, $15 = 0, $8 = 0;
 if (($0 | 0) == 0 & ($1 | 0) == 0) {
  $$05$lcssa = $2; //@line 57518
 } else {
  $$056 = $2; //@line 57520
  $15 = $1; //@line 57520
  $8 = $0; //@line 57520
  while (1) {
   $14 = $$056 + -1 | 0; //@line 57528
   HEAP8[$14 >> 0] = HEAPU8[110574 + ($8 & 15) >> 0] | 0 | $3; //@line 57529
   $8 = _bitshift64Lshr($8 | 0, $15 | 0, 4) | 0; //@line 57530
   $15 = tempRet0; //@line 57531
   if (($8 | 0) == 0 & ($15 | 0) == 0) {
    $$05$lcssa = $14; //@line 57536
    break;
   } else {
    $$056 = $14; //@line 57539
   }
  }
 }
 return $$05$lcssa | 0; //@line 57543
}
function __Z12op_80bc_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $24 = 0, $26 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 14883
 $22 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14902
 $24 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0) | HEAP32[$22 >> 2]; //@line 14904
 $26 = ($24 | 0) == 0 & 1; //@line 14906
 HEAP32[96441] = 0; //@line 14907
 HEAP32[96442] = 0; //@line 14907
 HEAP32[96443] = 0; //@line 14907
 HEAP32[96444] = 0; //@line 14907
 HEAP32[96442] = $26; //@line 14908
 HEAP32[96443] = $24 >>> 31; //@line 14910
 HEAP32[$22 >> 2] = $24; //@line 14911
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14914
 return;
}
function __Z12op_46fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $3 = 0, $4 = 0, $8 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49479
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 49482
  $4 = $3 + 2 | 0; //@line 49483
  HEAP32[162769] = $4; //@line 49484
  $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 49489
  $15 = HEAPU8[$4 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]; //@line 49496
  HEAP32[162769] = $3 + 4; //@line 49498
  $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 49499
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 49507
  __Z10MakeFromSRv(); //@line 49508
  return;
 }
}
function __Z12op_203c_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $21 = 0, $23 = 0, $3 = 0, $6 = 0;
 $2 = $0 >>> 9 & 7; //@line 28231
 $3 = HEAP32[162769] | 0; //@line 28232
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 28235
 $21 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | $6 << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 28250
 $23 = ($21 | 0) == 0 & 1; //@line 28252
 HEAP32[96441] = 0; //@line 28253
 HEAP32[96442] = 0; //@line 28253
 HEAP32[96443] = 0; //@line 28253
 HEAP32[96444] = 0; //@line 28253
 HEAP32[96442] = $23; //@line 28254
 HEAP32[96443] = $6 >>> 7; //@line 28256
 HEAP32[651008 + ($2 << 2) >> 2] = $21; //@line 28258
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28261
 return;
}
function _opendir($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $3 = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 59431
 STACKTOP = STACKTOP + 16 | 0; //@line 59432
 $vararg_buffer1 = sp + 8 | 0; //@line 59433
 $1 = _open($0, 589824, sp) | 0; //@line 59435
 do {
  if (($1 | 0) < 0) {
   $$0 = 0; //@line 59439
  } else {
   $3 = _calloc(1, 2072) | 0; //@line 59441
   if (!$3) {
    HEAP32[$vararg_buffer1 >> 2] = $1; //@line 59444
    ___syscall6(6, $vararg_buffer1 | 0) | 0; //@line 59445
    $$0 = 0; //@line 59446
    break;
   } else {
    HEAP32[$3 >> 2] = $1; //@line 59449
    $$0 = $3; //@line 59450
    break;
   }
  }
 } while (0);
 STACKTOP = sp; //@line 59455
 return $$0 | 0; //@line 59455
}
function __Z12op_b0c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25642
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25644
 $8 = $5 << 16 >> 16; //@line 25646
 $9 = $7 - $8 | 0; //@line 25647
 $$lobit = $7 >>> 31; //@line 25650
 $$lobit32 = $9 >>> 31; //@line 25651
 HEAP32[96442] = ($9 | 0) == 0 & 1; //@line 25654
 HEAP32[96444] = ($5 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit32 | 0) != ($$lobit | 0) & 1; //@line 25659
 HEAP32[96441] = $7 >>> 0 < $8 >>> 0 & 1; //@line 25662
 HEAP32[96443] = $$lobit32; //@line 25663
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25666
 return;
}
function __Z12op_b0c0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit = 0, $$lobit32 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 25606
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25608
 $8 = $5 << 16 >> 16; //@line 25610
 $9 = $7 - $8 | 0; //@line 25611
 $$lobit = $7 >>> 31; //@line 25614
 $$lobit32 = $9 >>> 31; //@line 25615
 HEAP32[96442] = ($9 | 0) == 0 & 1; //@line 25618
 HEAP32[96444] = ($5 >>> 15 & 1 | 0) != ($$lobit | 0) & ($$lobit32 | 0) != ($$lobit | 0) & 1; //@line 25623
 HEAP32[96441] = $7 >>> 0 < $8 >>> 0 & 1; //@line 25626
 HEAP32[96443] = $$lobit32; //@line 25627
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25630
 return;
}
function __Z12op_4c7a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $25 = 0, $30 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 53593
 $2 = $1 + 2 | 0; //@line 53594
 HEAP32[162769] = $2; //@line 53595
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53600
 $14 = ((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53608
 $25 = $6 + 2 + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 53620
 $30 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($25 >>> 16 << 2) >> 2] >> 2] & 127]($25) | 0; //@line 53625
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 53628
 __Z9m68k_divljjtj($0, $30, $14, $6); //@line 53629
 return;
}
function __Z11op_8f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $14 = 0, $20 = 0, $21 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 15270
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 15272
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 15282
 $14 = 123608 + ($12 >>> 16 << 2) | 0; //@line 15284
 $20 = $3 & 7; //@line 15290
 $21 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$14 >> 2] | 0) + 8 >> 2] & 127]($12) | 0) << 24 >> 24; //@line 15292
 HEAP32[96442] = $21 >>> $20 & 1 ^ 1; //@line 15296
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$14 >> 2] | 0) + 20 >> 2] & 31]($12, ($21 | 1 << $20) << 24 >> 24); //@line 15304
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 15307
 return;
}
function __Z11op_a80_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $21 = 0, $23 = 0, $25 = 0;
 $2 = HEAP32[162769] | 0; //@line 17792
 $21 = 651008 + (($0 & 7) << 2) | 0; //@line 17811
 $23 = ((HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) ^ HEAP32[$21 >> 2]; //@line 17813
 $25 = ($23 | 0) == 0 & 1; //@line 17815
 HEAP32[96441] = 0; //@line 17816
 HEAP32[96442] = 0; //@line 17816
 HEAP32[96443] = 0; //@line 17816
 HEAP32[96444] = 0; //@line 17816
 HEAP32[96442] = $25; //@line 17817
 HEAP32[96443] = $23 >>> 31; //@line 17819
 HEAP32[$21 >> 2] = $23; //@line 17820
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17823
 return;
}
function __Z12op_d1fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 37299
 $4 = $3 + 2 | 0; //@line 37300
 HEAP32[162769] = $4; //@line 37301
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 37306
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 37313
 HEAP32[162769] = $3 + 4; //@line 37315
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 37316
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 37321
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37322
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + $22; //@line 37325
 return;
}
function __Z12op_91fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 21727
 $4 = $3 + 2 | 0; //@line 21728
 HEAP32[162769] = $4; //@line 21729
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 21734
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 21741
 HEAP32[162769] = $3 + 4; //@line 21743
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 21744
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 21749
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21750
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) - $22; //@line 21753
 return;
}
function __Z12op_4ab9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $24 = 0, $26 = 0;
 $1 = HEAP32[162769] | 0; //@line 52421
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 52430
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 52444
 $26 = ($24 | 0) == 0 & 1; //@line 52446
 HEAP32[96441] = 0; //@line 52447
 HEAP32[96442] = 0; //@line 52447
 HEAP32[96443] = 0; //@line 52447
 HEAP32[96444] = 0; //@line 52447
 HEAP32[96442] = $26; //@line 52448
 HEAP32[96443] = $24 >>> 31; //@line 52450
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 52453
 return;
}
function __Z12op_e3d0_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $3 = 0, $5 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 40559
 $5 = 123608 + ($3 >>> 16 << 2) | 0; //@line 40561
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 40565
 HEAP32[96444] = 0; //@line 40570
 HEAP32[96442] = ($9 & 32767 | 0) == 0 & 1; //@line 40571
 HEAP32[96443] = $9 >>> 14 & 1; //@line 40574
 $15 = $9 >>> 15 & 1; //@line 40576
 HEAP32[96441] = $15; //@line 40577
 HEAP32[96445] = $15; //@line 40578
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$5 >> 2] | 0) + 16 >> 2] & 31]($3, $9 << 1 & 65534); //@line 40583
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 40586
 return;
}
function _lseek($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $3 = 0, $7 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 59583
 STACKTOP = STACKTOP + 32 | 0; //@line 59584
 $vararg_buffer = sp; //@line 59585
 $3 = sp + 20 | 0; //@line 59586
 HEAP32[$vararg_buffer >> 2] = $0; //@line 59588
 HEAP32[$vararg_buffer + 4 >> 2] = 0; //@line 59590
 HEAP32[$vararg_buffer + 8 >> 2] = $1; //@line 59592
 HEAP32[$vararg_buffer + 12 >> 2] = $3; //@line 59594
 HEAP32[$vararg_buffer + 16 >> 2] = $2; //@line 59596
 $7 = (___syscall_ret(___syscall140(140, $vararg_buffer | 0) | 0) | 0) != 0; //@line 59599
 STACKTOP = sp; //@line 59602
 return ($7 ? -1 : HEAP32[$3 >> 2] | 0) | 0; //@line 59602
}
function __Z12op_4aa8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $19 = 0, $21 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 52322
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 52333
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 52338
 $21 = ($19 | 0) == 0 & 1; //@line 52340
 HEAP32[96441] = 0; //@line 52341
 HEAP32[96442] = 0; //@line 52341
 HEAP32[96443] = 0; //@line 52341
 HEAP32[96444] = 0; //@line 52341
 HEAP32[96442] = $21; //@line 52342
 HEAP32[96443] = $19 >>> 31; //@line 52344
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52347
 return;
}
function ___stdout_write($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $14 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 54834
 STACKTOP = STACKTOP + 32 | 0; //@line 54835
 $vararg_buffer = sp; //@line 54836
 HEAP32[$0 + 36 >> 2] = 9; //@line 54839
 if (!(HEAP32[$0 >> 2] & 64)) {
  HEAP32[$vararg_buffer >> 2] = HEAP32[$0 + 60 >> 2]; //@line 54847
  HEAP32[$vararg_buffer + 4 >> 2] = 21523; //@line 54849
  HEAP32[$vararg_buffer + 8 >> 2] = sp + 16; //@line 54851
  if (___syscall54(54, $vararg_buffer | 0) | 0) {
   HEAP8[$0 + 75 >> 0] = -1; //@line 54856
  }
 }
 $14 = ___stdio_write($0, $1, $2) | 0; //@line 54859
 STACKTOP = sp; //@line 54860
 return $14 | 0; //@line 54860
}
function __Z12op_10bc_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 24290
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 24292
 $8 = $5 << 24 >> 24; //@line 24293
 $10 = $5 << 24 >> 24 == 0 & 1; //@line 24295
 HEAP32[96441] = 0; //@line 24296
 HEAP32[96442] = 0; //@line 24296
 HEAP32[96443] = 0; //@line 24296
 HEAP32[96444] = 0; //@line 24296
 HEAP32[96442] = $10; //@line 24297
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 24300
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($7, $8); //@line 24306
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24309
 return;
}
function __Z12op_46f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $4 = 0, $5 = 0, $7 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49314
  return;
 } else {
  $4 = HEAP32[162769] | 0; //@line 49318
  $5 = $4 + 2 | 0; //@line 49319
  HEAP32[162769] = $5; //@line 49320
  $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49322
  $14 = HEAPU8[$5 >> 0] << 8 | HEAPU8[$4 + 3 >> 0]; //@line 49329
  HEAP32[162769] = $4 + 4; //@line 49331
  $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 49332
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 49340
  __Z10MakeFromSRv(); //@line 49341
  return;
 }
}
function __Z12op_c040_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1819 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28358
 $7 = HEAP32[$6 >> 2] | 0; //@line 28359
 $sext1819 = $7 & HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 28360
 $8 = $sext1819 << 16 >> 16; //@line 28362
 $10 = ($8 | 0) == 0 & 1; //@line 28364
 HEAP32[96441] = 0; //@line 28365
 HEAP32[96442] = 0; //@line 28365
 HEAP32[96443] = 0; //@line 28365
 HEAP32[96444] = 0; //@line 28365
 HEAP32[96442] = $10; //@line 28366
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 28369
 HEAP32[$6 >> 2] = $8 & 65535 | $7 & -65536; //@line 28373
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28376
 return;
}
function __Z12op_b140_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1819 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 26588
 $7 = HEAP32[$6 >> 2] | 0; //@line 26589
 $sext1819 = $7 ^ HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2]; //@line 26590
 $8 = $sext1819 << 16 >> 16; //@line 26592
 $10 = ($8 | 0) == 0 & 1; //@line 26594
 HEAP32[96441] = 0; //@line 26595
 HEAP32[96442] = 0; //@line 26595
 HEAP32[96443] = 0; //@line 26595
 HEAP32[96444] = 0; //@line 26595
 HEAP32[96442] = $10; //@line 26596
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 26599
 HEAP32[$6 >> 2] = $8 & 65535 | $7 & -65536; //@line 26603
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26606
 return;
}
function __Z12op_8040_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1819 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14034
 $7 = HEAP32[$6 >> 2] | 0; //@line 14035
 $sext1819 = $7 | HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 14036
 $8 = $sext1819 << 16 >> 16; //@line 14038
 $10 = ($8 | 0) == 0 & 1; //@line 14040
 HEAP32[96441] = 0; //@line 14041
 HEAP32[96442] = 0; //@line 14041
 HEAP32[96443] = 0; //@line 14041
 HEAP32[96444] = 0; //@line 14041
 HEAP32[96442] = $10; //@line 14042
 HEAP32[96443] = $sext1819 >>> 15 & 1; //@line 14045
 HEAP32[$6 >> 2] = $8 & 65535 | $7 & -65536; //@line 14049
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14052
 return;
}
function __Z12op_4ab0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $18 = 0, $20 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 3129
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 3138
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 3143
 $20 = ($18 | 0) == 0 & 1; //@line 3145
 HEAP32[96441] = 0; //@line 3146
 HEAP32[96442] = 0; //@line 3146
 HEAP32[96443] = 0; //@line 3146
 HEAP32[96444] = 0; //@line 3146
 HEAP32[96442] = $20; //@line 3147
 HEAP32[96443] = $18 >>> 31; //@line 3149
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 3152
 return;
}
function __Z12op_40f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $4 = 0, $5 = 0, $7 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41369
  return;
 } else {
  $4 = HEAP32[162769] | 0; //@line 41373
  $5 = $4 + 2 | 0; //@line 41374
  HEAP32[162769] = $5; //@line 41375
  $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41377
  $14 = HEAPU8[$5 >> 0] << 8 | HEAPU8[$4 + 3 >> 0]; //@line 41384
  HEAP32[162769] = $4 + 4; //@line 41386
  $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 41387
  __Z6MakeSRv(); //@line 41388
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($16, HEAPU16[325558] | 0); //@line 41396
  return;
 }
}
function __Z11ether_writej($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $7 = 0;
 $1 = $0 + 2 | 0; //@line 47131
 $7 = (FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1 >>> 16 << 2) >> 2] >> 2] & 127]($1) | 0) + 6 | 0; //@line 47137
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($7) | 0; //@line 47143
 HEAP8[$13 >> 0] = HEAP8[657344] | 0; //@line 47144
 HEAP8[$13 + 1 >> 0] = HEAP8[657345] | 0; //@line 47144
 HEAP8[$13 + 2 >> 0] = HEAP8[657346] | 0; //@line 47144
 HEAP8[$13 + 3 >> 0] = HEAP8[657347] | 0; //@line 47144
 HEAP8[$13 + 4 >> 0] = HEAP8[657348] | 0; //@line 47144
 HEAP8[$13 + 5 >> 0] = HEAP8[657349] | 0; //@line 47144
 return 0; //@line 47145
}
function __Z12op_4c3b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $11 = 0, $15 = 0, $22 = 0, $24 = 0;
 $1 = HEAP32[162769] | 0; //@line 53193
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53202
 $11 = $1 + 4 | 0; //@line 53203
 HEAP32[162769] = $11; //@line 53204
 $15 = (HEAP32[162768] | 0) + $11 - (HEAP32[162770] | 0) | 0; //@line 53209
 $22 = (HEAPU8[$11 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 53216
 HEAP32[162769] = $1 + 6; //@line 53218
 $24 = __Z15get_disp_ea_020jj($15, $22) | 0; //@line 53219
 __Z9m68k_mulljjt($0, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($24 >>> 16 << 2) >> 2] >> 2] & 127]($24) | 0, $10); //@line 53225
 return;
}
function __Z12op_d1f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 37155
 $5 = $4 + 2 | 0; //@line 37156
 HEAP32[162769] = $5; //@line 37157
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 37159
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 37166
 HEAP32[162769] = $4 + 4; //@line 37168
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 37169
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 37174
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37175
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + $21; //@line 37178
 return;
}
function __Z12op_c000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1415 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 27879
 $7 = HEAP32[$6 >> 2] | 0; //@line 27880
 $sext1415 = $7 & HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 27881
 $8 = $sext1415 << 24 >> 24; //@line 27883
 $10 = ($8 | 0) == 0 & 1; //@line 27885
 HEAP32[96441] = 0; //@line 27886
 HEAP32[96442] = 0; //@line 27886
 HEAP32[96443] = 0; //@line 27886
 HEAP32[96444] = 0; //@line 27886
 HEAP32[96442] = $10; //@line 27887
 HEAP32[96443] = $sext1415 >>> 7 & 1; //@line 27890
 HEAP32[$6 >> 2] = $8 & 255 | $7 & -256; //@line 27894
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27897
 return;
}
function __Z12op_b100_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1415 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 26180
 $7 = HEAP32[$6 >> 2] | 0; //@line 26181
 $sext1415 = $7 ^ HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2]; //@line 26182
 $8 = $sext1415 << 24 >> 24; //@line 26184
 $10 = ($8 | 0) == 0 & 1; //@line 26186
 HEAP32[96441] = 0; //@line 26187
 HEAP32[96442] = 0; //@line 26187
 HEAP32[96443] = 0; //@line 26187
 HEAP32[96444] = 0; //@line 26187
 HEAP32[96442] = $10; //@line 26188
 HEAP32[96443] = $sext1415 >>> 7 & 1; //@line 26191
 HEAP32[$6 >> 2] = $8 & 255 | $7 & -256; //@line 26195
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26198
 return;
}
function __Z12op_91f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 21583
 $5 = $4 + 2 | 0; //@line 21584
 HEAP32[162769] = $5; //@line 21585
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21587
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 21594
 HEAP32[162769] = $4 + 4; //@line 21596
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 21597
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 21602
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21603
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) - $21; //@line 21606
 return;
}
function __Z12op_8000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $7 = 0, $8 = 0, $sext1415 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 13554
 $7 = HEAP32[$6 >> 2] | 0; //@line 13555
 $sext1415 = $7 | HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 13556
 $8 = $sext1415 << 24 >> 24; //@line 13558
 $10 = ($8 | 0) == 0 & 1; //@line 13560
 HEAP32[96441] = 0; //@line 13561
 HEAP32[96442] = 0; //@line 13561
 HEAP32[96443] = 0; //@line 13561
 HEAP32[96444] = 0; //@line 13561
 HEAP32[96442] = $10; //@line 13562
 HEAP32[96443] = $sext1415 >>> 7 & 1; //@line 13565
 HEAP32[$6 >> 2] = $8 & 255 | $7 & -256; //@line 13569
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13572
 return;
}
function __Z11op_280_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $21 = 0, $23 = 0, $25 = 0;
 $2 = HEAP32[162769] | 0; //@line 9207
 $21 = 651008 + (($0 & 7) << 2) | 0; //@line 9226
 $23 = ((HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) & HEAP32[$21 >> 2]; //@line 9228
 $25 = ($23 | 0) == 0 & 1; //@line 9230
 HEAP32[96441] = 0; //@line 9231
 HEAP32[96442] = 0; //@line 9231
 HEAP32[96443] = 0; //@line 9231
 HEAP32[96444] = 0; //@line 9231
 HEAP32[96442] = $25; //@line 9232
 HEAP32[96443] = $23 >>> 31; //@line 9234
 HEAP32[$21 >> 2] = $23; //@line 9235
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9238
 return;
}
function __Z11op_188_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $26 = 0, $8 = 0, $sext15 = 0;
 $8 = HEAP32[162769] | 0; //@line 7462
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7473
 $sext15 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 7474
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($18, $sext15 >> 24); //@line 7482
 $26 = $18 + 2 | 0; //@line 7483
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($26 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($26, $sext15 >> 16); //@line 7489
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7492
 return;
}
function __Z12op_4e74_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $25 = 0, $6 = 0, $8 = 0, $9 = 0;
 $1 = HEAP32[162767] | 0; //@line 483
 $6 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1 >>> 16 << 2) >> 2] >> 2] & 127]($1) | 0; //@line 488
 $8 = (HEAP32[162767] | 0) + 4 | 0; //@line 490
 HEAP32[162767] = $8; //@line 491
 $9 = HEAP32[162769] | 0; //@line 492
 HEAP32[162767] = (((HEAPU8[$9 + 2 >> 0] | 0) << 8 | (HEAPU8[$9 + 3 >> 0] | 0)) << 16 >> 16) + $8; //@line 504
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($6) | 0; //@line 510
 HEAP32[162770] = $25; //@line 511
 HEAP32[162769] = $25; //@line 512
 HEAP32[162768] = $6; //@line 513
 return;
}
function __Z12op_4c78_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $23 = 0, $28 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 53500
 $2 = $1 + 2 | 0; //@line 53501
 HEAP32[162769] = $2; //@line 53502
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53507
 $14 = ((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53515
 $23 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 53525
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($23 >>> 16 << 2) >> 2] >> 2] & 127]($23) | 0; //@line 53530
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 53533
 __Z9m68k_divljjtj($0, $28, $14, $6); //@line 53534
 return;
}
function ___towrite($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $14 = 0, $3 = 0, $7 = 0;
 $1 = $0 + 74 | 0; //@line 59253
 $3 = HEAP8[$1 >> 0] | 0; //@line 59255
 HEAP8[$1 >> 0] = $3 + 255 | $3; //@line 59259
 $7 = HEAP32[$0 >> 2] | 0; //@line 59260
 if (!($7 & 8)) {
  HEAP32[$0 + 8 >> 2] = 0; //@line 59265
  HEAP32[$0 + 4 >> 2] = 0; //@line 59267
  $14 = HEAP32[$0 + 44 >> 2] | 0; //@line 59269
  HEAP32[$0 + 28 >> 2] = $14; //@line 59271
  HEAP32[$0 + 20 >> 2] = $14; //@line 59273
  HEAP32[$0 + 16 >> 2] = $14 + (HEAP32[$0 + 48 >> 2] | 0); //@line 59278
  $$0 = 0; //@line 59279
 } else {
  HEAP32[$0 >> 2] = $7 | 32; //@line 59282
  $$0 = -1; //@line 59283
 }
 return $$0 | 0; //@line 59285
}
function __Z11op_13b_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $17 = 0, $19 = 0, $4 = 0, $5 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6885
 $5 = HEAP32[162769] | 0; //@line 6886
 $6 = $5 + 2 | 0; //@line 6887
 HEAP32[162769] = $6; //@line 6888
 $10 = $6 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 6893
 $17 = (HEAPU8[$6 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0); //@line 6900
 HEAP32[162769] = $5 + 4; //@line 6902
 $19 = __Z15get_disp_ea_020jj($10, $17) | 0; //@line 6903
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 6916
 return;
}
function __Z10op_80_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $21 = 0, $23 = 0, $25 = 0;
 $2 = HEAP32[162769] | 0; //@line 5473
 $21 = 651008 + (($0 & 7) << 2) | 0; //@line 5492
 $23 = (HEAPU8[$2 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 + 2 >> 0] | 0) << 24 | (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0) | HEAP32[$21 >> 2]; //@line 5494
 $25 = ($23 | 0) == 0 & 1; //@line 5496
 HEAP32[96441] = 0; //@line 5497
 HEAP32[96442] = 0; //@line 5497
 HEAP32[96443] = 0; //@line 5497
 HEAP32[96444] = 0; //@line 5497
 HEAP32[96442] = $25; //@line 5498
 HEAP32[96443] = $23 >>> 31; //@line 5500
 HEAP32[$21 >> 2] = $23; //@line 5501
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 5504
 return;
}
function __Z7SCSICmdiPh($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0;
 L1 : do {
  if ((HEAP32[28496] | 0) == 2) {
   switch ($0 | 0) {
   case 6:
   case 10:
   case 12:
    {
     break;
    }
   default:
    {
     $$0 = 4; //@line 22857
     break L1;
    }
   }
   if (__Z15scsi_set_targetii(HEAP32[28498] | 0, (HEAPU8[$1 + 1 >> 0] | 0) >>> 5) | 0) {
    HEAP32[28496] = 3; //@line 22868
    HEAP16[325962] = 110; //@line 22869
    $$0 = 0; //@line 22870
    break;
   } else {
    HEAP32[28496] = 0; //@line 22873
    HEAP16[325962] = 0; //@line 22874
    $$0 = 2; //@line 22875
    break;
   }
  } else {
   $$0 = 5; //@line 22879
  }
 } while (0);
 return $$0 | 0; //@line 22882
}
function __Z12op_3088_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35752
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35754
 $8 = $5 << 16 >> 16; //@line 35756
 $10 = ($8 | 0) == 0 & 1; //@line 35758
 HEAP32[96441] = 0; //@line 35759
 HEAP32[96442] = 0; //@line 35759
 HEAP32[96443] = 0; //@line 35759
 HEAP32[96444] = 0; //@line 35759
 HEAP32[96442] = $10; //@line 35760
 HEAP32[96443] = $5 >>> 15 & 1; //@line 35763
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($7, $8); //@line 35769
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35772
 return;
}
function __Z12op_3080_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 35720
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 35722
 $8 = $5 << 16 >> 16; //@line 35724
 $10 = ($8 | 0) == 0 & 1; //@line 35726
 HEAP32[96441] = 0; //@line 35727
 HEAP32[96442] = 0; //@line 35727
 HEAP32[96443] = 0; //@line 35727
 HEAP32[96444] = 0; //@line 35727
 HEAP32[96442] = $10; //@line 35728
 HEAP32[96443] = $5 >>> 15 & 1; //@line 35731
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($7, $8); //@line 35737
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35740
 return;
}
function __Z12op_4efb_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $2 = 0, $21 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 1158
 $2 = $1 + 2 | 0; //@line 1159
 HEAP32[162769] = $2; //@line 1160
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 1165
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 1172
 HEAP32[162769] = $1 + 4; //@line 1174
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 1175
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($15) | 0; //@line 1181
 HEAP32[162770] = $21; //@line 1182
 HEAP32[162769] = $21; //@line 1183
 HEAP32[162768] = $15; //@line 1184
 return;
}
function __Z12op_1080_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 23832
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 23834
 $8 = $5 << 24 >> 24; //@line 23836
 $10 = ($8 | 0) == 0 & 1; //@line 23838
 HEAP32[96441] = 0; //@line 23839
 HEAP32[96442] = 0; //@line 23839
 HEAP32[96443] = 0; //@line 23839
 HEAP32[96444] = 0; //@line 23839
 HEAP32[96442] = $10; //@line 23840
 HEAP32[96443] = $5 >>> 7 & 1; //@line 23843
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($7, $8); //@line 23849
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23852
 return;
}
function __Z12op_c1fc_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $16 = 0, $18 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 31192
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 31201
 $16 = Math_imul(((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16, HEAP32[$12 >> 2] << 16 >> 16) | 0; //@line 31207
 $18 = ($16 | 0) == 0 & 1; //@line 31209
 HEAP32[96441] = 0; //@line 31210
 HEAP32[96442] = 0; //@line 31210
 HEAP32[96443] = 0; //@line 31210
 HEAP32[96444] = 0; //@line 31210
 HEAP32[96442] = $18; //@line 31211
 HEAP32[96443] = $16 >>> 31; //@line 31213
 HEAP32[$12 >> 2] = $16; //@line 31214
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 31217
 return;
}
function __Z12op_4c30_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $2 = 0, $21 = 0, $23 = 0;
 $2 = HEAP32[162769] | 0; //@line 53033
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53042
 $12 = $2 + 4 | 0; //@line 53043
 HEAP32[162769] = $12; //@line 53044
 $14 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 53046
 $21 = (HEAPU8[$12 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 53053
 HEAP32[162769] = $2 + 6; //@line 53055
 $23 = __Z15get_disp_ea_020jj($14, $21) | 0; //@line 53056
 __Z9m68k_mulljjt($0, FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($23 >>> 16 << 2) >> 2] >> 2] & 127]($23) | 0, $11); //@line 53062
 return;
}
function _remove($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $2 = 0, $5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, sp = 0;
 sp = STACKTOP; //@line 2789
 STACKTOP = STACKTOP + 16 | 0; //@line 2790
 $vararg_buffer1 = sp + 8 | 0; //@line 2791
 $vararg_buffer = sp; //@line 2792
 $1 = $0; //@line 2793
 HEAP32[$vararg_buffer >> 2] = $1; //@line 2794
 $2 = ___syscall10(10, $vararg_buffer | 0) | 0; //@line 2795
 if (($2 | 0) == -21) {
  HEAP32[$vararg_buffer1 >> 2] = $1; //@line 2798
  $$0 = ___syscall40(40, $vararg_buffer1 | 0) | 0; //@line 2800
 } else {
  $$0 = $2; //@line 2802
 }
 $5 = ___syscall_ret($$0) | 0; //@line 2804
 STACKTOP = sp; //@line 2805
 return $5 | 0; //@line 2805
}
function __Z12op_4a58_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $2 = 0, $3 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 51894
 $3 = HEAP32[$2 >> 2] | 0; //@line 51895
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 51901
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 51904
 $13 = ($9 & 65535 | 0) == 0 & 1; //@line 51907
 HEAP32[96441] = 0; //@line 51908
 HEAP32[96442] = 0; //@line 51908
 HEAP32[96443] = 0; //@line 51908
 HEAP32[96444] = 0; //@line 51908
 HEAP32[96442] = $13; //@line 51909
 HEAP32[96443] = $9 >>> 15 & 1; //@line 51912
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51915
 return;
}
function __Z11op_130_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $18 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6717
 $6 = HEAP32[162769] | 0; //@line 6718
 $7 = $6 + 2 | 0; //@line 6719
 HEAP32[162769] = $7; //@line 6720
 $9 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6722
 $16 = (HEAPU8[$7 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0); //@line 6729
 HEAP32[162769] = $6 + 4; //@line 6731
 $18 = __Z15get_disp_ea_020jj($9, $16) | 0; //@line 6732
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 6745
 return;
}
function __Z12op_4ef0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $20 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 1032
 $3 = $2 + 2 | 0; //@line 1033
 HEAP32[162769] = $3; //@line 1034
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 1036
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 1043
 HEAP32[162769] = $2 + 4; //@line 1045
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 1046
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 1052
 HEAP32[162770] = $20; //@line 1053
 HEAP32[162769] = $20; //@line 1054
 HEAP32[162768] = $14; //@line 1055
 return;
}
function __Z13SerialControljji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $13 = 0, $3 = 0, $9 = 0;
 $3 = $0 + 26 | 0; //@line 14804
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 14810
 $13 = HEAP32[113900 + ($2 >> 1 << 2) >> 2] | 0; //@line 14814
 if (!(HEAP8[$13 + 4 >> 0] | 0)) {
  $$0 = -28; //@line 14819
  return $$0 | 0; //@line 14820
 }
 if (($9 & 65535 | 0) == 27238) {
  $$0 = 0; //@line 14825
  return $$0 | 0; //@line 14826
 }
 $$0 = FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[$13 >> 2] | 0) + 20 >> 2] & 7]($13, $0, $1, $9 & 65535) | 0; //@line 14832
 return $$0 | 0; //@line 14833
}
function __Z12op_803c_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $6 = 0, $7 = 0, $9 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14002
 $7 = HEAP32[$6 >> 2] | 0; //@line 14003
 $9 = HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0 | $7; //@line 14005
 $10 = $9 << 24 >> 24; //@line 14007
 $12 = ($10 | 0) == 0 & 1; //@line 14009
 HEAP32[96441] = 0; //@line 14010
 HEAP32[96442] = 0; //@line 14010
 HEAP32[96443] = 0; //@line 14010
 HEAP32[96444] = 0; //@line 14010
 HEAP32[96442] = $12; //@line 14011
 HEAP32[96443] = $9 >>> 7 & 1; //@line 14014
 HEAP32[$6 >> 2] = $10 & 255 | $7 & -256; //@line 14018
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14021
 return;
}
function __Z12op_4a60_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 51923
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 51925
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 51931
 HEAP32[$2 >> 2] = $4; //@line 51932
 $12 = ($10 & 65535 | 0) == 0 & 1; //@line 51935
 HEAP32[96441] = 0; //@line 51936
 HEAP32[96442] = 0; //@line 51936
 HEAP32[96443] = 0; //@line 51936
 HEAP32[96444] = 0; //@line 51936
 HEAP32[96442] = $12; //@line 51937
 HEAP32[96443] = $10 >>> 15 & 1; //@line 51940
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51943
 return;
}
function __Z12op_42b9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 46541
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 46550
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 46559
 HEAP32[96441] = 0; //@line 46560
 HEAP32[96442] = 0; //@line 46560
 HEAP32[96443] = 0; //@line 46560
 HEAP32[96444] = 0; //@line 46560
 HEAP32[96442] = 1; //@line 46561
 HEAP32[96443] = 0; //@line 46562
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, 0); //@line 46568
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 46571
 return;
}
function __Z12op_4279_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 43124
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 43133
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 43142
 HEAP32[96441] = 0; //@line 43143
 HEAP32[96442] = 0; //@line 43143
 HEAP32[96443] = 0; //@line 43143
 HEAP32[96444] = 0; //@line 43143
 HEAP32[96442] = 1; //@line 43144
 HEAP32[96443] = 0; //@line 43145
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($19, 0); //@line 43151
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 43154
 return;
}
function __Z12op_4239_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 42907
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 42916
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 42925
 HEAP32[96441] = 0; //@line 42926
 HEAP32[96442] = 0; //@line 42926
 HEAP32[96443] = 0; //@line 42926
 HEAP32[96444] = 0; //@line 42926
 HEAP32[96442] = 1; //@line 42927
 HEAP32[96443] = 0; //@line 42928
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($19, 0); //@line 42934
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42937
 return;
}
function __Z12op_4a78_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 52027
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 52037
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 52043
 $18 = ($16 & 65535 | 0) == 0 & 1; //@line 52046
 HEAP32[96441] = 0; //@line 52047
 HEAP32[96442] = 0; //@line 52047
 HEAP32[96443] = 0; //@line 52047
 HEAP32[96444] = 0; //@line 52047
 HEAP32[96442] = $18; //@line 52048
 HEAP32[96443] = $16 >>> 15 & 1; //@line 52051
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52054
 return;
}
function __Z12op_c03c_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $6 = 0, $7 = 0, $9 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28327
 $7 = HEAP32[$6 >> 2] | 0; //@line 28328
 $9 = (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0) & $7; //@line 28330
 $10 = $9 << 24 >> 24; //@line 28332
 $12 = ($10 | 0) == 0 & 1; //@line 28334
 HEAP32[96441] = 0; //@line 28335
 HEAP32[96442] = 0; //@line 28335
 HEAP32[96443] = 0; //@line 28335
 HEAP32[96444] = 0; //@line 28335
 HEAP32[96442] = $12; //@line 28336
 HEAP32[96443] = $9 >>> 7; //@line 28338
 HEAP32[$6 >> 2] = $10 & 255 | $7 & -256; //@line 28342
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28345
 return;
}
function __Z12op_41bc_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $4 = 0, $7 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 42496
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42499
 $$cast = $4; //@line 42500
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42503
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42506
  __Z9Exceptionij(6, $7); //@line 42507
  return;
 }
 if (($sext | 0) > (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42521
  __Z9Exceptionij(6, $7); //@line 42522
  return;
 } else {
  HEAP32[162769] = $$cast + 4; //@line 42526
  return;
 }
}
function __Z11op_83b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $17 = 0, $3 = 0, $4 = 0, $8 = 0;
 $1 = HEAP32[162769] | 0; //@line 14093
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14095
 $4 = $1 + 4 | 0; //@line 14096
 HEAP32[162769] = $4; //@line 14097
 $8 = (HEAP32[162768] | 0) + $4 - (HEAP32[162770] | 0) | 0; //@line 14102
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 14109
 HEAP32[162769] = $1 + 6; //@line 14111
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 14112
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24 >>> ($3 & 7) & 1 ^ 1; //@line 14126
 return;
}
function __Z9Sys_writePvS_ij($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0 = 0, $12 = 0, $6 = 0;
 if (!$0) {
  $$0 = 0; //@line 2252
  return $$0 | 0; //@line 2253
 }
 $6 = HEAP32[$0 + 24 >> 2] | 0; //@line 2256
 if ($6 | 0) {
  $$0 = FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[$6 >> 2] | 0) + 16 >> 2] & 7]($6, $1, $2, $3) | 0; //@line 2263
  return $$0 | 0; //@line 2264
 }
 $12 = $0 + 4 | 0; //@line 2266
 if ((_lseek(HEAP32[$12 >> 2] | 0, (HEAP32[$0 + 12 >> 2] | 0) + $2 | 0, 0) | 0) < 0) {
  $$0 = 0; //@line 2274
  return $$0 | 0; //@line 2275
 }
 $$0 = _write(HEAP32[$12 >> 2] | 0, $1, $3) | 0; //@line 2279
 return $$0 | 0; //@line 2280
}
function __Z14SoundInControljj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $2 = 0, $9 = 0;
 $2 = $0 + 26 | 0; //@line 28480
 switch (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 65535) << 16 >> 16) {
 case 2:
  {
   $9 = $0 + 28 | 0; //@line 28490
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($9) | 0; //@line 28496
   $$0 = -231; //@line 28497
   return $$0 | 0; //@line 28498
  }
 case 1:
  {
   $$0 = 0; //@line 28502
   return $$0 | 0; //@line 28503
  }
 default:
  {
   $$0 = -231; //@line 28507
   return $$0 | 0; //@line 28508
  }
 }
 return 0; //@line 28511
}
function __Z9VideoExitv() {
 var $$sroa$03$07 = 0, $0 = 0, $1 = 0, $3 = 0;
 $0 = HEAP32[30549] | 0; //@line 46045
 $1 = HEAP32[30548] | 0; //@line 46046
 if (($1 | 0) == ($0 | 0)) {
  return;
 } else {
  $$sroa$03$07 = $1; //@line 46051
 }
 do {
  _puts(102416) | 0; //@line 46054
  HEAP8[659472] = 0; //@line 46055
  _SDL_mutexV(0) | 0; //@line 46056
  _puts(102430) | 0; //@line 46057
  $3 = HEAP32[30855] | 0; //@line 46058
  if ($3 | 0) {
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[$3 >> 2] | 0) + 4 >> 2] & 4095]($3); //@line 46064
  }
  HEAP32[30855] = 0; //@line 46066
  $$sroa$03$07 = $$sroa$03$07 + 4 | 0; //@line 46067
 } while (($$sroa$03$07 | 0) != ($0 | 0));
 return;
}
function __Z12op_4a38_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0, $18 = 0;
 $1 = HEAP32[162769] | 0; //@line 51651
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 51661
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 51667
 $18 = ($16 & 255 | 0) == 0 & 1; //@line 51670
 HEAP32[96441] = 0; //@line 51671
 HEAP32[96442] = 0; //@line 51671
 HEAP32[96443] = 0; //@line 51671
 HEAP32[96444] = 0; //@line 51671
 HEAP32[96442] = $18; //@line 51672
 HEAP32[96443] = $16 >>> 7 & 1; //@line 51675
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 51678
 return;
}
function __Z12op_487b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $15 = 0, $17 = 0, $2 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 50276
 $2 = $1 + 2 | 0; //@line 50277
 HEAP32[162769] = $2; //@line 50278
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 50283
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 50290
 HEAP32[162769] = $1 + 4; //@line 50292
 $15 = __Z15get_disp_ea_020jj($6, $13) | 0; //@line 50293
 $17 = (HEAP32[162767] | 0) + -4 | 0; //@line 50295
 HEAP32[162767] = $17; //@line 50296
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($17, $15); //@line 50302
 return;
}
function __Z8Sys_readPvS_ij($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $$0 = 0, $12 = 0, $6 = 0;
 if (!$0) {
  $$0 = 0; //@line 2213
  return $$0 | 0; //@line 2214
 }
 $6 = HEAP32[$0 + 24 >> 2] | 0; //@line 2217
 if ($6 | 0) {
  $$0 = FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[$6 >> 2] | 0) + 12 >> 2] & 7]($6, $1, $2, $3) | 0; //@line 2224
  return $$0 | 0; //@line 2225
 }
 $12 = $0 + 4 | 0; //@line 2227
 if ((_lseek(HEAP32[$12 >> 2] | 0, (HEAP32[$0 + 12 >> 2] | 0) + $2 | 0, 0) | 0) < 0) {
  $$0 = 0; //@line 2235
  return $$0 | 0; //@line 2236
 }
 $$0 = _read(HEAP32[$12 >> 2] | 0, $1, $3) | 0; //@line 2240
 return $$0 | 0; //@line 2241
}
function __Z12op_e158_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39342
 $7 = HEAP32[$6 >> 2] | 0; //@line 39343
 $8 = $7 & 65535; //@line 39344
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 15; //@line 39345
 $13 = $8 << $9 | $8 >>> (16 - $9 | 0); //@line 39349
 $14 = $13 & 65535; //@line 39350
 HEAP32[96444] = 0; //@line 39352
 HEAP32[96441] = $13 & 1; //@line 39353
 HEAP32[96442] = ($14 | 0) == 0 & 1; //@line 39356
 HEAP32[96443] = $13 >>> 15 & 1; //@line 39359
 HEAP32[$6 >> 2] = $14 | $7 & -65536; //@line 39362
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39365
 return;
}
function __Z12op_4808_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0, $4 = 0;
 $3 = (HEAP32[162767] | 0) + -4 | 0; //@line 49589
 HEAP32[162767] = $3; //@line 49590
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 49591
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, HEAP32[$4 >> 2] | 0); //@line 49598
 HEAP32[$4 >> 2] = HEAP32[162767]; //@line 49600
 $12 = HEAP32[162769] | 0; //@line 49601
 HEAP32[162767] = ((HEAPU8[$12 + 3 >> 0] | 0) << 16 | (HEAPU8[$12 + 2 >> 0] | 0) << 24 | (HEAPU8[$12 + 4 >> 0] | 0) << 8 | (HEAPU8[$12 + 5 >> 0] | 0)) + (HEAP32[162767] | 0); //@line 49622
 HEAP32[162769] = $12 + 6; //@line 49624
 return;
}
function __Z9CDROMExitv() {
 var $$pre = 0, $$pre8 = 0, $$sroa$03$07 = 0, $0 = 0, $1 = 0;
 $0 = HEAP32[28494] | 0; //@line 19805
 $1 = HEAP32[28493] | 0; //@line 19806
 if (($1 | 0) == ($0 | 0)) {
  return;
 } else {
  $$sroa$03$07 = $1; //@line 19811
 }
 do {
  __Z9Sys_closePv(HEAP32[$$sroa$03$07 + 4 >> 2] | 0); //@line 19816
  $$sroa$03$07 = $$sroa$03$07 + 840 | 0; //@line 19817
 } while (($$sroa$03$07 | 0) != ($0 | 0));
 $$pre = HEAP32[28493] | 0; //@line 19825
 $$pre8 = HEAP32[28494] | 0; //@line 19826
 if (($$pre8 | 0) == ($$pre | 0)) {
  return;
 }
 HEAP32[28494] = $$pre8 + (~((($$pre8 + -840 - $$pre | 0) >>> 0) / 840 | 0) * 840 | 0); //@line 19838
 return;
}
function __Z12op_b1c8_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27375
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27377
 $8 = $7 - $5 | 0; //@line 27378
 $$lobit32 = $7 >>> 31; //@line 27380
 $$lobit33 = $8 >>> 31; //@line 27381
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 27384
 HEAP32[96444] = ($5 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 27389
 HEAP32[96441] = $7 >>> 0 < $5 >>> 0 & 1; //@line 27392
 HEAP32[96443] = $$lobit33; //@line 27393
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27396
 return;
}
function __Z12op_b1c0_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 27342
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 27344
 $8 = $7 - $5 | 0; //@line 27345
 $$lobit32 = $7 >>> 31; //@line 27347
 $$lobit33 = $8 >>> 31; //@line 27348
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 27351
 HEAP32[96444] = ($5 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 27356
 HEAP32[96441] = $7 >>> 0 < $5 >>> 0 & 1; //@line 27359
 HEAP32[96443] = $$lobit33; //@line 27360
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27363
 return;
}
function __Z12op_b088_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 25103
 $7 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25105
 $8 = $7 - $5 | 0; //@line 25106
 $$lobit32 = $7 >>> 31; //@line 25108
 $$lobit33 = $8 >>> 31; //@line 25109
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 25112
 HEAP32[96444] = ($5 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 25117
 HEAP32[96441] = $7 >>> 0 < $5 >>> 0 & 1; //@line 25120
 HEAP32[96443] = $$lobit33; //@line 25121
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25124
 return;
}
function __Z12op_b080_0_ffj($0) {
 $0 = $0 | 0;
 var $$lobit32 = 0, $$lobit33 = 0, $5 = 0, $7 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 25070
 $7 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 25072
 $8 = $7 - $5 | 0; //@line 25073
 $$lobit32 = $7 >>> 31; //@line 25075
 $$lobit33 = $8 >>> 31; //@line 25076
 HEAP32[96442] = ($8 | 0) == 0 & 1; //@line 25079
 HEAP32[96444] = ($5 >>> 31 | 0) != ($$lobit32 | 0) & ($$lobit33 | 0) != ($$lobit32 | 0) & 1; //@line 25084
 HEAP32[96441] = $7 >>> 0 < $5 >>> 0 & 1; //@line 25087
 HEAP32[96443] = $$lobit33; //@line 25088
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 25091
 return;
}
function __ZNK8tinyxml210XMLElement6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $12 = 0, $9 = 0;
 L1 : do {
  if (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[$1 >> 2] | 0) + 16 >> 2] & 15]($1, $0, HEAP32[$0 + 48 >> 2] | 0) | 0) {
   $9 = HEAP32[$0 + 24 >> 2] | 0; //@line 38132
   if ($9 | 0) {
    $12 = $9; //@line 38135
    do {
     if (!(FUNCTION_TABLE_iii[HEAP32[(HEAP32[$12 >> 2] | 0) + 56 >> 2] & 31]($12, $1) | 0)) {
      break L1;
     }
     $12 = HEAP32[$12 + 36 >> 2] | 0; //@line 38145
    } while (($12 | 0) != 0);
   }
  }
 } while (0);
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 20 >> 2] & 31]($1, $0) | 0; //@line 38160
}
function __Z12op_c0fc_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $15 = 0, $17 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 29648
 $12 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29657
 $15 = Math_imul(HEAP32[$12 >> 2] & 65535, (HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) | 0; //@line 29660
 $17 = ($15 | 0) == 0 & 1; //@line 29662
 HEAP32[96441] = 0; //@line 29663
 HEAP32[96442] = 0; //@line 29663
 HEAP32[96443] = 0; //@line 29663
 HEAP32[96444] = 0; //@line 29663
 HEAP32[96442] = $17; //@line 29664
 HEAP32[96443] = $15 >>> 31; //@line 29666
 HEAP32[$12 >> 2] = $15; //@line 29667
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 29670
 return;
}
function __Z12op_3008_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0;
 $3 = $0 >>> 9 & 7; //@line 34889
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 34891
 $6 = $5 << 16 >> 16; //@line 34893
 $8 = ($6 | 0) == 0 & 1; //@line 34895
 HEAP32[96441] = 0; //@line 34896
 HEAP32[96442] = 0; //@line 34896
 HEAP32[96443] = 0; //@line 34896
 HEAP32[96444] = 0; //@line 34896
 HEAP32[96442] = $8; //@line 34897
 HEAP32[96443] = $5 >>> 15 & 1; //@line 34900
 $10 = 651008 + ($3 << 2) | 0; //@line 34901
 HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -65536 | $6 & 65535; //@line 34906
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34909
 return;
}
function __Z12op_3000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0;
 $3 = $0 >>> 9 & 7; //@line 34860
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 34862
 $6 = $5 << 16 >> 16; //@line 34864
 $8 = ($6 | 0) == 0 & 1; //@line 34866
 HEAP32[96441] = 0; //@line 34867
 HEAP32[96442] = 0; //@line 34867
 HEAP32[96443] = 0; //@line 34867
 HEAP32[96444] = 0; //@line 34867
 HEAP32[96442] = $8; //@line 34868
 HEAP32[96443] = $5 >>> 15 & 1; //@line 34871
 $10 = 651008 + ($3 << 2) | 0; //@line 34872
 HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -65536 | $6 & 65535; //@line 34877
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 34880
 return;
}
function __Z11op_a00_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 15475
 $6 = HEAP32[$5 >> 2] | 0; //@line 15476
 $8 = (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0) ^ $6; //@line 15478
 $9 = $8 << 24 >> 24; //@line 15480
 $11 = ($9 | 0) == 0 & 1; //@line 15482
 HEAP32[96441] = 0; //@line 15483
 HEAP32[96442] = 0; //@line 15483
 HEAP32[96443] = 0; //@line 15483
 HEAP32[96444] = 0; //@line 15483
 HEAP32[96442] = $11; //@line 15484
 HEAP32[96443] = $8 >>> 7 & 1; //@line 15487
 HEAP32[$5 >> 2] = $9 & 255 | $6 & -256; //@line 15491
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15494
 return;
}
function __Z12op_4e90_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $22 = 0, $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 674
 $9 = (HEAP32[162768] | 0) + 2 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 680
 $11 = (HEAP32[162767] | 0) + -4 | 0; //@line 682
 HEAP32[162767] = $11; //@line 683
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($11, $9); //@line 689
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($3) | 0; //@line 695
 HEAP32[162770] = $22; //@line 696
 HEAP32[162769] = $22; //@line 697
 HEAP32[162768] = $3; //@line 698
 return;
}
function __Z12op_2010_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $3 = 0, $5 = 0;
 $3 = $0 >>> 9 & 7; //@line 27904
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27906
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 27911
 $12 = ($10 | 0) == 0 & 1; //@line 27913
 HEAP32[96441] = 0; //@line 27914
 HEAP32[96442] = 0; //@line 27914
 HEAP32[96443] = 0; //@line 27914
 HEAP32[96444] = 0; //@line 27914
 HEAP32[96442] = $12; //@line 27915
 HEAP32[96443] = $10 >>> 31; //@line 27917
 HEAP32[651008 + ($3 << 2) >> 2] = $10; //@line 27919
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27922
 return;
}
function __Z8DiskExitv() {
 var $$pre = 0, $$pre8 = 0, $$sroa$03$07 = 0, $0 = 0, $1 = 0;
 $0 = HEAP32[28490] | 0; //@line 18339
 $1 = HEAP32[28489] | 0; //@line 18340
 if (($1 | 0) == ($0 | 0)) {
  return;
 } else {
  $$sroa$03$07 = $1; //@line 18345
 }
 do {
  __Z9Sys_closePv(HEAP32[$$sroa$03$07 + 4 >> 2] | 0); //@line 18350
  $$sroa$03$07 = $$sroa$03$07 + 24 | 0; //@line 18351
 } while (($$sroa$03$07 | 0) != ($0 | 0));
 $$pre = HEAP32[28489] | 0; //@line 18359
 $$pre8 = HEAP32[28490] | 0; //@line 18360
 if (($$pre8 | 0) == ($$pre | 0)) {
  return;
 }
 HEAP32[28490] = $$pre8 + (~((($$pre8 + -24 - $$pre | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 18372
 return;
}
function __Z12op_103c_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $5 = 0, $6 = 0, $8 = 0;
 $2 = $0 >>> 9 & 7; //@line 23801
 $5 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 23804
 $6 = $5 & 255; //@line 23805
 $8 = $5 << 24 >> 24 == 0 & 1; //@line 23807
 HEAP32[96441] = 0; //@line 23808
 HEAP32[96442] = 0; //@line 23808
 HEAP32[96443] = 0; //@line 23808
 HEAP32[96444] = 0; //@line 23808
 HEAP32[96442] = $8; //@line 23809
 HEAP32[96443] = ($5 & 255) >>> 7 & 255; //@line 23812
 $10 = 651008 + ($2 << 2) | 0; //@line 23813
 HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -256 | $6; //@line 23817
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 23820
 return;
}
function __ZN16SDL_monitor_desc22switch_to_current_modeEv($0) {
 $0 = $0 | 0;
 var $1 = 0;
 _SDL_mutexP(0) | 0; //@line 44109
 _puts(102416) | 0; //@line 44110
 HEAP8[659472] = 0; //@line 44111
 _SDL_mutexV(0) | 0; //@line 44112
 _puts(102430) | 0; //@line 44113
 $1 = HEAP32[30855] | 0; //@line 44114
 if ($1 | 0) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$1 >> 2] | 0) + 4 >> 2] & 4095]($1); //@line 44120
 }
 HEAP32[30855] = 0; //@line 44122
 __ZN16SDL_monitor_desc10video_openEv($0) | 0; //@line 44123
 _SDL_mutexV(0) | 0; //@line 44124
 if (!(HEAP32[30855] | 0)) {
  __Z10ErrorAlerti(1008); //@line 44128
  __Z12QuitEmulatorv(); //@line 44129
 } else {
  return;
 }
}
function __Z12op_4c50_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $22 = 0, $3 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53301
 $3 = $2 + 2 | 0; //@line 53302
 HEAP32[162769] = $3; //@line 53303
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53308
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53316
 $17 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 53318
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 53323
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 53326
 __Z9m68k_divljjtj($0, $22, $15, $7); //@line 53327
 return;
}
function __Z11op_830_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 13929
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 13931
 $5 = $2 + 4 | 0; //@line 13932
 HEAP32[162769] = $5; //@line 13933
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13935
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0); //@line 13942
 HEAP32[162769] = $2 + 6; //@line 13944
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 13945
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 13959
 return;
}
function ___string_read($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$027 = 0, $$027$ = 0, $14 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 $3 = $0 + 84 | 0; //@line 1662
 $4 = HEAP32[$3 >> 2] | 0; //@line 1663
 $5 = $2 + 256 | 0; //@line 1664
 $6 = _memchr($4, 0, $5) | 0; //@line 1665
 $$027 = ($6 | 0) == 0 ? $5 : $6 - $4 | 0; //@line 1670
 $$027$ = $$027 >>> 0 < $2 >>> 0 ? $$027 : $2; //@line 1672
 _memcpy($1 | 0, $4 | 0, $$027$ | 0) | 0; //@line 1673
 HEAP32[$0 + 4 >> 2] = $4 + $$027$; //@line 1676
 $14 = $4 + $$027 | 0; //@line 1677
 HEAP32[$0 + 8 >> 2] = $14; //@line 1679
 HEAP32[$3 >> 2] = $14; //@line 1680
 return $$027$ | 0; //@line 1681
}
function __Z12op_d0fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 36872
 $$cast = $4; //@line 36877
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 36886
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 36892
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36893
 HEAP32[$24 >> 2] = ($23 << 16 >> 16) + (HEAP32[$24 >> 2] | 0); //@line 36898
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36901
 return;
}
function __Z12op_90fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $23 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 24095
 $$cast = $4; //@line 24100
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 24109
 $23 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 24115
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 24116
 HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) - ($23 << 16 >> 16); //@line 24121
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24124
 return;
}
function __Z12op_4a98_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $3 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 52268
 $3 = HEAP32[$2 >> 2] | 0; //@line 52269
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 52274
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 4; //@line 52277
 $12 = ($8 | 0) == 0 & 1; //@line 52279
 HEAP32[96441] = 0; //@line 52280
 HEAP32[96442] = 0; //@line 52280
 HEAP32[96443] = 0; //@line 52280
 HEAP32[96444] = 0; //@line 52280
 HEAP32[96442] = $12; //@line 52281
 HEAP32[96443] = $8 >>> 31; //@line 52283
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52286
 return;
}
function __Z12op_1000_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0;
 $3 = $0 >>> 9 & 7; //@line 23365
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 23367
 $6 = $5 << 24 >> 24; //@line 23369
 $8 = ($6 | 0) == 0 & 1; //@line 23371
 HEAP32[96441] = 0; //@line 23372
 HEAP32[96442] = 0; //@line 23372
 HEAP32[96443] = 0; //@line 23372
 HEAP32[96444] = 0; //@line 23372
 HEAP32[96442] = $8; //@line 23373
 HEAP32[96443] = $5 >>> 7 & 1; //@line 23376
 $10 = 651008 + ($3 << 2) | 0; //@line 23377
 HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -256 | $6 & 255; //@line 23382
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 23385
 return;
}
function __Z11op_850_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14180
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14182
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 14184
 $14 = $4 & 7; //@line 14190
 $15 = 1 << $14; //@line 14191
 $17 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0) ^ $15) << 24 >> 24; //@line 14194
 HEAP32[96442] = ($17 & $15) >>> $14; //@line 14197
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, $17); //@line 14201
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14204
 return;
}
function __Z12op_4870_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $16 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 50140
 $3 = $2 + 2 | 0; //@line 50141
 HEAP32[162769] = $3; //@line 50142
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 50144
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 50151
 HEAP32[162769] = $2 + 4; //@line 50153
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 50154
 $16 = (HEAP32[162767] | 0) + -4 | 0; //@line 50156
 HEAP32[162767] = $16; //@line 50157
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($16, $14); //@line 50163
 return;
}
function __Z11op_150_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $17 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7035
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7037
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 7039
 $14 = $5 & 7; //@line 7044
 $15 = 1 << $14; //@line 7045
 $17 = ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0) ^ $15) << 24 >> 24; //@line 7048
 HEAP32[96442] = ($17 & $15) >>> $14; //@line 7051
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, $17); //@line 7055
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7058
 return;
}
function _select($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 var $10 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2402
 STACKTOP = STACKTOP + 32 | 0; //@line 2403
 $vararg_buffer = sp; //@line 2404
 HEAP32[$vararg_buffer >> 2] = $0; //@line 2409
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 2411
 HEAP32[$vararg_buffer + 8 >> 2] = $2; //@line 2413
 HEAP32[$vararg_buffer + 12 >> 2] = $3; //@line 2415
 HEAP32[$vararg_buffer + 16 >> 2] = $4; //@line 2417
 $10 = ___syscall_ret(___syscall142(142, $vararg_buffer | 0) | 0) | 0; //@line 2419
 STACKTOP = sp; //@line 2420
 return $10 | 0; //@line 2420
}
function _fmt_o($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0$lcssa = 0, $$06 = 0, $10 = 0, $11 = 0, $7 = 0;
 if (($0 | 0) == 0 & ($1 | 0) == 0) {
  $$0$lcssa = $2; //@line 57555
 } else {
  $$06 = $2; //@line 57557
  $11 = $1; //@line 57557
  $7 = $0; //@line 57557
  while (1) {
   $10 = $$06 + -1 | 0; //@line 57562
   HEAP8[$10 >> 0] = $7 & 7 | 48; //@line 57563
   $7 = _bitshift64Lshr($7 | 0, $11 | 0, 3) | 0; //@line 57564
   $11 = tempRet0; //@line 57565
   if (($7 | 0) == 0 & ($11 | 0) == 0) {
    $$0$lcssa = $10; //@line 57570
    break;
   } else {
    $$06 = $10; //@line 57573
   }
  }
 }
 return $$0$lcssa | 0; //@line 57577
}
function __Z12op_e058_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37903
 $7 = HEAP32[$6 >> 2] | 0; //@line 37904
 $8 = $7 & 65535; //@line 37905
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 15; //@line 37906
 $13 = $8 << 16 - $9 & 65535 | $8 >>> $9; //@line 37911
 $14 = $13 >>> 15; //@line 37912
 HEAP32[96444] = 0; //@line 37913
 HEAP32[96441] = $14; //@line 37914
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 37917
 HEAP32[96443] = $14; //@line 37918
 HEAP32[$6 >> 2] = $13 | $7 & -65536; //@line 37921
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37924
 return;
}
function __ZN14EthernetPacketD2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $3 = 0, $4 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 17005
 STACKTOP = STACKTOP + 80 | 0; //@line 17006
 $1 = sp; //@line 17007
 $3 = (HEAP32[28481] | 0) + -1 | 0; //@line 17009
 HEAP32[28481] = $3; //@line 17010
 $4 = HEAP32[$0 >> 2] | 0; //@line 17011
 if (($4 | 0) == (HEAP32[28482] | 0)) {
  $9 = $3; //@line 17015
 } else {
  HEAP32[$1 + 32 >> 2] = $4; //@line 17018
  _Execute68kTrap(-24545, $1); //@line 17019
  $9 = HEAP32[28481] | 0; //@line 17021
 }
 if (!$9) {
  STACKTOP = sp; //@line 17025
  return;
 }
 _puts(93634) | 0; //@line 17027
 STACKTOP = sp; //@line 17028
 return;
}
function __Z12op_4640_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0, $sext = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 48570
 $3 = HEAP32[$2 >> 2] | 0; //@line 48571
 $sext = $3 << 16; //@line 48572
 $4 = $sext >> 16; //@line 48573
 $6 = ($4 | 0) == -1 & 1; //@line 48575
 HEAP32[96441] = 0; //@line 48576
 HEAP32[96442] = 0; //@line 48576
 HEAP32[96443] = 0; //@line 48576
 HEAP32[96444] = 0; //@line 48576
 HEAP32[96442] = $6; //@line 48577
 HEAP32[96443] = ($sext | 0) > -65536 & 1; //@line 48580
 HEAP32[$2 >> 2] = ($4 & 65535 | $3 & -65536) ^ 65535; //@line 48585
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48588
 return;
}
function __Z12op_4ab8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $15 = 0, $17 = 0;
 $1 = HEAP32[162769] | 0; //@line 52389
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 52399
 $15 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($10 >>> 16 << 2) >> 2] >> 2] & 127]($10) | 0; //@line 52404
 $17 = ($15 | 0) == 0 & 1; //@line 52406
 HEAP32[96441] = 0; //@line 52407
 HEAP32[96442] = 0; //@line 52407
 HEAP32[96443] = 0; //@line 52407
 HEAP32[96444] = 0; //@line 52407
 HEAP32[96442] = $17; //@line 52408
 HEAP32[96443] = $15 >>> 31; //@line 52410
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52413
 return;
}
function __Z12op_4600_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0, $sext = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 48258
 $3 = HEAP32[$2 >> 2] | 0; //@line 48259
 $sext = $3 << 24; //@line 48260
 $4 = $sext >> 24; //@line 48261
 $6 = ($4 | 0) == -1 & 1; //@line 48263
 HEAP32[96441] = 0; //@line 48264
 HEAP32[96442] = 0; //@line 48264
 HEAP32[96443] = 0; //@line 48264
 HEAP32[96444] = 0; //@line 48264
 HEAP32[96442] = $6; //@line 48265
 HEAP32[96443] = ($sext | 0) > -16777216 & 1; //@line 48268
 HEAP32[$2 >> 2] = ($4 & 255 | $3 & -256) ^ 255; //@line 48273
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48276
 return;
}
function __Z12op_d0fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 33415
 $$cast = $4; //@line 33417
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 33431
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 33437
 $25 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33438
 HEAP32[$25 >> 2] = ($24 << 16 >> 16) + (HEAP32[$25 >> 2] | 0); //@line 33443
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33446
 return;
}
function __Z12op_90fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $24 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 19793
 $$cast = $4; //@line 19795
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 19809
 $24 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 19815
 $25 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19816
 HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) - ($24 << 16 >> 16); //@line 19821
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19824
 return;
}
function __Z12op_4220_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 42786
 $2 = 651040 + ($1 << 2) | 0; //@line 42787
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 42791
 HEAP32[$2 >> 2] = $6; //@line 42792
 HEAP32[96441] = 0; //@line 42793
 HEAP32[96442] = 0; //@line 42793
 HEAP32[96443] = 0; //@line 42793
 HEAP32[96444] = 0; //@line 42793
 HEAP32[96442] = 1; //@line 42794
 HEAP32[96443] = 0; //@line 42795
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, 0); //@line 42801
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42804
 return;
}
function __Z8SonyExitv() {
 var $$pre = 0, $$pre8 = 0, $$sroa$03$07 = 0, $0 = 0, $1 = 0;
 $0 = HEAP32[28486] | 0; //@line 17191
 $1 = HEAP32[28485] | 0; //@line 17192
 if (($1 | 0) == ($0 | 0)) {
  return;
 } else {
  $$sroa$03$07 = $1; //@line 17197
 }
 do {
  __Z9Sys_closePv(HEAP32[$$sroa$03$07 + 4 >> 2] | 0); //@line 17202
  $$sroa$03$07 = $$sroa$03$07 + 16 | 0; //@line 17203
 } while (($$sroa$03$07 | 0) != ($0 | 0));
 $$pre = HEAP32[28485] | 0; //@line 17211
 $$pre8 = HEAP32[28486] | 0; //@line 17212
 if (($$pre8 | 0) == ($$pre | 0)) {
  return;
 }
 HEAP32[28486] = $$pre8 + (~(($$pre8 + -16 - $$pre | 0) >>> 4) << 4); //@line 17224
 return;
}
function __Z12op_4aa0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $4 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 52294
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 52296
 $9 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($4 >>> 16 << 2) >> 2] >> 2] & 127]($4) | 0; //@line 52301
 HEAP32[$2 >> 2] = $4; //@line 52302
 $11 = ($9 | 0) == 0 & 1; //@line 52304
 HEAP32[96441] = 0; //@line 52305
 HEAP32[96442] = 0; //@line 52305
 HEAP32[96443] = 0; //@line 52305
 HEAP32[96444] = 0; //@line 52305
 HEAP32[96442] = $11; //@line 52306
 HEAP32[96443] = $9 >>> 31; //@line 52308
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52311
 return;
}
function __Z12op_44fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0;
 $2 = HEAP32[162769] | 0; //@line 2409
 $$cast = $2; //@line 2414
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 2423
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 2429
 __Z6MakeSRv(); //@line 2430
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $21 & 255; //@line 2437
 __Z10MakeFromSRv(); //@line 2438
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2441
 return;
}
function __Z12MicrosecondsRjS_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $12 = 0, $2 = 0, $3 = 0, $6 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 13517
 STACKTOP = STACKTOP + 16 | 0; //@line 13518
 $2 = sp; //@line 13519
 _gettimeofday($2 | 0, 0) | 0; //@line 13520
 $3 = HEAP32[$2 >> 2] | 0; //@line 13521
 $6 = ___muldi3($3 | 0, (($3 | 0) < 0) << 31 >> 31 | 0, 1e6, 0) | 0; //@line 13524
 $9 = HEAP32[$2 + 4 >> 2] | 0; //@line 13527
 $12 = _i64Add($6 | 0, tempRet0 | 0, $9 | 0, (($9 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 13530
 HEAP32[$0 >> 2] = tempRet0; //@line 13532
 HEAP32[$1 >> 2] = $12; //@line 13533
 STACKTOP = sp; //@line 13534
 return;
}
function __Z11op_200_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 8452
 $6 = HEAP32[$5 >> 2] | 0; //@line 8453
 $8 = (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0) & $6; //@line 8455
 $9 = $8 << 24 >> 24; //@line 8457
 $11 = ($9 | 0) == 0 & 1; //@line 8459
 HEAP32[96441] = 0; //@line 8460
 HEAP32[96442] = 0; //@line 8460
 HEAP32[96443] = 0; //@line 8460
 HEAP32[96444] = 0; //@line 8460
 HEAP32[96442] = $11; //@line 8461
 HEAP32[96443] = $8 >>> 7; //@line 8463
 HEAP32[$5 >> 2] = $9 & 255 | $6 & -256; //@line 8467
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8470
 return;
}
function _vsscanf($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $3 = 0, $8 = 0, dest = 0, sp = 0, stop = 0;
 sp = STACKTOP; //@line 590
 STACKTOP = STACKTOP + 128 | 0; //@line 591
 $3 = sp; //@line 592
 dest = $3; //@line 593
 stop = dest + 124 | 0; //@line 593
 do {
  HEAP32[dest >> 2] = 0; //@line 593
  dest = dest + 4 | 0; //@line 593
 } while ((dest | 0) < (stop | 0));
 HEAP32[$3 + 32 >> 2] = 15; //@line 595
 HEAP32[$3 + 44 >> 2] = $0; //@line 597
 HEAP32[$3 + 76 >> 2] = -1; //@line 599
 HEAP32[$3 + 84 >> 2] = $0; //@line 601
 $8 = _vfscanf($3, $1, $2) | 0; //@line 602
 STACKTOP = sp; //@line 603
 return $8 | 0; //@line 603
}
function __Z9op_0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 4703
 $6 = HEAP32[$5 >> 2] | 0; //@line 4704
 $8 = HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0 | $6; //@line 4706
 $9 = $8 << 24 >> 24; //@line 4708
 $11 = ($9 | 0) == 0 & 1; //@line 4710
 HEAP32[96441] = 0; //@line 4711
 HEAP32[96442] = 0; //@line 4711
 HEAP32[96443] = 0; //@line 4711
 HEAP32[96444] = 0; //@line 4711
 HEAP32[96442] = $11; //@line 4712
 HEAP32[96443] = $8 >>> 7 & 1; //@line 4715
 HEAP32[$5 >> 2] = $9 & 255 | $6 & -256; //@line 4719
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4722
 return;
}
function __Z12op_e018_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $14 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 37513
 $7 = HEAP32[$6 >> 2] | 0; //@line 37514
 $8 = $7 & 255; //@line 37515
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 7; //@line 37516
 $13 = $8 << 8 - $9 & 255 | $8 >>> $9; //@line 37521
 $14 = $13 >>> 7; //@line 37522
 HEAP32[96444] = 0; //@line 37523
 HEAP32[96441] = $14; //@line 37524
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 37527
 HEAP32[96443] = $14; //@line 37528
 HEAP32[$6 >> 2] = $13 | $7 & -256; //@line 37531
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37534
 return;
}
function __Z12op_44fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0;
 $2 = HEAP32[162769] | 0; //@line 48155
 $$cast = $2; //@line 48157
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 48171
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 48177
 __Z6MakeSRv(); //@line 48178
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $22 & 255; //@line 48185
 __Z10MakeFromSRv(); //@line 48186
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48189
 return;
}
function __Z11op_890_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 14598
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 14600
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 14602
 $14 = $4 & 7; //@line 14608
 $15 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0) << 24 >> 24; //@line 14610
 HEAP32[96442] = $15 >>> $14 & 1 ^ 1; //@line 14614
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, ($15 & (1 << $14 ^ 255)) << 24 >> 24); //@line 14623
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14626
 return;
}
function __Z11op_190_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 7504
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7506
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 7508
 $14 = $5 & 7; //@line 7513
 $15 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0) << 24 >> 24; //@line 7515
 HEAP32[96442] = $15 >>> $14 & 1 ^ 1; //@line 7519
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, ($15 & (1 << $14 ^ 255)) << 24 >> 24); //@line 7528
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7531
 return;
}
function __Z12op_4218_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 42761
 $2 = 651040 + ($1 << 2) | 0; //@line 42762
 $3 = HEAP32[$2 >> 2] | 0; //@line 42763
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 42767
 HEAP32[96441] = 0; //@line 42768
 HEAP32[96442] = 0; //@line 42768
 HEAP32[96443] = 0; //@line 42768
 HEAP32[96444] = 0; //@line 42768
 HEAP32[96442] = 1; //@line 42769
 HEAP32[96443] = 0; //@line 42770
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 0); //@line 42776
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42779
 return;
}
function __Z12op_4270_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46175
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 46184
 HEAP32[96441] = 0; //@line 46185
 HEAP32[96442] = 0; //@line 46185
 HEAP32[96443] = 0; //@line 46185
 HEAP32[96444] = 0; //@line 46185
 HEAP32[96442] = 1; //@line 46186
 HEAP32[96443] = 0; //@line 46187
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, 0); //@line 46193
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46196
 return;
}
function __Z12op_4230_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46143
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 46152
 HEAP32[96441] = 0; //@line 46153
 HEAP32[96442] = 0; //@line 46153
 HEAP32[96443] = 0; //@line 46153
 HEAP32[96444] = 0; //@line 46153
 HEAP32[96442] = 1; //@line 46154
 HEAP32[96443] = 0; //@line 46155
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, 0); //@line 46161
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46164
 return;
}
function __ZNK8tinyxml211XMLDocument6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $10 = 0, $7 = 0;
 L1 : do {
  if (FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 8 >> 2] & 31]($1, $0) | 0) {
   $7 = HEAP32[$0 + 24 >> 2] | 0; //@line 40141
   if ($7 | 0) {
    $10 = $7; //@line 40144
    do {
     if (!(FUNCTION_TABLE_iii[HEAP32[(HEAP32[$10 >> 2] | 0) + 56 >> 2] & 31]($10, $1) | 0)) {
      break L1;
     }
     $10 = HEAP32[$10 + 36 >> 2] | 0; //@line 40154
    } while (($10 | 0) != 0);
   }
  }
 } while (0);
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 12 >> 2] & 31]($1, $0) | 0; //@line 40169
}
function __Z12op_42a8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46449
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 46460
 HEAP32[96441] = 0; //@line 46461
 HEAP32[96442] = 0; //@line 46461
 HEAP32[96443] = 0; //@line 46461
 HEAP32[96444] = 0; //@line 46461
 HEAP32[96442] = 1; //@line 46462
 HEAP32[96443] = 0; //@line 46463
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($14, 0); //@line 46469
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46472
 return;
}
function __Z12op_4268_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 43032
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 43043
 HEAP32[96441] = 0; //@line 43044
 HEAP32[96442] = 0; //@line 43044
 HEAP32[96443] = 0; //@line 43044
 HEAP32[96444] = 0; //@line 43044
 HEAP32[96442] = 1; //@line 43045
 HEAP32[96443] = 0; //@line 43046
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, 0); //@line 43052
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43055
 return;
}
function __Z12op_4228_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 42815
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 42826
 HEAP32[96441] = 0; //@line 42827
 HEAP32[96442] = 0; //@line 42827
 HEAP32[96443] = 0; //@line 42827
 HEAP32[96444] = 0; //@line 42827
 HEAP32[96442] = 1; //@line 42828
 HEAP32[96443] = 0; //@line 42829
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 0); //@line 42835
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42838
 return;
}
function __Z12m68k_executev() {
 var $0 = 0, $10 = 0, $17 = 0, $7 = 0;
 if (HEAP8[659737] | 0) {
  return;
 }
 while (1) {
  $0 = HEAP32[162769] | 0; //@line 52744
  $7 = HEAPU8[$0 >> 0] << 8 | HEAPU8[$0 + 1 >> 0]; //@line 52751
  FUNCTION_TABLE_vi[HEAP32[388864 + ($7 << 2) >> 2] & 4095]($7); //@line 52754
  $10 = HEAP32[1313] | 0; //@line 52755
  HEAP32[1313] = $10 + -1; //@line 52757
  if (($10 | 0) < 2) {
   __Z18cpu_do_check_ticksv(); //@line 52760
  }
  if (!(HEAP32[162771] & 63)) {
   continue;
  }
  $17 = (__Z19m68k_do_specialtiesv() | 0) == 0; //@line 52769
  if (!($17 | (HEAP8[659737] | 0) == 0)) {
   break;
  }
 }
 return;
}
function __Z11op_8d0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $4 = 0, $6 = 0, $8 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 15053
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 15055
 $8 = 123608 + ($6 >>> 16 << 2) | 0; //@line 15057
 $14 = $4 & 7; //@line 15063
 $15 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$8 >> 2] | 0) + 8 >> 2] & 127]($6) | 0) << 24 >> 24; //@line 15065
 HEAP32[96442] = $15 >>> $14 & 1 ^ 1; //@line 15069
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$8 >> 2] | 0) + 20 >> 2] & 31]($6, ($15 | 1 << $14) << 24 >> 24); //@line 15077
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15080
 return;
}
function __Z12op_d1fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 49788
 $$cast = $4; //@line 49793
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 49802
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 49807
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 49808
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + $22; //@line 49811
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49814
 return;
}
function __Z12op_91fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $22 = 0, $23 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 24347
 $$cast = $4; //@line 24352
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 24361
 $22 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 24366
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 24367
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) - $22; //@line 24370
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24373
 return;
}
function __Z12op_2088_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28638
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28640
 $9 = ($5 | 0) == 0 & 1; //@line 28642
 HEAP32[96441] = 0; //@line 28643
 HEAP32[96442] = 0; //@line 28643
 HEAP32[96443] = 0; //@line 28643
 HEAP32[96444] = 0; //@line 28643
 HEAP32[96442] = $9; //@line 28644
 HEAP32[96443] = $5 >>> 31; //@line 28646
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($7, $5); //@line 28652
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28655
 return;
}
function __Z12op_2080_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 28610
 $7 = HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 28612
 $9 = ($5 | 0) == 0 & 1; //@line 28614
 HEAP32[96441] = 0; //@line 28615
 HEAP32[96442] = 0; //@line 28615
 HEAP32[96443] = 0; //@line 28615
 HEAP32[96444] = 0; //@line 28615
 HEAP32[96442] = $9; //@line 28616
 HEAP32[96443] = $5 >>> 31; //@line 28618
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($7, $5); //@line 28624
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28627
 return;
}
function __Z11op_1d0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $15 = 0, $5 = 0, $7 = 0, $9 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 8025
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8027
 $9 = 123608 + ($7 >>> 16 << 2) | 0; //@line 8029
 $14 = $5 & 7; //@line 8034
 $15 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 8 >> 2] & 127]($7) | 0) << 24 >> 24; //@line 8036
 HEAP32[96442] = $15 >>> $14 & 1 ^ 1; //@line 8040
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[$9 >> 2] | 0) + 20 >> 2] & 31]($7, ($15 | 1 << $14) << 24 >> 24); //@line 8048
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8051
 return;
}
function __Z12op_61ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $20 = 0, $26 = 0, $28 = 0;
 $1 = HEAP32[162769] | 0; //@line 12398
 $20 = ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0; //@line 12417
 $26 = (HEAP32[162768] | 0) + 6 + $1 - (HEAP32[162770] | 0) | 0; //@line 12423
 $28 = (HEAP32[162767] | 0) + -4 | 0; //@line 12425
 HEAP32[162767] = $28; //@line 12426
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($28 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($28, $26); //@line 12432
 HEAP32[162769] = (HEAP32[162769] | 0) + $20; //@line 12435
 return;
}
function __Z12op_46fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $4 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 2617
  return;
 } else {
  $4 = HEAP32[162769] | 0; //@line 2621
  $$cast = $4; //@line 2626
  $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, HEAPU8[$$cast + 2 >> 0] << 8 | HEAPU8[$$cast + 3 >> 0]) | 0; //@line 2635
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0; //@line 2643
  __Z10MakeFromSRv(); //@line 2644
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2647
  return;
 }
}
function __Z12op_42b0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2160
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2169
 HEAP32[96441] = 0; //@line 2170
 HEAP32[96442] = 0; //@line 2170
 HEAP32[96443] = 0; //@line 2170
 HEAP32[96444] = 0; //@line 2170
 HEAP32[96442] = 1; //@line 2171
 HEAP32[96443] = 0; //@line 2172
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($13, 0); //@line 2178
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2181
 return;
}
function __ZNSt3__26__treeINS_12__value_typeItjEENS_19__map_value_compareItS2_NS_4lessItEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 if (!$1) {
  return;
 } else {
  __ZNSt3__26__treeINS_12__value_typeItjEENS_19__map_value_compareItS2_NS_4lessItEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0, HEAP32[$1 >> 2] | 0); //@line 15069
  __ZNSt3__26__treeINS_12__value_typeItjEENS_19__map_value_compareItS2_NS_4lessItEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0, HEAP32[$1 + 4 >> 2] | 0); //@line 15072
  __ZdlPv($1); //@line 15073
  return;
 }
}
function __Z12op_307b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 35657
 $4 = $3 + 2 | 0; //@line 35658
 HEAP32[162769] = $4; //@line 35659
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 35664
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 35671
 HEAP32[162769] = $3 + 4; //@line 35673
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 35674
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0) << 16 >> 16; //@line 35684
 return;
}
function _perror($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $4 = 0;
 $1 = HEAP32[22038] | 0; //@line 2683
 $4 = _strerror(HEAP32[(___errno_location() | 0) >> 2] | 0) | 0; //@line 2686
 if ((HEAP32[$1 + 76 >> 2] | 0) > -1) {
  $15 = ___lockfile($1) | 0; //@line 2692
 } else {
  $15 = 0; //@line 2694
 }
 if ($0 | 0) {
  if (HEAP8[$0 >> 0] | 0) {
   _fwrite($0, _strlen($0) | 0, 1, $1) | 0; //@line 2702
   _fputc(58, $1) | 0; //@line 2703
   _fputc(32, $1) | 0; //@line 2704
  }
 }
 _fwrite($4, _strlen($4) | 0, 1, $1) | 0; //@line 2708
 _fputc(10, $1) | 0; //@line 2709
 if ($15 | 0) {
  ___unlockfile($1); //@line 2712
 }
 return;
}
function __Z12op_46fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $4 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49435
  return;
 } else {
  $4 = HEAP32[162769] | 0; //@line 49439
  $$cast = $4; //@line 49441
  $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + ((HEAPU8[$$cast + 2 >> 0] << 8 | HEAPU8[$$cast + 3 >> 0]) << 16 >> 16) | 0; //@line 49455
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0; //@line 49463
  __Z10MakeFromSRv(); //@line 49464
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49467
  return;
 }
}
function __Z11op_13b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $19 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16411
 $6 = HEAP32[162769] | 0; //@line 16413
 $$cast = $6; //@line 16418
 $19 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 16427
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($19) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 16440
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16443
 return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 var $10 = 0;
 if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, $5) | 0) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0, $1, $2, $3, $4); //@line 3981
 } else {
  $10 = HEAP32[$0 + 8 >> 2] | 0; //@line 3984
  FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[$10 >> 2] | 0) + 20 >> 2] & 3]($10, $1, $2, $3, $4, $5); //@line 3988
 }
 return;
}
function __Z12op_d1fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 37261
 $$cast = $4; //@line 37263
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 37277
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 37282
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37283
 HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + $23; //@line 37286
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37289
 return;
}
function __Z12op_91fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $23 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 21689
 $$cast = $4; //@line 21691
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 21705
 $23 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 21710
 $24 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21711
 HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) - $23; //@line 21714
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21717
 return;
}
function ___fmodeflags($0) {
 $0 = $0 | 0;
 var $$0 = 0, $$0$ = 0, $$2 = 0, $$2$ = 0, $$4 = 0, $2 = 0, $3 = 0, $5 = 0, $8 = 0;
 $2 = (_strchr($0, 43) | 0) == 0; //@line 62
 $3 = HEAP8[$0 >> 0] | 0; //@line 63
 $$0 = $2 ? $3 << 24 >> 24 != 114 & 1 : 2; //@line 66
 $5 = (_strchr($0, 120) | 0) == 0; //@line 68
 $$0$ = $5 ? $$0 : $$0 | 128; //@line 70
 $8 = (_strchr($0, 101) | 0) == 0; //@line 72
 $$2 = $8 ? $$0$ : $$0$ | 524288; //@line 74
 $$2$ = $3 << 24 >> 24 == 114 ? $$2 : $$2 | 64; //@line 77
 $$4 = $3 << 24 >> 24 == 119 ? $$2$ | 512 : $$2$; //@line 80
 return ($3 << 24 >> 24 == 97 ? $$4 | 1024 : $$4) | 0; //@line 84
}
function __Z12op_e118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38937
 $7 = HEAP32[$6 >> 2] | 0; //@line 38938
 $8 = $7 & 255; //@line 38939
 $9 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 7; //@line 38940
 $13 = $8 << $9 & 255 | $8 >>> (8 - $9 | 0); //@line 38945
 HEAP32[96444] = 0; //@line 38947
 HEAP32[96441] = $13 & 1; //@line 38948
 HEAP32[96442] = ($13 | 0) == 0 & 1; //@line 38951
 HEAP32[96443] = $13 >>> 7; //@line 38953
 HEAP32[$6 >> 2] = $13 | $7 & -256; //@line 38956
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38959
 return;
}
function __Z12op_3070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 35509
 $5 = $4 + 2 | 0; //@line 35510
 HEAP32[162769] = $5; //@line 35511
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35513
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 35520
 HEAP32[162769] = $4 + 4; //@line 35522
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 35523
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0) << 16 >> 16; //@line 35533
 return;
}
function __Z11op_818_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0;
 $1 = $0 & 7; //@line 13818
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 13821
 $5 = 651040 + ($1 << 2) | 0; //@line 13822
 $6 = HEAP32[$5 >> 2] | 0; //@line 13823
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($6) | 0; //@line 13829
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + (HEAP32[5656 + ($1 << 2) >> 2] | 0); //@line 13834
 HEAP32[96442] = $12 << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 13842
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13845
 return;
}
function __Z11op_13a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $20 = 0, $4 = 0, $6 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6840
 $6 = HEAP32[162769] | 0; //@line 6842
 $$cast = $6; //@line 6844
 $20 = (HEAP32[162768] | 0) + 2 + $6 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 6858
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($20 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($20) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 6871
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6874
 return;
}
function __Z12op_5df0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 10455
 $3 = $2 + 2 | 0; //@line 10456
 HEAP32[162769] = $3; //@line 10457
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10459
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10466
 HEAP32[162769] = $2 + 4; //@line 10468
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 10469
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10479
 return;
}
function __Z12op_5cf0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 10115
 $3 = $2 + 2 | 0; //@line 10116
 HEAP32[162769] = $3; //@line 10117
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10119
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 10126
 HEAP32[162769] = $2 + 4; //@line 10128
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 10129
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10139
 return;
}
function __Z12op_4c7c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $14 = 0, $2 = 0, $32 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 53681
 $2 = $1 + 2 | 0; //@line 53682
 HEAP32[162769] = $2; //@line 53683
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53688
 $14 = ((HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53696
 $32 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 53714
 HEAP32[162769] = $1 + 8; //@line 53716
 __Z9m68k_divljjtj($0, $32, $14, $6); //@line 53717
 return;
}
function __Z11op_118_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0;
 $3 = $0 & 7; //@line 6604
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6606
 $6 = 651040 + ($3 << 2) | 0; //@line 6607
 $7 = HEAP32[$6 >> 2] | 0; //@line 6608
 $13 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($7) | 0; //@line 6614
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5656 + ($3 << 2) >> 2] | 0); //@line 6619
 HEAP32[96442] = $13 << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 6626
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6629
 return;
}
function __Z12op_c1c0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $6 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30772
 $10 = Math_imul(HEAP32[$6 >> 2] << 16 >> 16, HEAP32[651008 + (($0 & 7) << 2) >> 2] << 16 >> 16) | 0; //@line 30778
 $12 = ($10 | 0) == 0 & 1; //@line 30780
 HEAP32[96441] = 0; //@line 30781
 HEAP32[96442] = 0; //@line 30781
 HEAP32[96443] = 0; //@line 30781
 HEAP32[96444] = 0; //@line 30781
 HEAP32[96442] = $12; //@line 30782
 HEAP32[96443] = $10 >>> 31; //@line 30784
 HEAP32[$6 >> 2] = $10; //@line 30785
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30788
 return;
}
function __Z12op_42f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 46704
 $3 = $2 + 2 | 0; //@line 46705
 HEAP32[162769] = $3; //@line 46706
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46708
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 46715
 HEAP32[162769] = $2 + 4; //@line 46717
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 46718
 __Z6MakeSRv(); //@line 46719
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, HEAP16[325558] & 255); //@line 46728
 return;
}
function __Z12op_207b_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 28542
 $4 = $3 + 2 | 0; //@line 28543
 HEAP32[162769] = $4; //@line 28544
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 28549
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 28556
 HEAP32[162769] = $3 + 4; //@line 28558
 $17 = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 28559
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 28566
 return;
}
function __ZNK8tinyxml210XMLElement7GetTextEv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $2 = 0, $9 = 0;
 $1 = $0 + 24 | 0; //@line 41201
 $2 = HEAP32[$1 >> 2] | 0; //@line 41202
 if (!$2) {
  $$0 = 0; //@line 41205
  return $$0 | 0; //@line 41206
 }
 if (!(FUNCTION_TABLE_ii[HEAP32[(HEAP32[$2 >> 2] | 0) + 28 >> 2] & 127]($2) | 0)) {
  $$0 = 0; //@line 41214
  return $$0 | 0; //@line 41215
 }
 $9 = HEAP32[$1 >> 2] | 0; //@line 41217
 $$0 = __ZN8tinyxml27StrPair6GetStrEv((FUNCTION_TABLE_ii[HEAP32[(HEAP32[$9 >> 2] | 0) + 28 >> 2] & 127]($9) | 0) + 12 | 0) | 0; //@line 41224
 return $$0 | 0; //@line 41225
}
function __Z12op_4c18_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $13 = 0, $18 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 52930
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 52939
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 52940
 $13 = HEAP32[$12 >> 2] | 0; //@line 52941
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 52946
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 4; //@line 52949
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52952
 __Z9m68k_mulljjt($0, $18, $11); //@line 52953
 return;
}
function __Z11op_120_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $16 = 0, $3 = 0, $5 = 0, $6 = 0;
 $3 = $0 & 7; //@line 6639
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6641
 $6 = 651040 + ($3 << 2) | 0; //@line 6642
 $10 = (HEAP32[$6 >> 2] | 0) - (HEAP32[5656 + ($3 << 2) >> 2] | 0) | 0; //@line 6646
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($10) | 0; //@line 6652
 HEAP32[$6 >> 2] = $10; //@line 6653
 HEAP32[96442] = $16 << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 6660
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6663
 return;
}
function __Z12op_5fe0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 11174
 $2 = 651040 + ($1 << 2) | 0; //@line 11175
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 11179
 HEAP32[$2 >> 2] = $6; //@line 11180
 if (!(HEAP32[96442] | 0)) {
  $17 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11188
 } else {
  $17 = 255; //@line 11190
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, $17); //@line 11197
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 11200
 return;
}
function __Z12op_c0c0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $12 = 0, $6 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 29249
 $10 = Math_imul(HEAP32[$6 >> 2] & 65535, HEAP32[651008 + (($0 & 7) << 2) >> 2] & 65535) | 0; //@line 29253
 $12 = ($10 | 0) == 0 & 1; //@line 29255
 HEAP32[96441] = 0; //@line 29256
 HEAP32[96442] = 0; //@line 29256
 HEAP32[96443] = 0; //@line 29256
 HEAP32[96444] = 0; //@line 29256
 HEAP32[96442] = $12; //@line 29257
 HEAP32[96443] = $10 >>> 31; //@line 29259
 HEAP32[$6 >> 2] = $10; //@line 29260
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 29263
 return;
}
function __Z12op_52f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 6793
 $3 = $2 + 2 | 0; //@line 6794
 HEAP32[162769] = $3; //@line 6795
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6797
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 6804
 HEAP32[162769] = $2 + 4; //@line 6806
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 6807
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6818
 return;
}
function __Z12op_5ee0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 10759
 $2 = 651040 + ($1 << 2) | 0; //@line 10760
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 10764
 HEAP32[$2 >> 2] = $6; //@line 10765
 if (!(HEAP32[96442] | 0)) {
  $17 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10773
 } else {
  $17 = 0; //@line 10775
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, $17); //@line 10782
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10785
 return;
}
function __Z11op_820_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $15 = 0, $4 = 0, $5 = 0, $9 = 0;
 $1 = $0 & 7; //@line 13853
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 13856
 $5 = 651040 + ($1 << 2) | 0; //@line 13857
 $9 = (HEAP32[$5 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 13861
 $15 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($9 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($9) | 0; //@line 13867
 HEAP32[$5 >> 2] = $9; //@line 13868
 HEAP32[96442] = $15 << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 13876
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13879
 return;
}
function __Z12op_d0f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 36837
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 36846
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 36852
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 36853
 HEAP32[$22 >> 2] = ($21 << 16 >> 16) + (HEAP32[$22 >> 2] | 0); //@line 36858
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 36861
 return;
}
function __Z12op_90f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $21 = 0, $22 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 24060
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 24069
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 24075
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 24076
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) - ($21 << 16 >> 16); //@line 24081
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24084
 return;
}
function __Z12op_4e50_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0, $4 = 0;
 $3 = (HEAP32[162767] | 0) + -4 | 0; //@line 195
 HEAP32[162767] = $3; //@line 196
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 197
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, HEAP32[$4 >> 2] | 0); //@line 204
 HEAP32[$4 >> 2] = HEAP32[162767]; //@line 206
 $12 = HEAP32[162769] | 0; //@line 207
 HEAP32[162767] = (((HEAPU8[$12 + 2 >> 0] | 0) << 8 | (HEAPU8[$12 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[162767] | 0); //@line 220
 HEAP32[162769] = $12 + 4; //@line 222
 return;
}
function __Z12op_4180_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $7 = 0, $sext = 0;
 $4 = HEAP32[162769] | 0; //@line 42002
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42005
 $sext = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] << 16; //@line 42008
 if (($sext | 0) < 0) {
  HEAP32[96443] = 1; //@line 42012
  __Z9Exceptionij(6, $7); //@line 42013
  return;
 }
 if (($sext | 0) > (HEAP32[651008 + (($0 & 7) << 2) >> 2] << 16 | 0)) {
  HEAP32[96443] = 0; //@line 42022
  __Z9Exceptionij(6, $7); //@line 42023
  return;
 } else {
  HEAP32[162769] = $4 + 2; //@line 42027
  return;
 }
}
function __Z12op_5fd8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 11140
 $2 = 651040 + ($1 << 2) | 0; //@line 11141
 $3 = HEAP32[$2 >> 2] | 0; //@line 11142
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 11146
 if (!(HEAP32[96442] | 0)) {
  $17 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11154
 } else {
  $17 = 255; //@line 11156
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, $17); //@line 11163
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 11166
 return;
}
function __Z12op_4880_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 50310
 $3 = HEAP32[$2 >> 2] | 0; //@line 50311
 $4 = $3 << 24 >> 24; //@line 50313
 $6 = ($3 & 255 | 0) == 0 & 1; //@line 50316
 HEAP32[96441] = 0; //@line 50317
 HEAP32[96442] = 0; //@line 50317
 HEAP32[96443] = 0; //@line 50317
 HEAP32[96444] = 0; //@line 50317
 HEAP32[96442] = $6; //@line 50318
 HEAP32[96443] = $3 >>> 7 & 1; //@line 50321
 HEAP32[$2 >> 2] = $4 & 65535 | $3 & -65536; //@line 50325
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 50328
 return;
}
function __Z12op_2070_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 28406
 $5 = $4 + 2 | 0; //@line 28407
 HEAP32[162769] = $5; //@line 28408
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28410
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 28417
 HEAP32[162769] = $4 + 4; //@line 28419
 $16 = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 28420
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28427
 return;
}
function __Z12op_d0f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 33371
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 33380
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 33395
 $28 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33396
 HEAP32[$28 >> 2] = ($27 << 16 >> 16) + (HEAP32[$28 >> 2] | 0); //@line 33401
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 33404
 return;
}
function __Z12op_90f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $27 = 0, $28 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 19749
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 19758
 $27 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 19773
 $28 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19774
 HEAP32[$28 >> 2] = (HEAP32[$28 >> 2] | 0) - ($27 << 16 >> 16); //@line 19779
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 19782
 return;
}
function __Z12op_5ff0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 12161
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12170
 if (!(HEAP32[96442] | 0)) {
  $24 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 12178
 } else {
  $24 = 255; //@line 12180
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $24); //@line 12187
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12190
 return;
}
function __Z12op_4c3a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $26 = 0, $31 = 0;
 $1 = HEAP32[162769] | 0; //@line 53150
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53159
 $26 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 53176
 $31 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($26 >>> 16 << 2) >> 2] >> 2] & 127]($26) | 0; //@line 53181
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 53184
 __Z9m68k_mulljjt($0, $31, $10); //@line 53185
 return;
}
function __Z12op_487b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $17 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 2754
 $$cast = $2; //@line 2759
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 2768
 $17 = (HEAP32[162767] | 0) + -4 | 0; //@line 2770
 HEAP32[162767] = $17; //@line 2771
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($17, $15); //@line 2777
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2780
 return;
}
function __Z12op_e098_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 38269
 $7 = HEAP32[$6 >> 2] | 0; //@line 38270
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 31; //@line 38271
 $12 = $7 << 32 - $8 | $7 >>> $8; //@line 38275
 $13 = $12 >>> 31; //@line 38276
 HEAP32[96444] = 0; //@line 38277
 HEAP32[96441] = $13; //@line 38278
 HEAP32[96442] = ($12 | 0) == 0 & 1; //@line 38281
 HEAP32[96443] = $13; //@line 38282
 HEAP32[$6 >> 2] = $12; //@line 38283
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 38286
 return;
}
function __Z12op_5ed8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 10725
 $2 = 651040 + ($1 << 2) | 0; //@line 10726
 $3 = HEAP32[$2 >> 2] | 0; //@line 10727
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 10731
 if (!(HEAP32[96442] | 0)) {
  $17 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10739
 } else {
  $17 = 0; //@line 10741
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, $17); //@line 10748
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10751
 return;
}
function __Z12op_53f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 7145
 $3 = $2 + 2 | 0; //@line 7146
 HEAP32[162769] = $3; //@line 7147
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7149
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 7156
 HEAP32[162769] = $2 + 4; //@line 7158
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 7159
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7170
 return;
}
function __Z12op_d0e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 33263
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 33274
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 33280
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33281
 HEAP32[$23 >> 2] = ($22 << 16 >> 16) + (HEAP32[$23 >> 2] | 0); //@line 33286
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33289
 return;
}
function __Z12op_90e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $22 = 0, $23 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 19641
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 19652
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 19658
 $23 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19659
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) - ($22 << 16 >> 16); //@line 19664
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19667
 return;
}
function __Z12op_5ef0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $24 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 12121
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12130
 if (!(HEAP32[96442] | 0)) {
  $24 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 12138
 } else {
  $24 = 0; //@line 12140
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, $24); //@line 12147
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12150
 return;
}
function __Z12op_40f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $21 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41445
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 41448
  $12 = HEAPU8[$3 + 3 >> 0] << 16 | HEAPU8[$3 + 2 >> 0] << 24; //@line 41457
  $21 = $12 | HEAPU8[$3 + 4 >> 0] << 8 | HEAPU8[$3 + 5 >> 0]; //@line 41466
  __Z6MakeSRv(); //@line 41467
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($21, HEAPU16[325558] | 0); //@line 41475
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 41478
  return;
 }
}
function __Z12op_5ff9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $30 = 0;
 $1 = HEAP32[162769] | 0; //@line 11328
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 11337
 if (!(HEAP32[96442] | 0)) {
  $30 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11354
 } else {
  $30 = 255; //@line 11356
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), $30); //@line 11363
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11366
 return;
}
function __Z12op_4c20_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $14 = 0, $19 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 52962
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 52971
 $12 = 651040 + (($0 & 7) << 2) | 0; //@line 52972
 $14 = (HEAP32[$12 >> 2] | 0) + -4 | 0; //@line 52974
 $19 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($14 >>> 16 << 2) >> 2] >> 2] & 127]($14) | 0; //@line 52979
 HEAP32[$12 >> 2] = $14; //@line 52980
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52983
 __Z9m68k_mulljjt($0, $19, $11); //@line 52984
 return;
}
function __ZN13driver_window10grab_mouseEv($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $4 = 0;
 $1 = $0 + 20 | 0; //@line 43952
 if (HEAP8[$1 >> 0] | 0) {
  return;
 }
 $4 = _SDL_GetVideoInfo() | 0; //@line 43958
 if (!$4) {
  return;
 }
 if (!(HEAP32[$4 >> 2] & 2)) {
  return;
 }
 if ((_SDL_WM_GrabInput(1) | 0) != 1) {
  return;
 }
 $11 = _SDL_GetVideoInfo() | 0; //@line 43974
 if ($11 | 0) {
  if (HEAP32[$11 >> 2] & 2 | 0) {
   $16 = __Z9GetStringi(10047) | 0; //@line 43981
   _SDL_WM_SetCaption($16 | 0, $16 | 0); //@line 43982
  }
 }
 HEAP8[$1 >> 0] = 1; //@line 43985
 return;
}
function __Z12op_487a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $18 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 50240
 $$cast = $2; //@line 50242
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 50256
 $18 = (HEAP32[162767] | 0) + -4 | 0; //@line 50258
 HEAP32[162767] = $18; //@line 50259
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($18, $16); //@line 50265
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50268
 return;
}
function __Z12op_46d8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $4 = 0, $5 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49211
  return;
 } else {
  $4 = 651040 + (($0 & 7) << 2) | 0; //@line 49215
  $5 = HEAP32[$4 >> 2] | 0; //@line 49216
  $12 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0) & 65535; //@line 49223
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 49226
  HEAP16[325558] = $12; //@line 49227
  __Z10MakeFromSRv(); //@line 49228
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49231
  return;
 }
}
function __Z12op_44f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $25 = 0;
 $1 = HEAP32[162769] | 0; //@line 48110
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 48119
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 48134
 __Z6MakeSRv(); //@line 48135
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $25 & 255; //@line 48142
 __Z10MakeFromSRv(); //@line 48143
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 48146
 return;
}
function __Z10SCSISelecti($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 do {
  if ((HEAP32[28496] | 0) == 1) {
   if ($0 >>> 0 > 7) {
    $$0 = 4; //@line 22821
   } else {
    HEAP32[28498] = $0; //@line 22823
    if (__Z22scsi_is_target_presenti($0) | 0) {
     HEAP32[28496] = 2; //@line 22826
     HEAP16[325962] = 106; //@line 22827
     $$0 = 0; //@line 22828
     break;
    } else {
     HEAP32[28496] = 0; //@line 22831
     HEAP16[325962] = 0; //@line 22832
     $$0 = 2; //@line 22833
     break;
    }
   }
  } else {
   $$0 = 8; //@line 22838
  }
 } while (0);
 return $$0 | 0; //@line 22841
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0;
 $x_sroa_0_0_extract_trunc = $a$0; //@line 4646
 $y_sroa_0_0_extract_trunc = $b$0; //@line 4647
 $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0; //@line 4648
 $1$1 = tempRet0; //@line 4649
 return (tempRet0 = (Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0) + (Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $1$1 | $1$1 & 0, $1$0 | 0 | 0) | 0; //@line 4651
}
function __Z12op_6fff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $26 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 13467
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 13485
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   $27 = 6; //@line 13493
   $26 = $1 + $27 | 0; //@line 13494
   HEAP32[162769] = $26; //@line 13495
   return;
  }
 }
 $27 = $19 + 2 | 0; //@line 13500
 $26 = $1 + $27 | 0; //@line 13501
 HEAP32[162769] = $26; //@line 13502
 return;
}
function __Z12op_5fe8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11211
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 11222
 if (!(HEAP32[96442] | 0)) {
  $25 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11230
 } else {
  $25 = 255; //@line 11232
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, $25); //@line 11239
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11242
 return;
}
function __Z12op_5ef9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $30 = 0;
 $1 = HEAP32[162769] | 0; //@line 10913
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 10922
 if (!(HEAP32[96442] | 0)) {
  $30 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10939
 } else {
  $30 = 0; //@line 10941
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), $30); //@line 10948
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10951
 return;
}
function __Z12op_44e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 47999
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 48010
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($14) | 0; //@line 48016
 __Z6MakeSRv(); //@line 48017
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $20 & 255; //@line 48024
 __Z10MakeFromSRv(); //@line 48025
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48028
 return;
}
function __Z12op_5ee8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $25 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 10796
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 10807
 if (!(HEAP32[96442] | 0)) {
  $25 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10815
 } else {
  $25 = 0; //@line 10817
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, $25); //@line 10824
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10827
 return;
}
function __Z12op_4c39_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $33 = 0;
 $1 = HEAP32[162769] | 0; //@line 53106
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53115
 $19 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 53124
 $33 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0; //@line 53138
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 53141
 __Z9m68k_mulljjt($0, $33, $10); //@line 53142
 return;
}
function __Z12op_4a50_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51869
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 51875
 $11 = ($9 & 65535 | 0) == 0 & 1; //@line 51878
 HEAP32[96441] = 0; //@line 51879
 HEAP32[96442] = 0; //@line 51879
 HEAP32[96443] = 0; //@line 51879
 HEAP32[96444] = 0; //@line 51879
 HEAP32[96442] = $11; //@line 51880
 HEAP32[96443] = $9 >>> 15 & 1; //@line 51883
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51886
 return;
}
function __Z12op_44f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2373
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2382
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($13) | 0; //@line 2388
 __Z6MakeSRv(); //@line 2389
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $19 & 255; //@line 2396
 __Z10MakeFromSRv(); //@line 2397
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2400
 return;
}
function __Z12op_42a0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 46423
 $4 = (HEAP32[$2 >> 2] | 0) + -4 | 0; //@line 46425
 HEAP32[$2 >> 2] = $4; //@line 46426
 HEAP32[96441] = 0; //@line 46427
 HEAP32[96442] = 0; //@line 46427
 HEAP32[96443] = 0; //@line 46427
 HEAP32[96444] = 0; //@line 46427
 HEAP32[96442] = 1; //@line 46428
 HEAP32[96443] = 0; //@line 46429
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($4, 0); //@line 46435
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46438
 return;
}
function __Z12op_4260_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 43006
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 43008
 HEAP32[$2 >> 2] = $4; //@line 43009
 HEAP32[96441] = 0; //@line 43010
 HEAP32[96442] = 0; //@line 43010
 HEAP32[96443] = 0; //@line 43010
 HEAP32[96444] = 0; //@line 43010
 HEAP32[96442] = 1; //@line 43011
 HEAP32[96443] = 0; //@line 43012
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($4, 0); //@line 43018
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 43021
 return;
}
function __Z12op_4c28_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $23 = 0, $28 = 0;
 $2 = HEAP32[162769] | 0; //@line 52993
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53002
 $23 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 53015
 $28 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($23 >>> 16 << 2) >> 2] >> 2] & 127]($23) | 0; //@line 53020
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 53023
 __Z9m68k_mulljjt($0, $28, $11); //@line 53024
 return;
}
function __Z12op_42b8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 46511
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 46521
 HEAP32[96441] = 0; //@line 46522
 HEAP32[96442] = 0; //@line 46522
 HEAP32[96443] = 0; //@line 46522
 HEAP32[96444] = 0; //@line 46522
 HEAP32[96442] = 1; //@line 46523
 HEAP32[96443] = 0; //@line 46524
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($10, 0); //@line 46530
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46533
 return;
}
function __Z12op_4278_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 43094
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 43104
 HEAP32[96441] = 0; //@line 43105
 HEAP32[96442] = 0; //@line 43105
 HEAP32[96443] = 0; //@line 43105
 HEAP32[96444] = 0; //@line 43105
 HEAP32[96442] = 1; //@line 43106
 HEAP32[96443] = 0; //@line 43107
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($10, 0); //@line 43113
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 43116
 return;
}
function __Z12op_4238_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 42877
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 42887
 HEAP32[96441] = 0; //@line 42888
 HEAP32[96442] = 0; //@line 42888
 HEAP32[96443] = 0; //@line 42888
 HEAP32[96444] = 0; //@line 42888
 HEAP32[96442] = 1; //@line 42889
 HEAP32[96443] = 0; //@line 42890
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, 0); //@line 42896
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42899
 return;
}
function __Z12op_5af0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 9453
 $3 = $2 + 2 | 0; //@line 9454
 HEAP32[162769] = $3; //@line 9455
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9457
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 9464
 HEAP32[162769] = $2 + 4; //@line 9466
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 9467
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9476
 return;
}
function __Z12op_58f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 8797
 $3 = $2 + 2 | 0; //@line 8798
 HEAP32[162769] = $3; //@line 8799
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8801
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8808
 HEAP32[162769] = $2 + 4; //@line 8810
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 8811
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8820
 return;
}
function __Z12op_56f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 8141
 $3 = $2 + 2 | 0; //@line 8142
 HEAP32[162769] = $3; //@line 8143
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8145
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8152
 HEAP32[162769] = $2 + 4; //@line 8154
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 8155
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8164
 return;
}
function __Z12op_54f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 7485
 $3 = $2 + 2 | 0; //@line 7486
 HEAP32[162769] = $3; //@line 7487
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7489
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 7496
 HEAP32[162769] = $2 + 4; //@line 7498
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 7499
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7508
 return;
}
function __Z12op_4a10_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51487
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($3) | 0; //@line 51493
 $11 = ($9 & 255 | 0) == 0 & 1; //@line 51496
 HEAP32[96441] = 0; //@line 51497
 HEAP32[96442] = 0; //@line 51497
 HEAP32[96443] = 0; //@line 51497
 HEAP32[96444] = 0; //@line 51497
 HEAP32[96442] = $11; //@line 51498
 HEAP32[96443] = $9 >>> 7 & 1; //@line 51501
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51504
 return;
}
function __Z12op_6100_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $17 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 12334
 $11 = (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0; //@line 12345
 $17 = (HEAP32[162768] | 0) + 4 + $1 - (HEAP32[162770] | 0) | 0; //@line 12351
 $19 = (HEAP32[162767] | 0) + -4 | 0; //@line 12353
 HEAP32[162767] = $19; //@line 12354
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($19 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($19, $17); //@line 12360
 HEAP32[162769] = (HEAP32[162769] | 0) + $11; //@line 12363
 return;
}
function __Z12op_4298_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 43198
 $3 = HEAP32[$2 >> 2] | 0; //@line 43199
 HEAP32[$2 >> 2] = $3 + 4; //@line 43201
 HEAP32[96441] = 0; //@line 43202
 HEAP32[96442] = 0; //@line 43202
 HEAP32[96443] = 0; //@line 43202
 HEAP32[96444] = 0; //@line 43202
 HEAP32[96442] = 1; //@line 43203
 HEAP32[96443] = 0; //@line 43204
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, 0); //@line 43210
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 43213
 return;
}
function __Z12op_4258_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 42983
 $3 = HEAP32[$2 >> 2] | 0; //@line 42984
 HEAP32[$2 >> 2] = $3 + 2; //@line 42986
 HEAP32[96441] = 0; //@line 42987
 HEAP32[96442] = 0; //@line 42987
 HEAP32[96443] = 0; //@line 42987
 HEAP32[96444] = 0; //@line 42987
 HEAP32[96442] = 1; //@line 42988
 HEAP32[96443] = 0; //@line 42989
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, 0); //@line 42995
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42998
 return;
}
function __ZN13driver_window12ungrab_mouseEv($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $16 = 0, $4 = 0;
 $1 = $0 + 20 | 0; //@line 43992
 if (!(HEAP8[$1 >> 0] | 0)) {
  return;
 }
 $4 = _SDL_GetVideoInfo() | 0; //@line 43998
 if ($4 | 0) {
  if (HEAP32[$4 >> 2] & 2 | 0) {
   if (_SDL_WM_GrabInput(0) | 0) {
    return;
   }
  }
 }
 $11 = _SDL_GetVideoInfo() | 0; //@line 44012
 if ($11 | 0) {
  if (HEAP32[$11 >> 2] & 2 | 0) {
   $16 = __Z9GetStringi(4e3) | 0; //@line 44019
   _SDL_WM_SetCaption($16 | 0, $16 | 0); //@line 44020
  }
 }
 HEAP8[$1 >> 0] = 0; //@line 44023
 return;
}
function __Z12op_46e0_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49242
  return;
 } else {
  $4 = 651040 + (($0 & 7) << 2) | 0; //@line 49246
  $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 49248
  $13 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0) & 65535; //@line 49255
  HEAP32[$4 >> 2] = $6; //@line 49256
  HEAP16[325558] = $13; //@line 49257
  __Z10MakeFromSRv(); //@line 49258
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49261
  return;
 }
}
function __Z12op_5bf0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 9781
 $3 = $2 + 2 | 0; //@line 9782
 HEAP32[162769] = $3; //@line 9783
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9785
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 9792
 HEAP32[162769] = $2 + 4; //@line 9794
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 9795
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96443] | 0 ? 255 : 0); //@line 9804
 return;
}
function __Z12op_59f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 9125
 $3 = $2 + 2 | 0; //@line 9126
 HEAP32[162769] = $3; //@line 9127
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9129
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 9136
 HEAP32[162769] = $2 + 4; //@line 9138
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 9139
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96444] | 0 ? 255 : 0); //@line 9148
 return;
}
function __Z12op_57f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 8469
 $3 = $2 + 2 | 0; //@line 8470
 HEAP32[162769] = $3; //@line 8471
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8473
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 8480
 HEAP32[162769] = $2 + 4; //@line 8482
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 8483
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96442] | 0 ? 255 : 0); //@line 8492
 return;
}
function __Z12op_55f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 7813
 $3 = $2 + 2 | 0; //@line 7814
 HEAP32[162769] = $3; //@line 7815
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7817
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 7824
 HEAP32[162769] = $2 + 4; //@line 7826
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 7827
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96441] | 0 ? 255 : 0); //@line 7836
 return;
}
function __Z12op_4100_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $7 = 0, $9 = 0;
 $4 = HEAP32[162769] | 0; //@line 41489
 $7 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 41492
 $9 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 41494
 if (($9 | 0) < 0) {
  HEAP32[96443] = 1; //@line 41498
  __Z9Exceptionij(6, $7); //@line 41499
  return;
 }
 if (($9 | 0) > (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0)) {
  HEAP32[96443] = 0; //@line 41507
  __Z9Exceptionij(6, $7); //@line 41508
  return;
 } else {
  HEAP32[162769] = $4 + 2; //@line 41512
  return;
 }
}
function __Z9Init680x0v() {
 var $$0 = 0, $$sink = 0;
 HEAP32[30893] = 0; //@line 49108
 switch (HEAP16[325960] | 0) {
 case 630:
 case 117:
 case 0:
  {
   $$sink = 4194304; //@line 49112
   break;
  }
 case 376:
  {
   $$sink = 10485760; //@line 49116
   break;
  }
 case 1660:
  {
   $$sink = 1082130432; //@line 49120
   break;
  }
 default:
  {
   $$0 = 0; //@line 49124
   return $$0 | 0; //@line 49125
  }
 }
 HEAP32[30896] = $$sink; //@line 49128
 __Z11memory_initv(); //@line 49129
 __Z9init_m68kv(); //@line 49130
 $$0 = 1; //@line 49131
 return $$0 | 0; //@line 49132
}
function __Z12op_4840_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $6 = 0, $8 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 50051
 $3 = HEAP32[$2 >> 2] | 0; //@line 50052
 $6 = $3 >>> 16 | $3 << 16; //@line 50055
 $8 = ($6 | 0) == 0 & 1; //@line 50057
 HEAP32[96441] = 0; //@line 50058
 HEAP32[96442] = 0; //@line 50058
 HEAP32[96443] = 0; //@line 50058
 HEAP32[96444] = 0; //@line 50058
 HEAP32[96442] = $8; //@line 50059
 HEAP32[96443] = $3 >>> 15 & 1; //@line 50062
 HEAP32[$2 >> 2] = $6; //@line 50063
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 50066
 return;
}
function __ZL19get_path_for_fsitemP6FSItem($0) {
 $0 = $0 | 0;
 var $$sink = 0;
 switch (HEAP32[$0 + 4 >> 2] | 0) {
 case 2:
  {
   _strncpy(657423, HEAP32[30828] | 0, 1023) | 0; //@line 34681
   $$sink = 658446; //@line 34682
   HEAP8[$$sink >> 0] = 0; //@line 34683
   return;
  }
 case 1:
  {
   $$sink = 657423; //@line 34688
   HEAP8[$$sink >> 0] = 0; //@line 34689
   return;
  }
 default:
  {
   __ZL19get_path_for_fsitemP6FSItem(HEAP32[$0 + 12 >> 2] | 0); //@line 34696
   __Z18add_path_componentPcPKc(657423, HEAP32[$0 + 16 >> 2] | 0); //@line 34699
   return;
  }
 }
}
function __Z12op_d1f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 49756
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 49765
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 49770
 $21 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 49771
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + $20; //@line 49774
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49777
 return;
}
function __Z12op_91f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $20 = 0, $21 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 24315
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 24324
 $20 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 24329
 $21 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 24330
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) - $20; //@line 24333
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 24336
 return;
}
function _ftruncate($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2995
 STACKTOP = STACKTOP + 16 | 0; //@line 2996
 $vararg_buffer = sp; //@line 2997
 HEAP32[$vararg_buffer >> 2] = $0; //@line 3000
 HEAP32[$vararg_buffer + 4 >> 2] = 0; //@line 3002
 HEAP32[$vararg_buffer + 8 >> 2] = $1; //@line 3004
 HEAP32[$vararg_buffer + 12 >> 2] = (($1 | 0) < 0) << 31 >> 31; //@line 3006
 $5 = ___syscall_ret(___syscall194(194, $vararg_buffer | 0) | 0) | 0; //@line 3008
 STACKTOP = sp; //@line 3009
 return $5 | 0; //@line 3009
}
function _arg_n($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $10 = 0, $2 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 1558
 STACKTOP = STACKTOP + 16 | 0; //@line 1559
 $2 = sp; //@line 1560
 HEAP32[$2 >> 2] = HEAP32[$0 >> 2]; //@line 1562
 $$0 = $1; //@line 1563
 while (1) {
  $9 = (HEAP32[$2 >> 2] | 0) + (4 - 1) & ~(4 - 1); //@line 1577
  $10 = HEAP32[$9 >> 2] | 0; //@line 1578
  HEAP32[$2 >> 2] = $9 + 4; //@line 1580
  if ($$0 >>> 0 > 1) {
   $$0 = $$0 + -1 | 0; //@line 1583
  } else {
   break;
  }
 }
 STACKTOP = sp; //@line 1588
 return $10 | 0; //@line 1588
}
function __Z12op_40f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 45846
  return;
 } else {
  $6 = HEAP32[162769] | 0; //@line 45852
  $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, HEAPU8[$6 + 2 >> 0] << 8 | HEAPU8[$6 + 3 >> 0]) | 0; //@line 45861
  __Z6MakeSRv(); //@line 45862
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($15, HEAPU16[325558] | 0); //@line 45870
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 45873
  return;
 }
}
function __Z12op_d1f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 37220
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 37229
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 37243
 $27 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37244
 HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + $26; //@line 37247
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37250
 return;
}
function __Z12op_91f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $26 = 0, $27 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 21648
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 21657
 $26 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 21671
 $27 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21672
 HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) - $26; //@line 21675
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 21678
 return;
}
function __Z12op_46e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49273
  return;
 } else {
  $6 = HEAP32[162769] | 0; //@line 49279
  $16 = ((HEAPU8[$6 + 2 >> 0] << 8 | HEAPU8[$6 + 3 >> 0]) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 49290
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0; //@line 49298
  __Z10MakeFromSRv(); //@line 49299
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49302
  return;
 }
}
function __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $8 = 0;
 if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, 0) | 0) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0, $1, $2, $3); //@line 4107
 } else {
  $8 = HEAP32[$0 + 8 >> 2] | 0; //@line 4110
  FUNCTION_TABLE_viiii[HEAP32[(HEAP32[$8 >> 2] | 0) + 28 >> 2] & 3]($8, $1, $2, $3); //@line 4114
 }
 return;
}
function __Z12op_46f0_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 2578
  return;
 } else {
  $6 = HEAP32[162769] | 0; //@line 2584
  $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, HEAPU8[$6 + 2 >> 0] << 8 | HEAPU8[$6 + 3 >> 0]) | 0; //@line 2593
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0; //@line 2601
  __Z10MakeFromSRv(); //@line 2602
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2605
  return;
 }
}
function __Z12op_e198_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 39724
 $7 = HEAP32[$6 >> 2] | 0; //@line 39725
 $8 = HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] & 31; //@line 39726
 $12 = $7 >>> (32 - $8 | 0) | $7 << $8; //@line 39730
 HEAP32[96444] = 0; //@line 39732
 HEAP32[96441] = $12 & 1; //@line 39733
 HEAP32[96442] = ($12 | 0) == 0 & 1; //@line 39736
 HEAP32[96443] = $12 >>> 31; //@line 39738
 HEAP32[$6 >> 2] = $12; //@line 39739
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 39742
 return;
}
function __Z12op_d1e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 37121
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 37132
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 37137
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37138
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + $21; //@line 37141
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37144
 return;
}
function __Z12op_91e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $21 = 0, $22 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 21549
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 21560
 $21 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 21565
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21566
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) - $21; //@line 21569
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21572
 return;
}
function __Z12op_48c0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 50879
 $3 = HEAP32[$2 >> 2] | 0; //@line 50880
 $4 = $3 << 16 >> 16; //@line 50882
 $6 = ($4 | 0) == 0 & 1; //@line 50884
 HEAP32[96441] = 0; //@line 50885
 HEAP32[96442] = 0; //@line 50885
 HEAP32[96443] = 0; //@line 50885
 HEAP32[96444] = 0; //@line 50885
 HEAP32[96442] = $6; //@line 50886
 HEAP32[96443] = $3 >>> 15 & 1; //@line 50889
 HEAP32[$2 >> 2] = $4; //@line 50890
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 50893
 return;
}
function _memmove(dest, src, num) {
 dest = dest | 0;
 src = src | 0;
 num = num | 0;
 var ret = 0;
 if ((src | 0) < (dest | 0) & (dest | 0) < (src + num | 0)) {
  ret = dest; //@line 4508
  src = src + num | 0; //@line 4509
  dest = dest + num | 0; //@line 4510
  while ((num | 0) > 0) {
   dest = dest - 1 | 0; //@line 4512
   src = src - 1 | 0; //@line 4513
   num = num - 1 | 0; //@line 4514
   HEAP8[dest >> 0] = HEAP8[src >> 0] | 0; //@line 4515
  }
  dest = ret; //@line 4517
 } else {
  _memcpy(dest, src, num) | 0; //@line 4519
 }
 return dest | 0; //@line 4521
}
function __Z12op_49c0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 51444
 $3 = HEAP32[$2 >> 2] | 0; //@line 51445
 $4 = $3 << 24 >> 24; //@line 51447
 $6 = ($4 | 0) == 0 & 1; //@line 51449
 HEAP32[96441] = 0; //@line 51450
 HEAP32[96442] = 0; //@line 51450
 HEAP32[96443] = 0; //@line 51450
 HEAP32[96444] = 0; //@line 51450
 HEAP32[96442] = $6; //@line 51451
 HEAP32[96443] = $3 >>> 7 & 1; //@line 51454
 HEAP32[$2 >> 2] = $4; //@line 51455
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51458
 return;
}
function __Z12op_40e8_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41328
  return;
 } else {
  $6 = HEAP32[162769] | 0; //@line 41334
  $16 = ((HEAPU8[$6 + 2 >> 0] << 8 | HEAPU8[$6 + 3 >> 0]) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 41345
  __Z6MakeSRv(); //@line 41346
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($16, HEAPU16[325558] | 0); //@line 41354
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41357
  return;
 }
}
function __Z12op_c080_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $8 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 28837
 $8 = HEAP32[$6 >> 2] & HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 28839
 $10 = ($8 | 0) == 0 & 1; //@line 28841
 HEAP32[96441] = 0; //@line 28842
 HEAP32[96442] = 0; //@line 28842
 HEAP32[96443] = 0; //@line 28842
 HEAP32[96444] = 0; //@line 28842
 HEAP32[96442] = $10; //@line 28843
 HEAP32[96443] = $8 >>> 31; //@line 28845
 HEAP32[$6 >> 2] = $8; //@line 28846
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28849
 return;
}
function __Z12op_b180_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 26987
 $8 = HEAP32[$6 >> 2] ^ HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2]; //@line 26989
 $10 = ($8 | 0) == 0 & 1; //@line 26991
 HEAP32[96441] = 0; //@line 26992
 HEAP32[96442] = 0; //@line 26992
 HEAP32[96443] = 0; //@line 26992
 HEAP32[96444] = 0; //@line 26992
 HEAP32[96442] = $10; //@line 26993
 HEAP32[96443] = $8 >>> 31; //@line 26995
 HEAP32[$6 >> 2] = $8; //@line 26996
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 26999
 return;
}
function __Z12op_8080_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $8 = 0;
 $6 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 14514
 $8 = HEAP32[$6 >> 2] | HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 14516
 $10 = ($8 | 0) == 0 & 1; //@line 14518
 HEAP32[96441] = 0; //@line 14519
 HEAP32[96442] = 0; //@line 14519
 HEAP32[96443] = 0; //@line 14519
 HEAP32[96444] = 0; //@line 14519
 HEAP32[96442] = $10; //@line 14520
 HEAP32[96443] = $8 >>> 31; //@line 14522
 HEAP32[$6 >> 2] = $8; //@line 14523
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 14526
 return;
}
function __Z11op_130_3_ffj($0) {
 $0 = $0 | 0;
 var $17 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 16372
 $8 = HEAP32[162769] | 0; //@line 16375
 $17 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) | 0; //@line 16384
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 16397
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16400
 return;
}
function __Z12op_4a90_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $3 = 0, $8 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52246
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 52251
 $10 = ($8 | 0) == 0 & 1; //@line 52253
 HEAP32[96441] = 0; //@line 52254
 HEAP32[96442] = 0; //@line 52254
 HEAP32[96443] = 0; //@line 52254
 HEAP32[96444] = 0; //@line 52254
 HEAP32[96442] = $10; //@line 52255
 HEAP32[96443] = $8 >>> 31; //@line 52257
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52260
 return;
}
function ___ftello_unlocked($0) {
 $0 = $0 | 0;
 var $$0 = 0, $11 = 0, $12 = 0;
 if (!(HEAP32[$0 >> 2] & 128)) {
  $11 = 1; //@line 2470
 } else {
  $11 = (HEAP32[$0 + 20 >> 2] | 0) >>> 0 > (HEAP32[$0 + 28 >> 2] | 0) >>> 0 ? 2 : 1; //@line 2478
 }
 $12 = FUNCTION_TABLE_iiii[HEAP32[$0 + 40 >> 2] & 15]($0, 0, $11) | 0; //@line 2480
 if (($12 | 0) < 0) {
  $$0 = $12; //@line 2483
 } else {
  $$0 = $12 - (HEAP32[$0 + 8 >> 2] | 0) + (HEAP32[$0 + 4 >> 2] | 0) + (HEAP32[$0 + 20 >> 2] | 0) - (HEAP32[$0 + 28 >> 2] | 0) | 0; //@line 2497
 }
 return $$0 | 0; //@line 2499
}
function __Z12op_4efb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $15 = 0, $2 = 0, $21 = 0;
 $2 = HEAP32[162769] | 0; //@line 3724
 $$cast = $2; //@line 3729
 $15 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 3738
 $21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($15) | 0; //@line 3744
 HEAP32[162770] = $21; //@line 3745
 HEAP32[162769] = $21; //@line 3746
 HEAP32[162768] = $15; //@line 3747
 return;
}
function __Z12op_4480_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $2 = 0, $3 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 47558
 $3 = HEAP32[$2 >> 2] | 0; //@line 47559
 $6 = ($3 | 0) > 0 & 1; //@line 47563
 HEAP32[96442] = ($3 | 0) == 0 & 1; //@line 47566
 HEAP32[96444] = $6 & $3 >>> 31; //@line 47568
 $11 = ($3 | 0) != 0 & 1; //@line 47570
 HEAP32[96441] = $11; //@line 47571
 HEAP32[96445] = $11; //@line 47572
 HEAP32[96443] = $6; //@line 47573
 HEAP32[$2 >> 2] = 0 - $3; //@line 47574
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47577
 return;
}
function _calloc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $3 = 0, $8 = 0;
 if (!$0) {
  $$0 = 0; //@line 53304
 } else {
  $3 = Math_imul($1, $0) | 0; //@line 53306
  if (($1 | $0) >>> 0 > 65535) {
   $$0 = (($3 >>> 0) / ($0 >>> 0) | 0 | 0) == ($1 | 0) ? $3 : -1; //@line 53313
  } else {
   $$0 = $3; //@line 53315
  }
 }
 $8 = _malloc($$0) | 0; //@line 53318
 if (!$8) {
  return $8 | 0; //@line 53321
 }
 if (!(HEAP32[$8 + -4 >> 2] & 3)) {
  return $8 | 0; //@line 53328
 }
 _memset($8 | 0, 0, $$0 | 0) | 0; //@line 53330
 return $8 | 0; //@line 53331
}
function __Z12op_4abc_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $21 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 52536
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 52539
 $21 = ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | $4 << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0) | 0) == 0 & 1; //@line 52556
 HEAP32[96441] = 0; //@line 52557
 HEAP32[96442] = 0; //@line 52557
 HEAP32[96443] = 0; //@line 52557
 HEAP32[96444] = 0; //@line 52557
 HEAP32[96442] = $21; //@line 52558
 HEAP32[96443] = $4 >>> 7; //@line 52560
 HEAP32[162769] = $1 + 6; //@line 52562
 return;
}
function __Z12op_307b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 44315
 $$cast = $4; //@line 44320
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 44329
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($17) | 0) << 16 >> 16; //@line 44339
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44342
 return;
}
function __Z12op_46f9_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49390
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 49393
  $12 = HEAPU8[$3 + 3 >> 0] << 16 | HEAPU8[$3 + 2 >> 0] << 24; //@line 49402
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | HEAPU8[$3 + 4 >> 0] << 8 | HEAPU8[$3 + 5 >> 0]) | 0; //@line 49419
  __Z10MakeFromSRv(); //@line 49420
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 49423
  return;
 }
}
function __Z12op_6eff_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $5 = 0, $9 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22939
 HEAP32[162769] = $2; //@line 22940
 $5 = $2; //@line 22943
 if (HEAP32[96442] | 0) {
  return;
 }
 if ((HEAP32[96443] | 0) != (HEAP32[96444] | 0)) {
  return;
 }
 $9 = HEAP32[162768] | 0; //@line 22953
 $10 = HEAP32[162770] | 0; //@line 22954
 HEAP32[96446] = $9 + 2 + $5 - $10; //@line 22958
 HEAP32[96447] = $9 + 1 + $5 - $10; //@line 22962
 HEAP16[325963] = $0; //@line 22964
 __Z9Exceptionij(3, 0); //@line 22965
 return;
}
function __Z12op_4680_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 48878
 $3 = HEAP32[$2 >> 2] | 0; //@line 48879
 $4 = ~$3; //@line 48880
 $6 = ($3 | 0) == -1 & 1; //@line 48882
 HEAP32[96441] = 0; //@line 48883
 HEAP32[96442] = 0; //@line 48883
 HEAP32[96443] = 0; //@line 48883
 HEAP32[96444] = 0; //@line 48883
 HEAP32[96442] = $6; //@line 48884
 HEAP32[96443] = $3 >>> 31 ^ 1; //@line 48887
 HEAP32[$2 >> 2] = $4; //@line 48888
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48891
 return;
}
function __Z14SysGetFileSizePv($0) {
 $0 = $0 | 0;
 var $$0 = 0, $14 = 0;
 if (!$0) {
  $$0 = 1; //@line 2288
  return $$0 | 0; //@line 2289
 }
 if (HEAP32[$0 + 24 >> 2] | 0) {
  $$0 = HEAP32[$0 + 16 >> 2] | 0; //@line 2297
  return $$0 | 0; //@line 2298
 }
 if (!(HEAP8[$0 + 8 >> 0] | 0)) {
  $14 = _lseek(HEAP32[$0 + 4 >> 2] | 0, 0, 2) | 0; //@line 2306
  $$0 = $14 - (HEAP32[$0 + 12 >> 2] | 0) | 0; //@line 2310
  return $$0 | 0; //@line 2311
 } else {
  $$0 = HEAP32[$0 + 16 >> 2] | 0; //@line 2315
  return $$0 | 0; //@line 2316
 }
 return 0; //@line 2318
}
function __Z11op_139_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6794
 $5 = HEAP32[162769] | 0; //@line 6795
 $14 = (HEAPU8[$5 + 3 >> 0] | 0) << 16 | (HEAPU8[$5 + 2 >> 0] | 0) << 24; //@line 6804
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14 | (HEAPU8[$5 + 4 >> 0] | 0) << 8 | (HEAPU8[$5 + 5 >> 0] | 0)) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 6826
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6829
 return;
}
function __Z12op_6fff_3_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $5 = 0, $9 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22973
 HEAP32[162769] = $2; //@line 22974
 $5 = $2; //@line 22977
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   return;
  }
 }
 $9 = HEAP32[162768] | 0; //@line 22986
 $10 = HEAP32[162770] | 0; //@line 22987
 HEAP32[96446] = $9 + 2 + $5 - $10; //@line 22991
 HEAP32[96447] = $9 + 1 + $5 - $10; //@line 22995
 HEAP16[325963] = $0; //@line 22997
 __Z9Exceptionij(3, 0); //@line 22998
 return;
}
function __Z11op_83b_3_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $17 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 17330
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 17332
 $17 = __Z15get_disp_ea_000jj($1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0, (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) | 0; //@line 17347
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($17 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($17) | 0) << 24 >> 24 >>> ($3 & 7) & 1 ^ 1; //@line 17361
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17364
 return;
}
function __Z11op_128_0_ffj($0) {
 $0 = $0 | 0;
 var $18 = 0, $5 = 0, $8 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6675
 $8 = HEAP32[162769] | 0; //@line 6678
 $18 = (((HEAPU8[$8 + 2 >> 0] | 0) << 8 | (HEAPU8[$8 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6689
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 6702
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6705
 return;
}
function __Z13GetTicks_usecv() {
 var $0 = 0, $1 = 0, $10 = 0, $4 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 13690
 STACKTOP = STACKTOP + 16 | 0; //@line 13691
 $0 = sp; //@line 13692
 _gettimeofday($0 | 0, 0) | 0; //@line 13693
 $1 = HEAP32[$0 >> 2] | 0; //@line 13694
 $4 = ___muldi3($1 | 0, (($1 | 0) < 0) << 31 >> 31 | 0, 1e6, 0) | 0; //@line 13697
 $7 = HEAP32[$0 + 4 >> 2] | 0; //@line 13700
 $10 = _i64Add($4 | 0, tempRet0 | 0, $7 | 0, (($7 | 0) < 0) << 31 >> 31 | 0) | 0; //@line 13703
 STACKTOP = sp; //@line 13706
 return $10 | 0; //@line 13706
}
function __Z12op_d0d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 33202
 $5 = HEAP32[$4 >> 2] | 0; //@line 33203
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 33209
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 33212
 $14 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33213
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + ($11 << 16 >> 16); //@line 33218
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33221
 return;
}
function __Z12op_90d8_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $14 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 19580
 $5 = HEAP32[$4 >> 2] | 0; //@line 19581
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 19587
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 19590
 $14 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19591
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) - ($11 << 16 >> 16); //@line 19596
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19599
 return;
}
function __Z12op_50f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 4880
 $3 = $2 + 2 | 0; //@line 4881
 HEAP32[162769] = $3; //@line 4882
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4884
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 4891
 HEAP32[162769] = $2 + 4; //@line 4893
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 4894
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 255); //@line 4900
 return;
}
function __Z12op_6f00_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink4 = 0, $1 = 0, $16 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 13403
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 13411
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   $$sink4 = 4; //@line 13419
   $16 = $1 + $$sink4 | 0; //@line 13420
   HEAP32[162769] = $16; //@line 13421
   return;
  }
 }
 $$sink4 = ($9 << 16 >> 16) + 2 | 0; //@line 13428
 $16 = $1 + $$sink4 | 0; //@line 13429
 HEAP32[162769] = $16; //@line 13430
 return;
}
function __Z12op_4efa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $16 = 0, $2 = 0, $22 = 0;
 $2 = HEAP32[162769] | 0; //@line 1125
 $$cast = $2; //@line 1127
 $16 = (HEAP32[162768] | 0) + 2 + $2 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 1141
 $22 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($16) | 0; //@line 1147
 HEAP32[162770] = $22; //@line 1148
 HEAP32[162769] = $22; //@line 1149
 HEAP32[162768] = $16; //@line 1150
 return;
}
function __Z12op_51f0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $14 = 0, $2 = 0, $3 = 0, $5 = 0;
 $2 = HEAP32[162769] | 0; //@line 6499
 $3 = $2 + 2 | 0; //@line 6500
 HEAP32[162769] = $3; //@line 6501
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6503
 $12 = (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0); //@line 6510
 HEAP32[162769] = $2 + 4; //@line 6512
 $14 = __Z15get_disp_ea_020jj($5, $12) | 0; //@line 6513
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 0); //@line 6519
 return;
}
function __GLOBAL__sub_I_audio_cpp() {
 HEAP32[30808] = 0; //@line 26567
 HEAP32[30809] = 0; //@line 26568
 HEAP32[30810] = 0; //@line 26569
 ___cxa_atexit(2218, 123232, ___dso_handle | 0) | 0; //@line 26570
 HEAP32[30811] = 0; //@line 26571
 HEAP32[30812] = 0; //@line 26572
 HEAP32[30813] = 0; //@line 26573
 ___cxa_atexit(2219, 123244, ___dso_handle | 0) | 0; //@line 26574
 HEAP32[30814] = 0; //@line 26575
 HEAP32[30815] = 0; //@line 26576
 HEAP32[30816] = 0; //@line 26577
 ___cxa_atexit(2219, 123256, ___dso_handle | 0) | 0; //@line 26578
 return;
}
function __Z12op_307a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 35618
 $$cast = $4; //@line 35620
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 35634
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($18) | 0) << 16 >> 16; //@line 35644
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35647
 return;
}
function __Z12op_44d8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $9 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47937
 $3 = HEAP32[$2 >> 2] | 0; //@line 47938
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 47944
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 2; //@line 47947
 __Z6MakeSRv(); //@line 47948
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $9 & 255; //@line 47955
 __Z10MakeFromSRv(); //@line 47956
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47959
 return;
}
function __Z11op_83a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $18 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14049
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14051
 $18 = $1 + 4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) + (((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16) | 0; //@line 14068
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($18 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($18) | 0) << 24 >> 24 >>> ($3 & 7) & 1 ^ 1; //@line 14082
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 14085
 return;
}
function __Z12op_6eff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $26 = 0, $27 = 0;
 $1 = HEAP32[162769] | 0; //@line 13361
 if (HEAP32[96442] | 0) {
  $27 = 6; //@line 13365
  $26 = $1 + $27 | 0; //@line 13366
  HEAP32[162769] = $26; //@line 13367
  return;
 }
 $27 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6; //@line 13393
 $26 = $1 + $27 | 0; //@line 13394
 HEAP32[162769] = $26; //@line 13395
 return;
}
function __Z12op_2008_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 27882
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 27884
 $7 = ($5 | 0) == 0 & 1; //@line 27886
 HEAP32[96441] = 0; //@line 27887
 HEAP32[96442] = 0; //@line 27887
 HEAP32[96443] = 0; //@line 27887
 HEAP32[96444] = 0; //@line 27887
 HEAP32[96442] = $7; //@line 27888
 HEAP32[96443] = $5 >>> 31; //@line 27890
 HEAP32[651008 + ($3 << 2) >> 2] = $5; //@line 27892
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27895
 return;
}
function __Z12op_2000_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0, $7 = 0;
 $3 = $0 >>> 9 & 7; //@line 27860
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 27862
 $7 = ($5 | 0) == 0 & 1; //@line 27864
 HEAP32[96441] = 0; //@line 27865
 HEAP32[96442] = 0; //@line 27865
 HEAP32[96443] = 0; //@line 27865
 HEAP32[96444] = 0; //@line 27865
 HEAP32[96442] = $7; //@line 27866
 HEAP32[96443] = $5 >>> 31; //@line 27868
 HEAP32[651008 + ($3 << 2) >> 2] = $5; //@line 27870
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 27873
 return;
}
function __Z12op_d0e0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 33232
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 33234
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 33240
 HEAP32[$4 >> 2] = $6; //@line 33241
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33242
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + ($12 << 16 >> 16); //@line 33247
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33250
 return;
}
function __Z12op_90e0_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $13 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 19610
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 19612
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 19618
 HEAP32[$4 >> 2] = $6; //@line 19619
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19620
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) - ($12 << 16 >> 16); //@line 19625
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19628
 return;
}
function __ZL19Blit_Expand_8_To_32PhPKhj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$012 = 0, $$0811 = 0, $$0910 = 0;
 if (!$2) {
  return;
 }
 $$012 = 0; //@line 26497
 $$0811 = $0; //@line 26497
 $$0910 = $1; //@line 26497
 while (1) {
  HEAP32[$$0811 >> 2] = HEAP32[122204 + ((HEAPU8[$$0910 >> 0] | 0) << 2) >> 2]; //@line 26505
  $$012 = $$012 + 1 | 0; //@line 26506
  if (($$012 | 0) == ($2 | 0)) {
   break;
  } else {
   $$0811 = $$0811 + 4 | 0; //@line 26511
   $$0910 = $$0910 + 1 | 0; //@line 26511
  }
 }
 return;
}
function __Z12op_d0f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 33336
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 33346
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 33352
 $19 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33353
 HEAP32[$19 >> 2] = ($18 << 16 >> 16) + (HEAP32[$19 >> 2] | 0); //@line 33358
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33361
 return;
}
function __Z12op_90f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $18 = 0, $19 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 19714
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 19724
 $18 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 19730
 $19 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19731
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) - ($18 << 16 >> 16); //@line 19736
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19739
 return;
}
function __Z11op_830_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $2 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 17292
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 17294
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) | 0; //@line 17305
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($15) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 17319
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 17322
 return;
}
function ___muldsi3($a, $b) {
 $a = $a | 0;
 $b = $b | 0;
 var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
 $1 = $a & 65535; //@line 4631
 $2 = $b & 65535; //@line 4632
 $3 = Math_imul($2, $1) | 0; //@line 4633
 $6 = $a >>> 16; //@line 4634
 $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0; //@line 4635
 $11 = $b >>> 16; //@line 4636
 $12 = Math_imul($11, $1) | 0; //@line 4637
 return (tempRet0 = ($8 >>> 16) + (Math_imul($11, $6) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, $8 + $12 << 16 | $3 & 65535 | 0) | 0; //@line 4638
}
function __Z12op_5ff8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $21 = 0;
 $1 = HEAP32[162769] | 0; //@line 11290
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 11300
 if (!(HEAP32[96442] | 0)) {
  $21 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11308
 } else {
  $21 = 255; //@line 11310
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, $21); //@line 11317
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11320
 return;
}
function __Z12op_44e0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 47967
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 47969
 $10 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($4) | 0; //@line 47975
 HEAP32[$2 >> 2] = $4; //@line 47976
 __Z6MakeSRv(); //@line 47977
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $10 & 255; //@line 47984
 __Z10MakeFromSRv(); //@line 47985
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47988
 return;
}
function __Z12op_207b_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $17 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 32160
 $$cast = $4; //@line 32165
 $17 = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 32174
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($17 >>> 16 << 2) >> 2] >> 2] & 127]($17) | 0; //@line 32181
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32184
 return;
}
function __Z11op_839_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 14004
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 14006
 $12 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24; //@line 14015
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0)) | 0) << 24 >> 24 >>> ($3 & 7) & 1 ^ 1; //@line 14038
 HEAP32[162769] = (HEAP32[162769] | 0) + 8; //@line 14041
 return;
}
function __Z12op_44f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0;
 $1 = HEAP32[162769] | 0; //@line 48074
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 48084
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($10) | 0; //@line 48090
 __Z6MakeSRv(); //@line 48091
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $16 & 255; //@line 48098
 __Z10MakeFromSRv(); //@line 48099
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48102
 return;
}
function __Z12op_5ef8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $21 = 0;
 $1 = HEAP32[162769] | 0; //@line 10875
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 10885
 if (!(HEAP32[96442] | 0)) {
  $21 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10893
 } else {
  $21 = 0; //@line 10895
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, $21); //@line 10902
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10905
 return;
}
function __Z12op_4ac0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $5 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 52570
 $3 = HEAP32[$2 >> 2] | 0; //@line 52571
 $5 = ($3 & 255 | 0) == 0 & 1; //@line 52574
 HEAP32[96441] = 0; //@line 52575
 HEAP32[96442] = 0; //@line 52575
 HEAP32[96443] = 0; //@line 52575
 HEAP32[96444] = 0; //@line 52575
 HEAP32[96442] = $5; //@line 52576
 HEAP32[96443] = $3 >>> 7 & 1; //@line 52579
 HEAP32[$2 >> 2] = $3 | 128; //@line 52581
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52584
 return;
}
function __Z12op_4879_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $19 = 0, $21 = 0;
 $1 = HEAP32[162769] | 0; //@line 50201
 $19 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 50219
 $21 = (HEAP32[162767] | 0) + -4 | 0; //@line 50221
 HEAP32[162767] = $21; //@line 50222
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($21 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($21, $19); //@line 50228
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 50231
 return;
}
function __Z11op_828_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $2 = 0, $4 = 0;
 $2 = HEAP32[162769] | 0; //@line 13888
 $4 = HEAP8[$2 + 3 >> 0] | 0; //@line 13890
 $16 = (((HEAPU8[$2 + 4 >> 0] | 0) << 8 | (HEAPU8[$2 + 5 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 13903
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($16) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 13917
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13920
 return;
}
function __Z9set_finfoPKcjjb($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $4 = 0;
 $4 = __ZL11open_helperPKcS0_i($0, 103798, 2) | 0; //@line 46659
 if (($4 | 0) < 0) {
  return;
 }
 _write($4, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1) | 0, 16) | 0; //@line 46670
 if ($2 | 0) {
  _write($4, FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($2) | 0, 16) | 0; //@line 46679
 }
 _close($4) | 0; //@line 46681
 return;
}
function __Z9PrefsExitv() {
 var $$in910 = 0, $0 = 0, $$in910$looptemp = 0;
 $0 = HEAP32[28198] | 0; //@line 1023
 if (!$0) {
  HEAP32[28198] = 0; //@line 1026
  return;
 } else {
  $$in910 = $0; //@line 1029
 }
 do {
  $$in910$looptemp = $$in910;
  $$in910 = HEAP32[$$in910 >> 2] | 0; //@line 1032
  _free(HEAP32[$$in910$looptemp + 4 >> 2] | 0); //@line 1035
  _free(HEAP32[$$in910$looptemp + 12 >> 2] | 0); //@line 1038
  __ZdlPv($$in910$looptemp); //@line 1039
 } while (($$in910 | 0) != 0);
 HEAP32[28198] = 0; //@line 1047
 return;
}
function __Z12op_4c38_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $24 = 0;
 $1 = HEAP32[162769] | 0; //@line 53070
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53079
 $19 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 53089
 $24 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($19 >>> 16 << 2) >> 2] >> 2] & 127]($19) | 0; //@line 53094
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 53097
 __Z9m68k_mulljjt($0, $24, $10); //@line 53098
 return;
}
function __Z12op_4868_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $16 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 50108
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 50119
 $16 = (HEAP32[162767] | 0) + -4 | 0; //@line 50121
 HEAP32[162767] = $16; //@line 50122
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($16, $14); //@line 50128
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50131
 return;
}
function __Z12op_4ef9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0, $25 = 0;
 $1 = HEAP32[162769] | 0; //@line 1089
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 1098
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 1107
 $25 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($19) | 0; //@line 1113
 HEAP32[162770] = $25; //@line 1114
 HEAP32[162769] = $25; //@line 1115
 HEAP32[162768] = $19; //@line 1116
 return;
}
function __Z12op_4870_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $15 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2724
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2733
 $15 = (HEAP32[162767] | 0) + -4 | 0; //@line 2735
 HEAP32[162767] = $15; //@line 2736
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($15, $13); //@line 2742
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2745
 return;
}
function __Z9AudioExitv() {
 var $0 = 0, $4 = 0;
 _puts(104284) | 0; //@line 47482
 _puts(104294) | 0; //@line 47483
 $0 = HEAP32[1312] | 0; //@line 47484
 if (($0 | 0) > -1) {
  _close($0) | 0; //@line 47487
  HEAP32[1312] = -1; //@line 47488
 }
 HEAP8[657356] = 0; //@line 47490
 if (HEAP8[659477] | 0) {
  _sem_destroy(123464) | 0; //@line 47494
  HEAP8[659477] = 0; //@line 47495
 }
 $4 = HEAP32[1311] | 0; //@line 47497
 if (($4 | 0) <= -1) {
  return;
 }
 _close($4) | 0; //@line 47502
 HEAP32[1311] = -1; //@line 47503
 return;
}
function __Z12op_d1d8_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 35140
 $5 = HEAP32[$4 >> 2] | 0; //@line 35141
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 35146
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 35149
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 35150
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + $10; //@line 35153
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35156
 return;
}
function __Z12op_91d8_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $13 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 21495
 $5 = HEAP32[$4 >> 2] | 0; //@line 21496
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 21501
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 21504
 $13 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21505
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) - $10; //@line 21508
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21511
 return;
}
function __Z12op_40e0_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41297
  return;
 } else {
  $4 = 651040 + (($0 & 7) << 2) | 0; //@line 41301
  $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 41303
  HEAP32[$4 >> 2] = $6; //@line 41304
  __Z6MakeSRv(); //@line 41305
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($6, HEAPU16[325558] | 0); //@line 41313
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41316
  return;
 }
}
function __Z12op_207a_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $18 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 28506
 $$cast = $4; //@line 28508
 $18 = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16) | 0; //@line 28522
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($18 >>> 16 << 2) >> 2] >> 2] & 127]($18) | 0; //@line 28529
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28532
 return;
}
function __Z12op_4c40_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $17 = 0, $2 = 0, $3 = 0, $7 = 0;
 $2 = HEAP32[162769] | 0; //@line 53272
 $3 = $2 + 2 | 0; //@line 53273
 HEAP32[162769] = $3; //@line 53274
 $7 = $3 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 53279
 $15 = ((HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 53287
 $17 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 53289
 HEAP32[162769] = $2 + 4; //@line 53291
 __Z9m68k_divljjtj($0, $17, $15, $7); //@line 53292
 return;
}
function ___unlist_locked_file($0) {
 $0 = $0 | 0;
 var $$pre = 0, $$sink = 0, $5 = 0, $9 = 0;
 if (HEAP32[$0 + 68 >> 2] | 0) {
  $5 = HEAP32[$0 + 116 >> 2] | 0; //@line 62770
  $$pre = $0 + 112 | 0; //@line 62772
  if ($5 | 0) {
   HEAP32[$5 + 112 >> 2] = HEAP32[$$pre >> 2]; //@line 62776
  }
  $9 = HEAP32[$$pre >> 2] | 0; //@line 62778
  if (!$9) {
   $$sink = (___pthread_self_613() | 0) + 232 | 0; //@line 62783
  } else {
   $$sink = $9 + 116 | 0; //@line 62786
  }
  HEAP32[$$sink >> 2] = $5; //@line 62788
 }
 return;
}
function __Z14timer_add_timeR7timevalS_S_($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $10 = 0, $11 = 0, $5 = 0;
 $5 = (HEAP32[$2 >> 2] | 0) + (HEAP32[$1 >> 2] | 0) | 0; //@line 13558
 HEAP32[$0 >> 2] = $5; //@line 13559
 $10 = (HEAP32[$2 + 4 >> 2] | 0) + (HEAP32[$1 + 4 >> 2] | 0) | 0; //@line 13564
 $11 = $0 + 4 | 0; //@line 13565
 HEAP32[$11 >> 2] = $10; //@line 13566
 if (($10 | 0) <= 999999) {
  return;
 }
 HEAP32[$0 >> 2] = $5 + 1; //@line 13572
 HEAP32[$11 >> 2] = $10 + -1e6; //@line 13574
 return;
}
function __Z12op_40d8_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $5 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41267
  return;
 } else {
  $4 = 651040 + (($0 & 7) << 2) | 0; //@line 41271
  $5 = HEAP32[$4 >> 2] | 0; //@line 41272
  HEAP32[$4 >> 2] = $5 + 2; //@line 41274
  __Z6MakeSRv(); //@line 41275
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($5, HEAPU16[325558] | 0); //@line 41283
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41286
  return;
 }
}
function __Z12op_42f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 46767
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 46776
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 46785
 __Z6MakeSRv(); //@line 46786
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($19, HEAP16[325558] & 255); //@line 46795
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 46798
 return;
}
function __Z12op_7000_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $3 = 0, $5 = 0;
 $1 = $0 << 24 >> 24; //@line 13510
 $3 = $0 >>> 9 & 7; //@line 13512
 $5 = ($1 | 0) == 0 & 1; //@line 13514
 HEAP32[96441] = 0; //@line 13515
 HEAP32[96442] = 0; //@line 13515
 HEAP32[96443] = 0; //@line 13515
 HEAP32[96444] = 0; //@line 13515
 HEAP32[96442] = $5; //@line 13516
 HEAP32[96443] = $0 >>> 7 & 1; //@line 13519
 HEAP32[651008 + ($3 << 2) >> 2] = $1; //@line 13521
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13524
 return;
}
function __Z12op_46f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49353
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 49356
  $12 = (HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]) << 16 >> 16; //@line 49366
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0; //@line 49374
  __Z10MakeFromSRv(); //@line 49375
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49378
  return;
 }
}
function __Z12op_40f9_4_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $19 = 0;
 $1 = HEAP32[162769] | 0; //@line 46385
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 46394
 $19 = $10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 46403
 __Z6MakeSRv(); //@line 46404
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($19, HEAPU16[325558] | 0); //@line 46412
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 46415
 return;
}
function __Z14timer_sub_timeR7timevalS_S_($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $10 = 0, $11 = 0, $5 = 0;
 $5 = (HEAP32[$1 >> 2] | 0) - (HEAP32[$2 >> 2] | 0) | 0; //@line 13585
 HEAP32[$0 >> 2] = $5; //@line 13586
 $10 = (HEAP32[$1 + 4 >> 2] | 0) - (HEAP32[$2 + 4 >> 2] | 0) | 0; //@line 13591
 $11 = $0 + 4 | 0; //@line 13592
 HEAP32[$11 >> 2] = $10; //@line 13593
 if (($10 | 0) >= 0) {
  return;
 }
 HEAP32[$0 >> 2] = $5 + -1; //@line 13599
 HEAP32[$11 >> 2] = $10 + 1e6; //@line 13601
 return;
}
function __Z12op_d1e0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 37093
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 37095
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 37100
 HEAP32[$4 >> 2] = $6; //@line 37101
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37102
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + $11; //@line 37105
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 37108
 return;
}
function __Z12op_91e0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 21521
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 21523
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 21528
 HEAP32[$4 >> 2] = $6; //@line 21529
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21530
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) - $11; //@line 21533
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21536
 return;
}
function __Z12op_d1f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 37188
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 37198
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 37203
 $18 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37204
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + $17; //@line 37207
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 37210
 return;
}
function __Z12op_91f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $17 = 0, $18 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 21616
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 21626
 $17 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 21631
 $18 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21632
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) - $17; //@line 21635
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 21638
 return;
}
function __Z12op_6dff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $6 = 0, $7 = 0, $8 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22910
 HEAP32[162769] = $2; //@line 22911
 $6 = $2; //@line 22915
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  return;
 }
 $7 = HEAP32[162768] | 0; //@line 22919
 $8 = HEAP32[162770] | 0; //@line 22920
 HEAP32[96446] = $7 + 2 + $6 - $8; //@line 22924
 HEAP32[96447] = $7 + 1 + $6 - $8; //@line 22928
 HEAP16[325963] = $0; //@line 22930
 __Z9Exceptionij(3, 0); //@line 22931
 return;
}
function __Z12op_6cff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $6 = 0, $7 = 0, $8 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22881
 HEAP32[162769] = $2; //@line 22882
 $6 = $2; //@line 22886
 if ((HEAP32[96443] | 0) != (HEAP32[96444] | 0)) {
  return;
 }
 $7 = HEAP32[162768] | 0; //@line 22890
 $8 = HEAP32[162770] | 0; //@line 22891
 HEAP32[96446] = $7 + 2 + $6 - $8; //@line 22895
 HEAP32[96447] = $7 + 1 + $6 - $8; //@line 22899
 HEAP16[325963] = $0; //@line 22901
 __Z9Exceptionij(3, 0); //@line 22902
 return;
}
function _write($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 62603
 STACKTOP = STACKTOP + 16 | 0; //@line 62604
 $vararg_buffer = sp; //@line 62605
 HEAP32[$vararg_buffer >> 2] = $0; //@line 62607
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 62609
 HEAP32[$vararg_buffer + 8 >> 2] = $2; //@line 62611
 $5 = ___syscall_ret(___syscall4(4, $vararg_buffer | 0) | 0) | 0; //@line 62613
 STACKTOP = sp; //@line 62614
 return $5 | 0; //@line 62614
}
function __Z12fpuop_trapccjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $9 = 0;
 switch (__ZL8fpp_condi($0 & 63) | 0) {
 case -1:
  {
   $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($1 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($1) | 0; //@line 55805
   HEAP32[162770] = $9; //@line 55806
   HEAP32[162769] = $9; //@line 55807
   HEAP32[162768] = $1; //@line 55808
   __Z7op_illgj($0); //@line 55809
   break;
  }
 case 0:
  {
   return;
  }
 default:
  {}
 }
 __Z9Exceptionij(7, $1 + -2 | 0); //@line 55820
 return;
}
function _read($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 62621
 STACKTOP = STACKTOP + 16 | 0; //@line 62622
 $vararg_buffer = sp; //@line 62623
 HEAP32[$vararg_buffer >> 2] = $0; //@line 62625
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 62627
 HEAP32[$vararg_buffer + 8 >> 2] = $2; //@line 62629
 $5 = ___syscall_ret(___syscall3(3, $vararg_buffer | 0) | 0) | 0; //@line 62631
 STACKTOP = sp; //@line 62632
 return $5 | 0; //@line 62632
}
function __Z12op_40f8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41408
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 41411
  $12 = (HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]) << 16 >> 16; //@line 41421
  __Z6MakeSRv(); //@line 41422
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($12, HEAPU16[325558] | 0); //@line 41430
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 41433
  return;
 }
}
function __Z12op_6e00_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink4 = 0, $1 = 0, $17 = 0;
 $1 = HEAP32[162769] | 0; //@line 13301
 if (HEAP32[96442] | 0) {
  $$sink4 = 4; //@line 13305
  $17 = $1 + $$sink4 | 0; //@line 13306
  HEAP32[162769] = $17; //@line 13307
  return;
 }
 $$sink4 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4; //@line 13325
 $17 = $1 + $$sink4 | 0; //@line 13326
 HEAP32[162769] = $17; //@line 13327
 return;
}
function _copysign($0, $1) {
 $0 = +$0;
 $1 = +$1;
 var $2 = 0, $3 = 0, $8 = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 55706
 $2 = HEAP32[tempDoublePtr >> 2] | 0; //@line 55706
 $3 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 55707
 HEAPF64[tempDoublePtr >> 3] = $1; //@line 55708
 $8 = HEAP32[tempDoublePtr + 4 >> 2] & -2147483648 | $3 & 2147483647; //@line 55712
 HEAP32[tempDoublePtr >> 2] = $2; //@line 55713
 HEAP32[tempDoublePtr + 4 >> 2] = $8; //@line 55713
 return +(+HEAPF64[tempDoublePtr >> 3]);
}
function __Z12op_62ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22597
 HEAP32[162769] = $2; //@line 22598
 $7 = $2; //@line 22603
 if (HEAP32[96442] | HEAP32[96441] | 0) {
  return;
 }
 $8 = HEAP32[162768] | 0; //@line 22607
 $9 = HEAP32[162770] | 0; //@line 22608
 HEAP32[96446] = $8 + 2 + $7 - $9; //@line 22612
 HEAP32[96447] = $8 + 1 + $7 - $9; //@line 22616
 HEAP16[325963] = $0; //@line 22618
 __Z9Exceptionij(3, 0); //@line 22619
 return;
}
function __Z12op_63ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $7 = 0, $8 = 0, $9 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22627
 HEAP32[162769] = $2; //@line 22628
 $7 = $2; //@line 22633
 if (!(HEAP32[96442] | HEAP32[96441])) {
  return;
 }
 $8 = HEAP32[162768] | 0; //@line 22637
 $9 = HEAP32[162770] | 0; //@line 22638
 HEAP32[96446] = $8 + 2 + $7 - $9; //@line 22642
 HEAP32[96447] = $8 + 1 + $7 - $9; //@line 22646
 HEAP16[325963] = $0; //@line 22648
 __Z9Exceptionij(3, 0); //@line 22649
 return;
}
function __Z12op_f2c0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $23 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 48765
 $2 = $1 + 2 | 0; //@line 48766
 HEAP32[162769] = $2; //@line 48767
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 48772
 $23 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0); //@line 48789
 HEAP32[162769] = $1 + 6; //@line 48791
 __Z9fpuop_bccjjj($0, $6, $23); //@line 48792
 return;
}
function __Z11op_138_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0, $5 = 0;
 $4 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6756
 $5 = HEAP32[162769] | 0; //@line 6757
 $14 = ((HEAPU8[$5 + 2 >> 0] | 0) << 8 | (HEAPU8[$5 + 3 >> 0] | 0)) << 16 >> 16; //@line 6767
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($14) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 6780
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6783
 return;
}
function __Z12op_4c10_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $18 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 52901
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 52910
 $13 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52912
 $18 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($13 >>> 16 << 2) >> 2] >> 2] & 127]($13) | 0; //@line 52917
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 52920
 __Z9m68k_mulljjt($0, $18, $11); //@line 52921
 return;
}
function __Z12op_4290_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 43178
 HEAP32[96441] = 0; //@line 43179
 HEAP32[96442] = 0; //@line 43179
 HEAP32[96443] = 0; //@line 43179
 HEAP32[96444] = 0; //@line 43179
 HEAP32[96442] = 1; //@line 43180
 HEAP32[96443] = 0; //@line 43181
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($3, 0); //@line 43187
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 43190
 return;
}
function __Z12op_4250_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42963
 HEAP32[96441] = 0; //@line 42964
 HEAP32[96442] = 0; //@line 42964
 HEAP32[96443] = 0; //@line 42964
 HEAP32[96444] = 0; //@line 42964
 HEAP32[96442] = 1; //@line 42965
 HEAP32[96443] = 0; //@line 42966
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, 0); //@line 42972
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42975
 return;
}
function __Z12op_4210_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42742
 HEAP32[96441] = 0; //@line 42743
 HEAP32[96442] = 0; //@line 42743
 HEAP32[96443] = 0; //@line 42743
 HEAP32[96444] = 0; //@line 42743
 HEAP32[96442] = 1; //@line 42744
 HEAP32[96443] = 0; //@line 42745
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 0); //@line 42751
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42754
 return;
}
function __Z12op_4ef0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $19 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 3697
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 3706
 $19 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($13) | 0; //@line 3712
 HEAP32[162770] = $19; //@line 3713
 HEAP32[162769] = $19; //@line 3714
 HEAP32[162768] = $13; //@line 3715
 return;
}
function __Z12op_4e75_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $6 = 0;
 $1 = HEAP32[162767] | 0; //@line 520
 $6 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($1 >>> 16 << 2) >> 2] >> 2] & 127]($1) | 0; //@line 525
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($6) | 0; //@line 531
 HEAP32[162770] = $12; //@line 532
 HEAP32[162769] = $12; //@line 533
 HEAP32[162768] = $6; //@line 534
 HEAP32[162767] = (HEAP32[162767] | 0) + 4; //@line 537
 return;
}
function __Z12op_3070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 44282
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 44291
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($15 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($15) | 0) << 16 >> 16; //@line 44301
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 44304
 return;
}
function __Z9ExtFSExitv() {
 var $$in = 0, $0 = 0, $4 = 0, $$in$looptemp = 0;
 $0 = HEAP32[30826] | 0; //@line 28662
 if ($0 | 0) {
  $$in = $0; //@line 28665
  do {
   $$in$looptemp = $$in;
   $$in = HEAP32[$$in >> 2] | 0; //@line 28667
   $4 = HEAP32[$$in$looptemp + 16 >> 2] | 0; //@line 28669
   if ($4 | 0) {
    __ZdaPv($4); //@line 28672
   }
   __ZdlPv($$in$looptemp); //@line 28674
  } while (($$in | 0) != 0);
 }
 HEAP32[30827] = 0; //@line 28683
 HEAP32[30826] = 0; //@line 28684
 return;
}
function __Z12op_5de0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 10392
 $2 = 651040 + ($1 << 2) | 0; //@line 10393
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 10397
 HEAP32[$2 >> 2] = $6; //@line 10398
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10408
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10411
 return;
}
function __Z12op_5ce0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 10052
 $2 = 651040 + ($1 << 2) | 0; //@line 10053
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 10057
 HEAP32[$2 >> 2] = $6; //@line 10058
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10068
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10071
 return;
}
function __Z12op_4ee8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $20 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 1003
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 1014
 $20 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($14) | 0; //@line 1020
 HEAP32[162770] = $20; //@line 1021
 HEAP32[162769] = $20; //@line 1022
 HEAP32[162768] = $14; //@line 1023
 return;
}
function __Z14SysIsFixedDiskPv($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if (!$0) {
  $$0 = 1; //@line 2354
  return $$0 | 0; //@line 2355
 }
 if (HEAP32[$0 + 24 >> 2] | 0) {
  $$0 = 1; //@line 2361
  return $$0 | 0; //@line 2362
 }
 if (HEAP8[$0 + 8 >> 0] | 0) {
  $$0 = 1; //@line 2368
  return $$0 | 0; //@line 2369
 }
 if (!(HEAP8[$0 + 9 >> 0] | 0)) {
  return (HEAP8[$0 + 10 >> 0] | 0) == 0 | 0; //@line 2378
 } else {
  $$0 = 0; //@line 2380
  return $$0 | 0; //@line 2381
 }
 return 0; //@line 2383
}
function __Z12op_3079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 35576
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 35585
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0) << 16 >> 16; //@line 35604
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 35607
 return;
}
function __Z12op_6bff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22853
 HEAP32[162769] = $2; //@line 22854
 $5 = $2; //@line 22857
 if (!(HEAP32[96443] | 0)) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22861
 $7 = HEAP32[162770] | 0; //@line 22862
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22866
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22870
 HEAP16[325963] = $0; //@line 22872
 __Z9Exceptionij(3, 0); //@line 22873
 return;
}
function __Z12op_69ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22797
 HEAP32[162769] = $2; //@line 22798
 $5 = $2; //@line 22801
 if (!(HEAP32[96444] | 0)) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22805
 $7 = HEAP32[162770] | 0; //@line 22806
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22810
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22814
 HEAP16[325963] = $0; //@line 22816
 __Z9Exceptionij(3, 0); //@line 22817
 return;
}
function __Z12op_67ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22741
 HEAP32[162769] = $2; //@line 22742
 $5 = $2; //@line 22745
 if (!(HEAP32[96442] | 0)) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22749
 $7 = HEAP32[162770] | 0; //@line 22750
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22754
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22758
 HEAP16[325963] = $0; //@line 22760
 __Z9Exceptionij(3, 0); //@line 22761
 return;
}
function __Z12op_65ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22685
 HEAP32[162769] = $2; //@line 22686
 $5 = $2; //@line 22689
 if (!(HEAP32[96441] | 0)) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22693
 $7 = HEAP32[162770] | 0; //@line 22694
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22698
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22702
 HEAP16[325963] = $0; //@line 22704
 __Z9Exceptionij(3, 0); //@line 22705
 return;
}
function __Z12op_4a7c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $11 = 0, $4 = 0;
 $1 = HEAP32[162769] | 0; //@line 52185
 $4 = HEAPU8[$1 + 2 >> 0] | 0; //@line 52188
 $11 = ($4 << 8 | (HEAPU8[$1 + 3 >> 0] | 0) | 0) == 0 & 1; //@line 52195
 HEAP32[96441] = 0; //@line 52196
 HEAP32[96442] = 0; //@line 52196
 HEAP32[96443] = 0; //@line 52196
 HEAP32[96444] = 0; //@line 52196
 HEAP32[96442] = $11; //@line 52197
 HEAP32[96443] = $4 >>> 7; //@line 52199
 HEAP32[162769] = $1 + 4; //@line 52201
 return;
}
function __Z12op_4e72_0_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 319
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 322
 HEAP16[325558] = HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]; //@line 332
 __Z10MakeFromSRv(); //@line 333
 HEAP8[651123] = 1; //@line 334
 $13 = HEAP32[162771] | 0; //@line 335
 if (!($13 & 16)) {
  HEAP32[162771] = $13 | 1; //@line 340
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 344
 return;
}
function __Z12op_3068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 35474
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 35485
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($16 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($16) | 0) << 16 >> 16; //@line 35495
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35498
 return;
}
function __Z12op_6aff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22825
 HEAP32[162769] = $2; //@line 22826
 $5 = $2; //@line 22829
 if (HEAP32[96443] | 0) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22833
 $7 = HEAP32[162770] | 0; //@line 22834
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22838
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22842
 HEAP16[325963] = $0; //@line 22844
 __Z9Exceptionij(3, 0); //@line 22845
 return;
}
function __Z12op_68ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22769
 HEAP32[162769] = $2; //@line 22770
 $5 = $2; //@line 22773
 if (HEAP32[96444] | 0) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22777
 $7 = HEAP32[162770] | 0; //@line 22778
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22782
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22786
 HEAP16[325963] = $0; //@line 22788
 __Z9Exceptionij(3, 0); //@line 22789
 return;
}
function __Z12op_66ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22713
 HEAP32[162769] = $2; //@line 22714
 $5 = $2; //@line 22717
 if (HEAP32[96442] | 0) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22721
 $7 = HEAP32[162770] | 0; //@line 22722
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22726
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22730
 HEAP16[325963] = $0; //@line 22732
 __Z9Exceptionij(3, 0); //@line 22733
 return;
}
function __Z12op_64ff_3_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $5 = 0, $6 = 0, $7 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22657
 HEAP32[162769] = $2; //@line 22658
 $5 = $2; //@line 22661
 if (HEAP32[96441] | 0) {
  return;
 }
 $6 = HEAP32[162768] | 0; //@line 22665
 $7 = HEAP32[162770] | 0; //@line 22666
 HEAP32[96446] = $6 + 2 + $5 - $7; //@line 22670
 HEAP32[96447] = $6 + 1 + $5 - $7; //@line 22674
 HEAP16[325963] = $0; //@line 22676
 __Z9Exceptionij(3, 0); //@line 22677
 return;
}
function __Z12op_5dd8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 10366
 $2 = 651040 + ($1 << 2) | 0; //@line 10367
 $3 = HEAP32[$2 >> 2] | 0; //@line 10368
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 10372
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10382
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10385
 return;
}
function __Z12op_5cd8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 10026
 $2 = 651040 + ($1 << 2) | 0; //@line 10027
 $3 = HEAP32[$2 >> 2] | 0; //@line 10028
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 10032
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10042
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10045
 return;
}
function __Z12op_5df0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 12088
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12097
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 12107
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12110
 return;
}
function __Z12op_5cf0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 12055
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12064
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 12074
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12077
 return;
}
function __Z12op_52e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 6728
 $2 = 651040 + ($1 << 2) | 0; //@line 6729
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 6733
 HEAP32[$2 >> 2] = $6; //@line 6734
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6745
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6748
 return;
}
function __Z12op_41fb_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $3 = 0, $4 = 0, $8 = 0;
 $3 = HEAP32[162769] | 0; //@line 42697
 $4 = $3 + 2 | 0; //@line 42698
 HEAP32[162769] = $4; //@line 42699
 $8 = $4 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 42704
 $15 = (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0); //@line 42711
 HEAP32[162769] = $3 + 4; //@line 42713
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = __Z15get_disp_ea_020jj($8, $15) | 0; //@line 42716
 return;
}
function _rand() {
 var $0 = 0, $10 = 0, $14 = 0, $6 = 0, $8 = 0, $9 = 0;
 $0 = 112784; //@line 2375
 $6 = ___muldi3(HEAP32[$0 >> 2] | 0, HEAP32[$0 + 4 >> 2] | 0, 1284865837, 1481765933) | 0; //@line 2381
 $8 = _i64Add($6 | 0, tempRet0 | 0, 1, 0) | 0; //@line 2383
 $9 = tempRet0; //@line 2384
 $10 = 112784; //@line 2385
 HEAP32[$10 >> 2] = $8; //@line 2387
 HEAP32[$10 + 4 >> 2] = $9; //@line 2390
 $14 = _bitshift64Lshr($8 | 0, $9 | 0, 33) | 0; //@line 2391
 return $14 | 0; //@line 2393
}
function __Z12op_52f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11731
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11740
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 11751
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11754
 return;
}
function __Z12op_3058_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 35418
 $5 = HEAP32[$4 >> 2] | 0; //@line 35419
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 35425
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 35428
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = $11 << 16 >> 16; //@line 35432
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35435
 return;
}
function __Z12op_6e01_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink8 = 0, $8 = 0, $9 = 0;
 if (HEAP32[96442] | 0) {
  $$sink8 = 2; //@line 13337
  $8 = HEAP32[162769] | 0; //@line 13338
  $9 = $8 + $$sink8 | 0; //@line 13339
  HEAP32[162769] = $9; //@line 13340
  return;
 }
 $$sink8 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? ($0 << 24 >> 24) + 2 | 0 : 2; //@line 13350
 $8 = HEAP32[162769] | 0; //@line 13351
 $9 = $8 + $$sink8 | 0; //@line 13352
 HEAP32[162769] = $9; //@line 13353
 return;
}
function __Z12op_5df9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 10518
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 10527
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10546
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10549
 return;
}
function __Z12op_5cf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 10178
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 10187
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10206
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10209
 return;
}
function __Z12op_40f0_4_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46326
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 46335
 __Z6MakeSRv(); //@line 46336
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, HEAPU16[325558] | 0); //@line 46344
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46347
 return;
}
function __Z12op_5de8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 10422
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 10433
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10443
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10446
 return;
}
function __Z12op_5ce8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 10082
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 10093
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10103
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10106
 return;
}
function __Z12op_51c8_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $2 = 0, $3 = 0, $4 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 6373
 $3 = HEAP32[$2 >> 2] | 0; //@line 6374
 $4 = HEAP32[162769] | 0; //@line 6375
 $12 = (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 6383
 HEAP32[$2 >> 2] = $3 + 65535 & 65535 | $3 & -65536; //@line 6389
 HEAP32[162769] = (HEAP32[162769] | 0) + (($3 & 65535) << 16 >> 16 == 0 ? 4 : ($12 << 16 >> 16) + 2 | 0); //@line 6397
 return;
}
function __Z11op_838_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $12 = 0, $3 = 0;
 $1 = HEAP32[162769] | 0; //@line 13967
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 13969
 $12 = ((HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) << 16 >> 16; //@line 13979
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($12) | 0) << 24 >> 24 >>> ($3 & 7) & 1 ^ 1; //@line 13993
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 13996
 return;
}
function __Z12op_52d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 6701
 $2 = 651040 + ($1 << 2) | 0; //@line 6702
 $3 = HEAP32[$2 >> 2] | 0; //@line 6703
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 6707
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6718
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6721
 return;
}
function __Z12op_42f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 2192
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 2201
 __Z6MakeSRv(); //@line 2202
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($13, HEAP16[325558] & 255); //@line 2211
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 2214
 return;
}
function __Z12op_42e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46671
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 46682
 __Z6MakeSRv(); //@line 46683
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, HEAP16[325558] & 255); //@line 46692
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46695
 return;
}
function __Z12op_53e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 7080
 $2 = 651040 + ($1 << 2) | 0; //@line 7081
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 7085
 HEAP32[$2 >> 2] = $6; //@line 7086
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7097
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7100
 return;
}
function __Z12op_4878_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $12 = 0;
 $1 = HEAP32[162769] | 0; //@line 50171
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 50181
 $12 = (HEAP32[162767] | 0) + -4 | 0; //@line 50183
 HEAP32[162767] = $12; //@line 50184
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($12, $10); //@line 50190
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 50193
 return;
}
function __Z12op_40e8_4_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46292
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 46303
 __Z6MakeSRv(); //@line 46304
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($14, HEAPU16[325558] | 0); //@line 46312
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46315
 return;
}
function __ZN16SDL_monitor_descD0Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 1492; //@line 44080
 $2 = HEAP32[$0 + 4 >> 2] | 0; //@line 44082
 if (!$2) {
  __ZdlPv($0); //@line 44085
  return;
 }
 $4 = $0 + 8 | 0; //@line 44088
 $5 = HEAP32[$4 >> 2] | 0; //@line 44089
 if (($5 | 0) != ($2 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -24 - $2 | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 44099
 }
 __ZdlPv($2); //@line 44101
 __ZdlPv($0); //@line 44102
 return;
}
function __Z12op_53f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11765
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11774
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 11785
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11788
 return;
}
function __Z12op_52f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 6858
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 6867
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6887
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6890
 return;
}
function __Z12op_52e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 6759
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6770
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6781
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6784
 return;
}
function __Z12op_4a3c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $3 = 0, $5 = 0;
 $1 = HEAP32[162769] | 0; //@line 51809
 $3 = HEAP8[$1 + 3 >> 0] | 0; //@line 51811
 $5 = $3 << 24 >> 24 == 0 & 1; //@line 51813
 HEAP32[96441] = 0; //@line 51814
 HEAP32[96442] = 0; //@line 51814
 HEAP32[96443] = 0; //@line 51814
 HEAP32[96444] = 0; //@line 51814
 HEAP32[96442] = $5; //@line 51815
 HEAP32[96443] = ($3 & 255) >>> 7 & 255; //@line 51818
 HEAP32[162769] = $1 + 4; //@line 51820
 return;
}
function __Z12op_41f0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0, $5 = 0, $7 = 0;
 $4 = HEAP32[162769] | 0; //@line 42582
 $5 = $4 + 2 | 0; //@line 42583
 HEAP32[162769] = $5; //@line 42584
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 42586
 $14 = (HEAPU8[$5 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0); //@line 42593
 HEAP32[162769] = $4 + 4; //@line 42595
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = __Z15get_disp_ea_020jj($7, $14) | 0; //@line 42598
 return;
}
function __ZN12monitor_descD0Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 1492; //@line 23503
 $2 = HEAP32[$0 + 4 >> 2] | 0; //@line 23505
 if (!$2) {
  __ZdlPv($0); //@line 23508
  return;
 }
 $4 = $0 + 8 | 0; //@line 23511
 $5 = HEAP32[$4 >> 2] | 0; //@line 23512
 if (($5 | 0) != ($2 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -24 - $2 | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 23522
 }
 __ZdlPv($2); //@line 23524
 __ZdlPv($0); //@line 23525
 return;
}
function __Z12op_53d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 7053
 $2 = 651040 + ($1 << 2) | 0; //@line 7054
 $3 = HEAP32[$2 >> 2] | 0; //@line 7055
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 7059
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7070
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7073
 return;
}
function __Z12op_3060_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 35445
 $6 = (HEAP32[$4 >> 2] | 0) + -2 | 0; //@line 35447
 $12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($6) | 0; //@line 35453
 HEAP32[$4 >> 2] = $6; //@line 35454
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = $12 << 16 >> 16; //@line 35458
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35461
 return;
}
function __Z12op_2070_3_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 32130
 $15 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 32139
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($15 >>> 16 << 2) >> 2] >> 2] & 127]($15) | 0; //@line 32146
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 32149
 return;
}
function __Z12op_53f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7210
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 7219
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7239
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7242
 return;
}
function __Z12op_5ae0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 9392
 $2 = 651040 + ($1 << 2) | 0; //@line 9393
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 9397
 HEAP32[$2 >> 2] = $6; //@line 9398
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9407
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9410
 return;
}
function __Z12op_58e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 8736
 $2 = 651040 + ($1 << 2) | 0; //@line 8737
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 8741
 HEAP32[$2 >> 2] = $6; //@line 8742
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8751
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8754
 return;
}
function __Z12op_56e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 8080
 $2 = 651040 + ($1 << 2) | 0; //@line 8081
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 8085
 HEAP32[$2 >> 2] = $6; //@line 8086
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8095
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8098
 return;
}
function __Z12op_54e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 7424
 $2 = 651040 + ($1 << 2) | 0; //@line 7425
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 7429
 HEAP32[$2 >> 2] = $6; //@line 7430
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7439
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7442
 return;
}
function __Z12op_5af0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11991
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12000
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 12009
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12012
 return;
}
function __Z12op_58f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11927
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11936
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 11945
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11948
 return;
}
function __Z12op_56f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11863
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11872
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 11881
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11884
 return;
}
function __Z12op_54f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11799
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11808
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 11817
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11820
 return;
}
function __Z12op_53e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 7111
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7122
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7133
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7136
 return;
}
function __Z12op_2079_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 28467
 $12 = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24; //@line 28476
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) | 0; //@line 28492
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28495
 return;
}
function ___fseeko($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $8 = 0, $9 = 0, $phitmp = 0;
 if ((HEAP32[$0 + 76 >> 2] | 0) > -1) {
  $phitmp = (___lockfile($0) | 0) == 0; //@line 1715
  $8 = ___fseeko_unlocked($0, $1, $2) | 0; //@line 1716
  if ($phitmp) {
   $9 = $8; //@line 1718
  } else {
   ___unlockfile($0); //@line 1720
   $9 = $8; //@line 1721
  }
 } else {
  $9 = ___fseeko_unlocked($0, $1, $2) | 0; //@line 1725
 }
 return $9 | 0; //@line 1727
}
function __Z12op_2068_0_ffj($0) {
 $0 = $0 | 0;
 var $16 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 28374
 $16 = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 28385
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($16 >>> 16 << 2) >> 2] >> 2] & 127]($16) | 0; //@line 28392
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28395
 return;
}
function __Z12op_60ff_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $2 = 0, $3 = 0, $4 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 22574
 HEAP32[162769] = $2; //@line 22575
 $3 = HEAP32[162768] | 0; //@line 22576
 $$cast = $2; //@line 22577
 $4 = HEAP32[162770] | 0; //@line 22578
 HEAP32[96446] = $3 + 2 + $$cast - $4; //@line 22582
 HEAP32[96447] = $3 + 1 + $$cast - $4; //@line 22586
 HEAP16[325963] = $0; //@line 22588
 __Z9Exceptionij(3, 0); //@line 22589
 return;
}
function __Z12op_4240_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0;
 $1 = $0 & 7; //@line 42944
 HEAP32[96441] = 0; //@line 42945
 HEAP32[96442] = 0; //@line 42945
 HEAP32[96443] = 0; //@line 42945
 HEAP32[96444] = 0; //@line 42945
 HEAP32[96442] = 1; //@line 42946
 HEAP32[96443] = 0; //@line 42947
 $2 = 651008 + ($1 << 2) | 0; //@line 42948
 HEAP32[$2 >> 2] = HEAP32[$2 >> 2] & -65536; //@line 42951
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42954
 return;
}
function __Z9SaveXPRAMv() {
 var $0 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 13003
 STACKTOP = STACKTOP + 16 | 0; //@line 13004
 $vararg_buffer = sp; //@line 13005
 HEAP32[$vararg_buffer >> 2] = 438; //@line 13006
 $0 = _open(656281, 65, $vararg_buffer) | 0; //@line 13007
 if (($0 | 0) <= -1) {
  STACKTOP = sp; //@line 13010
  return;
 }
 _write($0, 656025, 256) | 0; //@line 13012
 _close($0) | 0; //@line 13013
 STACKTOP = sp; //@line 13014
 return;
}
function __Z12op_8180_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $20 = 0, $5 = 0;
 $5 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 16484
 $10 = HEAP32[162769] | 0; //@line 16489
 $20 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 16499
 HEAP32[$20 >> 2] = ((HEAPU8[$10 + 2 >> 0] | 0) << 8 | (HEAPU8[$10 + 3 >> 0] | 0)) + ($5 << 4 & 3840 | $5 & 15) & 65535 | HEAP32[$20 >> 2] & -65536; //@line 16504
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16507
 return;
}
function __Z12op_5ad8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 9367
 $2 = 651040 + ($1 << 2) | 0; //@line 9368
 $3 = HEAP32[$2 >> 2] | 0; //@line 9369
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 9373
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9382
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9385
 return;
}
function __Z12op_58d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 8711
 $2 = 651040 + ($1 << 2) | 0; //@line 8712
 $3 = HEAP32[$2 >> 2] | 0; //@line 8713
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 8717
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8726
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8729
 return;
}
function __Z12op_56d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 8055
 $2 = 651040 + ($1 << 2) | 0; //@line 8056
 $3 = HEAP32[$2 >> 2] | 0; //@line 8057
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 8061
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8070
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8073
 return;
}
function __Z12op_54d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 7399
 $2 = 651040 + ($1 << 2) | 0; //@line 7400
 $3 = HEAP32[$2 >> 2] | 0; //@line 7401
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 7405
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7414
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7417
 return;
}
function __Z12op_5be0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 9720
 $2 = 651040 + ($1 << 2) | 0; //@line 9721
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 9725
 HEAP32[$2 >> 2] = $6; //@line 9726
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, HEAP32[96443] | 0 ? 255 : 0); //@line 9735
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9738
 return;
}
function __Z12op_59e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 9064
 $2 = 651040 + ($1 << 2) | 0; //@line 9065
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 9069
 HEAP32[$2 >> 2] = $6; //@line 9070
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, HEAP32[96444] | 0 ? 255 : 0); //@line 9079
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9082
 return;
}
function __Z12op_57e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 8408
 $2 = 651040 + ($1 << 2) | 0; //@line 8409
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 8413
 HEAP32[$2 >> 2] = $6; //@line 8414
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, HEAP32[96442] | 0 ? 255 : 0); //@line 8423
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8426
 return;
}
function __Z12op_55e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 7752
 $2 = 651040 + ($1 << 2) | 0; //@line 7753
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 7757
 HEAP32[$2 >> 2] = $6; //@line 7758
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, HEAP32[96441] | 0 ? 255 : 0); //@line 7767
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7770
 return;
}
function __Z12op_4200_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0;
 $1 = $0 & 7; //@line 42723
 HEAP32[96441] = 0; //@line 42724
 HEAP32[96442] = 0; //@line 42724
 HEAP32[96443] = 0; //@line 42724
 HEAP32[96444] = 0; //@line 42724
 HEAP32[96442] = 1; //@line 42725
 HEAP32[96443] = 0; //@line 42726
 $2 = 651008 + ($1 << 2) | 0; //@line 42727
 HEAP32[$2 >> 2] = HEAP32[$2 >> 2] & -256; //@line 42730
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42733
 return;
}
function __Z12op_2058_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $4 = 0, $5 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28324
 $5 = HEAP32[$4 >> 2] | 0; //@line 28325
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28330
 HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 4; //@line 28333
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = $10; //@line 28335
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28338
 return;
}
function __Z12op_5bf0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 12023
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 12032
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[96443] | 0 ? 255 : 0); //@line 12041
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12044
 return;
}
function __Z12op_5af9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9514
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 9523
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9541
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9544
 return;
}
function __Z12op_59f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11959
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11968
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[96444] | 0 ? 255 : 0); //@line 11977
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11980
 return;
}
function __Z12op_58f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8858
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 8867
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8885
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8888
 return;
}
function __Z12op_57f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11895
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11904
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[96442] | 0 ? 255 : 0); //@line 11913
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11916
 return;
}
function __Z12op_56f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8202
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 8211
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8229
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8232
 return;
}
function __Z12op_55f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11831
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11840
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, HEAP32[96441] | 0 ? 255 : 0); //@line 11849
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11852
 return;
}
function __Z12op_54f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7546
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 7555
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7573
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7576
 return;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $rem = 0, __stackBase__ = 0;
 __stackBase__ = STACKTOP; //@line 4529
 STACKTOP = STACKTOP + 16 | 0; //@line 4530
 $rem = __stackBase__ | 0; //@line 4531
 ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0; //@line 4532
 STACKTOP = __stackBase__; //@line 4533
 return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0; //@line 4534
}
function __Z12op_5ae8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 9421
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 9432
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9441
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9444
 return;
}
function __Z12op_58e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 8765
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8776
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8785
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8788
 return;
}
function __Z12op_56e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 8109
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8120
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8129
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8132
 return;
}
function __Z12op_54e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 7453
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7464
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7473
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7476
 return;
}
function __Z12op_8140_0_ffj($0) {
 $0 = $0 | 0;
 var $15 = 0, $16 = 0, $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 16076
 $15 = ((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) + (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 16085
 $16 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 16086
 HEAP32[$16 >> 2] = $15 & 15 | HEAP32[$16 >> 2] & -256 | $15 >>> 4 & 240; //@line 16094
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 16097
 return;
}
function _llvm_cttz_i32(x) {
 x = x | 0;
 var ret = 0;
 ret = HEAP8[cttz_i8 + (x & 255) >> 0] | 0; //@line 4156
 if ((ret | 0) < 8) return ret | 0; //@line 4157
 ret = HEAP8[cttz_i8 + (x >> 8 & 255) >> 0] | 0; //@line 4158
 if ((ret | 0) < 8) return ret + 8 | 0; //@line 4159
 ret = HEAP8[cttz_i8 + (x >> 16 & 255) >> 0] | 0; //@line 4160
 if ((ret | 0) < 8) return ret + 16 | 0; //@line 4161
 return (HEAP8[cttz_i8 + (x >>> 24) >> 0] | 0) + 24 | 0; //@line 4162
}
function __Z12op_5bd8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 9695
 $2 = 651040 + ($1 << 2) | 0; //@line 9696
 $3 = HEAP32[$2 >> 2] | 0; //@line 9697
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 9701
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96443] | 0 ? 255 : 0); //@line 9710
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9713
 return;
}
function __Z12op_59d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 9039
 $2 = 651040 + ($1 << 2) | 0; //@line 9040
 $3 = HEAP32[$2 >> 2] | 0; //@line 9041
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 9045
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96444] | 0 ? 255 : 0); //@line 9054
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9057
 return;
}
function __Z12op_57d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 8383
 $2 = 651040 + ($1 << 2) | 0; //@line 8384
 $3 = HEAP32[$2 >> 2] | 0; //@line 8385
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 8389
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96442] | 0 ? 255 : 0); //@line 8398
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8401
 return;
}
function __Z12op_55d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 7727
 $2 = 651040 + ($1 << 2) | 0; //@line 7728
 $3 = HEAP32[$2 >> 2] | 0; //@line 7729
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 7733
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96441] | 0 ? 255 : 0); //@line 7742
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7745
 return;
}
function __Z12op_4a48_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 51849
 $5 = ($3 & 65535 | 0) == 0 & 1; //@line 51852
 HEAP32[96441] = 0; //@line 51853
 HEAP32[96442] = 0; //@line 51853
 HEAP32[96443] = 0; //@line 51853
 HEAP32[96444] = 0; //@line 51853
 HEAP32[96442] = $5; //@line 51854
 HEAP32[96443] = $3 >>> 15 & 1; //@line 51857
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51860
 return;
}
function __Z12op_4a40_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 51829
 $5 = ($3 & 65535 | 0) == 0 & 1; //@line 51832
 HEAP32[96441] = 0; //@line 51833
 HEAP32[96442] = 0; //@line 51833
 HEAP32[96443] = 0; //@line 51833
 HEAP32[96444] = 0; //@line 51833
 HEAP32[96442] = $5; //@line 51834
 HEAP32[96443] = $3 >>> 15 & 1; //@line 51837
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51840
 return;
}
function __Z12op_d0d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 33176
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 33182
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33183
 HEAP32[$12 >> 2] = ($11 << 16 >> 16) + (HEAP32[$12 >> 2] | 0); //@line 33188
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33191
 return;
}
function __Z12op_90d0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $12 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 19554
 $11 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 19560
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19561
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) - ($11 << 16 >> 16); //@line 19566
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19569
 return;
}
function __Z12op_5bf9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9842
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 9851
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), HEAP32[96443] | 0 ? 255 : 0); //@line 9869
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9872
 return;
}
function __Z12op_59f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9186
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 9195
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), HEAP32[96444] | 0 ? 255 : 0); //@line 9213
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9216
 return;
}
function __Z12op_57f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8530
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 8539
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), HEAP32[96442] | 0 ? 255 : 0); //@line 8557
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8560
 return;
}
function __Z12op_55f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7874
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 7883
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), HEAP32[96441] | 0 ? 255 : 0); //@line 7901
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7904
 return;
}
function ___uflow($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, sp = 0;
 sp = STACKTOP; //@line 55609
 STACKTOP = STACKTOP + 16 | 0; //@line 55610
 $1 = sp; //@line 55611
 if (!(___toread($0) | 0)) {
  if ((FUNCTION_TABLE_iiii[HEAP32[$0 + 32 >> 2] & 15]($0, $1, 1) | 0) == 1) {
   $$0 = HEAPU8[$1 >> 0] | 0; //@line 55622
  } else {
   $$0 = -1; //@line 55624
  }
 } else {
  $$0 = -1; //@line 55627
 }
 STACKTOP = sp; //@line 55629
 return $$0 | 0; //@line 55629
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0, $5 = 0;
 if (($0 | 0) != ($1 | 0)) {
  $4 = HEAP8[$1 + 11 >> 0] | 0; //@line 3191
  $5 = $4 << 24 >> 24 < 0; //@line 3192
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0, $5 ? HEAP32[$1 >> 2] | 0 : $1, $5 ? HEAP32[$1 + 4 >> 2] | 0 : $4 & 255) | 0; //@line 3199
 }
 return $0 | 0; //@line 3201
}
function __Z12op_4a00_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 51467
 $5 = ($3 & 255 | 0) == 0 & 1; //@line 51470
 HEAP32[96441] = 0; //@line 51471
 HEAP32[96442] = 0; //@line 51471
 HEAP32[96443] = 0; //@line 51471
 HEAP32[96444] = 0; //@line 51471
 HEAP32[96442] = $5; //@line 51472
 HEAP32[96443] = $3 >>> 7 & 1; //@line 51475
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 51478
 return;
}
function __Z12op_5be8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 9749
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 9760
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96443] | 0 ? 255 : 0); //@line 9769
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9772
 return;
}
function __Z12op_59e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 9093
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 9104
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96444] | 0 ? 255 : 0); //@line 9113
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9116
 return;
}
function __Z12op_57e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 8437
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 8448
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96442] | 0 ? 255 : 0); //@line 8457
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8460
 return;
}
function __Z12op_55e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 7781
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 7792
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, HEAP32[96441] | 0 ? 255 : 0); //@line 7801
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7804
 return;
}
function __Z12op_5fd0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 11112
 if (!(HEAP32[96442] | 0)) {
  $14 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11120
 } else {
  $14 = 255; //@line 11122
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, $14); //@line 11129
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 11132
 return;
}
function __Z12op_4e58_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0, $8 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 230
 $3 = HEAP32[$2 >> 2] | 0; //@line 231
 HEAP32[162767] = $3; //@line 232
 $8 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($3 >>> 16 << 2) >> 2] >> 2] & 127]($3) | 0; //@line 237
 HEAP32[162767] = (HEAP32[162767] | 0) + 4; //@line 240
 HEAP32[$2 >> 2] = $8; //@line 241
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 244
 return;
}
function __Z24AddPlatformPrefsDefaultsv() {
 __Z12PrefsAddBoolPKcb(104927, 0); //@line 49070
 __Z18PrefsReplaceStringPKcS0_i(105378, 105384, 0); //@line 49071
 __Z17PrefsReplaceInt32PKci(105093, 1); //@line 49072
 __Z17PrefsReplaceInt32PKci(105168, 3); //@line 49073
 __Z18PrefsReplaceStringPKcS0_i(105232, 105386, 0); //@line 49074
 __Z18PrefsReplaceStringPKcS0_i(105267, 105395, 0); //@line 49075
 __Z12PrefsAddBoolPKcb(105297, 1); //@line 49076
 return;
}
function __Z12op_6101_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $8 = 0;
 $8 = (HEAP32[162768] | 0) + 2 + (HEAP32[162769] | 0) - (HEAP32[162770] | 0) | 0; //@line 12378
 $10 = (HEAP32[162767] | 0) + -4 | 0; //@line 12380
 HEAP32[162767] = $10; //@line 12381
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($10, $8); //@line 12387
 HEAP32[162769] = (HEAP32[162769] | 0) + (($0 << 24 >> 24) + 2); //@line 12390
 return;
}
function __Z12op_2060_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $4 = 0, $6 = 0;
 $4 = 651040 + (($0 & 7) << 2) | 0; //@line 28348
 $6 = (HEAP32[$4 >> 2] | 0) + -4 | 0; //@line 28350
 $11 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($6 >>> 16 << 2) >> 2] >> 2] & 127]($6) | 0; //@line 28355
 HEAP32[$4 >> 2] = $6; //@line 28356
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = $11; //@line 28358
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28361
 return;
}
function __Z12op_5ed0_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10697
 if (!(HEAP32[96442] | 0)) {
  $14 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10705
 } else {
  $14 = 0; //@line 10707
 }
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, $14); //@line 10714
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10717
 return;
}
function __Z12op_4c3c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $28 = 0;
 $1 = HEAP32[162769] | 0; //@line 53233
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) & 65535; //@line 53242
 $28 = (HEAPU8[$1 + 5 >> 0] | 0) << 16 | (HEAPU8[$1 + 4 >> 0] | 0) << 24 | (HEAPU8[$1 + 6 >> 0] | 0) << 8 | (HEAPU8[$1 + 7 >> 0] | 0); //@line 53260
 HEAP32[162769] = $1 + 8; //@line 53262
 __Z9m68k_mulljjt($0, $28, $10); //@line 53263
 return;
}
function __Z12op_44d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 47910
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($3) | 0; //@line 47916
 __Z6MakeSRv(); //@line 47917
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $9 & 255; //@line 47924
 __Z10MakeFromSRv(); //@line 47925
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47928
 return;
}
function __Z12op_f280_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $13 = 0, $2 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 48738
 $2 = $1 + 2 | 0; //@line 48739
 HEAP32[162769] = $2; //@line 48740
 $6 = $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 48745
 $13 = (HEAPU8[$2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48752
 HEAP32[162769] = $1 + 4; //@line 48754
 __Z9fpuop_bccjjj($0, $6, $13 << 16 >> 16); //@line 48757
 return;
}
function _stat($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 62674
 STACKTOP = STACKTOP + 16 | 0; //@line 62675
 $vararg_buffer = sp; //@line 62676
 HEAP32[$vararg_buffer >> 2] = $0; //@line 62679
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 62681
 $5 = ___syscall_ret(___syscall195(195, $vararg_buffer | 0) | 0) | 0; //@line 62683
 STACKTOP = sp; //@line 62684
 return $5 | 0; //@line 62684
}
function __Z12op_4a88_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 52228
 $5 = ($3 | 0) == 0 & 1; //@line 52230
 HEAP32[96441] = 0; //@line 52231
 HEAP32[96442] = 0; //@line 52231
 HEAP32[96443] = 0; //@line 52231
 HEAP32[96444] = 0; //@line 52231
 HEAP32[96442] = $5; //@line 52232
 HEAP32[96443] = $3 >>> 31; //@line 52234
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52237
 return;
}
function __Z12op_4a80_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 52210
 $5 = ($3 | 0) == 0 & 1; //@line 52212
 HEAP32[96441] = 0; //@line 52213
 HEAP32[96442] = 0; //@line 52213
 HEAP32[96443] = 0; //@line 52213
 HEAP32[96444] = 0; //@line 52213
 HEAP32[96442] = $5; //@line 52214
 HEAP32[96443] = $3 >>> 31; //@line 52216
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 52219
 return;
}
function __Z12op_46d0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49183
  return;
 } else {
  $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 49188
  HEAP16[325558] = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0; //@line 49196
  __Z10MakeFromSRv(); //@line 49197
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49200
  return;
 }
}
function __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($0, $1, $2, $3, $4, $5) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, $5) | 0) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0, $1, $2, $3, $4); //@line 3652
 }
 return;
}
function __Z12op_4ef8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0, $16 = 0;
 $1 = HEAP32[162769] | 0; //@line 1062
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 1072
 $16 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($10) | 0; //@line 1078
 HEAP32[162770] = $16; //@line 1079
 HEAP32[162769] = $16; //@line 1080
 HEAP32[162768] = $10; //@line 1081
 return;
}
function _close($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 59329
 STACKTOP = STACKTOP + 16 | 0; //@line 59330
 $vararg_buffer = sp; //@line 59331
 HEAP32[$vararg_buffer >> 2] = _dummy_570($0) | 0; //@line 59333
 $2 = ___syscall6(6, $vararg_buffer | 0) | 0; //@line 59334
 $4 = ___syscall_ret(($2 | 0) == -4 ? 0 : $2) | 0; //@line 59337
 STACKTOP = sp; //@line 59338
 return $4 | 0; //@line 59338
}
function __Z12op_40d0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41239
  return;
 } else {
  $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 41244
  __Z6MakeSRv(); //@line 41245
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($5, HEAPU16[325558] | 0); //@line 41253
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41256
  return;
 }
}
function __Z19timer_mac2host_timeR7timevali($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sink = 0, $$sink9 = 0;
 if (($1 | 0) > 0) {
  $$sink = (($1 >>> 0) % 1e3 | 0) * 1e3 | 0; //@line 13637
  $$sink9 = ($1 >>> 0) / 1e3 | 0; //@line 13637
 } else {
  $$sink = (0 - $1 | 0) % 1e6 | 0; //@line 13642
  $$sink9 = ($1 | 0) / -1e6 | 0; //@line 13642
 }
 HEAP32[$0 >> 2] = $$sink9; //@line 13644
 HEAP32[$0 + 4 >> 2] = $$sink; //@line 13646
 return;
}
function __Z12op_50e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 4825
 $2 = 651040 + ($1 << 2) | 0; //@line 4826
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 4830
 HEAP32[$2 >> 2] = $6; //@line 4831
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, 255); //@line 4837
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4840
 return;
}
function __Z12op_3078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 35543
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 35553
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($12 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($12) | 0) << 16 >> 16; //@line 35563
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35566
 return;
}
function __Z12op_50f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11495
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11504
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, 255); //@line 11510
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11513
 return;
}
function _rename($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2811
 STACKTOP = STACKTOP + 16 | 0; //@line 2812
 $vararg_buffer = sp; //@line 2813
 HEAP32[$vararg_buffer >> 2] = $0; //@line 2816
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 2818
 $5 = ___syscall_ret(___syscall38(38, $vararg_buffer | 0) | 0) | 0; //@line 2820
 STACKTOP = sp; //@line 2821
 return $5 | 0; //@line 2821
}
function _access($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 1795
 STACKTOP = STACKTOP + 16 | 0; //@line 1796
 $vararg_buffer = sp; //@line 1797
 HEAP32[$vararg_buffer >> 2] = $0; //@line 1799
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 1801
 $4 = ___syscall_ret(___syscall33(33, $vararg_buffer | 0) | 0) | 0; //@line 1803
 STACKTOP = sp; //@line 1804
 return $4 | 0; //@line 1804
}
function __Z12op_51e0_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $0 & 7; //@line 6444
 $2 = 651040 + ($1 << 2) | 0; //@line 6445
 $6 = (HEAP32[$2 >> 2] | 0) - (HEAP32[5656 + ($1 << 2) >> 2] | 0) | 0; //@line 6449
 HEAP32[$2 >> 2] = $6; //@line 6450
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($6, 0); //@line 6456
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6459
 return;
}
function _mkdir($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 2426
 STACKTOP = STACKTOP + 16 | 0; //@line 2427
 $vararg_buffer = sp; //@line 2428
 HEAP32[$vararg_buffer >> 2] = $0; //@line 2430
 HEAP32[$vararg_buffer + 4 >> 2] = $1; //@line 2432
 $4 = ___syscall_ret(___syscall39(39, $vararg_buffer | 0) | 0) | 0; //@line 2434
 STACKTOP = sp; //@line 2435
 return $4 | 0; //@line 2435
}
function __Z12op_51f0_3_ffj($0) {
 $0 = $0 | 0;
 var $13 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 11702
 $13 = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) | 0; //@line 11711
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($13 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($13, 0); //@line 11717
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 11720
 return;
}
function __Z12op_50d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 4803
 $2 = 651040 + ($1 << 2) | 0; //@line 4804
 $3 = HEAP32[$2 >> 2] | 0; //@line 4805
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 4809
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 255); //@line 4815
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4818
 return;
}
function _sn_write($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$ = 0, $5 = 0, $6 = 0, $8 = 0;
 $5 = $0 + 20 | 0; //@line 59295
 $6 = HEAP32[$5 >> 2] | 0; //@line 59296
 $8 = (HEAP32[$0 + 16 >> 2] | 0) - $6 | 0; //@line 59298
 $$ = $8 >>> 0 > $2 >>> 0 ? $2 : $8; //@line 59300
 _memcpy($6 | 0, $1 | 0, $$ | 0) | 0; //@line 59301
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + $$; //@line 59304
 return $2 | 0; //@line 59305
}
function __Z13ADBMouseMovedii($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$sink = 0;
 if (!(HEAP8[657321] | 0)) {
  HEAP32[28469] = $0; //@line 14096
  $$sink = $1; //@line 14097
 } else {
  HEAP32[28469] = (HEAP32[28469] | 0) + $0; //@line 14101
  $$sink = (HEAP32[28470] | 0) + $1 | 0; //@line 14104
 }
 HEAP32[28470] = $$sink; //@line 14106
 __Z16SetInterruptFlagj(64); //@line 14107
 __Z16TriggerInterruptv(); //@line 14108
 return;
}
function __Z12op_d1d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35118
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 35123
 $11 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 35124
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + $10; //@line 35127
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35130
 return;
}
function __Z12op_91d0_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $11 = 0, $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 21473
 $10 = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 21478
 $11 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21479
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) - $10; //@line 21482
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21485
 return;
}
function __Z12op_51d8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $0 & 7; //@line 6422
 $2 = 651040 + ($1 << 2) | 0; //@line 6423
 $3 = HEAP32[$2 >> 2] | 0; //@line 6424
 HEAP32[$2 >> 2] = (HEAP32[5656 + ($1 << 2) >> 2] | 0) + $3; //@line 6428
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 0); //@line 6434
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6437
 return;
}
function __Z12op_50f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 4934
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 4943
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), 255); //@line 4958
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 4961
 return;
}
function __Z14timer_cmp_time7timevalS_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0, $2 = 0, $3 = 0;
 $2 = HEAP32[$0 >> 2] | 0; //@line 13609
 $3 = HEAP32[$1 >> 2] | 0; //@line 13610
 if (($2 | 0) == ($3 | 0)) {
  $$0 = (HEAP32[$0 + 4 >> 2] | 0) - (HEAP32[$1 + 4 >> 2] | 0) | 0; //@line 13618
  return $$0 | 0; //@line 13619
 } else {
  $$0 = $2 - $3 | 0; //@line 13622
  return $$0 | 0; //@line 13623
 }
 return 0; //@line 13625
}
function __Z12op_5df8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 10487
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 10497
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10507
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10510
 return;
}
function __Z12op_5cf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 10147
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 10157
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10167
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10170
 return;
}
function __Z12op_51f9_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 6553
 $10 = (HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24; //@line 6562
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0), 0); //@line 6577
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6580
 return;
}
function __Z12op_50e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 4851
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 4862
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 255); //@line 4868
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4871
 return;
}
function __Z12op_42e0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 46644
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 46646
 HEAP32[$2 >> 2] = $4; //@line 46647
 __Z6MakeSRv(); //@line 46648
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($4, HEAP16[325558] & 255); //@line 46657
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46660
 return;
}
function __Z12op_42f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 46736
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 46746
 __Z6MakeSRv(); //@line 46747
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($10, HEAP16[325558] & 255); //@line 46756
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46759
 return;
}
function __Z12op_40e0_4_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 46266
 $4 = (HEAP32[$2 >> 2] | 0) + -2 | 0; //@line 46268
 HEAP32[$2 >> 2] = $4; //@line 46269
 __Z6MakeSRv(); //@line 46270
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($4 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($4, HEAPU16[325558] | 0); //@line 46278
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46281
 return;
}
function __Z12op_51e8_0_ffj($0) {
 $0 = $0 | 0;
 var $14 = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 6470
 $14 = (((HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0) | 0; //@line 6481
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($14 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($14, 0); //@line 6487
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6490
 return;
}
function __Z12op_40f8_4_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 46355
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 46365
 __Z6MakeSRv(); //@line 46366
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($10, HEAPU16[325558] | 0); //@line 46374
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46377
 return;
}
function ___memrchr($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $$0 = 0, $$09 = 0, $3 = 0, $6 = 0;
 $3 = $1 & 255; //@line 1822
 $$09 = $2; //@line 1823
 while (1) {
  if (!$$09) {
   $$0 = 0; //@line 1828
   break;
  }
  $$09 = $$09 + -1 | 0; //@line 1825
  $6 = $0 + $$09 | 0; //@line 1831
  if ((HEAP8[$6 >> 0] | 0) == $3 << 24 >> 24) {
   $$0 = $6; //@line 1835
   break;
  }
 }
 return $$0 | 0; //@line 1841
}
function __Z12op_52f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 6826
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 6836
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6847
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6850
 return;
}
function __ZNSt3__213__vector_baseI16cdrom_drive_infoNS_9allocatorIS1_EEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 19663
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 19669
 $5 = HEAP32[$4 >> 2] | 0; //@line 19670
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -840 - $1 | 0) >>> 0) / 840 | 0) * 840 | 0); //@line 19679
 }
 __ZdlPv($1); //@line 19681
 return;
}
function __Z11op_a7c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 17761
  return;
 } else {
  __Z6MakeSRv(); //@line 17764
  $3 = HEAP32[162769] | 0; //@line 17765
  HEAP16[325558] = HEAPU16[325558] ^ (HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]); //@line 17778
  __Z10MakeFromSRv(); //@line 17779
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 17782
  return;
 }
}
function __Z12op_42d8_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 46620
 $3 = HEAP32[$2 >> 2] | 0; //@line 46621
 HEAP32[$2 >> 2] = $3 + 2; //@line 46623
 __Z6MakeSRv(); //@line 46624
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, HEAP16[325558] & 255); //@line 46633
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46636
 return;
}
function __Z13SoundInStatusjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $11 = 0, $2 = 0;
 $2 = $0 + 26 | 0; //@line 28518
 $11 = $0 + 28 | 0; //@line 28527
 if (((FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($2 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($2) | 0) & 65535 | 0) != 2) {
  return -231;
 }
 FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($11 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($11) | 0; //@line 28536
 return -231;
}
function __Z12op_40d8_4_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0, $3 = 0;
 $2 = 651040 + (($0 & 7) << 2) | 0; //@line 46243
 $3 = HEAP32[$2 >> 2] | 0; //@line 46244
 HEAP32[$2 >> 2] = $3 + 2; //@line 46246
 __Z6MakeSRv(); //@line 46247
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, HEAPU16[325558] | 0); //@line 46255
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46258
 return;
}
function __ZNSt3__213__vector_baseI15disk_drive_infoNS_9allocatorIS1_EEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 18192
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 18198
 $5 = HEAP32[$4 >> 2] | 0; //@line 18199
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -24 - $1 | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 18208
 }
 __ZdlPv($1); //@line 18210
 return;
}
function __Z11op_840_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $5 = 0, $8 = 0, $9 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 14157
 $8 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] & 31; //@line 14160
 $9 = 1 << $8; //@line 14161
 $10 = $9 ^ HEAP32[$5 >> 2]; //@line 14162
 HEAP32[96442] = ($10 & $9) >>> $8; //@line 14165
 HEAP32[$5 >> 2] = $10; //@line 14166
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14169
 return;
}
function __Z11op_140_0_ffj($0) {
 $0 = $0 | 0;
 var $10 = 0, $6 = 0, $8 = 0, $9 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 6949
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 31; //@line 6951
 $9 = 1 << $8; //@line 6952
 $10 = $9 ^ HEAP32[$6 >> 2]; //@line 6953
 HEAP32[96442] = ($10 & $9) >>> $8; //@line 6956
 HEAP32[$6 >> 2] = $10; //@line 6957
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6960
 return;
}
function __Z11op_110_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $7 = 0;
 $5 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] | 0; //@line 6576
 $7 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6578
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($7 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($7) | 0) << 24 >> 24 >>> ($5 & 7) & 1 ^ 1; //@line 6591
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6594
 return;
}
function __Z12op_6f01_0_ffj($0) {
 $0 = $0 | 0;
 var $$sink8 = 0, label = 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   $$sink8 = 2; //@line 13444
  } else {
   label = 3; //@line 13446
  }
 } else {
  label = 3; //@line 13449
 }
 if ((label | 0) == 3) {
  $$sink8 = ($0 << 24 >> 24) + 2 | 0; //@line 13455
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + $$sink8; //@line 13459
 return;
}
function ___stdio_close($0) {
 $0 = $0 | 0;
 var $5 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 54561
 STACKTOP = STACKTOP + 16 | 0; //@line 54562
 $vararg_buffer = sp; //@line 54563
 HEAP32[$vararg_buffer >> 2] = _dummy_570(HEAP32[$0 + 60 >> 2] | 0) | 0; //@line 54567
 $5 = ___syscall_ret(___syscall6(6, $vararg_buffer | 0) | 0) | 0; //@line 54569
 STACKTOP = sp; //@line 54570
 return $5 | 0; //@line 54570
}
function __ZN12monitor_descD2Ev($0) {
 $0 = $0 | 0;
 var $2 = 0, $4 = 0, $5 = 0;
 HEAP32[$0 >> 2] = 1492; //@line 23476
 $2 = HEAP32[$0 + 4 >> 2] | 0; //@line 23478
 if (!$2) {
  return;
 }
 $4 = $0 + 8 | 0; //@line 23483
 $5 = HEAP32[$4 >> 2] | 0; //@line 23484
 if (($5 | 0) != ($2 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -24 - $2 | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 23494
 }
 __ZdlPv($2); //@line 23496
 return;
}
function __Z12op_d1fc_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 37335
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 37354
 HEAP32[$22 >> 2] = ((HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)) + (HEAP32[$22 >> 2] | 0); //@line 37357
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 37360
 return;
}
function __Z12op_91fc_0_ffj($0) {
 $0 = $0 | 0;
 var $22 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 21763
 $22 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21782
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) - ((HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0)); //@line 21785
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 21788
 return;
}
function __Z12op_53f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7178
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 7188
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7199
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7202
 return;
}
function __Z12op_41fb_3_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 46113
 $$cast = $4; //@line 46118
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = __Z15get_disp_ea_000jj((HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) | 0, (HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) | 0; //@line 46129
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46132
 return;
}
function __Z11op_27c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 9176
  return;
 } else {
  __Z6MakeSRv(); //@line 9179
  $3 = HEAP32[162769] | 0; //@line 9180
  HEAP16[325558] = HEAPU16[325558] & (HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]); //@line 9193
  __Z10MakeFromSRv(); //@line 9194
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9197
  return;
 }
}
function __Z8ADBKeyUpi($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[28471] | 0; //@line 14179
 HEAP8[657325 + $3 >> 0] = $0 | 128; //@line 14181
 HEAP32[28471] = $3 + 1 & 15; //@line 14184
 $12 = 657305 + ($0 >> 3) | 0; //@line 14190
 HEAP8[$12 >> 0] = (HEAPU8[$12 >> 0] | 0) & (1 << ($0 & 7 ^ 7) ^ 255); //@line 14195
 __Z16SetInterruptFlagj(64); //@line 14196
 __Z16TriggerInterruptv(); //@line 14197
 return;
}
function __Z11op_810_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $6 = 0;
 $4 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 13791
 $6 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 13793
 HEAP32[96442] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($6 >>> 16 << 2) >> 2] | 0) + 8 >> 2] & 127]($6) | 0) << 24 >> 24 >>> ($4 & 7) & 1 ^ 1; //@line 13807
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 13810
 return;
}
function __Z12op_2078_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 28437
 $12 = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 28447
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($12 >>> 16 << 2) >> 2] >> 2] & 127]($12) | 0; //@line 28454
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 28457
 return;
}
function __ZNSt3__213__vector_baseI10video_modeNS_9allocatorIS1_EEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 45242
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 45248
 $5 = HEAP32[$4 >> 2] | 0; //@line 45249
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~((($5 + -24 - $1 | 0) >>> 0) / 24 | 0) * 24 | 0); //@line 45258
 }
 __ZdlPv($1); //@line 45260
 return;
}
function __ZL17video_refresh_dgav() {
 var $2 = 0;
 if (!(HEAP8[659473] | 0)) {
  __ZL27video_refresh_window_staticv(); //@line 44751
  return;
 }
 HEAP8[659473] = 0; //@line 44754
 $2 = HEAP32[30855] | 0; //@line 44755
 if ($2 | 0) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$2 >> 2] | 0) + 4 >> 2] & 4095]($2); //@line 44761
 }
 HEAP32[30855] = 0; //@line 44763
 __ZL27video_refresh_window_staticv(); //@line 44764
 return;
}
function __Z10op_7c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 5442
  return;
 } else {
  __Z6MakeSRv(); //@line 5445
  $3 = HEAP32[162769] | 0; //@line 5446
  HEAP16[325558] = HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0] | HEAPU16[325558]; //@line 5459
  __Z10MakeFromSRv(); //@line 5460
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5463
  return;
 }
}
function __Znwj($0) {
 $0 = $0 | 0;
 var $$ = 0, $$lcssa = 0, $2 = 0, $4 = 0;
 $$ = ($0 | 0) == 0 ? 1 : $0; //@line 3116
 while (1) {
  $2 = _malloc($$) | 0; //@line 3118
  if ($2 | 0) {
   $$lcssa = $2; //@line 3121
   break;
  }
  $4 = __ZSt15get_new_handlerv() | 0; //@line 3124
  if (!$4) {
   $$lcssa = 0; //@line 3127
   break;
  }
  FUNCTION_TABLE_v[$4 & 3](); //@line 3130
 }
 return $$lcssa | 0; //@line 3132
}
function __Z12op_5af8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9484
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 9494
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9503
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9506
 return;
}
function __Z12op_58f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8828
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 8838
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8847
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8850
 return;
}
function __Z12op_56f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8172
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 8182
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8191
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8194
 return;
}
function __Z12op_54f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7516
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 7526
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7535
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7538
 return;
}
function __Z12op_4280_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = $0 & 7; //@line 43161
 HEAP32[96441] = 0; //@line 43162
 HEAP32[96442] = 0; //@line 43162
 HEAP32[96443] = 0; //@line 43162
 HEAP32[96444] = 0; //@line 43162
 HEAP32[96442] = 1; //@line 43163
 HEAP32[96443] = 0; //@line 43164
 HEAP32[651008 + ($1 << 2) >> 2] = 0; //@line 43166
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 43169
 return;
}
function __ZNSt3__213__vector_baseI15sony_drive_infoNS_9allocatorIS1_EEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 17043
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 17049
 $5 = HEAP32[$4 >> 2] | 0; //@line 17050
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~(($5 + -16 - $1 | 0) >>> 4) << 4); //@line 17059
 }
 __ZdlPv($1); //@line 17061
 return;
}
function __Z12op_4e7b_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 642
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 645
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 648
 if (!(__Z11m68k_move2ciPj($6 << 8 & 3840 | HEAPU8[$3 + 3 >> 0], 651008 + ($6 >>> 4 << 2) | 0) | 0)) {
  return;
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 664
 return;
}
function __Z12op_4e7a_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $6 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 610
  return;
 }
 $3 = HEAP32[162769] | 0; //@line 613
 $6 = HEAPU8[$3 + 2 >> 0] | 0; //@line 616
 if (!(__Z11m68k_movec2iPj($6 << 8 & 3840 | HEAPU8[$3 + 3 >> 0], 651008 + ($6 >>> 4 << 2) | 0) | 0)) {
  return;
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 632
 return;
}
function __Z10ADBKeyDowni($0) {
 $0 = $0 | 0;
 var $10 = 0, $2 = 0;
 $2 = HEAP32[28471] | 0; //@line 14153
 HEAP8[657325 + $2 >> 0] = $0; //@line 14155
 HEAP32[28471] = $2 + 1 & 15; //@line 14158
 $10 = 657305 + ($0 >> 3) | 0; //@line 14163
 HEAP8[$10 >> 0] = HEAPU8[$10 >> 0] | 0 | 1 << ($0 & 7 ^ 7); //@line 14168
 __Z16SetInterruptFlagj(64); //@line 14169
 __Z16TriggerInterruptv(); //@line 14170
 return;
}
function __Z9DebugUtilj($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 switch ($0 | 0) {
 case 0:
  {
   $$0 = 3; //@line 12884
   break;
  }
 case 1:
  {
   $$0 = 0; //@line 12888
   break;
  }
 case 2:
  {
   $$0 = 0; //@line 12892
   break;
  }
 case 3:
  {
   __Z12ADBInterruptv(); //@line 12896
   $$0 = 0; //@line 12897
   break;
  }
 default:
  {
   $$0 = -50; //@line 12901
  }
 }
 return $$0 | 0; //@line 12904
}
function __Z12op_41fa_0_ffj($0) {
 $0 = $0 | 0;
 var $$cast = 0, $4 = 0;
 $4 = HEAP32[162769] | 0; //@line 42666
 $$cast = $4; //@line 42668
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (HEAP32[162768] | 0) + 2 + $4 - (HEAP32[162770] | 0) + (((HEAPU8[$$cast + 2 >> 0] | 0) << 8 | (HEAPU8[$$cast + 3 >> 0] | 0)) << 16 >> 16); //@line 42684
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42687
 return;
}
function __ZNSt3__213__vector_baseIP12monitor_descNS_9allocatorIS2_EEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 23164
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 23170
 $5 = HEAP32[$4 >> 2] | 0; //@line 23171
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~(($5 + -4 - $1 | 0) >>> 2) << 2); //@line 23180
 }
 __ZdlPv($1); //@line 23182
 return;
}
function __Z12op_5bf8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9812
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 9822
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, HEAP32[96443] | 0 ? 255 : 0); //@line 9831
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9834
 return;
}
function __Z12op_59f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 9156
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 9166
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, HEAP32[96444] | 0 ? 255 : 0); //@line 9175
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9178
 return;
}
function __Z12op_57f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 8500
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 8510
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, HEAP32[96442] | 0 ? 255 : 0); //@line 8519
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8522
 return;
}
function __Z12op_55f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 7844
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 7854
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, HEAP32[96441] | 0 ? 255 : 0); //@line 7863
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7866
 return;
}
function __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 if (__ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, HEAP32[$1 + 8 >> 2] | 0, 0) | 0) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0, $1, $2, $3); //@line 3727
 }
 return;
}
function ___shlim($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0, $6 = 0, $9 = 0;
 HEAP32[$0 + 104 >> 2] = $1; //@line 54907
 $4 = HEAP32[$0 + 8 >> 2] | 0; //@line 54909
 $6 = HEAP32[$0 + 4 >> 2] | 0; //@line 54911
 $9 = $4 - $6 | 0; //@line 54914
 HEAP32[$0 + 108 >> 2] = $9; //@line 54916
 HEAP32[$0 + 100 >> 2] = ($1 | 0) != 0 & ($9 | 0) > ($1 | 0) ? $6 + $1 | 0 : $4; //@line 54923
 return;
}
function __Z12op_4850_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $5 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 50085
 $5 = (HEAP32[162767] | 0) + -4 | 0; //@line 50087
 HEAP32[162767] = $5; //@line 50088
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 12 >> 2] & 31]($5, $3); //@line 50094
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 50097
 return;
}
function __Z11op_180_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 7434
 $7 = HEAP32[$6 >> 2] | 0; //@line 7435
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 31; //@line 7436
 HEAP32[96442] = $7 >>> $8 & 1 ^ 1; //@line 7440
 HEAP32[$6 >> 2] = $7 & ~(1 << $8); //@line 7444
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7447
 return;
}
function __Z11op_880_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $6 = 0, $8 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 14573
 $6 = HEAP32[$5 >> 2] | 0; //@line 14574
 $8 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] & 31; //@line 14576
 HEAP32[96442] = $6 >>> $8 & 1 ^ 1; //@line 14580
 HEAP32[$5 >> 2] = $6 & ~(1 << $8); //@line 14584
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 14587
 return;
}
function __Z12op_5fc0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $7 = 0;
 if (!(HEAP32[96442] | 0)) {
  $11 = (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0; //@line 11041
 } else {
  $11 = 255; //@line 11043
 }
 $7 = 651008 + (($0 & 7) << 2) | 0; //@line 11045
 HEAP32[$7 >> 2] = HEAP32[$7 >> 2] & -256 | $11; //@line 11049
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 11052
 return;
}
function __Z11op_1c0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0, $7 = 0, $8 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 7941
 $7 = HEAP32[$6 >> 2] | 0; //@line 7942
 $8 = HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 31; //@line 7943
 HEAP32[96442] = $7 >>> $8 & 1 ^ 1; //@line 7947
 HEAP32[$6 >> 2] = 1 << $8 | $7; //@line 7950
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7953
 return;
}
function _snprintf($0, $1, $2, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $varargs = $varargs | 0;
 var $3 = 0, $4 = 0, sp = 0;
 sp = STACKTOP; //@line 62161
 STACKTOP = STACKTOP + 16 | 0; //@line 62162
 $3 = sp; //@line 62163
 HEAP32[$3 >> 2] = $varargs; //@line 62164
 $4 = _vsnprintf($0, $1, $2, $3) | 0; //@line 62165
 STACKTOP = sp; //@line 62166
 return $4 | 0; //@line 62166
}
function __Z11op_8c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0, $6 = 0, $8 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 15029
 $6 = HEAP32[$5 >> 2] | 0; //@line 15030
 $8 = HEAP8[(HEAP32[162769] | 0) + 3 >> 0] & 31; //@line 15032
 HEAP32[96442] = $6 >>> $8 & 1 ^ 1; //@line 15036
 HEAP32[$5 >> 2] = 1 << $8 | $6; //@line 15039
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15042
 return;
}
function __Z12op_5ec0_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $7 = 0;
 if (!(HEAP32[96442] | 0)) {
  $11 = (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0; //@line 10630
 } else {
  $11 = 0; //@line 10632
 }
 $7 = 651008 + (($0 & 7) << 2) | 0; //@line 10634
 HEAP32[$7 >> 2] = HEAP32[$7 >> 2] & -256 | $11; //@line 10638
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10641
 return;
}
function __ZNSt3__213__vector_baseItNS_9allocatorItEEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 26610
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 26616
 $5 = HEAP32[$4 >> 2] | 0; //@line 26617
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~(($5 + -2 - $1 | 0) >>> 1) << 1); //@line 26626
 }
 __ZdlPv($1); //@line 26628
 return;
}
function __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0, $5 = 0;
 $1 = HEAP32[$0 >> 2] | 0; //@line 26585
 if (!$1) {
  return;
 }
 $4 = $0 + 4 | 0; //@line 26591
 $5 = HEAP32[$4 >> 2] | 0; //@line 26592
 if (($5 | 0) != ($1 | 0)) {
  HEAP32[$4 >> 2] = $5 + (~(($5 + -4 - $1 | 0) >>> 2) << 2); //@line 26601
 }
 __ZdlPv($1); //@line 26603
 return;
}
function __GLOBAL__sub_I_prefs_unix_cpp() {
 HEAP32[30887] = 0; //@line 48716
 HEAP32[30888] = 0; //@line 48716
 HEAP32[30889] = 0; //@line 48716
 ___cxa_atexit(2221, 123548, ___dso_handle | 0) | 0; //@line 48717
 HEAP32[30890] = 0; //@line 48718
 HEAP32[30891] = 0; //@line 48718
 HEAP32[30892] = 0; //@line 48718
 ___cxa_atexit(2221, 123560, ___dso_handle | 0) | 0; //@line 48719
 return;
}
function __ZL5usagePKc($0) {
 $0 = $0 | 0;
 var $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 48544
 STACKTOP = STACKTOP + 16 | 0; //@line 48545
 $vararg_buffer = sp; //@line 48546
 HEAP32[$vararg_buffer >> 2] = $0; //@line 48547
 _printf(104713, $vararg_buffer) | 0; //@line 48548
 __Z9LoadPrefsPKc(0); //@line 48549
 __Z15PrefsPrintUsagev(); //@line 48550
 _exit(0); //@line 48551
}
function ___ftello($0) {
 $0 = $0 | 0;
 var $6 = 0, $7 = 0, $phitmp = 0;
 if ((HEAP32[$0 + 76 >> 2] | 0) > -1) {
  $phitmp = (___lockfile($0) | 0) == 0; //@line 2446
  $6 = ___ftello_unlocked($0) | 0; //@line 2447
  if ($phitmp) {
   $7 = $6; //@line 2449
  } else {
   $7 = $6; //@line 2451
  }
 } else {
  $7 = ___ftello_unlocked($0) | 0; //@line 2455
 }
 return $7 | 0; //@line 2457
}
function __Z12op_50f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 4907
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 4917
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, 255); //@line 4923
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4926
 return;
}
function _uname($0) {
 $0 = $0 | 0;
 var $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 62705
 STACKTOP = STACKTOP + 16 | 0; //@line 62706
 $vararg_buffer = sp; //@line 62707
 HEAP32[$vararg_buffer >> 2] = $0; //@line 62709
 $3 = ___syscall_ret(___syscall122(122, $vararg_buffer | 0) | 0) | 0; //@line 62711
 STACKTOP = sp; //@line 62712
 return $3 | 0; //@line 62712
}
function __Z12op_51f8_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $10 = 0;
 $1 = HEAP32[162769] | 0; //@line 6526
 $10 = ((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16; //@line 6536
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($10 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($10, 0); //@line 6542
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6545
 return;
}
function __Z12op_40c0_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 41214
  return;
 } else {
  __Z6MakeSRv(); //@line 41218
  $4 = 651008 + (($0 & 7) << 2) | 0; //@line 41219
  HEAP32[$4 >> 2] = HEAPU16[325558] | HEAP32[$4 >> 2] & -65536; //@line 41225
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 41228
  return;
 }
}
function __Z12op_46fc_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49519
  return;
 } else {
  $3 = HEAP32[162769] | 0; //@line 49522
  HEAP16[325558] = HEAPU8[$3 + 2 >> 0] << 8 | HEAPU8[$3 + 3 >> 0]; //@line 49532
  __Z10MakeFromSRv(); //@line 49533
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 49536
  return;
 }
}
function __Z12op_c188_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $5 = 0, $6 = 0;
 $4 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30470
 $5 = HEAP32[$4 >> 2] | 0; //@line 30471
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30472
 HEAP32[$4 >> 2] = HEAP32[$6 >> 2]; //@line 30474
 HEAP32[$6 >> 2] = $5; //@line 30475
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30478
 return;
}
function __Z12op_c148_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $5 = 0, $6 = 0;
 $4 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 30141
 $5 = HEAP32[$4 >> 2] | 0; //@line 30142
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 30143
 HEAP32[$4 >> 2] = HEAP32[$6 >> 2]; //@line 30145
 HEAP32[$6 >> 2] = $5; //@line 30146
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30149
 return;
}
function __Z12op_c140_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0, $5 = 0, $6 = 0;
 $4 = 651008 + (($0 >>> 9 & 7) << 2) | 0; //@line 30123
 $5 = HEAP32[$4 >> 2] | 0; //@line 30124
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 30125
 HEAP32[$4 >> 2] = HEAP32[$6 >> 2]; //@line 30127
 HEAP32[$6 >> 2] = $5; //@line 30128
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 30131
 return;
}
function __Z14get_rfork_sizePKc($0) {
 $0 = $0 | 0;
 var $$0 = 0, $1 = 0, $3 = 0;
 $1 = __ZL11open_helperPKcS0_i($0, 104080, 0) | 0; //@line 46688
 if (($1 | 0) < 0) {
  $$0 = 0; //@line 46691
  return $$0 | 0; //@line 46692
 }
 $3 = _lseek($1, 0, 2) | 0; //@line 46694
 _close($1) | 0; //@line 46695
 $$0 = ($3 | 0) > 0 ? $3 : 0; //@line 46698
 return $$0 | 0; //@line 46699
}
function _rmdir($0) {
 $0 = $0 | 0;
 var $3 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 3067
 STACKTOP = STACKTOP + 16 | 0; //@line 3068
 $vararg_buffer = sp; //@line 3069
 HEAP32[$vararg_buffer >> 2] = $0; //@line 3071
 $3 = ___syscall_ret(___syscall40(40, $vararg_buffer | 0) | 0) | 0; //@line 3073
 STACKTOP = sp; //@line 3074
 return $3 | 0; //@line 3074
}
function _creat($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $2 = 0, $vararg_buffer = 0, sp = 0;
 sp = STACKTOP; //@line 59608
 STACKTOP = STACKTOP + 16 | 0; //@line 59609
 $vararg_buffer = sp; //@line 59610
 HEAP32[$vararg_buffer >> 2] = $1; //@line 59611
 $2 = _open($0, 577, $vararg_buffer) | 0; //@line 59612
 STACKTOP = sp; //@line 59613
 return $2 | 0; //@line 59613
}
function _sprintf($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $2 = 0, $3 = 0, sp = 0;
 sp = STACKTOP; //@line 56146
 STACKTOP = STACKTOP + 16 | 0; //@line 56147
 $2 = sp; //@line 56148
 HEAP32[$2 >> 2] = $varargs; //@line 56149
 $3 = _vsprintf($0, $1, $2) | 0; //@line 56150
 STACKTOP = sp; //@line 56151
 return $3 | 0; //@line 56151
}
function __Z12op_4c00_0_ffj($0) {
 $0 = $0 | 0;
 var $11 = 0, $13 = 0, $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 52878
 $11 = ((HEAPU8[$2 + 2 >> 0] | 0) << 8 | (HEAPU8[$2 + 3 >> 0] | 0)) & 65535; //@line 52887
 $13 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 52889
 HEAP32[162769] = $2 + 4; //@line 52891
 __Z9m68k_mulljjt($0, $13, $11); //@line 52892
 return;
}
function __Z12op_d0fc_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 33494
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33503
 HEAP32[$12 >> 2] = (((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[$12 >> 2] | 0); //@line 33508
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 33511
 return;
}
function __Z12op_90fc_0_ffj($0) {
 $0 = $0 | 0;
 var $12 = 0, $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 19872
 $12 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19881
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) - (((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16); //@line 19886
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 19889
 return;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 var $7 = 0;
 if ((HEAP32[$1 + 4 >> 2] | 0) == ($2 | 0)) {
  $7 = $1 + 28 | 0; //@line 3788
  if ((HEAP32[$7 >> 2] | 0) != 1) {
   HEAP32[$7 >> 2] = $3; //@line 3792
  }
 }
 return;
}
function __Z21audio_set_sample_sizei($0) {
 $0 = $0 | 0;
 var $1 = 0;
 _puts(104294) | 0; //@line 47758
 $1 = HEAP32[1312] | 0; //@line 47759
 if (($1 | 0) > -1) {
  _close($1) | 0; //@line 47762
  HEAP32[1312] = -1; //@line 47763
 }
 HEAP8[657356] = 0; //@line 47765
 HEAP32[30876] = $0; //@line 47766
 __ZL10open_audiov(); //@line 47767
 return 1; //@line 47768
}
function __Z21audio_set_sample_ratei($0) {
 $0 = $0 | 0;
 var $1 = 0;
 _puts(104294) | 0; //@line 47742
 $1 = HEAP32[1312] | 0; //@line 47743
 if (($1 | 0) > -1) {
  _close($1) | 0; //@line 47746
  HEAP32[1312] = -1; //@line 47747
 }
 HEAP8[657356] = 0; //@line 47749
 HEAP32[30875] = $0; //@line 47750
 __ZL10open_audiov(); //@line 47751
 return 1; //@line 47752
}
function _fprintf($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $2 = 0, $3 = 0, sp = 0;
 sp = STACKTOP; //@line 1697
 STACKTOP = STACKTOP + 16 | 0; //@line 1698
 $2 = sp; //@line 1699
 HEAP32[$2 >> 2] = $varargs; //@line 1700
 $3 = _vfprintf($0, $1, $2) | 0; //@line 1701
 STACKTOP = sp; //@line 1702
 return $3 | 0; //@line 1702
}
function __Z12op_3050_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 35395
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($5 >>> 16 << 2) >> 2] | 0) + 4 >> 2] & 127]($5) | 0) << 16 >> 16; //@line 35405
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35408
 return;
}
function __Z18audio_set_channelsi($0) {
 $0 = $0 | 0;
 var $1 = 0;
 _puts(104294) | 0; //@line 47774
 $1 = HEAP32[1312] | 0; //@line 47775
 if (($1 | 0) > -1) {
  _close($1) | 0; //@line 47778
  HEAP32[1312] = -1; //@line 47779
 }
 HEAP8[657356] = 0; //@line 47781
 HEAP32[30877] = $0; //@line 47782
 __ZL10open_audiov(); //@line 47783
 return 1; //@line 47784
}
function __Z12op_41f0_3_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 46088
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = __Z15get_disp_ea_000jj(HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0, (HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) | 0; //@line 46099
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 46102
 return;
}
function _printf($0, $varargs) {
 $0 = $0 | 0;
 $varargs = $varargs | 0;
 var $1 = 0, $3 = 0, sp = 0;
 sp = STACKTOP; //@line 2720
 STACKTOP = STACKTOP + 16 | 0; //@line 2721
 $1 = sp; //@line 2722
 HEAP32[$1 >> 2] = $varargs; //@line 2723
 $3 = _vfprintf(HEAP32[22131] | 0, $0, $1) | 0; //@line 2725
 STACKTOP = sp; //@line 2726
 return $3 | 0; //@line 2726
}
function __Z12op_41f9_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 42632
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 42652
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 42655
 return;
}
function __Z12op_207c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 28576
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (HEAPU8[$3 + 3 >> 0] | 0) << 16 | (HEAPU8[$3 + 2 >> 0] | 0) << 24 | (HEAPU8[$3 + 4 >> 0] | 0) << 8 | (HEAPU8[$3 + 5 >> 0] | 0); //@line 28596
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 28599
 return;
}
function __Z12op_4ed0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0, $9 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 983
 $9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 24 >> 2] & 127]($3) | 0; //@line 989
 HEAP32[162770] = $9; //@line 990
 HEAP32[162769] = $9; //@line 991
 HEAP32[162768] = $3; //@line 992
 return;
}
function _sscanf($0, $1, $varargs) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $varargs = $varargs | 0;
 var $2 = 0, $3 = 0, sp = 0;
 sp = STACKTOP; //@line 578
 STACKTOP = STACKTOP + 16 | 0; //@line 579
 $2 = sp; //@line 580
 HEAP32[$2 >> 2] = $varargs; //@line 581
 $3 = _vsscanf($0, $1, $2) | 0; //@line 582
 STACKTOP = sp; //@line 583
 return $3 | 0; //@line 583
}
function __ZN8tinyxml28MemPoolTILi52EE4FreeEPv($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $3 = 0, $6 = 0;
 if (!$1) {
  return;
 }
 $3 = $0 + 60 | 0; //@line 40536
 HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 40539
 $6 = $0 + 56 | 0; //@line 40540
 HEAP32[$1 >> 2] = HEAP32[$6 >> 2]; //@line 40542
 HEAP32[$6 >> 2] = $1; //@line 40543
 return;
}
function __ZN8tinyxml28MemPoolTILi48EE4FreeEPv($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $3 = 0, $6 = 0;
 if (!$1) {
  return;
 }
 $3 = $0 + 60 | 0; //@line 40798
 HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 40801
 $6 = $0 + 56 | 0; //@line 40802
 HEAP32[$1 >> 2] = HEAP32[$6 >> 2]; //@line 40804
 HEAP32[$6 >> 2] = $1; //@line 40805
 return;
}
function __ZN8tinyxml28MemPoolTILi44EE4FreeEPv($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $3 = 0, $6 = 0;
 if (!$1) {
  return;
 }
 $3 = $0 + 60 | 0; //@line 40929
 HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 40932
 $6 = $0 + 56 | 0; //@line 40933
 HEAP32[$1 >> 2] = HEAP32[$6 >> 2]; //@line 40935
 HEAP32[$6 >> 2] = $1; //@line 40936
 return;
}
function __ZN8tinyxml28MemPoolTILi36EE4FreeEPv($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $3 = 0, $6 = 0;
 if (!$1) {
  return;
 }
 $3 = $0 + 60 | 0; //@line 40667
 HEAP32[$3 >> 2] = (HEAP32[$3 >> 2] | 0) + -1; //@line 40670
 $6 = $0 + 56 | 0; //@line 40671
 HEAP32[$1 >> 2] = HEAP32[$6 >> 2]; //@line 40673
 HEAP32[$6 >> 2] = $1; //@line 40674
 return;
}
function __Z7SCSIGetv() {
 var $$0 = 0;
 if (HEAP32[28496] | 0) {
  $$0 = 7; //@line 22800
  return $$0 | 0; //@line 22801
 }
 HEAP32[28496] = 1; //@line 22803
 HEAP16[325962] = 64; //@line 22804
 HEAP8[657355] = 0; //@line 22805
 HEAP32[28497] = 0; //@line 22806
 HEAP32[28499] = 0; //@line 22807
 $$0 = 0; //@line 22808
 return $$0 | 0; //@line 22809
}
function __Z12op_5dd0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10346
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10356
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10359
 return;
}
function __Z12op_5cd0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 10006
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 10016
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10019
 return;
}
function __Z10SerialExitv() {
 var $0 = 0, $5 = 0;
 $0 = HEAP32[28475] | 0; //@line 47068
 if ($0 | 0) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[$0 >> 2] | 0) + 4 >> 2] & 4095]($0); //@line 47074
 }
 $5 = HEAP32[28476] | 0; //@line 47076
 if (!$5) {
  return;
 }
 FUNCTION_TABLE_vi[HEAP32[(HEAP32[$5 >> 2] | 0) + 4 >> 2] & 4095]($5); //@line 47084
 return;
}
function __Z12op_42d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46599
 __Z6MakeSRv(); //@line 46600
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, HEAP16[325558] & 255); //@line 46609
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46612
 return;
}
function __Z12op_41e8_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = HEAP32[162769] | 0; //@line 42556
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = (((HEAPU8[$6 + 2 >> 0] | 0) << 8 | (HEAPU8[$6 + 3 >> 0] | 0)) << 16 >> 16) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0); //@line 42569
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42572
 return;
}
function __ZN17disk_sparsebundleD0Ev($0) {
 $0 = $0 | 0;
 var $2 = 0;
 HEAP32[$0 >> 2] = 1544; //@line 35756
 $2 = HEAP32[$0 + 28 >> 2] | 0; //@line 35758
 if (($2 | 0) != -1) {
  _close($2) | 0; //@line 35761
 }
 _close(HEAP32[$0 + 4 >> 2] | 0) | 0; //@line 35765
 _free(HEAP32[$0 + 20 >> 2] | 0); //@line 35768
 __ZdlPv($0); //@line 35769
 return;
}
function __Z12op_40d0_4_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 46223
 __Z6MakeSRv(); //@line 46224
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 16 >> 2] & 31]($3, HEAPU16[325558] | 0); //@line 46232
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46235
 return;
}
function __Z18add_path_componentPcPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $2 = 0;
 $2 = _strlen($0) | 0; //@line 46438
 if (($2 | 0) < 1023) {
  if ((HEAP8[$0 + ($2 + -1) >> 0] | 0) != 47) {
   HEAP8[$0 + $2 >> 0] = 47; //@line 46449
   HEAP8[$0 + ($2 + 1) >> 0] = 0; //@line 46450
  }
 }
 _strncat($0, $1, 1023) | 0; //@line 46453
 return;
}
function __Z12op_52d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6680
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 6691
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6694
 return;
}
function __Z7ExitAllv() {
 __Z9XPRAMExitv(); //@line 223
 __Z9VideoExitv(); //@line 224
 __Z9AudioExitv(); //@line 225
 __Z7ADBExitv(); //@line 226
 __Z10SerialExitv(); //@line 227
 __Z9EtherExitv(); //@line 228
 __Z9ExtFSExitv(); //@line 229
 __Z9CDROMExitv(); //@line 230
 __Z8DiskExitv(); //@line 231
 __Z8SonyExitv(); //@line 232
 return;
}
function ___ofl_add($0) {
 $0 = $0 | 0;
 var $1 = 0, $4 = 0;
 $1 = ___ofl_lock() | 0; //@line 208
 HEAP32[$0 + 56 >> 2] = HEAP32[$1 >> 2]; //@line 211
 $4 = HEAP32[$1 >> 2] | 0; //@line 212
 if ($4 | 0) {
  HEAP32[$4 + 52 >> 2] = $0; //@line 216
 }
 HEAP32[$1 >> 2] = $0; //@line 218
 ___ofl_unlock(); //@line 219
 return $0 | 0; //@line 220
}
function __Z12op_53d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7032
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0); //@line 7043
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7046
 return;
}
function __Z12op_2050_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 28304
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = FUNCTION_TABLE_ii[HEAP32[HEAP32[123608 + ($5 >>> 16 << 2) >> 2] >> 2] & 127]($5) | 0; //@line 28311
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28314
 return;
}
function __Z12op_6dff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13268
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 13293
 return;
}
function __Z12op_6cff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13195
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 13220
 return;
}
function __Z12op_62ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12485
 HEAP32[162769] = $1 + ((HEAP32[96442] | HEAP32[96441] | 0) == 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 12511
 return;
}
function __Z12op_5ad0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9348
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9357
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9360
 return;
}
function __Z12op_58d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8692
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8701
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8704
 return;
}
function __Z12op_56d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8036
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 8045
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8048
 return;
}
function __Z12op_54d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7380
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, (HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7389
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7392
 return;
}
function __Z10EtherResetv() {
 __ZNSt3__26__treeINS_12__value_typeItjEENS_19__map_value_compareItS2_NS_4lessItEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(113912, HEAP32[28479] | 0); //@line 15233
 HEAP32[28480] = 0; //@line 15234
 HEAP32[28478] = 113916; //@line 15235
 HEAP32[28479] = 0; //@line 15236
 return;
}
function __Z12op_44c0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0; //@line 47889
 __Z6MakeSRv(); //@line 47890
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $3 & 255; //@line 47897
 __Z10MakeFromSRv(); //@line 47898
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 47901
 return;
}
function __ZN13driver_window17toggle_mouse_grabEv($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = HEAP32[$0 >> 2] | 0; //@line 43922
 if (!(HEAP8[$0 + 20 >> 0] | 0)) {
  FUNCTION_TABLE_vi[HEAP32[$4 + 28 >> 2] & 4095]($0); //@line 43926
  return;
 } else {
  FUNCTION_TABLE_vi[HEAP32[$4 + 32 >> 2] & 4095]($0); //@line 43931
  return;
 }
}
function __ZL10ram24_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0;
 $5 = (HEAP32[96438] | 0) + ($0 & 16777215) | 0; //@line 49665
 HEAP8[$5 >> 0] = $1 >>> 24; //@line 49668
 HEAP8[$5 + 1 >> 0] = $1 >>> 16; //@line 49672
 HEAP8[$5 + 2 >> 0] = $1 >>> 8; //@line 49676
 HEAP8[$5 + 3 >> 0] = $1; //@line 49679
 return;
}
function __Z12op_63ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12561
 HEAP32[162769] = $1 + (HEAP32[96442] | HEAP32[96441] | 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 12587
 return;
}
function __Z12op_5bd0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9676
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96443] | 0 ? 255 : 0); //@line 9685
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9688
 return;
}
function __Z12op_59d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 9020
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96444] | 0 ? 255 : 0); //@line 9029
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9032
 return;
}
function __Z12op_57d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 8364
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96442] | 0 ? 255 : 0); //@line 8373
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8376
 return;
}
function __Z12op_55d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 7708
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, HEAP32[96441] | 0 ? 255 : 0); //@line 7717
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7720
 return;
}
function __Z12op_44fc_0_ffj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0; //@line 48239
 __Z6MakeSRv(); //@line 48240
 HEAP16[325558] = HEAP16[325558] & -256 & 65535 | $4; //@line 48246
 __Z10MakeFromSRv(); //@line 48247
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 48250
 return;
}
function __Z12op_5ffc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 12256
   return;
  }
 }
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 12265
 return;
}
function __Z12op_5ffb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 12231
   return;
  }
 }
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 12240
 return;
}
function __Z12op_5ffa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 12206
   return;
  }
 }
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 12215
 return;
}
function __Z12op_5efc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 11020
   return;
  }
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 11026
 return;
}
function __Z12op_5efb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10995
   return;
  }
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 11001
 return;
}
function __Z12op_5efa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
   __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10970
   return;
  }
 }
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10976
 return;
}
function __ZN17disk_sparsebundleD2Ev($0) {
 $0 = $0 | 0;
 var $2 = 0;
 HEAP32[$0 >> 2] = 1544; //@line 35737
 $2 = HEAP32[$0 + 28 >> 2] | 0; //@line 35739
 if (($2 | 0) != -1) {
  _close($2) | 0; //@line 35742
 }
 _close(HEAP32[$0 + 4 >> 2] | 0) | 0; //@line 35746
 _free(HEAP32[$0 + 20 >> 2] | 0); //@line 35749
 return;
}
function __ZL17frame_direct_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0;
 $4 = (HEAP32[96440] | 0) + $0 | 0; //@line 49934
 HEAP8[$4 >> 0] = $1 >>> 24; //@line 49937
 HEAP8[$4 + 1 >> 0] = $1 >>> 16; //@line 49941
 HEAP8[$4 + 2 >> 0] = $1 >>> 8; //@line 49945
 HEAP8[$4 + 3 >> 0] = $1; //@line 49948
 return;
}
function __Z9EtherExitv() {
 if (!(HEAP8[657350] | 0)) {
  return;
 }
 if (!(HEAP8[657351] | 0)) {} else {
  if ((HEAP32[370] | 0) > -1) {
   __Z21ether_stop_udp_threadv(); //@line 15220
   _close(HEAP32[370] | 0) | 0; //@line 15222
   HEAP32[370] = -1; //@line 15223
  }
 }
 HEAP8[657350] = 0; //@line 15226
 return;
}
function __Z12op_6bff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13123
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == 0 ? 6 : ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0); //@line 13147
 return;
}
function __Z12op_6aff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13053
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 13077
 return;
}
function __Z12op_69ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12983
 HEAP32[162769] = $1 + ((HEAP32[96444] | 0) == 0 ? 6 : ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0); //@line 13007
 return;
}
function __Z12op_68ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12913
 HEAP32[162769] = $1 + ((HEAP32[96444] | 0) == 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 12937
 return;
}
function __Z12op_67ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12843
 HEAP32[162769] = $1 + ((HEAP32[96442] | 0) == 0 ? 6 : ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0); //@line 12867
 return;
}
function __Z12op_66ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12773
 HEAP32[162769] = $1 + ((HEAP32[96442] | 0) == 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 12797
 return;
}
function __Z12op_65ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12703
 HEAP32[162769] = $1 + ((HEAP32[96441] | 0) == 0 ? 6 : ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0); //@line 12727
 return;
}
function __Z12op_64ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12633
 HEAP32[162769] = $1 + ((HEAP32[96441] | 0) == 0 ? ((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2 | 0 : 6); //@line 12657
 return;
}
function _bitshift64Shl(low, high, bits) {
 low = low | 0;
 high = high | 0;
 bits = bits | 0;
 if ((bits | 0) < 32) {
  tempRet0 = high << bits | (low & (1 << bits) - 1 << 32 - bits) >>> 32 - bits; //@line 4593
  return low << bits; //@line 4594
 }
 tempRet0 = low << bits - 32; //@line 4596
 return 0; //@line 4597
}
function __Z12op_46c0_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49161
  return;
 } else {
  HEAP16[325558] = HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 49168
  __Z10MakeFromSRv(); //@line 49169
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49172
  return;
 }
}
function _bitshift64Lshr(low, high, bits) {
 low = low | 0;
 high = high | 0;
 bits = bits | 0;
 if ((bits | 0) < 32) {
  tempRet0 = high >>> bits; //@line 4398
  return low >>> bits | (high & (1 << bits) - 1) << 32 - bits; //@line 4399
 }
 tempRet0 = 0; //@line 4401
 return high >>> bits - 32 | 0; //@line 4402
}
function ___strdup($0) {
 $0 = $0 | 0;
 var $$0 = 0, $2 = 0, $3 = 0;
 $2 = (_strlen($0) | 0) + 1 | 0; //@line 62691
 $3 = _malloc($2) | 0; //@line 62692
 if (!$3) {
  $$0 = 0; //@line 62695
 } else {
  _memcpy($3 | 0, $0 | 0, $2 | 0) | 0; //@line 62697
  $$0 = $3; //@line 62698
 }
 return $$0 | 0; //@line 62700
}
function __ZL8ram_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0;
 $4 = (HEAP32[96438] | 0) + $0 | 0; //@line 49546
 HEAP8[$4 >> 0] = $1 >>> 24; //@line 49549
 HEAP8[$4 + 1 >> 0] = $1 >>> 16; //@line 49553
 HEAP8[$4 + 2 >> 0] = $1 >>> 8; //@line 49557
 HEAP8[$4 + 3 >> 0] = $1; //@line 49560
 return;
}
function __Z12op_41f8_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 42607
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 42619
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 42622
 return;
}
function __Z12op_307c_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[162769] | 0; //@line 35693
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = ((HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0)) << 16 >> 16; //@line 35705
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 35708
 return;
}
function __Z12op_50d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 4787
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 255); //@line 4793
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4796
 return;
}
function __Z12op_5dfc_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10606
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10614
  return;
 }
}
function __Z12op_5dfb_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10584
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10592
  return;
 }
}
function __Z12op_5dfa_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10562
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10570
  return;
 }
}
function __Z12op_5cfc_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10269
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10274
  return;
 }
}
function __Z12op_5cfb_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10247
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 10252
  return;
 }
}
function __Z12op_5cfa_0_ffj($0) {
 $0 = $0 | 0;
 if ((HEAP32[96443] | 0) == (HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 10225
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 10230
  return;
 }
}
function __Z12op_51d0_0_ffj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0; //@line 6406
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[123608 + ($3 >>> 16 << 2) >> 2] | 0) + 20 >> 2] & 31]($3, 0); //@line 6412
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6415
 return;
}
function __Z12op_f23c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48491
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48499
 HEAP32[162769] = $1 + 4; //@line 48501
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48504
 return;
}
function __Z12op_f23b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48471
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48479
 HEAP32[162769] = $1 + 4; //@line 48481
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48484
 return;
}
function __Z12op_f23a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48451
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48459
 HEAP32[162769] = $1 + 4; //@line 48461
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48464
 return;
}
function __Z12op_f239_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48431
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48439
 HEAP32[162769] = $1 + 4; //@line 48441
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48444
 return;
}
function __Z12op_f238_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48411
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48419
 HEAP32[162769] = $1 + 4; //@line 48421
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48424
 return;
}
function __Z12op_f230_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48391
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48399
 HEAP32[162769] = $1 + 4; //@line 48401
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48404
 return;
}
function __Z12op_f228_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48371
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48379
 HEAP32[162769] = $1 + 4; //@line 48381
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48384
 return;
}
function __Z12op_f220_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48351
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48359
 HEAP32[162769] = $1 + 4; //@line 48361
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48364
 return;
}
function __Z12op_f218_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48331
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48339
 HEAP32[162769] = $1 + 4; //@line 48341
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48344
 return;
}
function __Z12op_f210_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48311
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48319
 HEAP32[162769] = $1 + 4; //@line 48321
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48324
 return;
}
function __Z12op_f208_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48291
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48299
 HEAP32[162769] = $1 + 4; //@line 48301
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48304
 return;
}
function __Z12op_f200_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48271
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48279
 HEAP32[162769] = $1 + 4; //@line 48281
 __Z16fpuop_arithmeticjj($0, $9 << 16 >> 16); //@line 48284
 return;
}
function __Z12op_d0c8_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33157
 HEAP32[$6 >> 2] = (HEAP32[651040 + (($0 & 7) << 2) >> 2] << 16 >> 16) + (HEAP32[$6 >> 2] | 0); //@line 33162
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33165
 return;
}
function __Z12op_d0c0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 33137
 HEAP32[$6 >> 2] = (HEAP32[651008 + (($0 & 7) << 2) >> 2] << 16 >> 16) + (HEAP32[$6 >> 2] | 0); //@line 33142
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 33145
 return;
}
function __Z12op_90c8_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19535
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[651040 + (($0 & 7) << 2) >> 2] << 16 >> 16); //@line 19540
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19543
 return;
}
function __Z12op_90c0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 19515
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[651008 + (($0 & 7) << 2) >> 2] << 16 >> 16); //@line 19520
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 19523
 return;
}
function __Z12op_f248_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48531
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48539
 HEAP32[162769] = $1 + 4; //@line 48541
 __Z10fpuop_dbccjj($0, $9 << 16 >> 16); //@line 48544
 return;
}
function __Z12op_5dc0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 10287
 HEAP32[$6 >> 2] = HEAP32[$6 >> 2] & -256 | ((HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? 255 : 0); //@line 10291
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 10294
 return;
}
function __ZNSt3__23mapItjNS_4lessItEENS_9allocatorINS_4pairIKtjEEEEED2Ev($0) {
 $0 = $0 | 0;
 __ZNSt3__26__treeINS_12__value_typeItjEENS_19__map_value_compareItS2_NS_4lessItEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0, HEAP32[$0 + 4 >> 2] | 0); //@line 15056
 return;
}
function __Z12op_f279_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48671
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48679
 HEAP32[162769] = $1 + 4; //@line 48681
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48684
 return;
}
function __Z12op_f278_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48651
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48659
 HEAP32[162769] = $1 + 4; //@line 48661
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48664
 return;
}
function __Z12op_f270_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48631
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48639
 HEAP32[162769] = $1 + 4; //@line 48641
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48644
 return;
}
function __Z12op_f268_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48611
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48619
 HEAP32[162769] = $1 + 4; //@line 48621
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48624
 return;
}
function __Z12op_f260_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48591
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48599
 HEAP32[162769] = $1 + 4; //@line 48601
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48604
 return;
}
function __Z12op_f258_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48571
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48579
 HEAP32[162769] = $1 + 4; //@line 48581
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48584
 return;
}
function __Z12op_f250_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48551
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48559
 HEAP32[162769] = $1 + 4; //@line 48561
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48564
 return;
}
function __Z12op_f240_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $9 = 0;
 $1 = HEAP32[162769] | 0; //@line 48511
 $9 = (HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0); //@line 48519
 HEAP32[162769] = $1 + 4; //@line 48521
 __Z9fpuop_sccjj($0, $9 << 16 >> 16); //@line 48524
 return;
}
function __Z12op_42c0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 __Z6MakeSRv(); //@line 46579
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 46580
 HEAP32[$2 >> 2] = HEAP16[325558] & 255 | HEAP32[$2 >> 2] & -65536; //@line 46587
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46590
 return;
}
function __Z10vm_acquireji($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0;
 HEAP32[(___errno_location() | 0) >> 2] = 0; //@line 26532
 if ($1 & 20 | 0) {
  $$0 = 0; //@line 26536
  return $$0 | 0; //@line 26537
 }
 $$0 = _calloc($0, 1) | 0; //@line 26540
 return $$0 | 0; //@line 26541
}
function __Z12op_5cc0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651008 + (($0 & 7) << 2) | 0; //@line 9947
 HEAP32[$6 >> 2] = HEAP32[$6 >> 2] & -256 | ((HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? 255 : 0); //@line 9951
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9954
 return;
}
function __Z12op_40c0_4_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 __Z6MakeSRv(); //@line 46204
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 46205
 HEAP32[$2 >> 2] = HEAPU16[325558] | 0 | HEAP32[$2 >> 2] & -65536; //@line 46211
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 46214
 return;
}
function __Z12op_53fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7302
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7310
  return;
 }
}
function __Z12op_53fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7279
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7287
  return;
 }
}
function __Z12op_53fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7256
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7264
  return;
 }
}
function __Z12op_52fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 6953
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6958
  return;
 }
}
function __Z12op_52fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 6930
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6935
  return;
 }
}
function __Z12op_52fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | HEAP32[96441])) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 6907
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6912
  return;
 }
}
function __Z12op_52c0_0_ffj($0) {
 $0 = $0 | 0;
 var $7 = 0;
 $7 = 651008 + (($0 & 7) << 2) | 0; //@line 6620
 HEAP32[$7 >> 2] = ((HEAP32[96442] | HEAP32[96441] | 0) == 0 ? 255 : 0) | HEAP32[$7 >> 2] & -256; //@line 6624
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6627
 return;
}
function __Z12op_d1c8_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 35101
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0); //@line 35104
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35107
 return;
}
function __Z12op_d1c0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 35083
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0); //@line 35086
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35089
 return;
}
function __Z12op_91c8_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21456
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[651040 + (($0 & 7) << 2) >> 2] | 0); //@line 21459
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21462
 return;
}
function __Z12op_91c0_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 >>> 9 & 7) << 2) | 0; //@line 21438
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0); //@line 21441
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 21444
 return;
}
function __Z11op_23c_0_ffj($0) {
 $0 = $0 | 0;
 __Z6MakeSRv(); //@line 8781
 HEAP16[325558] = (HEAPU16[325558] | 0) & (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0 | 65280); //@line 8791
 __Z10MakeFromSRv(); //@line 8792
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8795
 return;
}
function __Z12op_60ff_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12305
 HEAP32[162769] = $1 + (((HEAPU8[$1 + 3 >> 0] | 0) << 16 | (HEAPU8[$1 + 2 >> 0] | 0) << 24 | (HEAPU8[$1 + 4 >> 0] | 0) << 8 | (HEAPU8[$1 + 5 >> 0] | 0)) + 2); //@line 12326
 return;
}
function __Z12op_6d00_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13227
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 13244
 return;
}
function __Z12op_6c00_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13154
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 13171
 return;
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($0, $1, __ZNSt3__211char_traitsIcE6lengthEPKc($1) | 0) | 0; //@line 3361
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($0, $1, __ZNSt3__211char_traitsIcE6lengthEPKc($1) | 0) | 0; //@line 3492
}
function __Z12op_5188_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 5997
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0); //@line 6000
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6003
 return;
}
function __Z12op_5148_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 5524
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) - (HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0); //@line 5527
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 5530
 return;
}
function __Z12op_5088_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 4395
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0); //@line 4398
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4401
 return;
}
function __Z12op_5048_0_ffj($0) {
 $0 = $0 | 0;
 var $6 = 0;
 $6 = 651040 + (($0 & 7) << 2) | 0; //@line 3913
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + (HEAP32[5688 + (($0 >>> 9 & 7) << 2) >> 2] | 0); //@line 3916
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 3919
 return;
}
function __Z12op_4e76_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 545
 HEAP32[162769] = $2; //@line 546
 if (!(HEAP32[96444] | 0)) {
  return;
 }
 __Z9Exceptionij(7, $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 557
 return;
}
function __Z12op_f27b_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 48707
 $6 = $1 + 2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 48713
 HEAP32[162769] = $1 + 6; //@line 48715
 __Z12fpuop_trapccjj($0, $6); //@line 48716
 return;
}
function __Z12op_f27a_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0, $6 = 0;
 $1 = HEAP32[162769] | 0; //@line 48691
 $6 = $1 + 2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0; //@line 48697
 HEAP32[162769] = $1 + 4; //@line 48699
 __Z12fpuop_trapccjj($0, $6); //@line 48700
 return;
}
function __Z12op_6200_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12442
 HEAP32[162769] = $1 + ((HEAP32[96442] | HEAP32[96441] | 0) == 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 12460
 return;
}
function __Z12op_53c0_0_ffj($0) {
 $0 = $0 | 0;
 var $7 = 0;
 $7 = 651008 + (($0 & 7) << 2) | 0; //@line 6972
 HEAP32[$7 >> 2] = (HEAP32[96442] | HEAP32[96441] | 0 ? 255 : 0) | HEAP32[$7 >> 2] & -256; //@line 6976
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6979
 return;
}
function __Z11op_a3c_0_ffj($0) {
 $0 = $0 | 0;
 __Z6MakeSRv(); //@line 15812
 HEAP16[325558] = (HEAPU16[325558] | 0) ^ (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0); //@line 15821
 __Z10MakeFromSRv(); //@line 15822
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 15825
 return;
}
function __Z6MakeSRv() {
 HEAP16[325558] = HEAP8[651119] << 14 | HEAP8[651118] << 15 | HEAP8[651120] << 13 | HEAP8[651121] << 12 | HEAP32[162772] << 8 | HEAP32[96445] << 4 | HEAP32[96443] << 3 | HEAP32[96442] << 2 | HEAP32[96444] << 1 | HEAP32[96441]; //@line 51317
 return;
}
function __Z12op_5bfc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9926
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9934
  return;
 }
}
function __Z12op_5bfb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9905
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9913
  return;
 }
}
function __Z12op_5bfa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9884
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9892
  return;
 }
}
function __Z12op_5afc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9601
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9606
  return;
 }
}
function __Z12op_5afb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9580
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9585
  return;
 }
}
function __Z12op_5afa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96443] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9559
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9564
  return;
 }
}
function __Z12op_59fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9270
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9278
  return;
 }
}
function __Z12op_59fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 9249
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9257
  return;
 }
}
function __Z12op_59fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 9228
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 9236
  return;
 }
}
function __Z12op_58fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8945
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8950
  return;
 }
}
function __Z12op_58fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8924
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8929
  return;
 }
}
function __Z12op_58fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96444] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8903
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8908
  return;
 }
}
function __Z12op_57fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8614
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8622
  return;
 }
}
function __Z12op_57fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8593
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8601
  return;
 }
}
function __Z12op_57fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8572
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8580
  return;
 }
}
function __Z12op_56fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8289
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8294
  return;
 }
}
function __Z12op_56fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8268
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 8273
  return;
 }
}
function __Z12op_56fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96442] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 8247
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 8252
  return;
 }
}
function __Z12op_55fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7958
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7966
  return;
 }
}
function __Z12op_55fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7937
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7945
  return;
 }
}
function __Z12op_55fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7916
  return;
 } else {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7924
  return;
 }
}
function __Z12op_54fc_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7633
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7638
  return;
 }
}
function __Z12op_54fb_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7612
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 7617
  return;
 }
}
function __Z12op_54fa_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP32[96441] | 0)) {
  __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 7591
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 7596
  return;
 }
}
function __Z12op_4e68_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 274
  return;
 } else {
  HEAP32[651040 + (($0 & 7) << 2) >> 2] = HEAP32[162776]; //@line 280
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 283
  return;
 }
}
function __Z12op_4e60_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 254
  return;
 } else {
  HEAP32[162776] = HEAP32[651040 + (($0 & 7) << 2) >> 2]; //@line 260
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 263
  return;
 }
}
function __ZL10rom24_lgetj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = (HEAP32[96439] | 0) + ($0 & 16777215) | 0; //@line 49814
 return (HEAPU8[$4 + 1 >> 0] | 0) << 16 | (HEAPU8[$4 >> 0] | 0) << 24 | (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0) | 0; //@line 49832
}
function __ZL10ram24_lgetj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = (HEAP32[96438] | 0) + ($0 & 16777215) | 0; //@line 49608
 return (HEAPU8[$4 + 1 >> 0] | 0) << 16 | (HEAPU8[$4 >> 0] | 0) << 24 | (HEAPU8[$4 + 2 >> 0] | 0) << 8 | (HEAPU8[$4 + 3 >> 0] | 0) | 0; //@line 49626
}
function __Z12op_6300_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12518
 HEAP32[162769] = $1 + (HEAP32[96442] | HEAP32[96441] | 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 12536
 return;
}
function __Z10op_3c_0_ffj($0) {
 $0 = $0 | 0;
 __Z6MakeSRv(); //@line 5040
 HEAP16[325558] = HEAPU16[325558] | 0 | (HEAPU8[(HEAP32[162769] | 0) + 3 >> 0] | 0); //@line 5049
 __Z10MakeFromSRv(); //@line 5050
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 5053
 return;
}
function __Z12op_5ac0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 9290
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | ((HEAP32[96443] | 0) == 0 ? 255 : 0); //@line 9294
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9297
 return;
}
function __Z12op_58c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 8634
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | ((HEAP32[96444] | 0) == 0 ? 255 : 0); //@line 8638
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8641
 return;
}
function __Z12op_56c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 7978
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | ((HEAP32[96442] | 0) == 0 ? 255 : 0); //@line 7982
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7985
 return;
}
function __Z12op_54c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 7322
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | ((HEAP32[96441] | 0) == 0 ? 255 : 0); //@line 7326
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7329
 return;
}
function runPostSets() {}
function _i64Subtract(a, b, c, d) {
 a = a | 0;
 b = b | 0;
 c = c | 0;
 d = d | 0;
 var h = 0;
 h = b - d >>> 0; //@line 4137
 h = b - d - (c >>> 0 > a >>> 0 | 0) >>> 0; //@line 4138
 return (tempRet0 = h, a - c >>> 0 | 0) | 0; //@line 4139
}
function __ZL17frame_direct_lgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96440] | 0) + $0 | 0; //@line 49880
 return (HEAPU8[$3 + 1 >> 0] | 0) << 16 | (HEAPU8[$3 >> 0] | 0) << 24 | (HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0) | 0; //@line 49898
}
function ___lctrans_impl($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0;
 if (!$1) {
  $$0 = 0; //@line 59020
 } else {
  $$0 = ___mo_lookup(HEAP32[$1 >> 2] | 0, HEAP32[$1 + 4 >> 2] | 0, $0) | 0; //@line 59026
 }
 return ($$0 | 0 ? $$0 : $0) | 0; //@line 59030
}
function __Z11op_13c_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = HEAP32[162769] | 0; //@line 6927
 HEAP32[96442] = (HEAP8[$5 + 3 >> 0] | 0) >>> (HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 7) & 1 ^ 1; //@line 6935
 HEAP32[162769] = $5 + 4; //@line 6937
 return;
}
function __Z12op_6b00_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13084
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == 0 ? 4 : (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0); //@line 13100
 return;
}
function __Z12op_6a00_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 13014
 HEAP32[162769] = $1 + ((HEAP32[96443] | 0) == 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 13030
 return;
}
function __Z12op_6900_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12944
 HEAP32[162769] = $1 + ((HEAP32[96444] | 0) == 0 ? 4 : (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0); //@line 12960
 return;
}
function __Z12op_6800_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12874
 HEAP32[162769] = $1 + ((HEAP32[96444] | 0) == 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 12890
 return;
}
function __Z12op_6700_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12804
 HEAP32[162769] = $1 + ((HEAP32[96442] | 0) == 0 ? 4 : (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0); //@line 12820
 return;
}
function __Z12op_6600_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12734
 HEAP32[162769] = $1 + ((HEAP32[96442] | 0) == 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 12750
 return;
}
function __Z12op_6500_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12664
 HEAP32[162769] = $1 + ((HEAP32[96441] | 0) == 0 ? 4 : (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0); //@line 12680
 return;
}
function __Z12op_6400_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12594
 HEAP32[162769] = $1 + ((HEAP32[96441] | 0) == 0 ? (((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2 | 0 : 4); //@line 12610
 return;
}
function __Z12op_5bc0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 9618
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | (HEAP32[96443] | 0 ? 255 : 0); //@line 9622
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 9625
 return;
}
function __Z12op_59c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 8962
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | (HEAP32[96444] | 0 ? 255 : 0); //@line 8966
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8969
 return;
}
function __Z12op_57c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 8306
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | (HEAP32[96442] | 0 ? 255 : 0); //@line 8310
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 8313
 return;
}
function __Z12op_55c0_0_ffj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = 651008 + (($0 & 7) << 2) | 0; //@line 7650
 HEAP32[$5 >> 2] = HEAP32[$5 >> 2] & -256 | (HEAP32[96441] | 0 ? 255 : 0); //@line 7654
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 7657
 return;
}
function __Z11op_800_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = HEAP32[162769] | 0; //@line 13768
 HEAP32[96442] = (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0) >>> (HEAP8[$2 + 3 >> 0] & 31) & 1 ^ 1; //@line 13778
 HEAP32[162769] = $2 + 4; //@line 13780
 return;
}
function __Z8SCSIReadj($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if ((HEAP32[28496] | 0) != 3) {
  $$0 = 5; //@line 22891
  return $$0 | 0; //@line 22892
 }
 HEAP8[657355] = 1; //@line 22894
 $$0 = __ZL8exec_tibj($0) | 0; //@line 22896
 return $$0 | 0; //@line 22897
}
function dynCall_viiiiii(index, a1, a2, a3, a4, a5, a6) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 a5 = a5 | 0;
 a6 = a6 | 0;
 FUNCTION_TABLE_viiiiii[index & 3](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0, a6 | 0); //@line 4718
}
function __ZL8rom_lgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96439] | 0) + $0 | 0; //@line 49729
 return (HEAPU8[$3 + 1 >> 0] | 0) << 16 | (HEAPU8[$3 >> 0] | 0) << 24 | (HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0) | 0; //@line 49747
}
function __ZL8ram_lgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96438] | 0) + $0 | 0; //@line 49492
 return (HEAPU8[$3 + 1 >> 0] | 0) << 16 | (HEAPU8[$3 >> 0] | 0) << 24 | (HEAPU8[$3 + 2 >> 0] | 0) << 8 | (HEAPU8[$3 + 3 >> 0] | 0) | 0; //@line 49510
}
function ___DOUBLE_BITS_685($0) {
 $0 = +$0;
 var $1 = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 58758
 $1 = HEAP32[tempDoublePtr >> 2] | 0; //@line 58758
 tempRet0 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 58760
 return $1 | 0; //@line 58761
}
function ___DOUBLE_BITS_272($0) {
 $0 = +$0;
 var $1 = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 61815
 $1 = HEAP32[tempDoublePtr >> 2] | 0; //@line 61815
 tempRet0 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 61817
 return $1 | 0; //@line 61818
}
function ___DOUBLE_BITS_260($0) {
 $0 = +$0;
 var $1 = 0;
 HEAPF64[tempDoublePtr >> 3] = $0; //@line 56009
 $1 = HEAP32[tempDoublePtr >> 2] | 0; //@line 56009
 tempRet0 = HEAP32[tempDoublePtr + 4 >> 2] | 0; //@line 56011
 return $1 | 0; //@line 56012
}
function __Z11op_100_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[96442] = (HEAP32[651008 + (($0 & 7) << 2) >> 2] | 0) >>> (HEAP32[651008 + (($0 >>> 9 & 7) << 2) >> 2] & 31) & 1 ^ 1; //@line 6512
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6515
 return;
}
function __Z15get_disp_ea_000jj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0;
 $5 = HEAP32[651008 + (($1 >>> 12 & 15) << 2) >> 2] | 0; //@line 51268
 return ($1 << 24 >> 24) + $0 + (($1 & 2048 | 0) == 0 ? $5 << 16 >> 16 : $5) | 0; //@line 51278
}
function __Z12op_f27c_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = (HEAP32[162769] | 0) + 2 | 0; //@line 48724
 HEAP32[162769] = $2; //@line 48725
 __Z12fpuop_trapccjj($0, $2 + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 48731
 return;
}
function ___syscall_ret($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if ($0 >>> 0 > 4294963200) {
  HEAP32[(___errno_location() | 0) >> 2] = 0 - $0; //@line 54726
  $$0 = -1; //@line 54727
 } else {
  $$0 = $0; //@line 54729
 }
 return $$0 | 0; //@line 54731
}
function __Z15PrefsPrintUsagev() {
 _puts(89044) | 0; //@line 1053
 __ZL13print_optionsPK10prefs_desc(360); //@line 1054
 _puts(89062) | 0; //@line 1055
 __ZL13print_optionsPK10prefs_desc(5260); //@line 1056
 _puts(89090) | 0; //@line 1057
 return;
}
function __Z12op_f37b_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49023
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49028
  __Z13fpuop_restorej($0); //@line 49029
  return;
 }
}
function __Z12op_f37a_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49006
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49011
  __Z13fpuop_restorej($0); //@line 49012
  return;
 }
}
function __Z12op_f379_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48989
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48994
  __Z13fpuop_restorej($0); //@line 48995
  return;
 }
}
function __Z12op_f378_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48972
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48977
  __Z13fpuop_restorej($0); //@line 48978
  return;
 }
}
function __Z12op_f370_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48955
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48960
  __Z13fpuop_restorej($0); //@line 48961
  return;
 }
}
function __Z12op_f368_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48938
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48943
  __Z13fpuop_restorej($0); //@line 48944
  return;
 }
}
function __Z12op_f358_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48921
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48926
  __Z13fpuop_restorej($0); //@line 48927
  return;
 }
}
function __Z12op_f350_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48904
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48909
  __Z13fpuop_restorej($0); //@line 48910
  return;
 }
}
function __ZL19frame_host_565_lgetj($0) {
 $0 = $0 | 0;
 var $4 = 0, $8 = 0;
 $4 = HEAP32[(HEAP32[96440] | 0) + $0 >> 2] | 0; //@line 50045
 $8 = $4 >>> 1 & 2145419232 | $4 & 2031647; //@line 50049
 return $8 >>> 16 | $8 << 16 | 0; //@line 50053
}
function __Z12op_f339_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48887
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48892
  __Z10fpuop_savej($0); //@line 48893
  return;
 }
}
function __Z12op_f338_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48870
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48875
  __Z10fpuop_savej($0); //@line 48876
  return;
 }
}
function __Z12op_f330_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48853
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48858
  __Z10fpuop_savej($0); //@line 48859
  return;
 }
}
function __Z12op_f328_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48836
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48841
  __Z10fpuop_savej($0); //@line 48842
  return;
 }
}
function __Z12op_f320_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48819
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48824
  __Z10fpuop_savej($0); //@line 48825
  return;
 }
}
function __Z12op_f310_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 48802
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 48807
  __Z10fpuop_savej($0); //@line 48808
  return;
 }
}
function __Z11op_83c_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 14133
 HEAP32[96442] = (HEAP8[$1 + 5 >> 0] | 0) >>> (HEAP8[$1 + 3 >> 0] & 7) & 1 ^ 1; //@line 14144
 HEAP32[162769] = $1 + 6; //@line 14146
 return;
}
function __ZN13driver_window11mouse_movedEii($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 HEAP32[$0 + 24 >> 2] = $1; //@line 43942
 HEAP32[$0 + 28 >> 2] = $2; //@line 43944
 __Z13ADBMouseMovedii($1, $2); //@line 43945
 return;
}
function __Z7ADBInitv() {
 var $2 = 0;
 HEAP32[28468] = __Z15B2_create_mutexv() | 0; //@line 13796
 $2 = (__Z14PrefsFindInt32PKc(93397) | 0) & 255; //@line 13798
 HEAP8[93410] = $2; //@line 13799
 HEAP8[93411] = $2; //@line 13800
 return;
}
function __ZL10ram24_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $5 = 0;
 $5 = (HEAP32[96438] | 0) + ($0 & 16777215) | 0; //@line 49690
 HEAP8[$5 >> 0] = $1 >>> 8; //@line 49693
 HEAP8[$5 + 1 >> 0] = $1; //@line 49696
 return;
}
function __Z18ADBSetRelMouseModeb($0) {
 $0 = $0 | 0;
 if ((HEAPU8[657321] | 0 | 0) == ($0 & 1 | 0)) {
  return;
 }
 HEAP8[657321] = $0 & 1; //@line 14143
 HEAP32[28470] = 0; //@line 14144
 HEAP32[28469] = 0; //@line 14145
 return;
}
function __Z12op_51c0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 6358
 HEAP32[$2 >> 2] = HEAP32[$2 >> 2] & -256; //@line 6361
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6364
 return;
}
function dynCall_viiiii(index, a1, a2, a3, a4, a5) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 a5 = a5 | 0;
 FUNCTION_TABLE_viiiii[index & 3](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0); //@line 4669
}
function __Z12op_50c0_0_ffj($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = 651008 + (($0 & 7) << 2) | 0; //@line 4763
 HEAP32[$2 >> 2] = HEAP32[$2 >> 2] | 255; //@line 4766
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 4769
 return;
}
function __ZL19frame_host_565_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $8 = 0;
 $8 = $1 << 1 & -4128832 | $1 & 2031647; //@line 50081
 HEAP32[(HEAP32[96440] | 0) + $0 >> 2] = $8 >>> 16 | $8 << 16; //@line 50085
 return;
}
function __Z12op_6000_0_ffj($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = HEAP32[162769] | 0; //@line 12272
 HEAP32[162769] = $1 + ((((HEAPU8[$1 + 2 >> 0] | 0) << 8 | (HEAPU8[$1 + 3 >> 0] | 0)) << 16 >> 16) + 2); //@line 12285
 return;
}
function __ZL17frame_direct_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0;
 $4 = (HEAP32[96440] | 0) + $0 | 0; //@line 49958
 HEAP8[$4 >> 0] = $1 >>> 8; //@line 49961
 HEAP8[$4 + 1 >> 0] = $1; //@line 49964
 return;
}
function __Z12op_3048_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = HEAP32[651040 + (($0 & 7) << 2) >> 2] << 16 >> 16; //@line 35381
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35384
 return;
}
function __Z12op_3040_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = HEAP32[651008 + (($0 & 7) << 2) >> 2] << 16 >> 16; //@line 35363
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 35366
 return;
}
function __GLOBAL__sub_I_ether_cpp() {
 HEAP32[28479] = 0; //@line 15044
 HEAP32[28480] = 0; //@line 15045
 HEAP32[28478] = 113916; //@line 15046
 ___cxa_atexit(2213, 113912, ___dso_handle | 0) | 0; //@line 15047
 return;
}
function __Z8CheckROMv() {
 var $3 = 0;
 $3 = _ntohs(HEAP16[(HEAP32[30897] | 0) + 8 >> 1] | 0) | 0; //@line 2794
 HEAP16[325960] = $3; //@line 2795
 return $3 << 16 >> 16 == 630 | $3 << 16 >> 16 == 1660 | 0; //@line 2799
}
function __GLOBAL__sub_I_video_sdl_cpp() {
 HEAP32[30863] = 0; //@line 45232
 HEAP32[30864] = 0; //@line 45233
 HEAP32[30865] = 0; //@line 45234
 ___cxa_atexit(2220, 123452, ___dso_handle | 0) | 0; //@line 45235
 return;
}
function __ZL8ram_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $4 = 0;
 $4 = (HEAP32[96438] | 0) + $0 | 0; //@line 49570
 HEAP8[$4 >> 0] = $1 >>> 8; //@line 49573
 HEAP8[$4 + 1 >> 0] = $1; //@line 49576
 return;
}
function __GLOBAL__sub_I_video_cpp() {
 HEAP32[30548] = 0; //@line 23154
 HEAP32[30549] = 0; //@line 23155
 HEAP32[30550] = 0; //@line 23156
 ___cxa_atexit(2217, 122192, ___dso_handle | 0) | 0; //@line 23157
 return;
}
function __GLOBAL__sub_I_cdrom_cpp() {
 HEAP32[28493] = 0; //@line 19653
 HEAP32[28494] = 0; //@line 19654
 HEAP32[28495] = 0; //@line 19655
 ___cxa_atexit(2216, 113972, ___dso_handle | 0) | 0; //@line 19656
 return;
}
function __Z13SysIsReadOnlyPv($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if (!$0) {
  $$0 = 1; //@line 2339
  return $$0 | 0; //@line 2340
 }
 $$0 = (HEAP8[$0 + 11 >> 0] | 0) != 0; //@line 2345
 return $$0 | 0; //@line 2346
}
function __GLOBAL__sub_I_sony_cpp() {
 HEAP32[28485] = 0; //@line 17033
 HEAP32[28486] = 0; //@line 17034
 HEAP32[28487] = 0; //@line 17035
 ___cxa_atexit(2214, 113940, ___dso_handle | 0) | 0; //@line 17036
 return;
}
function __GLOBAL__sub_I_disk_cpp() {
 HEAP32[28489] = 0; //@line 18182
 HEAP32[28490] = 0; //@line 18183
 HEAP32[28491] = 0; //@line 18184
 ___cxa_atexit(2215, 113956, ___dso_handle | 0) | 0; //@line 18185
 return;
}
function __Z12op_41d0_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = HEAP32[651040 + (($0 & 7) << 2) >> 2]; //@line 42540
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 42543
 return;
}
function __Z12op_2048_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = HEAP32[651040 + (($0 & 7) << 2) >> 2]; //@line 28290
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28293
 return;
}
function __Z12op_2040_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[651040 + (($0 >>> 9 & 7) << 2) >> 2] = HEAP32[651008 + (($0 & 7) << 2) >> 2]; //@line 28274
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 28277
 return;
}
function dynCall_iiiii(index, a1, a2, a3, a4) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 return FUNCTION_TABLE_iiiii[index & 7](a1 | 0, a2 | 0, a3 | 0, a4 | 0) | 0; //@line 4711
}
function __Z10TimerResetv() {
 var $$04 = 0;
 $$04 = 0; //@line 13041
 do {
  HEAP8[112848 + ($$04 << 4) + 12 >> 0] = 0; //@line 13044
  $$04 = $$04 + 1 | 0; //@line 13045
 } while (($$04 | 0) != 64);
 return;
}
function __Z9TimerInitv() {
 var $$04 = 0;
 $$04 = 0; //@line 13019
 do {
  HEAP8[112848 + ($$04 << 4) + 12 >> 0] = 0; //@line 13022
  $$04 = $$04 + 1 | 0; //@line 13023
 } while (($$04 | 0) != 64);
 return;
}
function __Z12op_f43f_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49344
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49349
  return;
 }
}
function __Z12op_f43e_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49328
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49333
  return;
 }
}
function __Z12op_f43d_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49312
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49317
  return;
 }
}
function __Z12op_f43c_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49296
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49301
  return;
 }
}
function __Z12op_f43b_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49280
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49285
  return;
 }
}
function __Z12op_f43a_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49264
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49269
  return;
 }
}
function __Z12op_f439_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49248
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49253
  return;
 }
}
function __Z12op_f438_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49232
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49237
  return;
 }
}
function __Z12op_f430_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49216
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49221
  return;
 }
}
function __Z12op_f428_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49200
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49205
  return;
 }
}
function __Z12op_f41f_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49184
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49189
  return;
 }
}
function __Z12op_f41e_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49168
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49173
  return;
 }
}
function __Z12op_f41d_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49152
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49157
  return;
 }
}
function __Z12op_f41c_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49136
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49141
  return;
 }
}
function __Z12op_f41b_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49120
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49125
  return;
 }
}
function __Z12op_f41a_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49104
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49109
  return;
 }
}
function __Z12op_f419_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49088
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49093
  return;
 }
}
function __Z12op_f418_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49072
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49077
  return;
 }
}
function __Z12op_f410_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49056
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49061
  return;
 }
}
function __Z12op_f408_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 49040
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49045
  return;
 }
}
function _i64Add(a, b, c, d) {
 a = a | 0;
 b = b | 0;
 c = c | 0;
 d = d | 0;
 var l = 0;
 l = a + c >>> 0; //@line 4149
 return (tempRet0 = b + d + (l >>> 0 < a >>> 0 | 0) >>> 0, l | 0) | 0; //@line 4151
}
function __Z9SCSIWritej($0) {
 $0 = $0 | 0;
 var $$0 = 0;
 if ((HEAP32[28496] | 0) == 3) {
  $$0 = __ZL8exec_tibj($0) | 0; //@line 23090
 } else {
  $$0 = 5; //@line 23092
 }
 return $$0 | 0; //@line 23094
}
function __ZL10rom24_wgetj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = (HEAP32[96439] | 0) + ($0 & 16777215) | 0; //@line 49841
 return (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$4 + 1 >> 0] | 0) | 0; //@line 49849
}
function __ZL10ram24_wgetj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = (HEAP32[96438] | 0) + ($0 & 16777215) | 0; //@line 49635
 return (HEAPU8[$4 >> 0] | 0) << 8 | (HEAPU8[$4 + 1 >> 0] | 0) | 0; //@line 49643
}
function __ZNSt3__211char_traitsIcE4moveEPcPKcj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 if ($2 | 0) {
  _memmove($0 | 0, $1 | 0, $2 | 0) | 0; //@line 3271
 }
 return $0 | 0; //@line 3273
}
function __Z17SavePrefsToStreamP8_IO_FILE($0) {
 $0 = $0 | 0;
 __ZL11write_prefsP8_IO_FILEPK10prefs_desc($0, 360); //@line 1732
 __ZL11write_prefsP8_IO_FILEPK10prefs_desc($0, 5260); //@line 1733
 return;
}
function __Z12op_4e70_0_ffj($0) {
 $0 = $0 | 0;
 if (!(HEAP8[651120] | 0)) {
  __Z9Exceptionij(8, 0); //@line 294
  return;
 } else {
  HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 299
  return;
 }
}
function dynCall_viiii(index, a1, a2, a3, a4) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 FUNCTION_TABLE_viiii[index & 3](a1 | 0, a2 | 0, a3 | 0, a4 | 0); //@line 4732
}
function __ZNSt3__211char_traitsIcE4copyEPcPKcj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 if ($2 | 0) {
  _memcpy($0 | 0, $1 | 0, $2 | 0) | 0; //@line 3100
 }
 return $0 | 0; //@line 3102
}
function __ZNK8tinyxml214XMLDeclaration6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 24 >> 2] & 31]($1, $0) | 0; //@line 40030
}
function stackAlloc(size) {
 size = size | 0;
 var ret = 0;
 ret = STACKTOP; //@line 4
 STACKTOP = STACKTOP + size | 0; //@line 5
 STACKTOP = STACKTOP + 15 & -16; //@line 6
 return ret | 0; //@line 8
}
function _strchr($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $2 = 0;
 $2 = ___strchrnul($0, $1) | 0; //@line 61900
 return ((HEAP8[$2 >> 0] | 0) == ($1 & 255) << 24 >> 24 ? $2 : 0) | 0; //@line 61905
}
function __ZNK8tinyxml210XMLUnknown6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 36 >> 2] & 31]($1, $0) | 0; //@line 39287
}
function __ZNK8tinyxml210XMLComment6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 32 >> 2] & 31]($1, $0) | 0; //@line 39807
}
function __ZL17frame_direct_wgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96440] | 0) + $0 | 0; //@line 49906
 return (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$3 + 1 >> 0] | 0) | 0; //@line 49914
}
function _wctomb($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $$0 = 0;
 if (!$0) {
  $$0 = 0; //@line 57827
 } else {
  $$0 = _wcrtomb($0, $1, 0) | 0; //@line 57830
 }
 return $$0 | 0; //@line 57832
}
function __Z7ADBExitv() {
 var $0 = 0;
 $0 = HEAP32[28468] | 0; //@line 13806
 if (!$0) {
  return;
 }
 __Z15B2_delete_mutexP8B2_mutex($0); //@line 13811
 HEAP32[28468] = 0; //@line 13812
 return;
}
function __ZNK8tinyxml27XMLText6AcceptEPNS_10XMLVisitorE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return FUNCTION_TABLE_iii[HEAP32[(HEAP32[$1 >> 2] | 0) + 28 >> 2] & 31]($1, $0) | 0; //@line 39509
}
function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0) {
 $0 = $0 | 0;
 if ((HEAP8[$0 + 11 >> 0] | 0) < 0) {
  __ZdlPv(HEAP32[$0 >> 2] | 0); //@line 3179
 }
 return;
}
function __Z13scsi_send_cmdjbiPPhPjPtj($0, $1, $2, $3, $4, $5, $6) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 $6 = $6 | 0;
 return 0; //@line 47249
}
function __Z9SCSIResetv() {
 HEAP32[28496] = 0; //@line 22788
 HEAP16[325962] = 0; //@line 22789
 HEAP32[28497] = 0; //@line 22790
 HEAP32[28498] = 8; //@line 22791
 return 0; //@line 22792
}
function __ZN8tinyxml28MemPoolTILi52EE10SetTrackedEv($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = $0 + 72 | 0; //@line 40550
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + -1; //@line 40553
 return;
}
function __ZN8tinyxml28MemPoolTILi48EE10SetTrackedEv($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = $0 + 72 | 0; //@line 40812
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + -1; //@line 40815
 return;
}
function __ZN8tinyxml28MemPoolTILi44EE10SetTrackedEv($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = $0 + 72 | 0; //@line 40943
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + -1; //@line 40946
 return;
}
function __ZN8tinyxml28MemPoolTILi36EE10SetTrackedEv($0) {
 $0 = $0 | 0;
 var $1 = 0;
 $1 = $0 + 72 | 0; //@line 40681
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + -1; //@line 40684
 return;
}
function __ZL8rom_wgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96439] | 0) + $0 | 0; //@line 49755
 return (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$3 + 1 >> 0] | 0) | 0; //@line 49763
}
function __ZL8ram_wgetj($0) {
 $0 = $0 | 0;
 var $3 = 0;
 $3 = (HEAP32[96438] | 0) + $0 | 0; //@line 49518
 return (HEAPU8[$3 >> 0] | 0) << 8 | (HEAPU8[$3 + 1 >> 0] | 0) | 0; //@line 49526
}
function __Z14SysCDGetVolumePvRhS0_($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 if ($0 | 0) {
  HEAP8[$2 >> 0] = 0; //@line 2477
  HEAP8[$1 >> 0] = 0; //@line 2478
 }
 return;
}
function __Z12op_6d01_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96443] | 0) != (HEAP32[96444] | 0) ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 13260
 return;
}
function __Z12op_6c01_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96443] | 0) == (HEAP32[96444] | 0) ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 13187
 return;
}
function dynCall_iiii(index, a1, a2, a3) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 return FUNCTION_TABLE_iiii[index & 15](a1 | 0, a2 | 0, a3 | 0) | 0; //@line 4662
}
function __ZL19frame_host_565_wgetj($0) {
 $0 = $0 | 0;
 var $5 = 0;
 $5 = HEAPU16[(HEAP32[96440] | 0) + $0 >> 1] | 0; //@line 50063
 return $5 >>> 1 & 32736 | $5 & 31 | 0; //@line 50068
}
function __Z12op_6201_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96442] | HEAP32[96441] | 0) == 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 12477
 return;
}
function _fputs($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $2 = 0;
 $2 = _strlen($0) | 0; //@line 62719
 return ((_fwrite($0, 1, $2, $1) | 0) != ($2 | 0)) << 31 >> 31 | 0; //@line 62723
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 return ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0; //@line 4625
}
function __Z12ADBMouseDowni($0) {
 $0 = $0 | 0;
 HEAP8[657322 + $0 >> 0] = 1; //@line 14116
 __Z16SetInterruptFlagj(64); //@line 14117
 __Z16TriggerInterruptv(); //@line 14118
 return;
}
function __Z9SysCDPlayPvhhhhhh($0, $1, $2, $3, $4, $5, $6) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 $5 = $5 | 0;
 $6 = $6 | 0;
 return 0; //@line 2428
}
function __Z10ADBMouseUpi($0) {
 $0 = $0 | 0;
 HEAP8[657322 + $0 >> 0] = 0; //@line 14126
 __Z16SetInterruptFlagj(64); //@line 14127
 __Z16TriggerInterruptv(); //@line 14128
 return;
}
function _strtoll($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $3 = 0;
 $3 = _strtox_742($0, $1, $2, 0, -2147483648) | 0; //@line 55686
 return $3 | 0; //@line 55689
}
function _strtol($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 var $3 = 0;
 $3 = _strtox_742($0, $1, $2, -2147483648, 0) | 0; //@line 55697
 return $3 | 0; //@line 55699
}
function _mbsinit($0) {
 $0 = $0 | 0;
 var $5 = 0;
 if (!$0) {
  $5 = 1; //@line 1647
 } else {
  $5 = (HEAP32[$0 >> 2] | 0) == 0; //@line 1651
 }
 return $5 & 1 | 0; //@line 1654
}
function __ZL19frame_host_555_lgetj($0) {
 $0 = $0 | 0;
 var $4 = 0;
 $4 = HEAP32[(HEAP32[96440] | 0) + $0 >> 2] | 0; //@line 49995
 return $4 >>> 16 | $4 << 16 | 0; //@line 49999
}
function __Z12op_6301_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + (HEAP32[96442] | HEAP32[96441] | 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 12553
 return;
}
function __Z12op_f500_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 49361
 __Z6mmu_opjt($0, ($0 >>> 3 & 255) << 24 >> 24); //@line 49363
 return;
}
function dynCall_viii(index, a1, a2, a3) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 FUNCTION_TABLE_viii[index & 7](a1 | 0, a2 | 0, a3 | 0); //@line 4697
}
function establishStackSpace(stackBase, stackMax) {
 stackBase = stackBase | 0;
 stackMax = stackMax | 0;
 STACKTOP = stackBase; //@line 20
 STACK_MAX = stackMax; //@line 21
}
function __Z12op_6b01_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96443] | 0) == 0 ? 2 : ($0 << 24 >> 24) + 2 | 0); //@line 13115
 return;
}
function __Z12op_6a01_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96443] | 0) == 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 13045
 return;
}
function __Z12op_6901_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96444] | 0) == 0 ? 2 : ($0 << 24 >> 24) + 2 | 0); //@line 12975
 return;
}
function __Z12op_6801_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96444] | 0) == 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 12905
 return;
}
function __Z12op_6701_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96442] | 0) == 0 ? 2 : ($0 << 24 >> 24) + 2 | 0); //@line 12835
 return;
}
function __Z12op_6601_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96442] | 0) == 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 12765
 return;
}
function __Z12op_6501_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96441] | 0) == 0 ? 2 : ($0 << 24 >> 24) + 2 | 0); //@line 12695
 return;
}
function __Z12op_6401_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + ((HEAP32[96441] | 0) == 0 ? ($0 << 24 >> 24) + 2 | 0 : 2); //@line 12625
 return;
}
function _swapc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 var $3 = 0;
 $3 = _llvm_bswap_i32($0 | 0) | 0; //@line 59156
 return (($1 | 0) == 0 ? $0 : $3) | 0; //@line 59158
}
function __ZN10__cxxabiv120__si_class_type_infoD0Ev($0) {
 $0 = $0 | 0;
 __ZN10__cxxabiv116__shim_type_infoD2Ev($0); //@line 3964
 __ZdlPv($0); //@line 3965
 return;
}
function __ZL19frame_host_565_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP16[(HEAP32[96440] | 0) + $0 >> 1] = $1 << 1 & 65472 | $1 & 31; //@line 50101
 return;
}
function _srand($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = 112784; //@line 2364
 HEAP32[$2 >> 2] = $0 + -1; //@line 2366
 HEAP32[$2 + 4 >> 2] = 0; //@line 2369
 return;
}
function __ZN10__cxxabiv117__class_type_infoD0Ev($0) {
 $0 = $0 | 0;
 __ZN10__cxxabiv116__shim_type_infoD2Ev($0); //@line 3570
 __ZdlPv($0); //@line 3571
 return;
}
function __Z12op_50fc_0_ffj($0) {
 $0 = $0 | 0;
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 4997
 return;
}
function __Z12op_50fb_0_ffj($0) {
 $0 = $0 | 0;
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 4985
 return;
}
function __Z12op_50fa_0_ffj($0) {
 $0 = $0 | 0;
 __Z9Exceptionij(7, (HEAP32[162769] | 0) + (HEAP32[162768] | 0) - (HEAP32[162770] | 0) | 0); //@line 4973
 return;
}
function __Z16vm_acquire_fixedPvji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 HEAP32[(___errno_location() | 0) >> 2] = 0; //@line 26550
 return -1;
}
function setThrew(threw, value) {
 threw = threw | 0;
 value = value | 0;
 if (!__THREW__) {
  __THREW__ = threw; //@line 28
  threwValue = value; //@line 29
 }
}
function _closedir($0) {
 $0 = $0 | 0;
 var $2 = 0;
 $2 = _close(HEAP32[$0 >> 2] | 0) | 0; //@line 59322
 _free($0); //@line 59323
 return $2 | 0; //@line 59324
}
function __ZL19frame_host_555_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP32[(HEAP32[96440] | 0) + $0 >> 2] = $1 >>> 16 | $1 << 16; //@line 50023
 return;
}
function __Z12op_4e40_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 183
 __Z9Exceptionij($0 & 15 | 32, 0); //@line 185
 return;
}
function dynCall_iii(index, a1, a2) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 return FUNCTION_TABLE_iii[index & 31](a1 | 0, a2 | 0) | 0; //@line 4725
}
function _out($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 if (!(HEAP32[$0 >> 2] & 32)) {
  ___fwritex($1, $2, $0) | 0; //@line 57189
 }
 return;
}
function __ZSt15get_new_handlerv() {
 var $0 = 0;
 $0 = HEAP32[162979] | 0; //@line 4127
 HEAP32[162979] = $0 + 0; //@line 4127
 return $0 | 0; //@line 4129
}
function __ZN10__cxxabiv18is_equalEPKSt9type_infoS2_b($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return ($0 | 0) == ($1 | 0) | 0; //@line 3738
}
function __ZL19frame_host_888_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP32[(HEAP32[30899] | 0) + $0 + 1610612736 >> 2] = $1; //@line 50122
 return;
}
function __Z17SysAddFloppyPrefsv() {
 __Z14PrefsAddStringPKcS0_(94198, 90657); //@line 1948
 __Z14PrefsAddStringPKcS0_(94198, 90666); //@line 1949
 return;
}
function __ZN11driver_base11mouse_movedEii($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 __Z13ADBMouseMovedii($1, $2); //@line 43863
 return;
}
function __Z12op_7101_0_ffj($0) {
 $0 = $0 | 0;
 __Z11m68k_emulopj($0); //@line 13538
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13541
 return;
}
function __ZL13Blit_Copy_RawPhPKhj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 _memcpy($0 | 0, $1 | 0, $2 | 0) | 0; //@line 26484
 return;
}
function __Z22ether_start_udp_threadi($0) {
 $0 = $0 | 0;
 HEAP32[1310] = $0; //@line 47151
 HEAP8[659476] = 1; //@line 47152
 return 1; //@line 47153
}
function dynCall_vii(index, a1, a2) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 FUNCTION_TABLE_vii[index & 31](a1 | 0, a2 | 0); //@line 4683
}
function __ZN8tinyxml211XMLDocumentD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml211XMLDocumentD2Ev($0); //@line 40421
 __ZdlPv($0); //@line 40422
 return;
}
function __Z12op_4848_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 50075
 __Z7op_illgj($0); //@line 50076
 return;
}
function _recv($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 return _recvfrom($0, $1, $2, $3, 0, 0) | 0; //@line 2154
}
function __ZNSt3__211char_traitsIcE6assignERcRKc($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP8[$0 >> 0] = HEAP8[$1 >> 0] | 0; //@line 3082
 return;
}
function __Z14VideoInterruptv() {
 _SDL_PumpEvents(); //@line 46087
 _SDL_mutexV(0) | 0; //@line 46088
 _SDL_mutexP(0) | 0; //@line 46089
 return;
}
function __Z11op_6fb_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13759
 __Z7op_illgj($0); //@line 13760
 return;
}
function __Z11op_6fa_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13749
 __Z7op_illgj($0); //@line 13750
 return;
}
function __Z11op_6f9_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13739
 __Z7op_illgj($0); //@line 13740
 return;
}
function __Z11op_6f8_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13729
 __Z7op_illgj($0); //@line 13730
 return;
}
function __Z11op_6f0_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13719
 __Z7op_illgj($0); //@line 13720
 return;
}
function __Z11op_6e8_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13709
 __Z7op_illgj($0); //@line 13710
 return;
}
function __Z11op_6d0_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13699
 __Z7op_illgj($0); //@line 13700
 return;
}
function __Z11op_6c8_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13689
 __Z7op_illgj($0); //@line 13690
 return;
}
function __Z11op_6c0_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 13679
 __Z7op_illgj($0); //@line 13680
 return;
}
function b8(p0, p1, p2, p3, p4, p5) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 p4 = p4 | 0;
 p5 = p5 | 0;
 abort(8); //@line 4763
}
function __ZN8tinyxml214XMLDeclarationD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 40098
 __ZdlPv($0); //@line 40099
 return;
}
function __ZL10ram24_bputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP8[(HEAP32[96438] | 0) + ($0 & 16777215) >> 0] = $1; //@line 49709
 return;
}
function _strncpy($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 ___stpncpy($0, $1, $2) | 0; //@line 2192
 return $0 | 0; //@line 2193
}
function _send($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 return _sendto($0, $1, $2, $3, 0, 0) | 0; //@line 1989
}
function __Z9SysCDScanPvhhhb($0, $1, $2, $3, $4) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 $4 = $4 | 0;
 return 0; //@line 2459
}
function __ZL19frame_host_555_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP16[(HEAP32[96440] | 0) + $0 >> 1] = $1; //@line 50035
 return;
}
function __ZN8tinyxml210XMLUnknownD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 39351
 __ZdlPv($0); //@line 39352
 return;
}
function __ZN8tinyxml210XMLCommentD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 39875
 __ZdlPv($0); //@line 39876
 return;
}
function __ZN17driver_fullscreenD0Ev($0) {
 $0 = $0 | 0;
 __ZN17driver_fullscreenD2Ev($0); //@line 44072
 __ZdlPv($0); //@line 44073
 return;
}
function _llvm_bswap_i32(x) {
 x = x | 0;
 return (x & 255) << 24 | (x >> 8 & 255) << 16 | (x >> 16 & 255) << 8 | x >>> 24 | 0; //@line 4538
}
function __ZL17frame_direct_bputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP8[(HEAP32[96440] | 0) + $0 >> 0] = $1; //@line 49976
 return;
}
function __ZN8tinyxml27XMLTextD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 39655
 __ZdlPv($0); //@line 39656
 return;
}
function __ZN8tinyxml27XMLNodeD0Ev($0) {
 $0 = $0 | 0;
 __ZN8tinyxml27XMLNodeD2Ev($0); //@line 36611
 __ZdlPv($0); //@line 36612
 return;
}
function _vsprintf($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return _vsnprintf($0, 2147483647, $1, $2) | 0; //@line 56160
}
function _strerror($0) {
 $0 = $0 | 0;
 return ___strerror_l($0, HEAP32[(___pthread_self_104() | 0) + 188 >> 2] | 0) | 0; //@line 57648
}
function ___expo2($0) {
 $0 = +$0;
 return +(+Math_exp(+($0 + -1416.0996898839683)) * 2.247116418577895e+307 * 2.247116418577895e+307);
}
function __Z9XPRAMInitPKc($0) {
 $0 = $0 | 0;
 _memset(656025, 0, 256) | 0; //@line 12953
 __Z9LoadXPRAMPKc($0); //@line 12954
 return;
}
function __Z12op_6001_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + (($0 << 24 >> 24) + 2); //@line 12297
 return;
}
function __Z10vm_releasePvj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 if ($0 | 0) {
  _free($0); //@line 26560
 }
 return 0; //@line 26562
}
function __Z10open_rforkPKci($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return __ZL11open_helperPKcS0_i($0, 104080, $1) | 0; //@line 46707
}
function b7(p0, p1, p2, p3) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 abort(7); //@line 4760
 return 0; //@line 4760
}
function __Z18m68k_emulop_returnv() {
 HEAP32[162771] = HEAP32[162771] | 4; //@line 52058
 HEAP8[659737] = 1; //@line 52059
 return;
}
function dynCall_ii(index, a1) {
 index = index | 0;
 a1 = a1 | 0;
 return FUNCTION_TABLE_ii[index & 127](a1 | 0) | 0; //@line 4690
}
function __Z11extfs_writeiPvj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return _write($0, $1, $2) | 0; //@line 46733
}
function __ZL8ram_bputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 HEAP8[(HEAP32[96438] | 0) + $0 >> 0] = $1; //@line 49588
 return;
}
function __Z10extfs_readiPvj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return _read($0, $1, $2) | 0; //@line 46724
}
function __ZNK8tinyxml211XMLDocument12ShallowEqualEPKNS_7XMLNodeE($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 40126
}
function __ZL10rom24_bgetj($0) {
 $0 = $0 | 0;
 return HEAPU8[(HEAP32[96439] | 0) + ($0 & 16777215) >> 0] | 0 | 0; //@line 49861
}
function __ZL10ram24_bgetj($0) {
 $0 = $0 | 0;
 return HEAPU8[(HEAP32[96438] | 0) + ($0 & 16777215) >> 0] | 0 | 0; //@line 49655
}
function b1(p0, p1, p2, p3, p4) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 p4 = p4 | 0;
 abort(1); //@line 4739
}
function _strrchr($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return ___memrchr($0, $1, (_strlen($0) | 0) + 1 | 0) | 0; //@line 1814
}
function _do_read($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return ___string_read($0, $1, $2) | 0; //@line 612
}
function __ZN17disk_sparsebundle12is_read_onlyEv($0) {
 $0 = $0 | 0;
 return (HEAP8[$0 + 8 >> 0] | 0) != 0 | 0; //@line 35779
}
function __ZL19frame_host_555_wgetj($0) {
 $0 = $0 | 0;
 return HEAPU16[(HEAP32[96440] | 0) + $0 >> 1] | 0 | 0; //@line 50010
}
function __Z9SysCDStopPvhhh($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 return 0; //@line 2449
}
function _strcpy($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 ___stpcpy($0, $1) | 0; //@line 62173
 return $0 | 0; //@line 62174
}
function __ZN9DSERDPort7controlEjjt($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 return -17;
}
function __ZL17frame_direct_bgetj($0) {
 $0 = $0 | 0;
 return HEAPU8[(HEAP32[96440] | 0) + $0 >> 0] | 0 | 0; //@line 49925
}
function dynCall_vi(index, a1) {
 index = index | 0;
 a1 = a1 | 0;
 FUNCTION_TABLE_vi[index & 4095](a1 | 0); //@line 4676
}
function __ZN9DSERDPort6statusEjjt($0, $1, $2, $3) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 $3 = $3 | 0;
 return -18;
}
function __ZL19frame_host_888_lgetj($0) {
 $0 = $0 | 0;
 return HEAP32[(HEAP32[96440] | 0) + $0 >> 2] | 0; //@line 50112
}
function _fseek($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return ___fseeko($0, $1, $2) | 0; //@line 1690
}
function __ZNK8tinyxml211XMLDocument12ShallowCloneEPS0_($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 40119
}
function __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv($0) {
 $0 = $0 | 0;
 _abort(); //@line 3167
}
function __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv($0) {
 $0 = $0 | 0;
 _abort(); //@line 3108
}
function b0(p0, p1, p2) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 abort(0); //@line 4736
 return 0; //@line 4736
}
function __Z19VideoQuitFullScreenv() {
 _puts(103129) | 0; //@line 46080
 HEAP8[659473] = 1; //@line 46081
 return;
}
function __Z18timer_current_timeR7timeval($0) {
 $0 = $0 | 0;
 _gettimeofday($0 | 0, 0) | 0; //@line 13547
 return;
}
function __Z15B2_delete_mutexP8B2_mutex($0) {
 $0 = $0 | 0;
 if ($0 | 0) {
  __ZdlPv($0); //@line 48657
 }
 return;
}
function __Z18ClearInterruptFlagj($0) {
 $0 = $0 | 0;
 HEAP32[30882] = HEAP32[30882] & ~$0; //@line 48677
 return;
}
function __Z12op_51fc_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 6607
 return;
}
function __Z12op_51fb_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 6; //@line 6598
 return;
}
function __Z12op_51fa_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 6589
 return;
}
function __Z12op_50c8_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 4; //@line 4778
 return;
}
function __ZL8rom_bgetj($0) {
 $0 = $0 | 0;
 return HEAPU8[(HEAP32[96439] | 0) + $0 >> 0] | 0 | 0; //@line 49774
}
function __ZL8ram_bgetj($0) {
 $0 = $0 | 0;
 return HEAPU8[(HEAP32[96438] | 0) + $0 >> 0] | 0 | 0; //@line 49537
}
function __ZL11rom24_xlatej($0) {
 $0 = $0 | 0;
 return (HEAP32[96439] | 0) + ($0 & 16777215) | 0; //@line 49871
}
function __ZL11ram24_xlatej($0) {
 $0 = $0 | 0;
 return (HEAP32[96438] | 0) + ($0 & 16777215) | 0; //@line 49720
}
function __Z12op_4e71_0_ffj($0) {
 $0 = $0 | 0;
 HEAP32[162769] = (HEAP32[162769] | 0) + 2; //@line 309
 return;
}
function b10(p0, p1, p2, p3) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 abort(10); //@line 4769
}
function _isspace($0) {
 $0 = $0 | 0;
 return (($0 | 0) == 32 | ($0 + -9 | 0) >>> 0 < 5) & 1 | 0; //@line 55604
}
function __Z16SetInterruptFlagj($0) {
 $0 = $0 | 0;
 HEAP32[30882] = HEAP32[30882] | $0; //@line 48667
 return;
}
function __Z10ErrorAlerti($0) {
 $0 = $0 | 0;
 __Z10ErrorAlertPKc(__Z9GetStringi($0) | 0); //@line 217
 return;
}
function __Z10Start680x0v() {
 __Z10m68k_resetv(); //@line 49149
 __Z12m68k_executev(); //@line 49150
 return;
}
function ___lctrans($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return ___lctrans_impl($0, $1) | 0; //@line 59011
}
function __ZN17disk_sparsebundle4sizeEv($0) {
 $0 = $0 | 0;
 return HEAP32[$0 + 16 >> 2] | 0; //@line 35897
}
function __Z13default_xlatej($0) {
 $0 = $0 | 0;
 _puts(105406) | 0; //@line 49482
 return 0; //@line 49483
}
function __Z11close_rforkPKci($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 _close($1) | 0; //@line 46714
 return;
}
function __ZNK8tinyxml214XMLDeclaration13ToDeclarationEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39889
}
function __ZN9DSERDPort9prime_outEjj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return -20;
}
function __ZN8tinyxml214XMLDeclaration13ToDeclarationEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39883
}
function __ZnwjRKSt9nothrow_t($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return __Znwj($0) | 0; //@line 3140
}
function __ZNSt3__211char_traitsIcE6lengthEPKc($0) {
 $0 = $0 | 0;
 return _strlen($0) | 0; //@line 3090
}
function __ZN9DSERDPort8prime_inEjj($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return -19;
}
function __ZNK8tinyxml211XMLDocument10ToDocumentEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 40112
}
function __ZN8tinyxml211XMLDocument10ToDocumentEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 40106
}
function __ZL11frame_xlatej($0) {
 $0 = $0 | 0;
 return (HEAP32[96440] | 0) + $0 | 0; //@line 49986
}
function __Z12op_7100_0_ffj($0) {
 $0 = $0 | 0;
 __Z18m68k_emulop_returnv(); //@line 13531
 return;
}
function b9(p0, p1) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 abort(9); //@line 4766
 return 0; //@line 4766
}
function _llvm_bswap_i16(x) {
 x = x | 0;
 return (x & 255) << 8 | x >> 8 & 255 | 0; //@line 4655
}
function _isalpha($0) {
 $0 = $0 | 0;
 return (($0 | 32) + -97 | 0) >>> 0 < 26 | 0; //@line 59315
}
function __ZNK8tinyxml210XMLUnknown9ToUnknownEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39149
}
function __ZNK8tinyxml210XMLElement9ToElementEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 37853
}
function __ZNK8tinyxml210XMLComment9ToCommentEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39669
}
function __Z14SysCDSetVolumePvhh($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return;
}
function __ZNK8tinyxml28MemPoolTILi52EE8ItemSizeEv($0) {
 $0 = $0 | 0;
 return 52; //@line 40525
}
function __ZNK8tinyxml28MemPoolTILi48EE8ItemSizeEv($0) {
 $0 = $0 | 0;
 return 48; //@line 40787
}
function __ZNK8tinyxml28MemPoolTILi44EE8ItemSizeEv($0) {
 $0 = $0 | 0;
 return 44; //@line 40918
}
function __ZNK8tinyxml28MemPoolTILi36EE8ItemSizeEv($0) {
 $0 = $0 | 0;
 return 36; //@line 40656
}
function __ZN8tinyxml210XMLUnknown9ToUnknownEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39143
}
function __ZN8tinyxml210XMLElement9ToElementEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 37847
}
function __ZN8tinyxml210XMLComment9ToCommentEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39663
}
function __ZL9rom_xlatej($0) {
 $0 = $0 | 0;
 return (HEAP32[96439] | 0) + $0 | 0; //@line 49804
}
function __ZL9ram_xlatej($0) {
 $0 = $0 | 0;
 return (HEAP32[96438] | 0) + $0 | 0; //@line 49598
}
function __Z16TriggerInterruptv() {
 HEAP32[162771] = HEAP32[162771] | 2; //@line 49158
 return;
}
function __Z16SysCDGetPositionPvPh($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 2416
}
function ___bswap_32_489($0) {
 $0 = $0 | 0;
 return _llvm_bswap_i32($0 | 0) | 0; //@line 2343
}
function ___bswap_16_490($0) {
 $0 = $0 | 0;
 return _llvm_bswap_i16($0 | 0) | 0; //@line 2357
}
function __Z15scsi_set_targetii($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 47237
}
function __Z15ether_attach_phtj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 47119
}
function _putchar($0) {
 $0 = $0 | 0;
 return _fputc($0, HEAP32[22131] | 0) | 0; //@line 2734
}
function __ZNK8tinyxml27XMLNode13ToDeclarationEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36172
}
function __Z17SysIsDiskInsertedPv($0) {
 $0 = $0 | 0;
 return ($0 | 0) != 0 | 0; //@line 2390
}
function __Z13TimerDateTimev() {
 return __Z13TimeToMacTimel(_time(0) | 0) | 0; //@line 13541
}
function dynCall_v(index) {
 index = index | 0;
 FUNCTION_TABLE_v[index & 3](); //@line 4704
}
function __ZN8tinyxml27XMLNode13ToDeclarationEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36136
}
function __Z25macroman_to_host_encodingPKc($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 46974
}
function __Z25host_encoding_to_macromanPKc($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 46968
}
function __Z12SysCDReadTOCPvPh($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 2409
}
function b5(p0, p1, p2) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 abort(5); //@line 4751
}
function __Z8GetScrapPPvji($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return;
}
function __Z12SoundInClosejj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 28544
}
function ___errno_location() {
 return (___pthread_self_103() | 0) + 64 | 0; //@line 54738
}
function ___bswap_32($0) {
 $0 = $0 | 0;
 return _llvm_bswap_i32($0 | 0) | 0; //@line 2137
}
function ___bswap_16($0) {
 $0 = $0 | 0;
 return _llvm_bswap_i16($0 | 0) | 0; //@line 2144
}
function __ZNK8tinyxml27XMLText6ToTextEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39365
}
function __ZNK8tinyxml27XMLNode10ToDocumentEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36166
}
function __Z8PutScrapjPvi($0, $1, $2) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 $2 = $2 | 0;
 return;
}
function __Z11SoundInOpenjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return 0; //@line 28466
}
function __ZN8tinyxml27XMLText6ToTextEv($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 39359
}
function __ZN8tinyxml27XMLNode10ToDocumentEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36130
}
function __ZNK8tinyxml27XMLNode9ToUnknownEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36178
}
function __ZNK8tinyxml27XMLNode9ToElementEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36148
}
function __ZNK8tinyxml27XMLNode9ToCommentEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36160
}
function __ZN8tinyxml27XMLNode9ToUnknownEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36142
}
function __ZN8tinyxml27XMLNode9ToElementEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36112
}
function __ZN8tinyxml27XMLNode9ToCommentEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36124
}
function __Z22InitFrameBufferMappingv() {
 __Z11memory_initv(); //@line 49143
 return;
}
function __ZNK8tinyxml27XMLNode6ToTextEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36154
}
function __ZN9DSERDPortD0Ev($0) {
 $0 = $0 | 0;
 __ZdlPv($0); //@line 46986
 return;
}
function __ZN8tinyxml27XMLNode6ToTextEv($0) {
 $0 = $0 | 0;
 return 0; //@line 36118
}
function __Z9SysFormatPv($0) {
 $0 = $0 | 0;
 return ($0 | 0) != 0 | 0; //@line 2331
}
function __Z21ether_stop_udp_threadv() {
 HEAP8[659476] = 0; //@line 47158
 return;
}
function _copysignl($0, $1) {
 $0 = +$0;
 $1 = +$1;
 return +(+_copysign($0, $1));
}
function ___ofl_lock() {
 ___lock(651904); //@line 225
 return 651912; //@line 226
}
function __Z22scsi_is_target_presenti($0) {
 $0 = $0 | 0;
 return 0; //@line 47230
}
function __Z11SCSIMgrBusyv() {
 return (HEAP32[28496] | 0) != 0 | 0; //@line 23149
}
function _scalbnl($0, $1) {
 $0 = +$0;
 $1 = $1 | 0;
 return +(+_scalbn($0, $1));
}
function _ntohs($0) {
 $0 = $0 | 0;
 return ___bswap_16_490($0) | 0; //@line 2350
}
function _ntohl($0) {
 $0 = $0 | 0;
 return ___bswap_32_489($0) | 0; //@line 2336
}
function __ZNK10__cxxabiv116__shim_type_info5noop2Ev($0) {
 $0 = $0 | 0;
 return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop1Ev($0) {
 $0 = $0 | 0;
 return;
}
function __ZN9DSERDPort4openEt($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return -23;
}
function __Z17PatchAfterStartupv() {
 __Z12InstallExtFSv(); //@line 2785
 return;
}
function setTempRet0(value) {
 value = value | 0;
 tempRet0 = value; //@line 35
}
function b4(p0) {
 p0 = p0 | 0;
 abort(4); //@line 4748
 return 0; //@line 4748
}
function _frexpl($0, $1) {
 $0 = +$0;
 $1 = $1 | 0;
 return +(+_frexp($0, $1));
}
function __Z19ether_del_multicastj($0) {
 $0 = $0 | 0;
 return 0; //@line 47112
}
function __Z19ether_add_multicastj($0) {
 $0 = $0 | 0;
 return 0; //@line 47106
}
function __Z12SoundInPrimejj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return -50;
}
function ___cxa_pure_virtual__wrapper() {
 ___cxa_pure_virtual(); //@line 4757
}
function __Z14FlushCodeCachePvj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function _htons($0) {
 $0 = $0 | 0;
 return ___bswap_16($0) | 0; //@line 2029
}
function _htonl($0) {
 $0 = $0 | 0;
 return ___bswap_32($0) | 0; //@line 2036
}
function __ZN9DSERDPort5closeEv($0) {
 $0 = $0 | 0;
 return 0; //@line 47034
}
function __ZN11driver_base17toggle_mouse_grabEv($0) {
 $0 = $0 | 0;
 return;
}
function __ZN10__cxxabiv116__shim_type_infoD2Ev($0) {
 $0 = $0 | 0;
 return;
}
function __Z6intlevv() {
 return (HEAP32[30882] | 0) != 0 | 0; //@line 49172
}
function __Z12scsi_set_cmdiPh($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function _ftell($0) {
 $0 = $0 | 0;
 return ___ftello($0) | 0; //@line 2677
}
function ___pthread_self_613() {
 return _pthread_self() | 0; //@line 62796
}
function ___pthread_self_431() {
 return _pthread_self() | 0; //@line 58932
}
function ___pthread_self_422() {
 return _pthread_self() | 0; //@line 62153
}
function ___pthread_self_104() {
 return _pthread_self() | 0; //@line 58938
}
function ___pthread_self_103() {
 return _pthread_self() | 0; //@line 54744
}
function __Z24audio_get_speaker_volumev() {
 return 16777472; //@line 47804
}
function __Z15ether_detach_pht($0) {
 $0 = $0 | 0;
 return 0; //@line 47125
}
function _fmodl($0, $1) {
 $0 = +$0;
 $1 = +$1;
 return +(+_fmod($0, $1));
}
function __ZL10dummy_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __ZL10dummy_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __ZL10dummy_bputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __Z9idle_waitv() {
 __Z10Delay_usecj(1e4); //@line 13784
 return;
}
function b3(p0, p1) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 abort(3); //@line 4745
}
function __ZN11driver_base14update_paletteEv($0) {
 $0 = $0 | 0;
 return;
}
function stackRestore(top) {
 top = top | 0;
 STACKTOP = top; //@line 15
}
function __Znaj($0) {
 $0 = $0 | 0;
 return __Znwj($0) | 0; //@line 3147
}
function __ZdaPv($0) {
 $0 = $0 | 0;
 __ZdlPv($0); //@line 3160
 return;
}
function __Z8SCSIInitv() {
 __Z9SCSIResetv() | 0; //@line 47211
 return;
}
function __Z21audio_get_main_volumev() {
 return 16777472; //@line 47794
}
function __Z10AudioResetv() {
 HEAP32[30824] = 0; //@line 26634
 return;
}
function __ZN11driver_base12ungrab_mouseEv($0) {
 $0 = $0 | 0;
 return;
}
function __ZL8rom_wputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __ZL8rom_lputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __ZL8rom_bputjj($0, $1) {
 $0 = $0 | 0;
 $1 = $1 | 0;
 return;
}
function __ZL10dummy_wgetj($0) {
 $0 = $0 | 0;
 return 0; //@line 49449
}
function __ZL10dummy_lgetj($0) {
 $0 = $0 | 0;
 return 0; //@line 49443
}
function __ZL10dummy_bgetj($0) {
 $0 = $0 | 0;
 return 0; //@line 49455
}
function __Z15B2_create_mutexv() {
 return __Znwj(4) | 0; //@line 48637
}
function __Z11SysCDResumePv($0) {
 $0 = $0 | 0;
 return 0; //@line 2440
}
function _emscripten_get_global_libc() {
 return 651836; //@line 54556
}
function __ZdlPv($0) {
 $0 = $0 | 0;
 _free($0); //@line 3153
 return;
}
function __Z10SysCDPausePv($0) {
 $0 = $0 | 0;
 return 0; //@line 2434
}
function _dummy_570($0) {
 $0 = $0 | 0;
 return $0 | 0; //@line 54755
}
function __ZN11driver_base10grab_mouseEv($0) {
 $0 = $0 | 0;
 return;
}
function __Z9XPRAMExitv() {
 __Z9SaveXPRAMv(); //@line 12960
 return;
}
function __Z9Exit680x0v() {
 __Z9exit_m68kv(); //@line 49137
 return;
}
function __Z8SCSIStatv() {
 return HEAP16[325962] | 0; //@line 23141
}
function __Z24audio_set_speaker_volumej($0) {
 $0 = $0 | 0;
 return;
}
function __Z15B2_unlock_mutexP8B2_mutex($0) {
 $0 = $0 | 0;
 return;
}
function ___ofl_unlock() {
 ___unlock(651904); //@line 231
 return;
}
function __Z22audio_set_speaker_muteb($0) {
 $0 = $0 | 0;
 return;
}
function __Z22audio_get_speaker_mutev() {
 return 0; //@line 47799
}
function __Z13B2_lock_mutexP8B2_mutex($0) {
 $0 = $0 | 0;
 return;
}
function ___lockfile($0) {
 $0 = $0 | 0;
 return 0; //@line 57171
}
function __ZN11driver_base7suspendEv($0) {
 $0 = $0 | 0;
 return;
}
function __Z21audio_set_main_volumej($0) {
 $0 = $0 | 0;
 return;
}
function __ZN11driver_base6resumeEv($0) {
 $0 = $0 | 0;
 return;
}
function __Z19audio_set_main_muteb($0) {
 $0 = $0 | 0;
 return;
}
function __Z19audio_get_main_mutev() {
 return 0; //@line 47789
}
function __Z17SysPreventRemovalPv($0) {
 $0 = $0 | 0;
 return;
}
function __Z15SysAllowRemovalPv($0) {
 $0 = $0 | 0;
 return;
}
function __ZNSt9type_infoD2Ev($0) {
 $0 = $0 | 0;
 return;
}
function getTempRet0() {
 return tempRet0 | 0; //@line 38
}
function stackSave() {
 return STACKTOP | 0; //@line 11
}
function b2(p0) {
 p0 = p0 | 0;
 abort(2); //@line 4742
}
function _pthread_self() {
 return 88280; //@line 54749
}
function __ZN8SERDPortD2Ev($0) {
 $0 = $0 | 0;
 return;
}
function __Z11PrefsEditorv() {
 return 1; //@line 47833
}
function __Z10ether_initv() {
 return 1; //@line 47090
}
function __Z8SysEjectPv($0) {
 $0 = $0 | 0;
 return;
}
function ___unlockfile($0) {
 $0 = $0 | 0;
 return;
}
function __Z7vm_initv() {
 return 0; //@line 26519
}
function __Z18audio_enter_streamv() {
 return;
}
function __Z17audio_exit_streamv() {
 return;
}
function __Z17SysAddSerialPrefsv() {
 return;
}
function __Z16SysAddCDROMPrefsv() {
 return;
}
function __Z15SysAddDiskPrefsv() {
 return;
}
function b6() {
 abort(6); //@line 4754
}
function __Z11idle_resumev() {
 return;
}
function __Z11ether_resetv() {
 return;
}
function __Z10extfs_initv() {
 return;
}
function __Z10extfs_exitv() {
 return;
}
function __Z10ether_exitv() {
 return;
}
function __Z10TriggerNMIv() {
 return;
}
function __Z9exit_m68kv() {
 return;
}
function __Z9TimerExitv() {
 return;
}
function __Z8fpu_exitv() {
 return;
}
function __Z8SCSIExitv() {
 return;
}
function __Z8ClipInitv() {
 return;
}
function __Z8ClipExitv() {
 return;
}
function __Z7vm_exitv() {
 return;
}
function __Z7SysInitv() {
 return;
}
function __Z7SysExitv() {
 return;
}

// EMSCRIPTEN_END_FUNCS
var FUNCTION_TABLE_iiii = [b0,__ZN8tinyxml27XMLNode9ParseDeepEPcPNS_7StrPairE,__ZN8tinyxml214XMLDeclaration9ParseDeepEPcPNS_7StrPairE,__ZN8tinyxml210XMLComment9ParseDeepEPcPNS_7StrPairE,__ZN8tinyxml27XMLText9ParseDeepEPcPNS_7StrPairE,__ZN8tinyxml210XMLUnknown9ParseDeepEPcPNS_7StrPairE,__ZN8tinyxml210XMLElement9ParseDeepEPcPNS_7StrPairE,__ZN9DSERDPort8prime_inEjj,__ZN9DSERDPort9prime_outEjj,___stdio_write,___stdio_seek,___stdout_write,_sn_write,__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv,___stdio_read,_do_read];
var FUNCTION_TABLE_viiiii = [b1,__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,b1];
var FUNCTION_TABLE_vi = [b2,__ZN12monitor_descD2Ev,__ZN12monitor_descD0Ev,__ZN17disk_sparsebundleD2Ev,__ZN17disk_sparsebundleD0Ev,__ZN8tinyxml27XMLNodeD2Ev,__ZN8tinyxml27XMLNodeD0Ev,__ZN8tinyxml214XMLDeclarationD0Ev,__ZN8tinyxml210XMLCommentD0Ev,__ZN8tinyxml27XMLTextD0Ev,__ZN8tinyxml210XMLUnknownD0Ev,__ZN8tinyxml210XMLElementD2Ev,__ZN8tinyxml210XMLElementD0Ev,__ZN8tinyxml212XMLAttributeD2Ev,__ZN8tinyxml212XMLAttributeD0Ev,__ZN8tinyxml211XMLDocumentD2Ev,__ZN8tinyxml211XMLDocumentD0Ev,__ZN8tinyxml28MemPoolTILi44EED2Ev,__ZN8tinyxml28MemPoolTILi44EED0Ev,__ZN8tinyxml28MemPoolTILi44EE10SetTrackedEv,__ZN8tinyxml28MemPoolTILi48EED2Ev,__ZN8tinyxml28MemPoolTILi48EED0Ev,__ZN8tinyxml28MemPoolTILi48EE10SetTrackedEv,__ZN8tinyxml28MemPoolTILi36EED2Ev,__ZN8tinyxml28MemPoolTILi36EED0Ev,__ZN8tinyxml28MemPoolTILi36EE10SetTrackedEv,__ZN8tinyxml28MemPoolTILi52EED2Ev,__ZN8tinyxml28MemPoolTILi52EED0Ev,__ZN8tinyxml28MemPoolTILi52EE10SetTrackedEv
,__ZN11driver_baseD2Ev,__ZN11driver_baseD0Ev,__ZN11driver_base14update_paletteEv,__ZN11driver_base7suspendEv,__ZN11driver_base6resumeEv,__ZN11driver_base17toggle_mouse_grabEv,__ZN11driver_base10grab_mouseEv,__ZN11driver_base12ungrab_mouseEv,__ZN13driver_windowD0Ev,__ZN13driver_window17toggle_mouse_grabEv,__ZN13driver_window10grab_mouseEv,__ZN13driver_window12ungrab_mouseEv,__ZN17driver_fullscreenD2Ev,__ZN17driver_fullscreenD0Ev,__ZN16SDL_monitor_descD0Ev,__ZN16SDL_monitor_desc22switch_to_current_modeEv,__ZN8SERDPortD2Ev,__ZN9DSERDPortD0Ev,__Z9op_0_0_ffj,__Z10op_10_0_ffj,__Z10op_18_0_ffj,__Z10op_20_0_ffj,__Z10op_28_0_ffj,__Z10op_30_0_ffj,__Z10op_38_0_ffj,__Z10op_39_0_ffj,__Z10op_3c_0_ffj,__Z10op_40_0_ffj,__Z10op_50_0_ffj,__Z10op_58_0_ffj
,__Z10op_60_0_ffj,__Z10op_68_0_ffj,__Z10op_70_0_ffj,__Z10op_78_0_ffj,__Z10op_79_0_ffj,__Z10op_7c_0_ffj,__Z10op_80_0_ffj,__Z10op_90_0_ffj,__Z10op_98_0_ffj,__Z10op_a0_0_ffj,__Z10op_a8_0_ffj,__Z10op_b0_0_ffj,__Z10op_b8_0_ffj,__Z10op_b9_0_ffj,__Z10op_d0_0_ffj,__Z10op_e8_0_ffj,__Z10op_f0_0_ffj,__Z10op_f8_0_ffj,__Z10op_f9_0_ffj,__Z10op_fa_0_ffj,__Z10op_fb_0_ffj,__Z11op_100_0_ffj,__Z11op_108_0_ffj,__Z11op_110_0_ffj,__Z11op_118_0_ffj,__Z11op_120_0_ffj,__Z11op_128_0_ffj,__Z11op_130_0_ffj,__Z11op_138_0_ffj,__Z11op_139_0_ffj
,__Z11op_13a_0_ffj,__Z11op_13b_0_ffj,__Z11op_13c_0_ffj,__Z11op_140_0_ffj,__Z11op_148_0_ffj,__Z11op_150_0_ffj,__Z11op_158_0_ffj,__Z11op_160_0_ffj,__Z11op_168_0_ffj,__Z11op_170_0_ffj,__Z11op_178_0_ffj,__Z11op_179_0_ffj,__Z11op_17a_0_ffj,__Z11op_17b_0_ffj,__Z11op_180_0_ffj,__Z11op_188_0_ffj,__Z11op_190_0_ffj,__Z11op_198_0_ffj,__Z11op_1a0_0_ffj,__Z11op_1a8_0_ffj,__Z11op_1b0_0_ffj,__Z11op_1b8_0_ffj,__Z11op_1b9_0_ffj,__Z11op_1ba_0_ffj,__Z11op_1bb_0_ffj,__Z11op_1c0_0_ffj,__Z11op_1c8_0_ffj,__Z11op_1d0_0_ffj,__Z11op_1d8_0_ffj,__Z11op_1e0_0_ffj
,__Z11op_1e8_0_ffj,__Z11op_1f0_0_ffj,__Z11op_1f8_0_ffj,__Z11op_1f9_0_ffj,__Z11op_1fa_0_ffj,__Z11op_1fb_0_ffj,__Z11op_200_0_ffj,__Z11op_210_0_ffj,__Z11op_218_0_ffj,__Z11op_220_0_ffj,__Z11op_228_0_ffj,__Z11op_230_0_ffj,__Z11op_238_0_ffj,__Z11op_239_0_ffj,__Z11op_23c_0_ffj,__Z11op_240_0_ffj,__Z11op_250_0_ffj,__Z11op_258_0_ffj,__Z11op_260_0_ffj,__Z11op_268_0_ffj,__Z11op_270_0_ffj,__Z11op_278_0_ffj,__Z11op_279_0_ffj,__Z11op_27c_0_ffj,__Z11op_280_0_ffj,__Z11op_290_0_ffj,__Z11op_298_0_ffj,__Z11op_2a0_0_ffj,__Z11op_2a8_0_ffj,__Z11op_2b0_0_ffj
,__Z11op_2b8_0_ffj,__Z11op_2b9_0_ffj,__Z11op_2d0_0_ffj,__Z11op_2e8_0_ffj,__Z11op_2f0_0_ffj,__Z11op_2f8_0_ffj,__Z11op_2f9_0_ffj,__Z11op_2fa_0_ffj,__Z11op_2fb_0_ffj,__Z11op_400_0_ffj,__Z11op_410_0_ffj,__Z11op_418_0_ffj,__Z11op_420_0_ffj,__Z11op_428_0_ffj,__Z11op_430_0_ffj,__Z11op_438_0_ffj,__Z11op_439_0_ffj,__Z11op_440_0_ffj,__Z11op_450_0_ffj,__Z11op_458_0_ffj,__Z11op_460_0_ffj,__Z11op_468_0_ffj,__Z11op_470_0_ffj,__Z11op_478_0_ffj,__Z11op_479_0_ffj,__Z11op_480_0_ffj,__Z11op_490_0_ffj,__Z11op_498_0_ffj,__Z11op_4a0_0_ffj,__Z11op_4a8_0_ffj
,__Z11op_4b0_0_ffj,__Z11op_4b8_0_ffj,__Z11op_4b9_0_ffj,__Z11op_4d0_0_ffj,__Z11op_4e8_0_ffj,__Z11op_4f0_0_ffj,__Z11op_4f8_0_ffj,__Z11op_4f9_0_ffj,__Z11op_4fa_0_ffj,__Z11op_4fb_0_ffj,__Z11op_600_0_ffj,__Z11op_610_0_ffj,__Z11op_618_0_ffj,__Z11op_620_0_ffj,__Z11op_628_0_ffj,__Z11op_630_0_ffj,__Z11op_638_0_ffj,__Z11op_639_0_ffj,__Z11op_640_0_ffj,__Z11op_650_0_ffj,__Z11op_658_0_ffj,__Z11op_660_0_ffj,__Z11op_668_0_ffj,__Z11op_670_0_ffj,__Z11op_678_0_ffj,__Z11op_679_0_ffj,__Z11op_680_0_ffj,__Z11op_690_0_ffj,__Z11op_698_0_ffj,__Z11op_6a0_0_ffj
,__Z11op_6a8_0_ffj,__Z11op_6b0_0_ffj,__Z11op_6b8_0_ffj,__Z11op_6b9_0_ffj,__Z11op_6c0_0_ffj,__Z11op_6c8_0_ffj,__Z11op_6d0_0_ffj,__Z11op_6e8_0_ffj,__Z11op_6f0_0_ffj,__Z11op_6f8_0_ffj,__Z11op_6f9_0_ffj,__Z11op_6fa_0_ffj,__Z11op_6fb_0_ffj,__Z11op_800_0_ffj,__Z11op_810_0_ffj,__Z11op_818_0_ffj,__Z11op_820_0_ffj,__Z11op_828_0_ffj,__Z11op_830_0_ffj,__Z11op_838_0_ffj,__Z11op_839_0_ffj,__Z11op_83a_0_ffj,__Z11op_83b_0_ffj,__Z11op_83c_0_ffj,__Z11op_840_0_ffj,__Z11op_850_0_ffj,__Z11op_858_0_ffj,__Z11op_860_0_ffj,__Z11op_868_0_ffj,__Z11op_870_0_ffj
,__Z11op_878_0_ffj,__Z11op_879_0_ffj,__Z11op_87a_0_ffj,__Z11op_87b_0_ffj,__Z11op_880_0_ffj,__Z11op_890_0_ffj,__Z11op_898_0_ffj,__Z11op_8a0_0_ffj,__Z11op_8a8_0_ffj,__Z11op_8b0_0_ffj,__Z11op_8b8_0_ffj,__Z11op_8b9_0_ffj,__Z11op_8ba_0_ffj,__Z11op_8bb_0_ffj,__Z11op_8c0_0_ffj,__Z11op_8d0_0_ffj,__Z11op_8d8_0_ffj,__Z11op_8e0_0_ffj,__Z11op_8e8_0_ffj,__Z11op_8f0_0_ffj,__Z11op_8f8_0_ffj,__Z11op_8f9_0_ffj,__Z11op_8fa_0_ffj,__Z11op_8fb_0_ffj,__Z11op_a00_0_ffj,__Z11op_a10_0_ffj,__Z11op_a18_0_ffj,__Z11op_a20_0_ffj,__Z11op_a28_0_ffj,__Z11op_a30_0_ffj
,__Z11op_a38_0_ffj,__Z11op_a39_0_ffj,__Z11op_a3c_0_ffj,__Z11op_a40_0_ffj,__Z11op_a50_0_ffj,__Z11op_a58_0_ffj,__Z11op_a60_0_ffj,__Z11op_a68_0_ffj,__Z11op_a70_0_ffj,__Z11op_a78_0_ffj,__Z11op_a79_0_ffj,__Z11op_a7c_0_ffj,__Z11op_a80_0_ffj,__Z11op_a90_0_ffj,__Z11op_a98_0_ffj,__Z11op_aa0_0_ffj,__Z11op_aa8_0_ffj,__Z11op_ab0_0_ffj,__Z11op_ab8_0_ffj,__Z11op_ab9_0_ffj,__Z11op_ad0_0_ffj,__Z11op_ad8_0_ffj,__Z11op_ae0_0_ffj,__Z11op_ae8_0_ffj,__Z11op_af0_0_ffj,__Z11op_af8_0_ffj,__Z11op_af9_0_ffj,__Z11op_c00_0_ffj,__Z11op_c10_0_ffj,__Z11op_c18_0_ffj
,__Z11op_c20_0_ffj,__Z11op_c28_0_ffj,__Z11op_c30_0_ffj,__Z11op_c38_0_ffj,__Z11op_c39_0_ffj,__Z11op_c3a_0_ffj,__Z11op_c3b_0_ffj,__Z11op_c40_0_ffj,__Z11op_c50_0_ffj,__Z11op_c58_0_ffj,__Z11op_c60_0_ffj,__Z11op_c68_0_ffj,__Z11op_c70_0_ffj,__Z11op_c78_0_ffj,__Z11op_c79_0_ffj,__Z11op_c7a_0_ffj,__Z11op_c7b_0_ffj,__Z11op_c80_0_ffj,__Z11op_c90_0_ffj,__Z11op_c98_0_ffj,__Z11op_ca0_0_ffj,__Z11op_ca8_0_ffj,__Z11op_cb0_0_ffj,__Z11op_cb8_0_ffj,__Z11op_cb9_0_ffj,__Z11op_cba_0_ffj,__Z11op_cbb_0_ffj,__Z11op_cd0_0_ffj,__Z11op_cd8_0_ffj,__Z11op_ce0_0_ffj
,__Z11op_ce8_0_ffj,__Z11op_cf0_0_ffj,__Z11op_cf8_0_ffj,__Z11op_cf9_0_ffj,__Z11op_cfc_0_ffj,__Z11op_e10_0_ffj,__Z11op_e18_0_ffj,__Z11op_e20_0_ffj,__Z11op_e28_0_ffj,__Z11op_e30_0_ffj,__Z11op_e38_0_ffj,__Z11op_e39_0_ffj,__Z11op_e50_0_ffj,__Z11op_e58_0_ffj,__Z11op_e60_0_ffj,__Z11op_e68_0_ffj,__Z11op_e70_0_ffj,__Z11op_e78_0_ffj,__Z11op_e79_0_ffj,__Z11op_e90_0_ffj,__Z11op_e98_0_ffj,__Z11op_ea0_0_ffj,__Z11op_ea8_0_ffj,__Z11op_eb0_0_ffj,__Z11op_eb8_0_ffj,__Z11op_eb9_0_ffj,__Z11op_ed0_0_ffj,__Z11op_ed8_0_ffj,__Z11op_ee0_0_ffj,__Z11op_ee8_0_ffj
,__Z11op_ef0_0_ffj,__Z11op_ef8_0_ffj,__Z11op_ef9_0_ffj,__Z11op_efc_0_ffj,__Z12op_1000_0_ffj,__Z12op_1010_0_ffj,__Z12op_1018_0_ffj,__Z12op_1020_0_ffj,__Z12op_1028_0_ffj,__Z12op_1030_0_ffj,__Z12op_1038_0_ffj,__Z12op_1039_0_ffj,__Z12op_103a_0_ffj,__Z12op_103b_0_ffj,__Z12op_103c_0_ffj,__Z12op_1080_0_ffj,__Z12op_1090_0_ffj,__Z12op_1098_0_ffj,__Z12op_10a0_0_ffj,__Z12op_10a8_0_ffj,__Z12op_10b0_0_ffj,__Z12op_10b8_0_ffj,__Z12op_10b9_0_ffj,__Z12op_10ba_0_ffj,__Z12op_10bb_0_ffj,__Z12op_10bc_0_ffj,__Z12op_10c0_0_ffj,__Z12op_10d0_0_ffj,__Z12op_10d8_0_ffj,__Z12op_10e0_0_ffj
,__Z12op_10e8_0_ffj,__Z12op_10f0_0_ffj,__Z12op_10f8_0_ffj,__Z12op_10f9_0_ffj,__Z12op_10fa_0_ffj,__Z12op_10fb_0_ffj,__Z12op_10fc_0_ffj,__Z12op_1100_0_ffj,__Z12op_1110_0_ffj,__Z12op_1118_0_ffj,__Z12op_1120_0_ffj,__Z12op_1128_0_ffj,__Z12op_1130_0_ffj,__Z12op_1138_0_ffj,__Z12op_1139_0_ffj,__Z12op_113a_0_ffj,__Z12op_113b_0_ffj,__Z12op_113c_0_ffj,__Z12op_1140_0_ffj,__Z12op_1150_0_ffj,__Z12op_1158_0_ffj,__Z12op_1160_0_ffj,__Z12op_1168_0_ffj,__Z12op_1170_0_ffj,__Z12op_1178_0_ffj,__Z12op_1179_0_ffj,__Z12op_117a_0_ffj,__Z12op_117b_0_ffj,__Z12op_117c_0_ffj,__Z12op_1180_0_ffj
,__Z12op_1190_0_ffj,__Z12op_1198_0_ffj,__Z12op_11a0_0_ffj,__Z12op_11a8_0_ffj,__Z12op_11b0_0_ffj,__Z12op_11b8_0_ffj,__Z12op_11b9_0_ffj,__Z12op_11ba_0_ffj,__Z12op_11bb_0_ffj,__Z12op_11bc_0_ffj,__Z12op_11c0_0_ffj,__Z12op_11d0_0_ffj,__Z12op_11d8_0_ffj,__Z12op_11e0_0_ffj,__Z12op_11e8_0_ffj,__Z12op_11f0_0_ffj,__Z12op_11f8_0_ffj,__Z12op_11f9_0_ffj,__Z12op_11fa_0_ffj,__Z12op_11fb_0_ffj,__Z12op_11fc_0_ffj,__Z12op_13c0_0_ffj,__Z12op_13d0_0_ffj,__Z12op_13d8_0_ffj,__Z12op_13e0_0_ffj,__Z12op_13e8_0_ffj,__Z12op_13f0_0_ffj,__Z12op_13f8_0_ffj,__Z12op_13f9_0_ffj,__Z12op_13fa_0_ffj
,__Z12op_13fb_0_ffj,__Z12op_13fc_0_ffj,__Z12op_2000_0_ffj,__Z12op_2008_0_ffj,__Z12op_2010_0_ffj,__Z12op_2018_0_ffj,__Z12op_2020_0_ffj,__Z12op_2028_0_ffj,__Z12op_2030_0_ffj,__Z12op_2038_0_ffj,__Z12op_2039_0_ffj,__Z12op_203a_0_ffj,__Z12op_203b_0_ffj,__Z12op_203c_0_ffj,__Z12op_2040_0_ffj,__Z12op_2048_0_ffj,__Z12op_2050_0_ffj,__Z12op_2058_0_ffj,__Z12op_2060_0_ffj,__Z12op_2068_0_ffj,__Z12op_2070_0_ffj,__Z12op_2078_0_ffj,__Z12op_2079_0_ffj,__Z12op_207a_0_ffj,__Z12op_207b_0_ffj,__Z12op_207c_0_ffj,__Z12op_2080_0_ffj,__Z12op_2088_0_ffj,__Z12op_2090_0_ffj,__Z12op_2098_0_ffj
,__Z12op_20a0_0_ffj,__Z12op_20a8_0_ffj,__Z12op_20b0_0_ffj,__Z12op_20b8_0_ffj,__Z12op_20b9_0_ffj,__Z12op_20ba_0_ffj,__Z12op_20bb_0_ffj,__Z12op_20bc_0_ffj,__Z12op_20c0_0_ffj,__Z12op_20c8_0_ffj,__Z12op_20d0_0_ffj,__Z12op_20d8_0_ffj,__Z12op_20e0_0_ffj,__Z12op_20e8_0_ffj,__Z12op_20f0_0_ffj,__Z12op_20f8_0_ffj,__Z12op_20f9_0_ffj,__Z12op_20fa_0_ffj,__Z12op_20fb_0_ffj,__Z12op_20fc_0_ffj,__Z12op_2100_0_ffj,__Z12op_2108_0_ffj,__Z12op_2110_0_ffj,__Z12op_2118_0_ffj,__Z12op_2120_0_ffj,__Z12op_2128_0_ffj,__Z12op_2130_0_ffj,__Z12op_2138_0_ffj,__Z12op_2139_0_ffj,__Z12op_213a_0_ffj
,__Z12op_213b_0_ffj,__Z12op_213c_0_ffj,__Z12op_2140_0_ffj,__Z12op_2148_0_ffj,__Z12op_2150_0_ffj,__Z12op_2158_0_ffj,__Z12op_2160_0_ffj,__Z12op_2168_0_ffj,__Z12op_2170_0_ffj,__Z12op_2178_0_ffj,__Z12op_2179_0_ffj,__Z12op_217a_0_ffj,__Z12op_217b_0_ffj,__Z12op_217c_0_ffj,__Z12op_2180_0_ffj,__Z12op_2188_0_ffj,__Z12op_2190_0_ffj,__Z12op_2198_0_ffj,__Z12op_21a0_0_ffj,__Z12op_21a8_0_ffj,__Z12op_21b0_0_ffj,__Z12op_21b8_0_ffj,__Z12op_21b9_0_ffj,__Z12op_21ba_0_ffj,__Z12op_21bb_0_ffj,__Z12op_21bc_0_ffj,__Z12op_21c0_0_ffj,__Z12op_21c8_0_ffj,__Z12op_21d0_0_ffj,__Z12op_21d8_0_ffj
,__Z12op_21e0_0_ffj,__Z12op_21e8_0_ffj,__Z12op_21f0_0_ffj,__Z12op_21f8_0_ffj,__Z12op_21f9_0_ffj,__Z12op_21fa_0_ffj,__Z12op_21fb_0_ffj,__Z12op_21fc_0_ffj,__Z12op_23c0_0_ffj,__Z12op_23c8_0_ffj,__Z12op_23d0_0_ffj,__Z12op_23d8_0_ffj,__Z12op_23e0_0_ffj,__Z12op_23e8_0_ffj,__Z12op_23f0_0_ffj,__Z12op_23f8_0_ffj,__Z12op_23f9_0_ffj,__Z12op_23fa_0_ffj,__Z12op_23fb_0_ffj,__Z12op_23fc_0_ffj,__Z12op_3000_0_ffj,__Z12op_3008_0_ffj,__Z12op_3010_0_ffj,__Z12op_3018_0_ffj,__Z12op_3020_0_ffj,__Z12op_3028_0_ffj,__Z12op_3030_0_ffj,__Z12op_3038_0_ffj,__Z12op_3039_0_ffj,__Z12op_303a_0_ffj
,__Z12op_303b_0_ffj,__Z12op_303c_0_ffj,__Z12op_3040_0_ffj,__Z12op_3048_0_ffj,__Z12op_3050_0_ffj,__Z12op_3058_0_ffj,__Z12op_3060_0_ffj,__Z12op_3068_0_ffj,__Z12op_3070_0_ffj,__Z12op_3078_0_ffj,__Z12op_3079_0_ffj,__Z12op_307a_0_ffj,__Z12op_307b_0_ffj,__Z12op_307c_0_ffj,__Z12op_3080_0_ffj,__Z12op_3088_0_ffj,__Z12op_3090_0_ffj,__Z12op_3098_0_ffj,__Z12op_30a0_0_ffj,__Z12op_30a8_0_ffj,__Z12op_30b0_0_ffj,__Z12op_30b8_0_ffj,__Z12op_30b9_0_ffj,__Z12op_30ba_0_ffj,__Z12op_30bb_0_ffj,__Z12op_30bc_0_ffj,__Z12op_30c0_0_ffj,__Z12op_30c8_0_ffj,__Z12op_30d0_0_ffj,__Z12op_30d8_0_ffj
,__Z12op_30e0_0_ffj,__Z12op_30e8_0_ffj,__Z12op_30f0_0_ffj,__Z12op_30f8_0_ffj,__Z12op_30f9_0_ffj,__Z12op_30fa_0_ffj,__Z12op_30fb_0_ffj,__Z12op_30fc_0_ffj,__Z12op_3100_0_ffj,__Z12op_3108_0_ffj,__Z12op_3110_0_ffj,__Z12op_3118_0_ffj,__Z12op_3120_0_ffj,__Z12op_3128_0_ffj,__Z12op_3130_0_ffj,__Z12op_3138_0_ffj,__Z12op_3139_0_ffj,__Z12op_313a_0_ffj,__Z12op_313b_0_ffj,__Z12op_313c_0_ffj,__Z12op_3140_0_ffj,__Z12op_3148_0_ffj,__Z12op_3150_0_ffj,__Z12op_3158_0_ffj,__Z12op_3160_0_ffj,__Z12op_3168_0_ffj,__Z12op_3170_0_ffj,__Z12op_3178_0_ffj,__Z12op_3179_0_ffj,__Z12op_317a_0_ffj
,__Z12op_317b_0_ffj,__Z12op_317c_0_ffj,__Z12op_3180_0_ffj,__Z12op_3188_0_ffj,__Z12op_3190_0_ffj,__Z12op_3198_0_ffj,__Z12op_31a0_0_ffj,__Z12op_31a8_0_ffj,__Z12op_31b0_0_ffj,__Z12op_31b8_0_ffj,__Z12op_31b9_0_ffj,__Z12op_31ba_0_ffj,__Z12op_31bb_0_ffj,__Z12op_31bc_0_ffj,__Z12op_31c0_0_ffj,__Z12op_31c8_0_ffj,__Z12op_31d0_0_ffj,__Z12op_31d8_0_ffj,__Z12op_31e0_0_ffj,__Z12op_31e8_0_ffj,__Z12op_31f0_0_ffj,__Z12op_31f8_0_ffj,__Z12op_31f9_0_ffj,__Z12op_31fa_0_ffj,__Z12op_31fb_0_ffj,__Z12op_31fc_0_ffj,__Z12op_33c0_0_ffj,__Z12op_33c8_0_ffj,__Z12op_33d0_0_ffj,__Z12op_33d8_0_ffj
,__Z12op_33e0_0_ffj,__Z12op_33e8_0_ffj,__Z12op_33f0_0_ffj,__Z12op_33f8_0_ffj,__Z12op_33f9_0_ffj,__Z12op_33fa_0_ffj,__Z12op_33fb_0_ffj,__Z12op_33fc_0_ffj,__Z12op_4000_0_ffj,__Z12op_4010_0_ffj,__Z12op_4018_0_ffj,__Z12op_4020_0_ffj,__Z12op_4028_0_ffj,__Z12op_4030_0_ffj,__Z12op_4038_0_ffj,__Z12op_4039_0_ffj,__Z12op_4040_0_ffj,__Z12op_4050_0_ffj,__Z12op_4058_0_ffj,__Z12op_4060_0_ffj,__Z12op_4068_0_ffj,__Z12op_4070_0_ffj,__Z12op_4078_0_ffj,__Z12op_4079_0_ffj,__Z12op_4080_0_ffj,__Z12op_4090_0_ffj,__Z12op_4098_0_ffj,__Z12op_40a0_0_ffj,__Z12op_40a8_0_ffj,__Z12op_40b0_0_ffj
,__Z12op_40b8_0_ffj,__Z12op_40b9_0_ffj,__Z12op_40c0_0_ffj,__Z12op_40d0_0_ffj,__Z12op_40d8_0_ffj,__Z12op_40e0_0_ffj,__Z12op_40e8_0_ffj,__Z12op_40f0_0_ffj,__Z12op_40f8_0_ffj,__Z12op_40f9_0_ffj,__Z12op_4100_0_ffj,__Z12op_4110_0_ffj,__Z12op_4118_0_ffj,__Z12op_4120_0_ffj,__Z12op_4128_0_ffj,__Z12op_4130_0_ffj,__Z12op_4138_0_ffj,__Z12op_4139_0_ffj,__Z12op_413a_0_ffj,__Z12op_413b_0_ffj,__Z12op_413c_0_ffj,__Z12op_4180_0_ffj,__Z12op_4190_0_ffj,__Z12op_4198_0_ffj,__Z12op_41a0_0_ffj,__Z12op_41a8_0_ffj,__Z12op_41b0_0_ffj,__Z12op_41b8_0_ffj,__Z12op_41b9_0_ffj,__Z12op_41ba_0_ffj
,__Z12op_41bb_0_ffj,__Z12op_41bc_0_ffj,__Z12op_41d0_0_ffj,__Z12op_41e8_0_ffj,__Z12op_41f0_0_ffj,__Z12op_41f8_0_ffj,__Z12op_41f9_0_ffj,__Z12op_41fa_0_ffj,__Z12op_41fb_0_ffj,__Z12op_4200_0_ffj,__Z12op_4210_0_ffj,__Z12op_4218_0_ffj,__Z12op_4220_0_ffj,__Z12op_4228_0_ffj,__Z12op_4230_0_ffj,__Z12op_4238_0_ffj,__Z12op_4239_0_ffj,__Z12op_4240_0_ffj,__Z12op_4250_0_ffj,__Z12op_4258_0_ffj,__Z12op_4260_0_ffj,__Z12op_4268_0_ffj,__Z12op_4270_0_ffj,__Z12op_4278_0_ffj,__Z12op_4279_0_ffj,__Z12op_4280_0_ffj,__Z12op_4290_0_ffj,__Z12op_4298_0_ffj,__Z12op_42a0_0_ffj,__Z12op_42a8_0_ffj
,__Z12op_42b0_0_ffj,__Z12op_42b8_0_ffj,__Z12op_42b9_0_ffj,__Z12op_42c0_0_ffj,__Z12op_42d0_0_ffj,__Z12op_42d8_0_ffj,__Z12op_42e0_0_ffj,__Z12op_42e8_0_ffj,__Z12op_42f0_0_ffj,__Z12op_42f8_0_ffj,__Z12op_42f9_0_ffj,__Z12op_4400_0_ffj,__Z12op_4410_0_ffj,__Z12op_4418_0_ffj,__Z12op_4420_0_ffj,__Z12op_4428_0_ffj,__Z12op_4430_0_ffj,__Z12op_4438_0_ffj,__Z12op_4439_0_ffj,__Z12op_4440_0_ffj,__Z12op_4450_0_ffj,__Z12op_4458_0_ffj,__Z12op_4460_0_ffj,__Z12op_4468_0_ffj,__Z12op_4470_0_ffj,__Z12op_4478_0_ffj,__Z12op_4479_0_ffj,__Z12op_4480_0_ffj,__Z12op_4490_0_ffj,__Z12op_4498_0_ffj
,__Z12op_44a0_0_ffj,__Z12op_44a8_0_ffj,__Z12op_44b0_0_ffj,__Z12op_44b8_0_ffj,__Z12op_44b9_0_ffj,__Z12op_44c0_0_ffj,__Z12op_44d0_0_ffj,__Z12op_44d8_0_ffj,__Z12op_44e0_0_ffj,__Z12op_44e8_0_ffj,__Z12op_44f0_0_ffj,__Z12op_44f8_0_ffj,__Z12op_44f9_0_ffj,__Z12op_44fa_0_ffj,__Z12op_44fb_0_ffj,__Z12op_44fc_0_ffj,__Z12op_4600_0_ffj,__Z12op_4610_0_ffj,__Z12op_4618_0_ffj,__Z12op_4620_0_ffj,__Z12op_4628_0_ffj,__Z12op_4630_0_ffj,__Z12op_4638_0_ffj,__Z12op_4639_0_ffj,__Z12op_4640_0_ffj,__Z12op_4650_0_ffj,__Z12op_4658_0_ffj,__Z12op_4660_0_ffj,__Z12op_4668_0_ffj,__Z12op_4670_0_ffj
,__Z12op_4678_0_ffj,__Z12op_4679_0_ffj,__Z12op_4680_0_ffj,__Z12op_4690_0_ffj,__Z12op_4698_0_ffj,__Z12op_46a0_0_ffj,__Z12op_46a8_0_ffj,__Z12op_46b0_0_ffj,__Z12op_46b8_0_ffj,__Z12op_46b9_0_ffj,__Z12op_46c0_0_ffj,__Z12op_46d0_0_ffj,__Z12op_46d8_0_ffj,__Z12op_46e0_0_ffj,__Z12op_46e8_0_ffj,__Z12op_46f0_0_ffj,__Z12op_46f8_0_ffj,__Z12op_46f9_0_ffj,__Z12op_46fa_0_ffj,__Z12op_46fb_0_ffj,__Z12op_46fc_0_ffj,__Z12op_4800_0_ffj,__Z12op_4808_0_ffj,__Z12op_4810_0_ffj,__Z12op_4818_0_ffj,__Z12op_4820_0_ffj,__Z12op_4828_0_ffj,__Z12op_4830_0_ffj,__Z12op_4838_0_ffj,__Z12op_4839_0_ffj
,__Z12op_4840_0_ffj,__Z12op_4848_0_ffj,__Z12op_4850_0_ffj,__Z12op_4868_0_ffj,__Z12op_4870_0_ffj,__Z12op_4878_0_ffj,__Z12op_4879_0_ffj,__Z12op_487a_0_ffj,__Z12op_487b_0_ffj,__Z12op_4880_0_ffj,__Z12op_4890_0_ffj,__Z12op_48a0_0_ffj,__Z12op_48a8_0_ffj,__Z12op_48b0_0_ffj,__Z12op_48b8_0_ffj,__Z12op_48b9_0_ffj,__Z12op_48c0_0_ffj,__Z12op_48d0_0_ffj,__Z12op_48e0_0_ffj,__Z12op_48e8_0_ffj,__Z12op_48f0_0_ffj,__Z12op_48f8_0_ffj,__Z12op_48f9_0_ffj,__Z12op_49c0_0_ffj,__Z12op_4a00_0_ffj,__Z12op_4a10_0_ffj,__Z12op_4a18_0_ffj,__Z12op_4a20_0_ffj,__Z12op_4a28_0_ffj,__Z12op_4a30_0_ffj
,__Z12op_4a38_0_ffj,__Z12op_4a39_0_ffj,__Z12op_4a3a_0_ffj,__Z12op_4a3b_0_ffj,__Z12op_4a3c_0_ffj,__Z12op_4a40_0_ffj,__Z12op_4a48_0_ffj,__Z12op_4a50_0_ffj,__Z12op_4a58_0_ffj,__Z12op_4a60_0_ffj,__Z12op_4a68_0_ffj,__Z12op_4a70_0_ffj,__Z12op_4a78_0_ffj,__Z12op_4a79_0_ffj,__Z12op_4a7a_0_ffj,__Z12op_4a7b_0_ffj,__Z12op_4a7c_0_ffj,__Z12op_4a80_0_ffj,__Z12op_4a88_0_ffj,__Z12op_4a90_0_ffj,__Z12op_4a98_0_ffj,__Z12op_4aa0_0_ffj,__Z12op_4aa8_0_ffj,__Z12op_4ab0_0_ffj,__Z12op_4ab8_0_ffj,__Z12op_4ab9_0_ffj,__Z12op_4aba_0_ffj,__Z12op_4abb_0_ffj,__Z12op_4abc_0_ffj,__Z12op_4ac0_0_ffj
,__Z12op_4ad0_0_ffj,__Z12op_4ad8_0_ffj,__Z12op_4ae0_0_ffj,__Z12op_4ae8_0_ffj,__Z12op_4af0_0_ffj,__Z12op_4af8_0_ffj,__Z12op_4af9_0_ffj,__Z12op_4c00_0_ffj,__Z12op_4c10_0_ffj,__Z12op_4c18_0_ffj,__Z12op_4c20_0_ffj,__Z12op_4c28_0_ffj,__Z12op_4c30_0_ffj,__Z12op_4c38_0_ffj,__Z12op_4c39_0_ffj,__Z12op_4c3a_0_ffj,__Z12op_4c3b_0_ffj,__Z12op_4c3c_0_ffj,__Z12op_4c40_0_ffj,__Z12op_4c50_0_ffj,__Z12op_4c58_0_ffj,__Z12op_4c60_0_ffj,__Z12op_4c68_0_ffj,__Z12op_4c70_0_ffj,__Z12op_4c78_0_ffj,__Z12op_4c79_0_ffj,__Z12op_4c7a_0_ffj,__Z12op_4c7b_0_ffj,__Z12op_4c7c_0_ffj,__Z12op_4c90_0_ffj
,__Z12op_4c98_0_ffj,__Z12op_4ca8_0_ffj,__Z12op_4cb0_0_ffj,__Z12op_4cb8_0_ffj,__Z12op_4cb9_0_ffj,__Z12op_4cba_0_ffj,__Z12op_4cbb_0_ffj,__Z12op_4cd0_0_ffj,__Z12op_4cd8_0_ffj,__Z12op_4ce8_0_ffj,__Z12op_4cf0_0_ffj,__Z12op_4cf8_0_ffj,__Z12op_4cf9_0_ffj,__Z12op_4cfa_0_ffj,__Z12op_4cfb_0_ffj,__Z12op_4e40_0_ffj,__Z12op_4e50_0_ffj,__Z12op_4e58_0_ffj,__Z12op_4e60_0_ffj,__Z12op_4e68_0_ffj,__Z12op_4e70_0_ffj,__Z12op_4e71_0_ffj,__Z12op_4e72_0_ffj,__Z12op_4e73_0_ffj,__Z12op_4e74_0_ffj,__Z12op_4e75_0_ffj,__Z12op_4e76_0_ffj,__Z12op_4e77_0_ffj,__Z12op_4e7a_0_ffj,__Z12op_4e7b_0_ffj
,__Z12op_4e90_0_ffj,__Z12op_4ea8_0_ffj,__Z12op_4eb0_0_ffj,__Z12op_4eb8_0_ffj,__Z12op_4eb9_0_ffj,__Z12op_4eba_0_ffj,__Z12op_4ebb_0_ffj,__Z12op_4ed0_0_ffj,__Z12op_4ee8_0_ffj,__Z12op_4ef0_0_ffj,__Z12op_4ef8_0_ffj,__Z12op_4ef9_0_ffj,__Z12op_4efa_0_ffj,__Z12op_4efb_0_ffj,__Z12op_5000_0_ffj,__Z12op_5010_0_ffj,__Z12op_5018_0_ffj,__Z12op_5020_0_ffj,__Z12op_5028_0_ffj,__Z12op_5030_0_ffj,__Z12op_5038_0_ffj,__Z12op_5039_0_ffj,__Z12op_5040_0_ffj,__Z12op_5048_0_ffj,__Z12op_5050_0_ffj,__Z12op_5058_0_ffj,__Z12op_5060_0_ffj,__Z12op_5068_0_ffj,__Z12op_5070_0_ffj,__Z12op_5078_0_ffj
,__Z12op_5079_0_ffj,__Z12op_5080_0_ffj,__Z12op_5088_0_ffj,__Z12op_5090_0_ffj,__Z12op_5098_0_ffj,__Z12op_50a0_0_ffj,__Z12op_50a8_0_ffj,__Z12op_50b0_0_ffj,__Z12op_50b8_0_ffj,__Z12op_50b9_0_ffj,__Z12op_50c0_0_ffj,__Z12op_50c8_0_ffj,__Z12op_50d0_0_ffj,__Z12op_50d8_0_ffj,__Z12op_50e0_0_ffj,__Z12op_50e8_0_ffj,__Z12op_50f0_0_ffj,__Z12op_50f8_0_ffj,__Z12op_50f9_0_ffj,__Z12op_50fa_0_ffj,__Z12op_50fb_0_ffj,__Z12op_50fc_0_ffj,__Z12op_5100_0_ffj,__Z12op_5110_0_ffj,__Z12op_5118_0_ffj,__Z12op_5120_0_ffj,__Z12op_5128_0_ffj,__Z12op_5130_0_ffj,__Z12op_5138_0_ffj,__Z12op_5139_0_ffj
,__Z12op_5140_0_ffj,__Z12op_5148_0_ffj,__Z12op_5150_0_ffj,__Z12op_5158_0_ffj,__Z12op_5160_0_ffj,__Z12op_5168_0_ffj,__Z12op_5170_0_ffj,__Z12op_5178_0_ffj,__Z12op_5179_0_ffj,__Z12op_5180_0_ffj,__Z12op_5188_0_ffj,__Z12op_5190_0_ffj,__Z12op_5198_0_ffj,__Z12op_51a0_0_ffj,__Z12op_51a8_0_ffj,__Z12op_51b0_0_ffj,__Z12op_51b8_0_ffj,__Z12op_51b9_0_ffj,__Z12op_51c0_0_ffj,__Z12op_51c8_0_ffj,__Z12op_51d0_0_ffj,__Z12op_51d8_0_ffj,__Z12op_51e0_0_ffj,__Z12op_51e8_0_ffj,__Z12op_51f0_0_ffj,__Z12op_51f8_0_ffj,__Z12op_51f9_0_ffj,__Z12op_51fa_0_ffj,__Z12op_51fb_0_ffj,__Z12op_51fc_0_ffj
,__Z12op_52c0_0_ffj,__Z12op_52c8_0_ffj,__Z12op_52d0_0_ffj,__Z12op_52d8_0_ffj,__Z12op_52e0_0_ffj,__Z12op_52e8_0_ffj,__Z12op_52f0_0_ffj,__Z12op_52f8_0_ffj,__Z12op_52f9_0_ffj,__Z12op_52fa_0_ffj,__Z12op_52fb_0_ffj,__Z12op_52fc_0_ffj,__Z12op_53c0_0_ffj,__Z12op_53c8_0_ffj,__Z12op_53d0_0_ffj,__Z12op_53d8_0_ffj,__Z12op_53e0_0_ffj,__Z12op_53e8_0_ffj,__Z12op_53f0_0_ffj,__Z12op_53f8_0_ffj,__Z12op_53f9_0_ffj,__Z12op_53fa_0_ffj,__Z12op_53fb_0_ffj,__Z12op_53fc_0_ffj,__Z12op_54c0_0_ffj,__Z12op_54c8_0_ffj,__Z12op_54d0_0_ffj,__Z12op_54d8_0_ffj,__Z12op_54e0_0_ffj,__Z12op_54e8_0_ffj
,__Z12op_54f0_0_ffj,__Z12op_54f8_0_ffj,__Z12op_54f9_0_ffj,__Z12op_54fa_0_ffj,__Z12op_54fb_0_ffj,__Z12op_54fc_0_ffj,__Z12op_55c0_0_ffj,__Z12op_55c8_0_ffj,__Z12op_55d0_0_ffj,__Z12op_55d8_0_ffj,__Z12op_55e0_0_ffj,__Z12op_55e8_0_ffj,__Z12op_55f0_0_ffj,__Z12op_55f8_0_ffj,__Z12op_55f9_0_ffj,__Z12op_55fa_0_ffj,__Z12op_55fb_0_ffj,__Z12op_55fc_0_ffj,__Z12op_56c0_0_ffj,__Z12op_56c8_0_ffj,__Z12op_56d0_0_ffj,__Z12op_56d8_0_ffj,__Z12op_56e0_0_ffj,__Z12op_56e8_0_ffj,__Z12op_56f0_0_ffj,__Z12op_56f8_0_ffj,__Z12op_56f9_0_ffj,__Z12op_56fa_0_ffj,__Z12op_56fb_0_ffj,__Z12op_56fc_0_ffj
,__Z12op_57c0_0_ffj,__Z12op_57c8_0_ffj,__Z12op_57d0_0_ffj,__Z12op_57d8_0_ffj,__Z12op_57e0_0_ffj,__Z12op_57e8_0_ffj,__Z12op_57f0_0_ffj,__Z12op_57f8_0_ffj,__Z12op_57f9_0_ffj,__Z12op_57fa_0_ffj,__Z12op_57fb_0_ffj,__Z12op_57fc_0_ffj,__Z12op_58c0_0_ffj,__Z12op_58c8_0_ffj,__Z12op_58d0_0_ffj,__Z12op_58d8_0_ffj,__Z12op_58e0_0_ffj,__Z12op_58e8_0_ffj,__Z12op_58f0_0_ffj,__Z12op_58f8_0_ffj,__Z12op_58f9_0_ffj,__Z12op_58fa_0_ffj,__Z12op_58fb_0_ffj,__Z12op_58fc_0_ffj,__Z12op_59c0_0_ffj,__Z12op_59c8_0_ffj,__Z12op_59d0_0_ffj,__Z12op_59d8_0_ffj,__Z12op_59e0_0_ffj,__Z12op_59e8_0_ffj
,__Z12op_59f0_0_ffj,__Z12op_59f8_0_ffj,__Z12op_59f9_0_ffj,__Z12op_59fa_0_ffj,__Z12op_59fb_0_ffj,__Z12op_59fc_0_ffj,__Z12op_5ac0_0_ffj,__Z12op_5ac8_0_ffj,__Z12op_5ad0_0_ffj,__Z12op_5ad8_0_ffj,__Z12op_5ae0_0_ffj,__Z12op_5ae8_0_ffj,__Z12op_5af0_0_ffj,__Z12op_5af8_0_ffj,__Z12op_5af9_0_ffj,__Z12op_5afa_0_ffj,__Z12op_5afb_0_ffj,__Z12op_5afc_0_ffj,__Z12op_5bc0_0_ffj,__Z12op_5bc8_0_ffj,__Z12op_5bd0_0_ffj,__Z12op_5bd8_0_ffj,__Z12op_5be0_0_ffj,__Z12op_5be8_0_ffj,__Z12op_5bf0_0_ffj,__Z12op_5bf8_0_ffj,__Z12op_5bf9_0_ffj,__Z12op_5bfa_0_ffj,__Z12op_5bfb_0_ffj,__Z12op_5bfc_0_ffj
,__Z12op_5cc0_0_ffj,__Z12op_5cc8_0_ffj,__Z12op_5cd0_0_ffj,__Z12op_5cd8_0_ffj,__Z12op_5ce0_0_ffj,__Z12op_5ce8_0_ffj,__Z12op_5cf0_0_ffj,__Z12op_5cf8_0_ffj,__Z12op_5cf9_0_ffj,__Z12op_5cfa_0_ffj,__Z12op_5cfb_0_ffj,__Z12op_5cfc_0_ffj,__Z12op_5dc0_0_ffj,__Z12op_5dc8_0_ffj,__Z12op_5dd0_0_ffj,__Z12op_5dd8_0_ffj,__Z12op_5de0_0_ffj,__Z12op_5de8_0_ffj,__Z12op_5df0_0_ffj,__Z12op_5df8_0_ffj,__Z12op_5df9_0_ffj,__Z12op_5dfa_0_ffj,__Z12op_5dfb_0_ffj,__Z12op_5dfc_0_ffj,__Z12op_5ec0_0_ffj,__Z12op_5ec8_0_ffj,__Z12op_5ed0_0_ffj,__Z12op_5ed8_0_ffj,__Z12op_5ee0_0_ffj,__Z12op_5ee8_0_ffj
,__Z12op_5ef0_0_ffj,__Z12op_5ef8_0_ffj,__Z12op_5ef9_0_ffj,__Z12op_5efa_0_ffj,__Z12op_5efb_0_ffj,__Z12op_5efc_0_ffj,__Z12op_5fc0_0_ffj,__Z12op_5fc8_0_ffj,__Z12op_5fd0_0_ffj,__Z12op_5fd8_0_ffj,__Z12op_5fe0_0_ffj,__Z12op_5fe8_0_ffj,__Z12op_5ff0_0_ffj,__Z12op_5ff8_0_ffj,__Z12op_5ff9_0_ffj,__Z12op_5ffa_0_ffj,__Z12op_5ffb_0_ffj,__Z12op_5ffc_0_ffj,__Z12op_6000_0_ffj,__Z12op_6001_0_ffj,__Z12op_60ff_0_ffj,__Z12op_6100_0_ffj,__Z12op_6101_0_ffj,__Z12op_61ff_0_ffj,__Z12op_6200_0_ffj,__Z12op_6201_0_ffj,__Z12op_62ff_0_ffj,__Z12op_6300_0_ffj,__Z12op_6301_0_ffj,__Z12op_63ff_0_ffj
,__Z12op_6400_0_ffj,__Z12op_6401_0_ffj,__Z12op_64ff_0_ffj,__Z12op_6500_0_ffj,__Z12op_6501_0_ffj,__Z12op_65ff_0_ffj,__Z12op_6600_0_ffj,__Z12op_6601_0_ffj,__Z12op_66ff_0_ffj,__Z12op_6700_0_ffj,__Z12op_6701_0_ffj,__Z12op_67ff_0_ffj,__Z12op_6800_0_ffj,__Z12op_6801_0_ffj,__Z12op_68ff_0_ffj,__Z12op_6900_0_ffj,__Z12op_6901_0_ffj,__Z12op_69ff_0_ffj,__Z12op_6a00_0_ffj,__Z12op_6a01_0_ffj,__Z12op_6aff_0_ffj,__Z12op_6b00_0_ffj,__Z12op_6b01_0_ffj,__Z12op_6bff_0_ffj,__Z12op_6c00_0_ffj,__Z12op_6c01_0_ffj,__Z12op_6cff_0_ffj,__Z12op_6d00_0_ffj,__Z12op_6d01_0_ffj,__Z12op_6dff_0_ffj
,__Z12op_6e00_0_ffj,__Z12op_6e01_0_ffj,__Z12op_6eff_0_ffj,__Z12op_6f00_0_ffj,__Z12op_6f01_0_ffj,__Z12op_6fff_0_ffj,__Z12op_7000_0_ffj,__Z12op_7100_0_ffj,__Z12op_7101_0_ffj,__Z12op_8000_0_ffj,__Z12op_8010_0_ffj,__Z12op_8018_0_ffj,__Z12op_8020_0_ffj,__Z12op_8028_0_ffj,__Z12op_8030_0_ffj,__Z12op_8038_0_ffj,__Z12op_8039_0_ffj,__Z12op_803a_0_ffj,__Z12op_803b_0_ffj,__Z12op_803c_0_ffj,__Z12op_8040_0_ffj,__Z12op_8050_0_ffj,__Z12op_8058_0_ffj,__Z12op_8060_0_ffj,__Z12op_8068_0_ffj,__Z12op_8070_0_ffj,__Z12op_8078_0_ffj,__Z12op_8079_0_ffj,__Z12op_807a_0_ffj,__Z12op_807b_0_ffj
,__Z12op_807c_0_ffj,__Z12op_8080_0_ffj,__Z12op_8090_0_ffj,__Z12op_8098_0_ffj,__Z12op_80a0_0_ffj,__Z12op_80a8_0_ffj,__Z12op_80b0_0_ffj,__Z12op_80b8_0_ffj,__Z12op_80b9_0_ffj,__Z12op_80ba_0_ffj,__Z12op_80bb_0_ffj,__Z12op_80bc_0_ffj,__Z12op_80c0_0_ffj,__Z12op_80d0_0_ffj,__Z12op_80d8_0_ffj,__Z12op_80e0_0_ffj,__Z12op_80e8_0_ffj,__Z12op_80f0_0_ffj,__Z12op_80f8_0_ffj,__Z12op_80f9_0_ffj,__Z12op_80fa_0_ffj,__Z12op_80fb_0_ffj,__Z12op_80fc_0_ffj,__Z12op_8100_0_ffj,__Z12op_8108_0_ffj,__Z12op_8110_0_ffj,__Z12op_8118_0_ffj,__Z12op_8120_0_ffj,__Z12op_8128_0_ffj,__Z12op_8130_0_ffj
,__Z12op_8138_0_ffj,__Z12op_8139_0_ffj,__Z12op_8140_0_ffj,__Z12op_8148_0_ffj,__Z12op_8150_0_ffj,__Z12op_8158_0_ffj,__Z12op_8160_0_ffj,__Z12op_8168_0_ffj,__Z12op_8170_0_ffj,__Z12op_8178_0_ffj,__Z12op_8179_0_ffj,__Z12op_8180_0_ffj,__Z12op_8188_0_ffj,__Z12op_8190_0_ffj,__Z12op_8198_0_ffj,__Z12op_81a0_0_ffj,__Z12op_81a8_0_ffj,__Z12op_81b0_0_ffj,__Z12op_81b8_0_ffj,__Z12op_81b9_0_ffj,__Z12op_81c0_0_ffj,__Z12op_81d0_0_ffj,__Z12op_81d8_0_ffj,__Z12op_81e0_0_ffj,__Z12op_81e8_0_ffj,__Z12op_81f0_0_ffj,__Z12op_81f8_0_ffj,__Z12op_81f9_0_ffj,__Z12op_81fa_0_ffj,__Z12op_81fb_0_ffj
,__Z12op_81fc_0_ffj,__Z12op_9000_0_ffj,__Z12op_9010_0_ffj,__Z12op_9018_0_ffj,__Z12op_9020_0_ffj,__Z12op_9028_0_ffj,__Z12op_9030_0_ffj,__Z12op_9038_0_ffj,__Z12op_9039_0_ffj,__Z12op_903a_0_ffj,__Z12op_903b_0_ffj,__Z12op_903c_0_ffj,__Z12op_9040_0_ffj,__Z12op_9048_0_ffj,__Z12op_9050_0_ffj,__Z12op_9058_0_ffj,__Z12op_9060_0_ffj,__Z12op_9068_0_ffj,__Z12op_9070_0_ffj,__Z12op_9078_0_ffj,__Z12op_9079_0_ffj,__Z12op_907a_0_ffj,__Z12op_907b_0_ffj,__Z12op_907c_0_ffj,__Z12op_9080_0_ffj,__Z12op_9088_0_ffj,__Z12op_9090_0_ffj,__Z12op_9098_0_ffj,__Z12op_90a0_0_ffj,__Z12op_90a8_0_ffj
,__Z12op_90b0_0_ffj,__Z12op_90b8_0_ffj,__Z12op_90b9_0_ffj,__Z12op_90ba_0_ffj,__Z12op_90bb_0_ffj,__Z12op_90bc_0_ffj,__Z12op_90c0_0_ffj,__Z12op_90c8_0_ffj,__Z12op_90d0_0_ffj,__Z12op_90d8_0_ffj,__Z12op_90e0_0_ffj,__Z12op_90e8_0_ffj,__Z12op_90f0_0_ffj,__Z12op_90f8_0_ffj,__Z12op_90f9_0_ffj,__Z12op_90fa_0_ffj,__Z12op_90fb_0_ffj,__Z12op_90fc_0_ffj,__Z12op_9100_0_ffj,__Z12op_9108_0_ffj,__Z12op_9110_0_ffj,__Z12op_9118_0_ffj,__Z12op_9120_0_ffj,__Z12op_9128_0_ffj,__Z12op_9130_0_ffj,__Z12op_9138_0_ffj,__Z12op_9139_0_ffj,__Z12op_9140_0_ffj,__Z12op_9148_0_ffj,__Z12op_9150_0_ffj
,__Z12op_9158_0_ffj,__Z12op_9160_0_ffj,__Z12op_9168_0_ffj,__Z12op_9170_0_ffj,__Z12op_9178_0_ffj,__Z12op_9179_0_ffj,__Z12op_9180_0_ffj,__Z12op_9188_0_ffj,__Z12op_9190_0_ffj,__Z12op_9198_0_ffj,__Z12op_91a0_0_ffj,__Z12op_91a8_0_ffj,__Z12op_91b0_0_ffj,__Z12op_91b8_0_ffj,__Z12op_91b9_0_ffj,__Z12op_91c0_0_ffj,__Z12op_91c8_0_ffj,__Z12op_91d0_0_ffj,__Z12op_91d8_0_ffj,__Z12op_91e0_0_ffj,__Z12op_91e8_0_ffj,__Z12op_91f0_0_ffj,__Z12op_91f8_0_ffj,__Z12op_91f9_0_ffj,__Z12op_91fa_0_ffj,__Z12op_91fb_0_ffj,__Z12op_91fc_0_ffj,__Z12op_b000_0_ffj,__Z12op_b010_0_ffj,__Z12op_b018_0_ffj
,__Z12op_b020_0_ffj,__Z12op_b028_0_ffj,__Z12op_b030_0_ffj,__Z12op_b038_0_ffj,__Z12op_b039_0_ffj,__Z12op_b03a_0_ffj,__Z12op_b03b_0_ffj,__Z12op_b03c_0_ffj,__Z12op_b040_0_ffj,__Z12op_b048_0_ffj,__Z12op_b050_0_ffj,__Z12op_b058_0_ffj,__Z12op_b060_0_ffj,__Z12op_b068_0_ffj,__Z12op_b070_0_ffj,__Z12op_b078_0_ffj,__Z12op_b079_0_ffj,__Z12op_b07a_0_ffj,__Z12op_b07b_0_ffj,__Z12op_b07c_0_ffj,__Z12op_b080_0_ffj,__Z12op_b088_0_ffj,__Z12op_b090_0_ffj,__Z12op_b098_0_ffj,__Z12op_b0a0_0_ffj,__Z12op_b0a8_0_ffj,__Z12op_b0b0_0_ffj,__Z12op_b0b8_0_ffj,__Z12op_b0b9_0_ffj,__Z12op_b0ba_0_ffj
,__Z12op_b0bb_0_ffj,__Z12op_b0bc_0_ffj,__Z12op_b0c0_0_ffj,__Z12op_b0c8_0_ffj,__Z12op_b0d0_0_ffj,__Z12op_b0d8_0_ffj,__Z12op_b0e0_0_ffj,__Z12op_b0e8_0_ffj,__Z12op_b0f0_0_ffj,__Z12op_b0f8_0_ffj,__Z12op_b0f9_0_ffj,__Z12op_b0fa_0_ffj,__Z12op_b0fb_0_ffj,__Z12op_b0fc_0_ffj,__Z12op_b100_0_ffj,__Z12op_b108_0_ffj,__Z12op_b110_0_ffj,__Z12op_b118_0_ffj,__Z12op_b120_0_ffj,__Z12op_b128_0_ffj,__Z12op_b130_0_ffj,__Z12op_b138_0_ffj,__Z12op_b139_0_ffj,__Z12op_b140_0_ffj,__Z12op_b148_0_ffj,__Z12op_b150_0_ffj,__Z12op_b158_0_ffj,__Z12op_b160_0_ffj,__Z12op_b168_0_ffj,__Z12op_b170_0_ffj
,__Z12op_b178_0_ffj,__Z12op_b179_0_ffj,__Z12op_b180_0_ffj,__Z12op_b188_0_ffj,__Z12op_b190_0_ffj,__Z12op_b198_0_ffj,__Z12op_b1a0_0_ffj,__Z12op_b1a8_0_ffj,__Z12op_b1b0_0_ffj,__Z12op_b1b8_0_ffj,__Z12op_b1b9_0_ffj,__Z12op_b1c0_0_ffj,__Z12op_b1c8_0_ffj,__Z12op_b1d0_0_ffj,__Z12op_b1d8_0_ffj,__Z12op_b1e0_0_ffj,__Z12op_b1e8_0_ffj,__Z12op_b1f0_0_ffj,__Z12op_b1f8_0_ffj,__Z12op_b1f9_0_ffj,__Z12op_b1fa_0_ffj,__Z12op_b1fb_0_ffj,__Z12op_b1fc_0_ffj,__Z12op_c000_0_ffj,__Z12op_c010_0_ffj,__Z12op_c018_0_ffj,__Z12op_c020_0_ffj,__Z12op_c028_0_ffj,__Z12op_c030_0_ffj,__Z12op_c038_0_ffj
,__Z12op_c039_0_ffj,__Z12op_c03a_0_ffj,__Z12op_c03b_0_ffj,__Z12op_c03c_0_ffj,__Z12op_c040_0_ffj,__Z12op_c050_0_ffj,__Z12op_c058_0_ffj,__Z12op_c060_0_ffj,__Z12op_c068_0_ffj,__Z12op_c070_0_ffj,__Z12op_c078_0_ffj,__Z12op_c079_0_ffj,__Z12op_c07a_0_ffj,__Z12op_c07b_0_ffj,__Z12op_c07c_0_ffj,__Z12op_c080_0_ffj,__Z12op_c090_0_ffj,__Z12op_c098_0_ffj,__Z12op_c0a0_0_ffj,__Z12op_c0a8_0_ffj,__Z12op_c0b0_0_ffj,__Z12op_c0b8_0_ffj,__Z12op_c0b9_0_ffj,__Z12op_c0ba_0_ffj,__Z12op_c0bb_0_ffj,__Z12op_c0bc_0_ffj,__Z12op_c0c0_0_ffj,__Z12op_c0d0_0_ffj,__Z12op_c0d8_0_ffj,__Z12op_c0e0_0_ffj
,__Z12op_c0e8_0_ffj,__Z12op_c0f0_0_ffj,__Z12op_c0f8_0_ffj,__Z12op_c0f9_0_ffj,__Z12op_c0fa_0_ffj,__Z12op_c0fb_0_ffj,__Z12op_c0fc_0_ffj,__Z12op_c100_0_ffj,__Z12op_c108_0_ffj,__Z12op_c110_0_ffj,__Z12op_c118_0_ffj,__Z12op_c120_0_ffj,__Z12op_c128_0_ffj,__Z12op_c130_0_ffj,__Z12op_c138_0_ffj,__Z12op_c139_0_ffj,__Z12op_c140_0_ffj,__Z12op_c148_0_ffj,__Z12op_c150_0_ffj,__Z12op_c158_0_ffj,__Z12op_c160_0_ffj,__Z12op_c168_0_ffj,__Z12op_c170_0_ffj,__Z12op_c178_0_ffj,__Z12op_c179_0_ffj,__Z12op_c188_0_ffj,__Z12op_c190_0_ffj,__Z12op_c198_0_ffj,__Z12op_c1a0_0_ffj,__Z12op_c1a8_0_ffj
,__Z12op_c1b0_0_ffj,__Z12op_c1b8_0_ffj,__Z12op_c1b9_0_ffj,__Z12op_c1c0_0_ffj,__Z12op_c1d0_0_ffj,__Z12op_c1d8_0_ffj,__Z12op_c1e0_0_ffj,__Z12op_c1e8_0_ffj,__Z12op_c1f0_0_ffj,__Z12op_c1f8_0_ffj,__Z12op_c1f9_0_ffj,__Z12op_c1fa_0_ffj,__Z12op_c1fb_0_ffj,__Z12op_c1fc_0_ffj,__Z12op_d000_0_ffj,__Z12op_d010_0_ffj,__Z12op_d018_0_ffj,__Z12op_d020_0_ffj,__Z12op_d028_0_ffj,__Z12op_d030_0_ffj,__Z12op_d038_0_ffj,__Z12op_d039_0_ffj,__Z12op_d03a_0_ffj,__Z12op_d03b_0_ffj,__Z12op_d03c_0_ffj,__Z12op_d040_0_ffj,__Z12op_d048_0_ffj,__Z12op_d050_0_ffj,__Z12op_d058_0_ffj,__Z12op_d060_0_ffj
,__Z12op_d068_0_ffj,__Z12op_d070_0_ffj,__Z12op_d078_0_ffj,__Z12op_d079_0_ffj,__Z12op_d07a_0_ffj,__Z12op_d07b_0_ffj,__Z12op_d07c_0_ffj,__Z12op_d080_0_ffj,__Z12op_d088_0_ffj,__Z12op_d090_0_ffj,__Z12op_d098_0_ffj,__Z12op_d0a0_0_ffj,__Z12op_d0a8_0_ffj,__Z12op_d0b0_0_ffj,__Z12op_d0b8_0_ffj,__Z12op_d0b9_0_ffj,__Z12op_d0ba_0_ffj,__Z12op_d0bb_0_ffj,__Z12op_d0bc_0_ffj,__Z12op_d0c0_0_ffj,__Z12op_d0c8_0_ffj,__Z12op_d0d0_0_ffj,__Z12op_d0d8_0_ffj,__Z12op_d0e0_0_ffj,__Z12op_d0e8_0_ffj,__Z12op_d0f0_0_ffj,__Z12op_d0f8_0_ffj,__Z12op_d0f9_0_ffj,__Z12op_d0fa_0_ffj,__Z12op_d0fb_0_ffj
,__Z12op_d0fc_0_ffj,__Z12op_d100_0_ffj,__Z12op_d108_0_ffj,__Z12op_d110_0_ffj,__Z12op_d118_0_ffj,__Z12op_d120_0_ffj,__Z12op_d128_0_ffj,__Z12op_d130_0_ffj,__Z12op_d138_0_ffj,__Z12op_d139_0_ffj,__Z12op_d140_0_ffj,__Z12op_d148_0_ffj,__Z12op_d150_0_ffj,__Z12op_d158_0_ffj,__Z12op_d160_0_ffj,__Z12op_d168_0_ffj,__Z12op_d170_0_ffj,__Z12op_d178_0_ffj,__Z12op_d179_0_ffj,__Z12op_d180_0_ffj,__Z12op_d188_0_ffj,__Z12op_d190_0_ffj,__Z12op_d198_0_ffj,__Z12op_d1a0_0_ffj,__Z12op_d1a8_0_ffj,__Z12op_d1b0_0_ffj,__Z12op_d1b8_0_ffj,__Z12op_d1b9_0_ffj,__Z12op_d1c0_0_ffj,__Z12op_d1c8_0_ffj
,__Z12op_d1d0_0_ffj,__Z12op_d1d8_0_ffj,__Z12op_d1e0_0_ffj,__Z12op_d1e8_0_ffj,__Z12op_d1f0_0_ffj,__Z12op_d1f8_0_ffj,__Z12op_d1f9_0_ffj,__Z12op_d1fa_0_ffj,__Z12op_d1fb_0_ffj,__Z12op_d1fc_0_ffj,__Z12op_e000_0_ffj,__Z12op_e008_0_ffj,__Z12op_e010_0_ffj,__Z12op_e018_0_ffj,__Z12op_e020_0_ffj,__Z12op_e028_0_ffj,__Z12op_e030_0_ffj,__Z12op_e038_0_ffj,__Z12op_e040_0_ffj,__Z12op_e048_0_ffj,__Z12op_e050_0_ffj,__Z12op_e058_0_ffj,__Z12op_e060_0_ffj,__Z12op_e068_0_ffj,__Z12op_e070_0_ffj,__Z12op_e078_0_ffj,__Z12op_e080_0_ffj,__Z12op_e088_0_ffj,__Z12op_e090_0_ffj,__Z12op_e098_0_ffj
,__Z12op_e0a0_0_ffj,__Z12op_e0a8_0_ffj,__Z12op_e0b0_0_ffj,__Z12op_e0b8_0_ffj,__Z12op_e0d0_0_ffj,__Z12op_e0d8_0_ffj,__Z12op_e0e0_0_ffj,__Z12op_e0e8_0_ffj,__Z12op_e0f0_0_ffj,__Z12op_e0f8_0_ffj,__Z12op_e0f9_0_ffj,__Z12op_e100_0_ffj,__Z12op_e108_0_ffj,__Z12op_e110_0_ffj,__Z12op_e118_0_ffj,__Z12op_e120_0_ffj,__Z12op_e128_0_ffj,__Z12op_e130_0_ffj,__Z12op_e138_0_ffj,__Z12op_e140_0_ffj,__Z12op_e148_0_ffj,__Z12op_e150_0_ffj,__Z12op_e158_0_ffj,__Z12op_e160_0_ffj,__Z12op_e168_0_ffj,__Z12op_e170_0_ffj,__Z12op_e178_0_ffj,__Z12op_e180_0_ffj,__Z12op_e188_0_ffj,__Z12op_e190_0_ffj
,__Z12op_e198_0_ffj,__Z12op_e1a0_0_ffj,__Z12op_e1a8_0_ffj,__Z12op_e1b0_0_ffj,__Z12op_e1b8_0_ffj,__Z12op_e1d0_0_ffj,__Z12op_e1d8_0_ffj,__Z12op_e1e0_0_ffj,__Z12op_e1e8_0_ffj,__Z12op_e1f0_0_ffj,__Z12op_e1f8_0_ffj,__Z12op_e1f9_0_ffj,__Z12op_e2d0_0_ffj,__Z12op_e2d8_0_ffj,__Z12op_e2e0_0_ffj,__Z12op_e2e8_0_ffj,__Z12op_e2f0_0_ffj,__Z12op_e2f8_0_ffj,__Z12op_e2f9_0_ffj,__Z12op_e3d0_0_ffj,__Z12op_e3d8_0_ffj,__Z12op_e3e0_0_ffj,__Z12op_e3e8_0_ffj,__Z12op_e3f0_0_ffj,__Z12op_e3f8_0_ffj,__Z12op_e3f9_0_ffj,__Z12op_e4d0_0_ffj,__Z12op_e4d8_0_ffj,__Z12op_e4e0_0_ffj,__Z12op_e4e8_0_ffj
,__Z12op_e4f0_0_ffj,__Z12op_e4f8_0_ffj,__Z12op_e4f9_0_ffj,__Z12op_e5d0_0_ffj,__Z12op_e5d8_0_ffj,__Z12op_e5e0_0_ffj,__Z12op_e5e8_0_ffj,__Z12op_e5f0_0_ffj,__Z12op_e5f8_0_ffj,__Z12op_e5f9_0_ffj,__Z12op_e6d0_0_ffj,__Z12op_e6d8_0_ffj,__Z12op_e6e0_0_ffj,__Z12op_e6e8_0_ffj,__Z12op_e6f0_0_ffj,__Z12op_e6f8_0_ffj,__Z12op_e6f9_0_ffj,__Z12op_e7d0_0_ffj,__Z12op_e7d8_0_ffj,__Z12op_e7e0_0_ffj,__Z12op_e7e8_0_ffj,__Z12op_e7f0_0_ffj,__Z12op_e7f8_0_ffj,__Z12op_e7f9_0_ffj,__Z12op_e8c0_0_ffj,__Z12op_e8d0_0_ffj,__Z12op_e8e8_0_ffj,__Z12op_e8f0_0_ffj,__Z12op_e8f8_0_ffj,__Z12op_e8f9_0_ffj
,__Z12op_e8fa_0_ffj,__Z12op_e8fb_0_ffj,__Z12op_e9c0_0_ffj,__Z12op_e9d0_0_ffj,__Z12op_e9e8_0_ffj,__Z12op_e9f0_0_ffj,__Z12op_e9f8_0_ffj,__Z12op_e9f9_0_ffj,__Z12op_e9fa_0_ffj,__Z12op_e9fb_0_ffj,__Z12op_eac0_0_ffj,__Z12op_ead0_0_ffj,__Z12op_eae8_0_ffj,__Z12op_eaf0_0_ffj,__Z12op_eaf8_0_ffj,__Z12op_eaf9_0_ffj,__Z12op_ebc0_0_ffj,__Z12op_ebd0_0_ffj,__Z12op_ebe8_0_ffj,__Z12op_ebf0_0_ffj,__Z12op_ebf8_0_ffj,__Z12op_ebf9_0_ffj,__Z12op_ebfa_0_ffj,__Z12op_ebfb_0_ffj,__Z12op_ecc0_0_ffj,__Z12op_ecd0_0_ffj,__Z12op_ece8_0_ffj,__Z12op_ecf0_0_ffj,__Z12op_ecf8_0_ffj,__Z12op_ecf9_0_ffj
,__Z12op_edc0_0_ffj,__Z12op_edd0_0_ffj,__Z12op_ede8_0_ffj,__Z12op_edf0_0_ffj,__Z12op_edf8_0_ffj,__Z12op_edf9_0_ffj,__Z12op_edfa_0_ffj,__Z12op_edfb_0_ffj,__Z12op_eec0_0_ffj,__Z12op_eed0_0_ffj,__Z12op_eee8_0_ffj,__Z12op_eef0_0_ffj,__Z12op_eef8_0_ffj,__Z12op_eef9_0_ffj,__Z12op_efc0_0_ffj,__Z12op_efd0_0_ffj,__Z12op_efe8_0_ffj,__Z12op_eff0_0_ffj,__Z12op_eff8_0_ffj,__Z12op_eff9_0_ffj,__Z12op_f200_0_ffj,__Z12op_f208_0_ffj,__Z12op_f210_0_ffj,__Z12op_f218_0_ffj,__Z12op_f220_0_ffj,__Z12op_f228_0_ffj,__Z12op_f230_0_ffj,__Z12op_f238_0_ffj,__Z12op_f239_0_ffj,__Z12op_f23a_0_ffj
,__Z12op_f23b_0_ffj,__Z12op_f23c_0_ffj,__Z12op_f240_0_ffj,__Z12op_f248_0_ffj,__Z12op_f250_0_ffj,__Z12op_f258_0_ffj,__Z12op_f260_0_ffj,__Z12op_f268_0_ffj,__Z12op_f270_0_ffj,__Z12op_f278_0_ffj,__Z12op_f279_0_ffj,__Z12op_f27a_0_ffj,__Z12op_f27b_0_ffj,__Z12op_f27c_0_ffj,__Z12op_f280_0_ffj,__Z12op_f2c0_0_ffj,__Z12op_f310_0_ffj,__Z12op_f320_0_ffj,__Z12op_f328_0_ffj,__Z12op_f330_0_ffj,__Z12op_f338_0_ffj,__Z12op_f339_0_ffj,__Z12op_f350_0_ffj,__Z12op_f358_0_ffj,__Z12op_f368_0_ffj,__Z12op_f370_0_ffj,__Z12op_f378_0_ffj,__Z12op_f379_0_ffj,__Z12op_f37a_0_ffj,__Z12op_f37b_0_ffj
,__Z12op_f408_0_ffj,__Z12op_f410_0_ffj,__Z12op_f418_0_ffj,__Z12op_f419_0_ffj,__Z12op_f41a_0_ffj,__Z12op_f41b_0_ffj,__Z12op_f41c_0_ffj,__Z12op_f41d_0_ffj,__Z12op_f41e_0_ffj,__Z12op_f41f_0_ffj,__Z12op_f428_0_ffj,__Z12op_f430_0_ffj,__Z12op_f438_0_ffj,__Z12op_f439_0_ffj,__Z12op_f43a_0_ffj,__Z12op_f43b_0_ffj,__Z12op_f43c_0_ffj,__Z12op_f43d_0_ffj,__Z12op_f43e_0_ffj,__Z12op_f43f_0_ffj,__Z12op_f500_0_ffj,__Z12op_f600_0_ffj,__Z12op_f608_0_ffj,__Z12op_f610_0_ffj,__Z12op_f618_0_ffj,__Z12op_f620_0_ffj,__Z12op_4800_1_ffj,__Z12op_4810_1_ffj,__Z12op_4818_1_ffj,__Z12op_4820_1_ffj
,__Z12op_4828_1_ffj,__Z12op_4830_1_ffj,__Z12op_4838_1_ffj,__Z12op_4839_1_ffj,__Z12op_8100_1_ffj,__Z12op_8108_1_ffj,__Z12op_c100_1_ffj,__Z12op_c108_1_ffj,__Z10op_30_3_ffj,__Z10op_70_3_ffj,__Z10op_b0_3_ffj,__Z11op_130_3_ffj,__Z11op_13b_3_ffj,__Z11op_170_3_ffj,__Z11op_17b_3_ffj,__Z11op_1b0_3_ffj,__Z11op_1bb_3_ffj,__Z11op_1f0_3_ffj,__Z11op_1fb_3_ffj,__Z11op_230_3_ffj,__Z11op_270_3_ffj,__Z11op_2b0_3_ffj,__Z11op_430_3_ffj,__Z11op_470_3_ffj,__Z11op_4b0_3_ffj,__Z11op_630_3_ffj,__Z11op_670_3_ffj,__Z11op_6b0_3_ffj,__Z11op_830_3_ffj,__Z11op_83b_3_ffj
,__Z11op_870_3_ffj,__Z11op_87b_3_ffj,__Z11op_8b0_3_ffj,__Z11op_8bb_3_ffj,__Z11op_8f0_3_ffj,__Z11op_8fb_3_ffj,__Z11op_a30_3_ffj,__Z11op_a70_3_ffj,__Z11op_ab0_3_ffj,__Z11op_c30_3_ffj,__Z11op_c3b_3_ffj,__Z11op_c70_3_ffj,__Z11op_c7b_3_ffj,__Z11op_cb0_3_ffj,__Z11op_cbb_3_ffj,__Z12op_1030_3_ffj,__Z12op_103b_3_ffj,__Z12op_10b0_3_ffj,__Z12op_10bb_3_ffj,__Z12op_10f0_3_ffj,__Z12op_10fb_3_ffj,__Z12op_1130_3_ffj,__Z12op_113b_3_ffj,__Z12op_1170_3_ffj,__Z12op_117b_3_ffj,__Z12op_1180_3_ffj,__Z12op_1190_3_ffj,__Z12op_1198_3_ffj,__Z12op_11a0_3_ffj,__Z12op_11a8_3_ffj
,__Z12op_11b0_3_ffj,__Z12op_11b8_3_ffj,__Z12op_11b9_3_ffj,__Z12op_11ba_3_ffj,__Z12op_11bb_3_ffj,__Z12op_11bc_3_ffj,__Z12op_11f0_3_ffj,__Z12op_11fb_3_ffj,__Z12op_13f0_3_ffj,__Z12op_13fb_3_ffj,__Z12op_2030_3_ffj,__Z12op_203b_3_ffj,__Z12op_2070_3_ffj,__Z12op_207b_3_ffj,__Z12op_20b0_3_ffj,__Z12op_20bb_3_ffj,__Z12op_20f0_3_ffj,__Z12op_20fb_3_ffj,__Z12op_2130_3_ffj,__Z12op_213b_3_ffj,__Z12op_2170_3_ffj,__Z12op_217b_3_ffj,__Z12op_2180_3_ffj,__Z12op_2188_3_ffj,__Z12op_2190_3_ffj,__Z12op_2198_3_ffj,__Z12op_21a0_3_ffj,__Z12op_21a8_3_ffj,__Z12op_21b0_3_ffj,__Z12op_21b8_3_ffj
,__Z12op_21b9_3_ffj,__Z12op_21ba_3_ffj,__Z12op_21bb_3_ffj,__Z12op_21bc_3_ffj,__Z12op_21f0_3_ffj,__Z12op_21fb_3_ffj,__Z12op_23f0_3_ffj,__Z12op_23fb_3_ffj,__Z12op_3030_3_ffj,__Z12op_303b_3_ffj,__Z12op_3070_3_ffj,__Z12op_307b_3_ffj,__Z12op_30b0_3_ffj,__Z12op_30bb_3_ffj,__Z12op_30f0_3_ffj,__Z12op_30fb_3_ffj,__Z12op_3130_3_ffj,__Z12op_313b_3_ffj,__Z12op_3170_3_ffj,__Z12op_317b_3_ffj,__Z12op_3180_3_ffj,__Z12op_3188_3_ffj,__Z12op_3190_3_ffj,__Z12op_3198_3_ffj,__Z12op_31a0_3_ffj,__Z12op_31a8_3_ffj,__Z12op_31b0_3_ffj,__Z12op_31b8_3_ffj,__Z12op_31b9_3_ffj,__Z12op_31ba_3_ffj
,__Z12op_31bb_3_ffj,__Z12op_31bc_3_ffj,__Z12op_31f0_3_ffj,__Z12op_31fb_3_ffj,__Z12op_33f0_3_ffj,__Z12op_33fb_3_ffj,__Z12op_4030_3_ffj,__Z12op_4070_3_ffj,__Z12op_40b0_3_ffj,__Z12op_40f0_3_ffj,__Z12op_4130_3_ffj,__Z12op_413b_3_ffj,__Z12op_41b0_3_ffj,__Z12op_41bb_3_ffj,__Z12op_41f0_3_ffj,__Z12op_41fb_3_ffj,__Z12op_4230_3_ffj,__Z12op_4270_3_ffj,__Z12op_42b0_3_ffj,__Z12op_42f0_3_ffj,__Z12op_4430_3_ffj,__Z12op_4470_3_ffj,__Z12op_44b0_3_ffj,__Z12op_44f0_3_ffj,__Z12op_44fb_3_ffj,__Z12op_4630_3_ffj,__Z12op_4670_3_ffj,__Z12op_46b0_3_ffj,__Z12op_46f0_3_ffj,__Z12op_46fb_3_ffj
,__Z12op_4830_3_ffj,__Z12op_4870_3_ffj,__Z12op_487b_3_ffj,__Z12op_48b0_3_ffj,__Z12op_48f0_3_ffj,__Z12op_4a30_3_ffj,__Z12op_4a3b_3_ffj,__Z12op_4a70_3_ffj,__Z12op_4a7b_3_ffj,__Z12op_4ab0_3_ffj,__Z12op_4abb_3_ffj,__Z12op_4af0_3_ffj,__Z12op_4cb0_3_ffj,__Z12op_4cbb_3_ffj,__Z12op_4cf0_3_ffj,__Z12op_4cfb_3_ffj,__Z12op_4eb0_3_ffj,__Z12op_4ebb_3_ffj,__Z12op_4ef0_3_ffj,__Z12op_4efb_3_ffj,__Z12op_5030_3_ffj,__Z12op_5070_3_ffj,__Z12op_50b0_3_ffj,__Z12op_50f0_3_ffj,__Z12op_5130_3_ffj,__Z12op_5170_3_ffj,__Z12op_51b0_3_ffj,__Z12op_51f0_3_ffj,__Z12op_52f0_3_ffj,__Z12op_53f0_3_ffj
,__Z12op_54f0_3_ffj,__Z12op_55f0_3_ffj,__Z12op_56f0_3_ffj,__Z12op_57f0_3_ffj,__Z12op_58f0_3_ffj,__Z12op_59f0_3_ffj,__Z12op_5af0_3_ffj,__Z12op_5bf0_3_ffj,__Z12op_5cf0_3_ffj,__Z12op_5df0_3_ffj,__Z12op_5ef0_3_ffj,__Z12op_5ff0_3_ffj,__Z12op_60ff_3_ffj,__Z12op_62ff_3_ffj,__Z12op_63ff_3_ffj,__Z12op_64ff_3_ffj,__Z12op_65ff_3_ffj,__Z12op_66ff_3_ffj,__Z12op_67ff_3_ffj,__Z12op_68ff_3_ffj,__Z12op_69ff_3_ffj,__Z12op_6aff_3_ffj,__Z12op_6bff_3_ffj,__Z12op_6cff_3_ffj,__Z12op_6dff_3_ffj,__Z12op_6eff_3_ffj,__Z12op_6fff_3_ffj,__Z12op_8030_3_ffj,__Z12op_803b_3_ffj,__Z12op_8070_3_ffj
,__Z12op_807b_3_ffj,__Z12op_80b0_3_ffj,__Z12op_80bb_3_ffj,__Z12op_80f0_3_ffj,__Z12op_80fb_3_ffj,__Z12op_8130_3_ffj,__Z12op_8170_3_ffj,__Z12op_81b0_3_ffj,__Z12op_81f0_3_ffj,__Z12op_81fb_3_ffj,__Z12op_9030_3_ffj,__Z12op_903b_3_ffj,__Z12op_9070_3_ffj,__Z12op_907b_3_ffj,__Z12op_90b0_3_ffj,__Z12op_90bb_3_ffj,__Z12op_90f0_3_ffj,__Z12op_90fb_3_ffj,__Z12op_9130_3_ffj,__Z12op_9170_3_ffj,__Z12op_91b0_3_ffj,__Z12op_91f0_3_ffj,__Z12op_91fb_3_ffj,__Z12op_b030_3_ffj,__Z12op_b03b_3_ffj,__Z12op_b070_3_ffj,__Z12op_b07b_3_ffj,__Z12op_b0b0_3_ffj,__Z12op_b0bb_3_ffj,__Z12op_b0f0_3_ffj
,__Z12op_b0fb_3_ffj,__Z12op_b130_3_ffj,__Z12op_b170_3_ffj,__Z12op_b1b0_3_ffj,__Z12op_b1f0_3_ffj,__Z12op_b1fb_3_ffj,__Z12op_c030_3_ffj,__Z12op_c03b_3_ffj,__Z12op_c070_3_ffj,__Z12op_c07b_3_ffj,__Z12op_c0b0_3_ffj,__Z12op_c0bb_3_ffj,__Z12op_c0f0_3_ffj,__Z12op_c0fb_3_ffj,__Z12op_c130_3_ffj,__Z12op_c170_3_ffj,__Z12op_c1b0_3_ffj,__Z12op_c1f0_3_ffj,__Z12op_c1fb_3_ffj,__Z12op_d030_3_ffj,__Z12op_d03b_3_ffj,__Z12op_d070_3_ffj,__Z12op_d07b_3_ffj,__Z12op_d0b0_3_ffj,__Z12op_d0bb_3_ffj,__Z12op_d0f0_3_ffj,__Z12op_d0fb_3_ffj,__Z12op_d130_3_ffj,__Z12op_d170_3_ffj,__Z12op_d1b0_3_ffj
,__Z12op_d1f0_3_ffj,__Z12op_d1fb_3_ffj,__Z12op_e0f0_3_ffj,__Z12op_e1f0_3_ffj,__Z12op_e2f0_3_ffj,__Z12op_e3f0_3_ffj,__Z12op_e4f0_3_ffj,__Z12op_e5f0_3_ffj,__Z12op_e6f0_3_ffj,__Z12op_e7f0_3_ffj,__Z12op_40c0_4_ffj,__Z12op_40d0_4_ffj,__Z12op_40d8_4_ffj,__Z12op_40e0_4_ffj,__Z12op_40e8_4_ffj,__Z12op_40f0_4_ffj,__Z12op_40f8_4_ffj,__Z12op_40f9_4_ffj,__Z12op_4e73_4_ffj,__ZN10__cxxabiv116__shim_type_infoD2Ev,__ZN10__cxxabiv117__class_type_infoD0Ev,__ZNK10__cxxabiv116__shim_type_info5noop1Ev,__ZNK10__cxxabiv116__shim_type_info5noop2Ev,__ZN10__cxxabiv120__si_class_type_infoD0Ev,__ZNSt3__23mapItjNS_4lessItEENS_9allocatorINS_4pairIKtjEEEEED2Ev,__ZNSt3__213__vector_baseI15sony_drive_infoNS_9allocatorIS1_EEED2Ev,__ZNSt3__213__vector_baseI15disk_drive_infoNS_9allocatorIS1_EEED2Ev,__ZNSt3__213__vector_baseI16cdrom_drive_infoNS_9allocatorIS1_EEED2Ev,__ZNSt3__213__vector_baseIP12monitor_descNS_9allocatorIS2_EEED2Ev,__ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev
,__ZNSt3__213__vector_baseItNS_9allocatorItEEED2Ev,__ZNSt3__213__vector_baseI10video_modeNS_9allocatorIS1_EEED2Ev,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev,__Z9op_illg_1j,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2];
var FUNCTION_TABLE_vii = [b3,__ZN8tinyxml28MemPoolTILi44EE4FreeEPv,__ZN8tinyxml28MemPoolTILi48EE4FreeEPv,__ZN8tinyxml28MemPoolTILi36EE4FreeEPv,__ZN8tinyxml28MemPoolTILi52EE4FreeEPv,__ZL10dummy_lputjj,__ZL10dummy_wputjj,__ZL10dummy_bputjj,__ZL8ram_lputjj,__ZL8ram_wputjj,__ZL8ram_bputjj,__ZL10ram24_lputjj,__ZL10ram24_wputjj,__ZL10ram24_bputjj,__ZL8rom_lputjj,__ZL8rom_wputjj,__ZL8rom_bputjj,__ZL17frame_direct_lputjj,__ZL17frame_direct_wputjj,__ZL17frame_direct_bputjj,__ZL19frame_host_555_lputjj,__ZL19frame_host_555_wputjj,__ZL19frame_host_565_lputjj,__ZL19frame_host_565_wputjj,__ZL19frame_host_888_lputjj,b3,b3,b3,b3
,b3,b3,b3];
var FUNCTION_TABLE_ii = [b4,__ZN17disk_sparsebundle12is_read_onlyEv,__ZN17disk_sparsebundle4sizeEv,__ZN8tinyxml27XMLNode9ToElementEv,__ZN8tinyxml27XMLNode6ToTextEv,__ZN8tinyxml27XMLNode9ToCommentEv,__ZN8tinyxml27XMLNode10ToDocumentEv,__ZN8tinyxml27XMLNode13ToDeclarationEv,__ZN8tinyxml27XMLNode9ToUnknownEv,__ZNK8tinyxml27XMLNode9ToElementEv,__ZNK8tinyxml27XMLNode6ToTextEv,__ZNK8tinyxml27XMLNode9ToCommentEv,__ZNK8tinyxml27XMLNode10ToDocumentEv,__ZNK8tinyxml27XMLNode13ToDeclarationEv,__ZNK8tinyxml27XMLNode9ToUnknownEv,__ZN8tinyxml214XMLDeclaration13ToDeclarationEv,__ZNK8tinyxml214XMLDeclaration13ToDeclarationEv,__ZN8tinyxml210XMLComment9ToCommentEv,__ZNK8tinyxml210XMLComment9ToCommentEv,__ZN8tinyxml27XMLText6ToTextEv,__ZNK8tinyxml27XMLText6ToTextEv,__ZN8tinyxml210XMLUnknown9ToUnknownEv,__ZNK8tinyxml210XMLUnknown9ToUnknownEv,__ZN8tinyxml210XMLElement9ToElementEv,__ZNK8tinyxml210XMLElement9ToElementEv,__ZN8tinyxml211XMLDocument10ToDocumentEv,__ZNK8tinyxml211XMLDocument10ToDocumentEv,__ZNK8tinyxml28MemPoolTILi44EE8ItemSizeEv,__ZN8tinyxml28MemPoolTILi44EE5AllocEv
,__ZNK8tinyxml28MemPoolTILi48EE8ItemSizeEv,__ZN8tinyxml28MemPoolTILi48EE5AllocEv,__ZNK8tinyxml28MemPoolTILi36EE8ItemSizeEv,__ZN8tinyxml28MemPoolTILi36EE5AllocEv,__ZNK8tinyxml28MemPoolTILi52EE8ItemSizeEv,__ZN8tinyxml28MemPoolTILi52EE5AllocEv,__ZN9DSERDPort5closeEv,__ZL10dummy_lgetj,__ZL10dummy_wgetj,__ZL10dummy_bgetj,__Z13default_xlatej,__ZL8ram_lgetj,__ZL8ram_wgetj,__ZL8ram_bgetj,__ZL9ram_xlatej,__ZL10ram24_lgetj,__ZL10ram24_wgetj,__ZL10ram24_bgetj,__ZL11ram24_xlatej,__ZL8rom_lgetj,__ZL8rom_wgetj,__ZL8rom_bgetj,__ZL9rom_xlatej,__ZL10rom24_lgetj,__ZL10rom24_wgetj,__ZL10rom24_bgetj,__ZL11rom24_xlatej,__ZL17frame_direct_lgetj,__ZL17frame_direct_wgetj,__ZL17frame_direct_bgetj
,__ZL11frame_xlatej,__ZL19frame_host_555_lgetj,__ZL19frame_host_555_wgetj,__ZL19frame_host_565_lgetj,__ZL19frame_host_565_wgetj,__ZL19frame_host_888_lgetj,___stdio_close,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4];
var FUNCTION_TABLE_viii = [b5,__ZN11driver_base11mouse_movedEii,__ZN13driver_window11mouse_movedEii,__ZN16SDL_monitor_desc11set_paletteEPhi,__ZL13Blit_Copy_RawPhPKhj,__ZL19Blit_Expand_8_To_32PhPKhj,b5,b5];
var FUNCTION_TABLE_v = [b6,___cxa_pure_virtual__wrapper,__ZL17video_refresh_dgav,__ZL27video_refresh_window_staticv];
var FUNCTION_TABLE_iiiii = [b7,__ZN17disk_sparsebundle4readEPvij,__ZN17disk_sparsebundle5writeEPvij,__ZN9DSERDPort7controlEjjt,__ZN9DSERDPort6statusEjjt,b7,b7,b7];
var FUNCTION_TABLE_viiiiii = [b8,__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,b8];
var FUNCTION_TABLE_iii = [b9,__ZNK8tinyxml214XMLDeclaration12ShallowCloneEPNS_11XMLDocumentE,__ZNK8tinyxml214XMLDeclaration12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml214XMLDeclaration6AcceptEPNS_10XMLVisitorE,__ZNK8tinyxml210XMLComment12ShallowCloneEPNS_11XMLDocumentE,__ZNK8tinyxml210XMLComment12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml210XMLComment6AcceptEPNS_10XMLVisitorE,__ZNK8tinyxml27XMLText12ShallowCloneEPNS_11XMLDocumentE,__ZNK8tinyxml27XMLText12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml27XMLText6AcceptEPNS_10XMLVisitorE,__ZNK8tinyxml210XMLUnknown12ShallowCloneEPNS_11XMLDocumentE,__ZNK8tinyxml210XMLUnknown12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml210XMLUnknown6AcceptEPNS_10XMLVisitorE,__ZNK8tinyxml210XMLElement12ShallowCloneEPNS_11XMLDocumentE,__ZNK8tinyxml210XMLElement12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml210XMLElement6AcceptEPNS_10XMLVisitorE,__ZNK8tinyxml211XMLDocument12ShallowCloneEPS0_,__ZNK8tinyxml211XMLDocument12ShallowEqualEPKNS_7XMLNodeE,__ZNK8tinyxml211XMLDocument6AcceptEPNS_10XMLVisitorE,__ZN9DSERDPort4openEt,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9];
var FUNCTION_TABLE_viiii = [b10,__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b10];

  return { _main: _main, stackSave: stackSave, _i64Subtract: _i64Subtract, ___udivdi3: ___udivdi3, setThrew: setThrew, __GLOBAL__sub_I_ether_cpp: __GLOBAL__sub_I_ether_cpp, _bitshift64Lshr: _bitshift64Lshr, __GLOBAL__sub_I_prefs_unix_cpp: __GLOBAL__sub_I_prefs_unix_cpp, dynCall_vi: dynCall_vi, __GLOBAL__sub_I_cdrom_cpp: __GLOBAL__sub_I_cdrom_cpp, _fflush: _fflush, _htonl: _htonl, ___errno_location: ___errno_location, __GLOBAL__sub_I_audio_cpp: __GLOBAL__sub_I_audio_cpp, _memset: _memset, _sbrk: _sbrk, dynCall_viii: dynCall_viii, _memcpy: _memcpy, stackAlloc: stackAlloc, ___muldi3: ___muldi3, __GLOBAL__sub_I_video_sdl_cpp: __GLOBAL__sub_I_video_sdl_cpp, _bitshift64Shl: _bitshift64Shl, ___uremdi3: ___uremdi3, ___divdi3: ___divdi3, getTempRet0: getTempRet0, __GLOBAL__sub_I_sony_cpp: __GLOBAL__sub_I_sony_cpp, dynCall_vii: dynCall_vii, _ntohs: _ntohs, setTempRet0: setTempRet0, _i64Add: _i64Add, dynCall_iiii: dynCall_iiii, dynCall_ii: dynCall_ii, _llvm_bswap_i16: _llvm_bswap_i16, _emscripten_get_global_libc: _emscripten_get_global_libc, dynCall_iiiii: dynCall_iiiii, ___remdi3: ___remdi3, _htons: _htons, dynCall_viiii: dynCall_viiii, _llvm_bswap_i32: _llvm_bswap_i32, dynCall_viiiii: dynCall_viiiii, _free: _free, runPostSets: runPostSets, dynCall_viiiiii: dynCall_viiiiii, establishStackSpace: establishStackSpace, _memmove: _memmove, stackRestore: stackRestore, _malloc: _malloc, dynCall_iii: dynCall_iii, dynCall_v: dynCall_v, __GLOBAL__sub_I_disk_cpp: __GLOBAL__sub_I_disk_cpp, __GLOBAL__sub_I_video_cpp: __GLOBAL__sub_I_video_cpp };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);

var _main = Module["_main"] = asm["_main"];
var stackSave = Module["stackSave"] = asm["stackSave"];
var getTempRet0 = Module["getTempRet0"] = asm["getTempRet0"];
var ___udivdi3 = Module["___udivdi3"] = asm["___udivdi3"];
var setThrew = Module["setThrew"] = asm["setThrew"];
var __GLOBAL__sub_I_ether_cpp = Module["__GLOBAL__sub_I_ether_cpp"] = asm["__GLOBAL__sub_I_ether_cpp"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var __GLOBAL__sub_I_cdrom_cpp = Module["__GLOBAL__sub_I_cdrom_cpp"] = asm["__GLOBAL__sub_I_cdrom_cpp"];
var _fflush = Module["_fflush"] = asm["_fflush"];
var setTempRet0 = Module["setTempRet0"] = asm["setTempRet0"];
var _memset = Module["_memset"] = asm["_memset"];
var _sbrk = Module["_sbrk"] = asm["_sbrk"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _llvm_bswap_i32 = Module["_llvm_bswap_i32"] = asm["_llvm_bswap_i32"];
var ___muldi3 = Module["___muldi3"] = asm["___muldi3"];
var __GLOBAL__sub_I_video_sdl_cpp = Module["__GLOBAL__sub_I_video_sdl_cpp"] = asm["__GLOBAL__sub_I_video_sdl_cpp"];
var __GLOBAL__sub_I_prefs_unix_cpp = Module["__GLOBAL__sub_I_prefs_unix_cpp"] = asm["__GLOBAL__sub_I_prefs_unix_cpp"];
var ___uremdi3 = Module["___uremdi3"] = asm["___uremdi3"];
var ___divdi3 = Module["___divdi3"] = asm["___divdi3"];
var stackAlloc = Module["stackAlloc"] = asm["stackAlloc"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var __GLOBAL__sub_I_sony_cpp = Module["__GLOBAL__sub_I_sony_cpp"] = asm["__GLOBAL__sub_I_sony_cpp"];
var _ntohs = Module["_ntohs"] = asm["_ntohs"];
var _htonl = Module["_htonl"] = asm["_htonl"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _llvm_bswap_i16 = Module["_llvm_bswap_i16"] = asm["_llvm_bswap_i16"];
var _emscripten_get_global_libc = Module["_emscripten_get_global_libc"] = asm["_emscripten_get_global_libc"];
var ___remdi3 = Module["___remdi3"] = asm["___remdi3"];
var _htons = Module["_htons"] = asm["_htons"];
var stackRestore = Module["stackRestore"] = asm["stackRestore"];
var ___errno_location = Module["___errno_location"] = asm["___errno_location"];
var _free = Module["_free"] = asm["_free"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var establishStackSpace = Module["establishStackSpace"] = asm["establishStackSpace"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var __GLOBAL__sub_I_audio_cpp = Module["__GLOBAL__sub_I_audio_cpp"] = asm["__GLOBAL__sub_I_audio_cpp"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var __GLOBAL__sub_I_disk_cpp = Module["__GLOBAL__sub_I_disk_cpp"] = asm["__GLOBAL__sub_I_disk_cpp"];
var __GLOBAL__sub_I_video_cpp = Module["__GLOBAL__sub_I_video_cpp"] = asm["__GLOBAL__sub_I_video_cpp"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
;
Runtime.stackAlloc = Module['stackAlloc'];
Runtime.stackSave = Module['stackSave'];
Runtime.stackRestore = Module['stackRestore'];
Runtime.establishStackSpace = Module['establishStackSpace'];
Runtime.setTempRet0 = Module['setTempRet0'];
Runtime.getTempRet0 = Module['getTempRet0'];


// === Auto-generated postamble setup entry stuff ===

Module['asm'] = asm;



if (memoryInitializer) {
  if (typeof Module['locateFile'] === 'function') {
    memoryInitializer = Module['locateFile'](memoryInitializer);
  } else if (Module['memoryInitializerPrefixURL']) {
    memoryInitializer = Module['memoryInitializerPrefixURL'] + memoryInitializer;
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, Runtime.GLOBAL_BASE);
  } else {
    addRunDependency('memory initializer');
    var applyMemoryInitializer = function(data) {
      if (data.byteLength) data = new Uint8Array(data);
      HEAPU8.set(data, Runtime.GLOBAL_BASE);
      // Delete the typed array that contains the large blob of the memory initializer request response so that
      // we won't keep unnecessary memory lying around. However, keep the XHR object itself alive so that e.g.
      // its .status field can still be accessed later.
      if (Module['memoryInitializerRequest']) delete Module['memoryInitializerRequest'].response;
      removeRunDependency('memory initializer');
    }
    function doBrowserLoad() {
      Module['readAsync'](memoryInitializer, applyMemoryInitializer, function() {
        throw 'could not load memory initializer ' + memoryInitializer;
      });
    }
    if (Module['memoryInitializerRequest']) {
      // a network request has already been created, just use that
      function useRequest() {
        var request = Module['memoryInitializerRequest'];
        if (request.status !== 200 && request.status !== 0) {
          // If you see this warning, the issue may be that you are using locateFile or memoryInitializerPrefixURL, and defining them in JS. That
          // means that the HTML file doesn't know about them, and when it tries to create the mem init request early, does it to the wrong place.
          // Look in your browser's devtools network console to see what's going on.
          console.warn('a problem seems to have happened with Module.memoryInitializerRequest, status: ' + request.status + ', retrying ' + memoryInitializer);
          doBrowserLoad();
          return;
        }
        applyMemoryInitializer(request.response);
      }
      if (Module['memoryInitializerRequest'].response) {
        setTimeout(useRequest, 0); // it's already here; but, apply it asynchronously
      } else {
        Module['memoryInitializerRequest'].addEventListener('load', useRequest); // wait for it
      }
    } else {
      // fetch it from the network ourselves
      doBrowserLoad();
    }
  }
}



/**
 * @constructor
 * @extends {Error}
 */
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);


  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      var toLog = e;
      if (e && typeof e === 'object' && e.stack) {
        toLog = [e, e.stack];
      }
      Module.printErr('exception thrown: ' + toLog);
      Module['quit'](1, e);
    }
  } finally {
    calledMain = true;
  }
}




/** @type {function(Array=)} */
function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    return;
  }


  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return;

    ensureInitRuntime();

    preMain();


    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status, implicit) {
  if (implicit && Module['noExitRuntime']) {
    return;
  }

  if (Module['noExitRuntime']) {
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  if (ENVIRONMENT_IS_NODE) {
    process['exit'](status);
  }
  Module['quit'](status, new ExitStatus(status));
}
Module['exit'] = Module.exit = exit;

var abortDecorators = [];

function abort(what) {
  if (Module['onAbort']) {
    Module['onAbort'](what);
  }

  if (what !== undefined) {
    Module.print(what);
    Module.printErr(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.';

  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

run();



// {{POST_RUN_ADDITIONS}}





// {{MODULE_ADDITIONS}}






//# sourceMappingURL=BasiliskII.js.map